<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl action func securitym" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:func="http://exslt.org/functions"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>		
	<sw:include href="/lib/swa/securitym.xsl"/>

	<xsl:template match="/">
		<xsl:variable name="role-names" select="/data/role/name"/>

		<xsl:if test="action:start('role.clone', $role-names)"/>
		<xsl:for-each select="/data/role">
			<xsl:variable name="name" select="name"/>
			<xsl:if
				test="action:run-child(local:clone-role(.),concat('Clone role ',$name),'role.clone',$name)"
			/>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('role.clone', $role-names)"/>
	</xsl:template>

	<func:function name="local:clone-role">
		<xsl:param name="role"/>
		<xsl:param name="role-name-limit" select="25"/>
		<xsl:variable name="all-roles" select="securitym:list-roles()"/>
		<xsl:variable name="clone-match" select="sw:re-match($role/name,'^Copy\s([1-9]?)\s?of\s+(.*)$')"/>
		<xsl:variable name="rbn-tmp" select="sw:if(
			string($clone-match[1])!='',
			sw:if(not($clone-match[3]!=''),string($clone-match[2]),string($clone-match[3])),
			$role/name)"/>
		<xsl:variable name="role-base-name" select="sw:if(
			string-length($rbn-tmp) &gt; $role-name-limit - 10,
			concat(substring($rbn-tmp,1,$role-name-limit - 10 - 3),'...'),
			$rbn-tmp)"/>
		<xsl:variable name="new-role-rtf">
			<xsl:if test="not($all-roles[self::error]) and $all-roles[name=string($role/name)]">
				<xsl:copy-of select="$all-roles[name=string($role/name)]/*[local-name() != 'name']"/>
				<name>
					<xsl:choose>
						<xsl:when test="string($clone-match[1])!=''">
							<xsl:value-of select="local:gen-role-name(
								$role-base-name,
								$all-roles/name,
								sw:if(not($clone-match[3]!=''),2,number($clone-match[2])+1))"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="local:gen-role-name($role-base-name,$all-roles/name)"/>
						</xsl:otherwise>
					</xsl:choose>
				</name>
			</xsl:if>
		</xsl:variable>
		<func:result select="securitym:cmd-add-role(exsl:node-set($new-role-rtf))"/>
	</func:function>
		
	<!-- Local function to generate name for cloned role, up to 1000 clones
		Parameter:
			orig-name - original role name
			all-role-names - all names of existing roles
			orig-index - incremental clone number
		Returns: new role name or empty node-set if too many clones already exists
	-->
	<func:function name="local:gen-role-name">
		<xsl:param name="orig-name"/>
		<xsl:param name="all-role-names"/>
		<xsl:param name="orig-index" select="1"/>
		<xsl:variable name="new-role-name" select="concat('Copy ',
			sw:if($orig-index=1,'',concat($orig-index,' ')),'of ',$orig-name)"/>
		<xsl:choose>
			<xsl:when test="9 &lt; $orig-index">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:when test="not($all-role-names=$new-role-name)">
				<func:result select="$new-role-name"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="local:gen-role-name($orig-name,$all-role-names,1+$orig-index)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
</xsl:stylesheet>
