<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env func action dirm"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:dirm		="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:func		="http://exslt.org/functions"	
>
	<sw:include href="/lib/core/action-funcs.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<xsl:output method="xml"/>
	
	<!--
		/data
			/id
		
	-->
	<xsl:template match="/">
	
		<xsl:variable name="items" select="/data/id"/>
	
		<xsl:if test="action:start('farmdir.stop_unit')"/>
		
		<xsl:for-each select="$items">		
			<xsl:variable name="ldap-id" select="."/>			
			<xsl:variable name="ldap-item" select="dirm:search($ldap-id,'',0)/obj"/>
			<xsl:variable name="eid" select="$ldap-item/objectId"/>						
				
			<xsl:choose>
				<!-- Found VZ VE -->
				<xsl:when test="$ldap-item/objectType='ve.vz.vt'">		
										
					<xsl:variable name="old-env" select="env:get-env($eid)/env"/> 
					<xsl:variable name="ve-id" select="$old-env/virtual_config/veid"/> 
					<xsl:variable name="old-status" select="$old-env/status"/> 
								
					<!-- Stop running VE -->
					<xsl:choose>
						<xsl:when test="$old-status/state=$env-state/mounted">
							<xsl:if test="action:run-child(local:vz-umount-ve($eid,$fast),concat('Unmount Container #',$ve-id),'vzaenvm.stop',$eid)"/>	
						</xsl:when>
						<xsl:when test="$old-status/state=$env-state/running">
							<xsl:if test="action:run-child(local:vz-stop-ve($eid),concat('Stop Container #',$ve-id),'vzaenvm.stop',$eid)"/>	
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="action:log-env-error(concat('Can not stop Container #',$ve-id),'vzaenvm.stop',$eid,3,$old-status)"/>	
						</xsl:otherwise>
					</xsl:choose>					
					<!-- /Stop running VE -->					
				</xsl:when>
				<!-- /Found VZ VE -->
				<!-- Found VZ HN -->
				<xsl:when test="$ldap-item/objectType='hn.vz.vt'">		
					<xsl:if test="action:log-error('Virtuzoo HN can not be stopped.',3,$eid)"/>
				</xsl:when>
				<!-- /Found VZ HN -->
				<!-- Found logical unit -->
				<xsl:otherwise>
					<xsl:if test="action:log-error(concat('Logical unit ',dirm:dn-first-title($ldap-id),' can not be stopped.'),3)"/>
				</xsl:otherwise>
				<!-- /Found logical unit -->
			</xsl:choose>			
		</xsl:for-each>
	
		<xsl:if test="action:complete('farmdir.stop_unit')"/>

	</xsl:template>

	
	<func:function name="local:vz-stop-ve">
		<xsl:param name="eid"/>		
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.stop_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
						</stop>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:vz-umount-ve">
		<xsl:param name="eid"/>
		<xsl:param name="fast"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.umount_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<umount>
							<eid><xsl:value-of select="$eid"/></eid>
						</umount>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
</xsl:stylesheet>