<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl action func securitym" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:func="http://exslt.org/functions"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/swa/securitym.xsl"/>

	<xsl:template match="/">
		<xsl:variable name="role-names" select="/data/role_assignments/*/role"/>
		<xsl:variable name="scope" select="/data/scope"/>

		<xsl:if test="action:start('permission.add', $role-names)"/>
		<xsl:for-each select="/data/role_assignments/*">
			<xsl:variable name="role-name" select="role"/>
			<xsl:if
				test="action:run-child(local:add-role-assignment(.,$scope),concat('Add assignments to ',$role-name,' role'),'permission.add',$role-name)"
			/>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('permission.add', $role-names)"/>
	</xsl:template>

	<func:function name="local:add-role-assignment">
		<xsl:param name="role-assignment"/>
		<xsl:param name="scope" select="/.."/>
		<xsl:variable name="role-name" select="string($role-assignment/role)"></xsl:variable>
		<xsl:variable name="member-assignments"
			select="securitym:list-role-assignments($scope)[sw:lc(role)=sw:lc($role-name)]"/>
		<xsl:choose>
			<xsl:when
				test="not($member-assignments[self::error]) and count($member-assignments) &gt; 0">
				<xsl:variable name="upd-assignment-rtf">
					<xsl:copy-of select="$member-assignments[1]/*[local-name() != 'member']"/>
					<xsl:copy-of select="$member-assignments[1]/member[not(string(.) = $role-assignment/member)]"/>
					<xsl:copy-of select="$role-assignment/member"/>
				</xsl:variable>
				<func:result
					select="securitym:cmd-update-role-assignments(exsl:node-set($upd-assignment-rtf),$scope)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="securitym:cmd-add-role-assignment($role-assignment,$scope)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
</xsl:stylesheet>
