<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
	extension-element-prefixes="sw exsl action func securitym" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:func="http://exslt.org/functions"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/swa/securitym.xsl"/>

	<xsl:template match="/">
		<xsl:variable name="role-names" select="/data/role_assignments/*/role"/>
		<xsl:variable name="scope" select="/data/scope"/>

		<xsl:if test="action:start('permission.delete', $role-names)"/>
		<xsl:for-each select="/data/role_assignments/*">
			<xsl:variable name="ra-name" select="role"/>
			<xsl:if
				test="action:run-child(local:update-role-assignment(.,$scope),concat('Delete principal assignments from ',$ra-name),'permission.delete',$ra-name)"
			/>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('permission.delete', $role-names)"/>
	</xsl:template>

	<func:function name="local:update-role-assignment">
		<xsl:param name="role-assignment"/>
		<xsl:param name="scope" select="/.."/>
		<xsl:variable name="role-name" select="string($role-assignment/role)"/>
		<xsl:variable name="member-assignments"
			select="securitym:list-role-assignments($scope)[sw:lc(role)=sw:lc($role-name)]"/>
		<xsl:choose>
			<xsl:when test="not($member-assignments[self::error]) and count($member-assignments) &gt; 0">
				<xsl:variable name="upd-assignments-rtf">
					<xsl:for-each select="$member-assignments">
						<role_assignment>
							<xsl:copy-of select="*[local-name() != 'member']"/>
							<xsl:copy-of select="member[not(string(.) = $role-assignment/member)]"/>
						</role_assignment>
					</xsl:for-each>					
				</xsl:variable>
				<xsl:variable name="upd-assignments" select="exsl:node-set($upd-assignments-rtf)"/>
				<xsl:variable name="req-rtf">
					<packet log="on">
						<target>securitym</target>
						<data>
							<xsl:copy-of 
								select="exsl:node-set(securitym:cmd-update-role-assignments(
									$upd-assignments/role_assignment[member],$scope))/packet/data/*"/>
							<xsl:for-each select="$upd-assignments/role_assignment[not(member)]">
								<xsl:copy-of 
									select="exsl:node-set(securitym:cmd-delete-role-assignment(name,$scope))/packet/data/*"/>
							</xsl:for-each>
						</data>
					</packet>
				</xsl:variable>
				<func:result select="exsl:node-set($req-rtf)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
</xsl:stylesheet>
