<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred env func action env"
	xmlns:xsl					="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl				="http://exslt.org/common"
	xmlns:sw					="http://www.swsoft.com/xsl/cp" 
	xmlns:action			="http://www.swsoft.com/xsl/cp/action"
	xmlns:env					="http://www.swsoft.com/xsl/cp/env" 
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred				="http://www.swsoft.com/xsl/cp/cred" 
	xmlns:func				="http://exslt.org/functions"
	xmlns:voc					="http://www.swsoft.com/xsl/cp/voc"	
>
	<sw:include href="/lib/vocabulary.xsl"/>		
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>		

	<xsl:output method="xml"/>

	<!--
		/data
			/cmd ( backup or renew )
			/backup
				/ve-eid
				/backup-id (optional)
			/options
				/include
				/exclude
				/description 
				/compression-level (optional)
				/backup-type (optional)
				/storage-server-eid (optional)
	-->
	<xsl:template match="/">

		<xsl:variable name="data" select="/data"/>
		<xsl:variable name="ve-list" select="/data/backup/ve-eid"/>
		<xsl:variable name="op-label" select="sw:if($data/cmd='renew','backupm.renew_backup','backupm.backup_env')"/>

		<xsl:if test="action:start($op-label, $ve-list)"/>

		<xsl:for-each select="$data/backup">
			<xsl:variable name="eid" select="ve-eid"/>
			<xsl:variable name="env" select="env:get-env($eid)/env"/>
			<xsl:variable name="env-title" select="env:env2title($env)"/>
			<xsl:if
				test="action:run-child(local:backup-ve(.,$data),concat('Backup Container ',$env-title),'backupm.backup',$eid)"
			/>
		</xsl:for-each>

		<xsl:copy-of select="action:complete($op-label, $ve-list)"/>

	</xsl:template>


	<func:function name="local:backup-ve">
		<xsl:param name="backup"/>
		<xsl:param name="data"/>

		<xsl:variable name="exclude" select="$data/options/exclude[path or hidden='true' or system='true']"/>
		<xsl:variable name="include" select="$data/options/include[path]"/>	
				
		<xsl:variable name="platform-ref" select="env:make-platform-ref(sw:ve-parent($backup/ve-eid))"/>

		<func:result>
			<packet log="on" 
				xmlns:ns2="http://www.swsoft.com/webservices/vzl/4.0.0/backupm" 
				xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
			>
				<target>backupm</target>
				<cookie>
					<operation>xsl-child.backup_ve</operation>
				</cookie>
				<data>
					<backupm>
						<backup_env>
							<env_list>
								<eid>
									<xsl:value-of select="$backup/ve-eid"/>
								</eid>
							</env_list>
							<xsl:choose>
								<xsl:when test="$data/options/storage-server-eid!=''">
									<backup_server>
										<protocol>agent</protocol>
										<address><xsl:value-of select="$data/options/storage-server-eid"/></address>
									</backup_server>
								</xsl:when>
								<xsl:otherwise>
									<global/>
								</xsl:otherwise>
							</xsl:choose>
							<backup_options xsi:type="ns2:backup_optionsType">
								<xsl:if test="$data/options/backup-type!=''">
									<type>
										<xsl:value-of select="$data/options/backup-type"/>
									</type>
								</xsl:if>
								<xsl:if test="$data/options/description!=''">
									<description>
										<xsl:value-of
											select="sw:base64-encode($data/options/description)"/>
									</description>
								</xsl:if>
								<xsl:if test="$data/options/compression-level!=''">
									<compression>
										<xsl:value-of select="$data/options/compression-level"/>
									</compression>
								</xsl:if>
								<xsl:if test="$exclude">
									<exclude_list>
										<xsl:for-each select="$exclude/path">
											<path>
												<xsl:value-of select="sw:base64-encode(.)"/>
											</path>
										</xsl:for-each>
										<xsl:if test="voc:check-feature('backup.exclude.system',$platform-ref)">
											<xsl:if test="$exclude/hidden='true'">
												<hidden/>
											</xsl:if>
											<xsl:if test="$exclude/system='true'">
												<system/>
											</xsl:if>
										</xsl:if>
									</exclude_list>
								</xsl:if>
								<xsl:if test="$include">
									<include_list>
										<xsl:for-each select="$include/path">
											<path>
												<xsl:value-of select="sw:base64-encode(.)"/>
											</path>
										</xsl:for-each>
									</include_list>
								</xsl:if>
								
								<!-- Renew backups -->
								<xsl:if test="$backup/backup-id">
									<remove>
										<backup><xsl:value-of select="$backup/backup-id"/></backup>
									</remove>
								</xsl:if>
							</backup_options>
						</backup_env>
					</backupm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
