<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action env backups"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"	
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:backups	="http://www.swsoft.com/xsl/cp/backups"
>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>		
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/backups-core.xsl"/>

	<xsl:output method="xml"/>
	
	<!--
		/data
			/backup[]
				/id
				/dst-eid
		
	-->
	<xsl:template match="/">
	
		<xsl:variable name="backups" select="/data/backup"/>

		<xsl:for-each select="$backups">
			<xsl:variable name="backup-restore" select="."/>		
			<xsl:variable name="backup-id" select="id"/>

			<xsl:variable name="backup" select="backups:find-backup($backup-id)"/>					
			<xsl:variable name="backuped-ve" select="backups:find-env-info($backup)/env"/>		
			<xsl:variable name="existed-ve" select="env:get-env($backuped-ve/eid)/env[status/state!=$env-state/unexist]"/>			

			<xsl:choose>
				<xsl:when test="$backup[not(self::backup)]">
					<xsl:if test="action:log-error('Can not get Container info due to error cp1302 was occured.')"/>
				</xsl:when>	
				<xsl:when test="$backuped-ve[not(self::env)]">
					<xsl:if test="action:log-error('Can not get Container info due to error cp1302 was occured.')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="eid" select="$backuped-ve/eid"/>									
					<xsl:if test="action:start('backupm.restore_env', $eid)"/>
			
					<xsl:variable name="existed-state" select="$existed-ve/status/state"/> 	
					<xsl:variable name="env-title" select="env:env2title($backuped-ve)"/>
				
					<!-- Stop running VE -->
					<xsl:if test="$existed-ve and ($existed-state=$env-state/running)">
						<xsl:if test="action:run-child(local:stop-ve($eid),concat('Stop Container ',$env-title ),'vzaenvm.stop',$eid)"/>	
					</xsl:if>
					
					<!-- Unmount mounted VE -->
					<xsl:if test="$existed-ve and ($existed-state=$env-state/mounted)">
						<xsl:if test="action:run-child(local:unmount-ve($eid),concat('Unmount Container ',$env-title),'vzaenvm.unmount',$eid)"/>	
					</xsl:if>
					
					<!-- Restore VE -->
					<xsl:if test="action:run-child(local:restore-ve($backup-id,$backup-restore/dst-eid,$existed-ve),concat('Restore Container ',$env-title),'backupm.restore_env',$eid)"/>
				
					<!-- Start ext-running VE -->
					<xsl:if test="$existed-ve and ($existed-state=$env-state/running)">
						<xsl:if test="action:run-child(local:start-ve($eid),concat('Start Container ',$env-title),'vzaenvm.start',$eid)"/>	
					</xsl:if>
					
					<xsl:copy-of select="action:complete('backupm.restore_env', $eid)"/>
				</xsl:otherwise>
			</xsl:choose>
			
		</xsl:for-each>
	

	</xsl:template>

	<func:function name="local:restore-ve">
		<xsl:param name="backup-id"/>	
		<xsl:param name="parent-eid"/>		
		<xsl:param name="existed-ve"/>		
		<func:result>
			<packet log="on"
				xmlns:xsi							="http://www.w3.org/2001/XMLSchema-instance"	
				xmlns:vzat						="http://www.swsoft.com/webservices/vzl/4.0.0/backupm"				
			>
				<target>backupm</target>      
				<cookie>
					<operation>restore_ve</operation>
				</cookie>
				<data>
					<backupm>
						<restore_env>
							<backup_id><xsl:value-of select="$backup-id"/></backup_id>
							<xsl:if test="not($existed-ve)">
								<parent_eid><xsl:value-of select="$parent-eid"/></parent_eid>
							</xsl:if>
							<restore_options xsi:type="vzat:restore_optionsType">
								<force/>
							</restore_options>
						</restore_env>
					</backupm>
				</data>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:stop-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.stop_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
						</stop>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:unmount-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.umount_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<umount>
							<eid><xsl:value-of select="$eid"/></eid>
						</umount>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
		
	<func:function name="local:start-ve">
		<xsl:param name="eid"/>
		<func:result>
			<packet log="on">
				<target>vzaenvm</target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<vzaenvm>
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</vzaenvm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
</xsl:stylesheet>