<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>	
	<sw:include href="/lib/vt/env-core.xsl"/>	

	<xsl:output method="xml"/>
	
	<!-- Destroy specifed VE(s)	
		/data
			/eid[]
		
	-->
	<xsl:template match="/">
	
		<xsl:variable name="ve-list" select="/data/eid"/>
	
		<xsl:if test="action:start('vzaenvm.destroy', $ve-list)"/>
		
		<xsl:for-each select="$ve-list">
			<xsl:variable name="eid" select="."/>
			<xsl:variable name="old-env" select="env:get-env($eid)/env"/> 
			<xsl:variable name="old-state" select="$old-env/status/state"/> 
			<xsl:choose>
        <xsl:when test="$old-state = $env-state/unexist or not($old-env !='')">
          <!-- ve not exists, log it and skipped -->
          <xsl:if test="action:log-error(concat('Can not delete unexisted Container with eid ',$eid),'',$eid)"/>
        </xsl:when>
        <xsl:otherwise>
					<xsl:variable name="ve-title" select="env:env2title($old-env)"/> 
					<xsl:variable name="packet-target" select="env:get-target($eid)"/>
					<!-- Stop running VE -->
					<xsl:if test="$old-state=$env-state/running">
						<xsl:if test="action:run-child(local:stop-ve($eid,$packet-target),concat('Stop Container ',$ve-title),'vzaenvm.stop',$eid)"/>	
					</xsl:if>
					<!-- Unmount mounted stopped VE -->
					<xsl:if test="$old-state=$env-state/mounted">
						<xsl:if test="action:run-child(local:unmount-ve($eid,$packet-target),concat('Unmount Container ',$ve-title),'vzaenvm.destroy',$eid)"/>	
					</xsl:if>
					<!-- Delete the VE -->
					<xsl:if test="action:run-child(local:destroy-ve($eid,$packet-target),concat('Delete Container ',$ve-title),'vzaenvm.destroy',$eid)"/>
				</xsl:otherwise>
      </xsl:choose>
		</xsl:for-each>
	
		<xsl:copy-of select="action:complete('vzaenvm.destroy', $ve-list)"/>

	</xsl:template>

	
	<func:function name="local:stop-ve">
		<xsl:param name="eid"/>
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.stop_ve</operation>
        </cookie>			
				<data>
					<xsl:element name="{$packet-target}">
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
						</stop>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:unmount-ve">
		<xsl:param name="eid"/>
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.unmount_ve</operation>
        </cookie>			
				<data>
					<xsl:element name="{$packet-target}">
						<umount>
							<eid><xsl:value-of select="$eid"/></eid>
						</umount>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:destroy-ve">
		<xsl:param name="eid"/>
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.destroy_ve</operation>
        </cookie>			
				<data>
					<xsl:element name="{$packet-target}">
						<destroy>
							<eid><xsl:value-of select="$eid"/></eid>
						</destroy>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>
	
</xsl:stylesheet>
