<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
>

	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>	

	<xsl:output method="xml"/>
	
	<!--
		/data
			/eid
		
	-->
	<xsl:template match="/">
	
		<xsl:variable name="ve-list" select="/data/eid"/>
	
		<xsl:if test="action:start('vzaenvm.start', $ve-list)"/>
		
		<xsl:for-each select="$ve-list">
			<xsl:variable name="eid" select="."/>
			<xsl:variable name="old-env" select="env:get-env($eid)/env"/> 
			<xsl:variable name="old-status" select="$old-env/status"/> 			
			<xsl:choose>
        <xsl:when test="$old-status/state = $env-state/unexist  or not($old-env !='')">
          <!-- ve not exists, log it and skipped -->
          <xsl:if test="action:log-error(concat('Can not start unexisted Container with eid ',$eid),'',$eid)"/>
        </xsl:when>
        <xsl:otherwise>
					<xsl:variable name="ve-id" select="$old-env/virtual_config/veid"/> 
					<xsl:variable name="title" select="env:env2title($old-env)"/> 
					<xsl:variable name="packet-target" select="env:get-target($eid)"/>
					<!-- Start stopped VE -->
					<xsl:choose>
						<xsl:when test="$old-status/state=$env-state/suspended">
							<xsl:if test="action:run-child(local:resume-ve($eid,$packet-target),concat('Resume Container ',$title),'vzaenvm.resume',$eid)"/>	
						</xsl:when>
						<xsl:when test="$old-status/state=$env-state/down or $old-status/state=$env-state/mounted">
							<xsl:if test="action:run-child(local:start-ve($eid,$packet-target),concat('Start Container ',$title),'vzaenvm.start',$eid)"/>	
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="action:log-env-error(concat('Can not start Container ',$title),'vzaenvm.start',$eid,3,$old-status)"/>	
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
      </xsl:choose>
		</xsl:for-each>
		<xsl:copy-of select="action:complete('vzaenvm.start', $ve-list)"/>
	</xsl:template>

	
	<func:function name="local:start-ve">
		<xsl:param name="eid"/>
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.start_ve</operation>
        </cookie>			
				<data>
					<xsl:element name="{$packet-target}">
						<start>
							<eid><xsl:value-of select="$eid"/></eid>
						</start>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>
	

	<func:function name="local:resume-ve">
		<xsl:param name="eid"/>
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($eid)" />
				<cookie>
					<operation>xsl-child.resume_ve</operation>
				</cookie>
				<data>
					<xsl:element name="{$packet-target}">
						<resume>
							<eid><xsl:value-of select="$eid"/></eid>
						</resume>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>
	

</xsl:stylesheet>
