<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:func		="http://exslt.org/functions"	
>

	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>	

	<xsl:output method="xml"/>
	
	<!-- Stop specifed VE(s)	
		/data
			/eid
			/fast
		
	-->
	<xsl:template match="/">
	
		<xsl:variable name="ve-list" select="/data/eid"/>
		<xsl:variable name="fast" select="/data/fast"/>
	
		<xsl:if test="action:start('vzaenvm.stop', $ve-list)"/>
		
		<xsl:for-each select="$ve-list">
			<xsl:variable name="eid" select="."/>
			<xsl:variable name="old-env" select="env:get-env($eid)/env"/> 
			<xsl:variable name="old-status" select="$old-env/status"/> 			
			<xsl:choose>
				<xsl:when test="$old-status/state = $env-state/unexist or not($old-env !='')">
					<!-- ve not exists, log it and skipped -->
					<xsl:if test="action:log-error(concat('Can not stop unexisted Container with eid ',$eid),'',$eid)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="ve-id" select="$old-env/virtual_config/veid"/> 
					<xsl:variable name="title" select="env:env2title($old-env)"/> 
					<xsl:variable name="packet-target" select="env:get-target($eid)"/>
					<!-- Stop running VE -->
					<xsl:choose>
						<xsl:when test="$old-status/state=$env-state/mounted">
							<xsl:if test="action:run-child(local:umount-ve($eid,$fast,$packet-target),concat('Unmount Container ',$title),'vzaenvm.stop',$eid)"/>	
						</xsl:when>
						<xsl:when test="$old-status/state=$env-state/running">
							<xsl:if test="action:run-child(local:stop-ve($eid,$fast,$packet-target),concat('Stop Container ',$title),'vzaenvm.stop',$eid)"/>	
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="action:log-env-error(concat('Can not stop Container ',$title),'vzaenvm.stop',$eid,3,$old-status)"/>	
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>

		<xsl:copy-of select="action:complete('vzaenvm.stop', $ve-list)"/>
	</xsl:template>

	
	<func:function name="local:stop-ve">
		<xsl:param name="eid"/>
		<xsl:param name="fast"/>
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>		
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.stop_ve</operation>
        </cookie>			
				<data>
					<xsl:element name="{$packet-target}">
						<stop>
							<eid><xsl:value-of select="$eid"/></eid>
							<xsl:if test="$fast">
                <force/>
              </xsl:if>
						</stop>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>
	

	<func:function name="local:umount-ve">
		<xsl:param name="eid"/>
		<xsl:param name="fast"/>
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>		
				<xsl:copy-of select="sw:hn-dst($eid)"/>
        <cookie>
          <operation>xsl-child.umount_ve</operation>
        </cookie>			
				<data>
					<xsl:element name="{$packet-target}">
						<umount>
							<eid><xsl:value-of select="$eid"/></eid>
						</umount>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>

	
</xsl:stylesheet>
