<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:env="http://www.swsoft.com/xsl/cp/env" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
	xmlns:func="http://exslt.org/functions"
>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/core/action-funcs.xsl"/>	

	<xsl:output method="xml" />

	<!-- Stop specifed VE(s)	
		/data
		/eid
		
	-->
	<xsl:template match="/">

		<xsl:variable name="ve-list" select="/data/eid" />

		<xsl:if test="action:start('vzaenvm.suspend', $ve-list)" />
		
		<xsl:for-each select="$ve-list">
			<xsl:variable name="eid" select="."/>
			<xsl:variable name="old-env" select="env:get-env($eid)/env"/>
			<xsl:variable name="old-status" select="$old-env/status" />			
			<xsl:choose>
        <xsl:when test="$old-status/state = $env-state/unexist  or not($old-env !='')">
          <!-- ve not exists, log it and skipped -->
          <xsl:if test="action:log-error(concat('Can not suspend unexisted Container with eid ',$eid),'',$eid)"/>
        </xsl:when>
        <xsl:otherwise>
					<xsl:variable name="ve-id" select="$old-env/virtual_config/veid"/>
					<xsl:variable name="title"	select="env:env2title($old-env)"/>
					<xsl:variable name="packet-target" select="env:get-target($eid)"/>

					<!-- Suspend running VE -->
					<xsl:choose>
						<xsl:when test="$old-status/state=$env-state/running">
							<xsl:if
								test="action:run-child(local:suspend-ve($eid,$packet-target),concat('Suspend Container ',$title),'vzaenvm.suspend',$eid)" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:if
								test="action:log-env-error(concat('Can not suspend Container ',$title),'vzaenvm.suspend',$eid,$global:task-failed,$old-status)" />
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
      </xsl:choose>
		</xsl:for-each>

		<xsl:copy-of select="action:complete('vzaenvm.suspend', $ve-list)" />

	</xsl:template>


	<func:function name="local:suspend-ve">
		<xsl:param name="eid" />
		<xsl:param name="packet-target"/>
		<func:result>
			<packet log="on">
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($eid)" />
				<cookie>
					<operation>xsl-child.suspend_ve</operation>
				</cookie>
				<data>
					<xsl:element name="{$packet-target}">
						<suspend>
							<eid>
								<xsl:value-of select="$eid" />
							</eid>
						</suspend>
					</xsl:element>
				</data>
			</packet>
		</func:result>
	</func:function>

</xsl:stylesheet>
