<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func cred path"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:path="http://www.swsoft.com/xsl/cp/path"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:http="http://www.swsoft.com/xsl/cp/http"
	xmlns:cookies="http://www.swsoft.com/xsl/cp/cookies"
  >

  <xsl:output method="html" encoding="utf-8"/>  

  <sw:include href="../http/redirect.xsl"/>
  <sw:include href="../http/cookies.xsl"/>
  <sw:include href="/lib/panel/homepage.xsl"/>

  <!-- output of HTTP document -->
  <xsl:template name="document">

	<xsl:variable name="content-type" select="sw:if(ui:binary/@type, ui:binary/@type, 'text/html')"/>

	<!-- begin HTTP header -->
	<http:header>
		<name>Status</name>
		<value>200 OK</value>
	</http:header>
	<http:header>
		<name>Content-type</name>
		<value><xsl:value-of select="$content-type"/></value>
	</http:header>
	<xsl:if test="ui:binary/@file-name">
		<http:header>
			<name>Content-Disposition</name>
			<value>attachment; filename="<xsl:value-of select="ui:binary/@file-name"/>"</value>
		</http:header>
		<http:header>
			<name>Accept-Ranges</name>
			<value>bytes</value>
		</http:header>
	</xsl:if>
	<http:header>
		<name>Expires</name>
		<value>-1</value>
	</http:header>
	<http:header>
		<name>Cache-control</name>
		<value>no-store, must-revalidate, private</value>
	</http:header>

	<xsl:for-each select="ui:binary/download">
		<http:download>
			<path><xsl:value-of select="path"/></path>
			<eid><xsl:value-of select="eid"/></eid>
			<size><xsl:value-of select="size"/></size>
			<xsl:if test="cwd">
				<cwd><xsl:value-of select="cwd"/></cwd>
			</xsl:if>
			<xsl:copy-of select="dst"/>
		</http:download>
	</xsl:for-each>
    
	<xsl:variable name="allCookies">
		<xsl:copy-of select="cookies:get-cookies()"/>
		<xsl:copy-of select="/ui:screen/ui:properties/ui:cookies/*"/>
	</xsl:variable>
	<xsl:copy-of select="http:cookies(exsl:node-set($allCookies)/cookie)"/>
	
	<!-- Quircks mode -->
 	<xsl:if test="not(ui:binary) and not(ui:raw) and not(ui:screen/ui:properties/ui:disable-html-loose)">
		<xsl:text disable-output-escaping="yes">&lt;!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd"&gt;&#10;</xsl:text>
	</xsl:if> 

	<xsl:call-template name="process-screen"/>
	
  </xsl:template>

  <!-- defeault entry point -->
	<xsl:template name="match-document" match="/">
		<xsl:choose>
			<!-- redirect if user have no rights to access this page -->
			<xsl:when test="/*/@access and /*/@access != 'true'">
				<xsl:copy-of select="http:redirect(sw:home-page())"/>
			</xsl:when>

			<!-- redirect if user have no rights to access this page -->
			<xsl:when test="/*/@cred and not(cred:check-context(/*/@cred,/*/@security-obj-type))">
				<xsl:copy-of select="http:redirect(sw:home-page())"/>
			</xsl:when>
			<xsl:when test="/ui:redirect">
				<xsl:apply-templates select="/ui:redirect"/>
			</xsl:when>

			<!-- show page -->
			<xsl:otherwise>
				<xsl:call-template name="document"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
  
  <sw:include href="../lib/globals.xsl"/>

</xsl:stylesheet>
