<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func path"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:http="http://www.swsoft.com/xsl/cp/http"
	xmlns:path="http://www.swsoft.com/xsl/cp/path"
  >
  <xsl:output method="html"/>

  <!-- HTTP 302 redirect (get args) -->
  <!-- Example:
			 <xsl:copy-of select="http:redirect("/somewhere/xxx", $args, $cookies)"/>
				 $args - nodeset like:
          <arg name="varname">value</arg>
          <arg name="tstname">nameX</arg>
				 $cookies - nodeset like:
					<cookie name="vzcpBlah" Path="/" Max-Age="86400">blah</cookie>
    -->
  <func:function name="http:redirect">
    <xsl:param name="location" select="$baseurl"/>
		<xsl:param name="args" select="/.."/>
		<xsl:param name="cookies" select="/.."/>

		<func:result>
			<http:header>
				<name>Status</name>
				<value>302 Not Found</value>
			</http:header>
			
			<xsl:copy-of select="http:cookies($cookies)"/>
			<http:header>
				<name>Location</name>
				<value><sw:text lang="C" select="sw:if($location, $location, $baseurl)"/>
					<xsl:if test="$args">
						<xsl:text>?</xsl:text>
						<xsl:for-each select="$args">
							<xsl:if test="@name"><xsl:value-of select="@name"/>=</xsl:if>
							<xsl:value-of select="string(.)"/>
							<xsl:if test="position() != last()">
								<xsl:text disable-output-escaping="yes">&amp;</xsl:text>
							</xsl:if>
						</xsl:for-each>
					</xsl:if>
				</value>
			</http:header>

			<xsl:text>redirected</xsl:text>
		</func:result>

	</func:function>

  <!-- JavaScript redirect (POST args, in html body) -->
  <func:function name="http:redirect-javascript-inline">
    <xsl:param name="location" select="$baseurl"/>
		<xsl:param name="args" select="/.."/>
		<xsl:param name="target"/>
		<xsl:param name="popup-location"/>
		<func:result>
					<form method="post" action="{$popup-location}" name="redirectForm" id="redirectForm">
						<xsl:if test="$target != ''">
								<xsl:attribute name="target"><xsl:value-of select="$target"/></xsl:attribute>
						</xsl:if>
						<xsl:for-each select="$args">
							<input type="hidden" name="{@name}" value="{string(.)}"/>
						</xsl:for-each>
					</form>
			 		<script language="javascript">
						function onLoad() {
							this.document.redirectForm.submit();
							<xsl:if test="$location != ''">
								this.location.href = '<xsl:value-of select="$location"/>';
							</xsl:if>
						} 
					</script>
		</func:result>

	</func:function>


  <!-- JavaScript redirect (POST args) -->
  <!-- Example:
			 <xsl:copy-of select="http:redirect-javascript("/somewhere/xxx", $args, $coocies)/>
				 $args - nodeset like:
          <arg name="varname">value</arg>
          <arg name="tstname">nameX</arg>
				 $cookies - nodeset like:
					<cookie name="vzcpBlah" Path="/" Max-Age="86400">blah</cookie>
    -->
  <func:function name="http:redirect-javascript">
    <xsl:param name="location" select="$baseurl"/>
		<xsl:param name="args" select="/.."/>
		<xsl:param name="cookies" select="/.."/>
		<xsl:param name="target"/>
		
		<func:result>
			<http:header>
				<name>Status</name>
				<value>200 OK</value>
			</http:header>
			<http:header>
				<name>Content-type</name>
				<value>text/html</value>
			</http:header>
			<http:header>
				<name>Expires</name>
				<value>-1</value>
			</http:header>
			<!-- insert cookies -->
			<xsl:copy-of select="http:cookies($cookies)"/>
			<http:header>
				<name>Cache-control</name>
				<value>no-store, must-revalidate, private</value>
			</http:header>

			<html>
				<body onload="document.redirectForm.submit()">
					<form method="post" action="{sw:if($location, $location, $baseurl)}" name="redirectForm" id="redirectForm">
						<xsl:if test="$target != ''">
							<xsl:attribute name="target"><xsl:value-of select="$target"/></xsl:attribute>
						</xsl:if>
						<xsl:for-each select="$args">
							<input type="hidden" name="{@name}" value="{string(.)}"/>
						</xsl:for-each>
					</form>
				</body>
			</html>
		</func:result>

	</func:function>

  <!-- prepare http cookies -->
  <func:function name="http:cookies">
		<xsl:param name="cookies" select="/.."/>

		<func:result>
			<xsl:for-each select="$cookies">
				<http:header>
					<name>Set-Cookie</name>
					<value>
						<xsl:value-of select="@name"/><xsl:text>=</xsl:text>
						<xsl:value-of select="."/>
						<xsl:for-each select="@*">
							<xsl:choose>
								<!-- skip name -->
								<xsl:when test="name() = 'name'"></xsl:when>
          
								<!-- cookie never expires -->
								<xsl:when test="name() = 'Expires' and string(.)='never'">
									<xsl:text>;Expires=01-Jan-2030 00:00:00 GMT</xsl:text>
								</xsl:when>

								<!-- passthrough other cookie attributes -->
								<xsl:otherwise>
									<xsl:text>;</xsl:text><xsl:value-of select="name()"/>
									<xsl:text>=</xsl:text><xsl:value-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</value>
				</http:header>
			</xsl:for-each>  
		</func:result>

	</func:function>


	<!-- new style redirect -->
	<xsl:template match="ui:redirect">

		<xsl:variable name="location">
			<xsl:choose>

				<xsl:when test="@path = 'prev'">
					<xsl:value-of select="path:href(path:prev(path:get()))" />
				</xsl:when>

				<xsl:when test="@path = 'last'">
					<xsl:value-of select="path:href(path:last(path:get()))" />
				</xsl:when>

				<xsl:when test="@location">
					<xsl:value-of select="@location"/>
				</xsl:when>

				<xsl:otherwise>
					<xsl:value-of select="$baseurl"/>
				</xsl:otherwise>

			</xsl:choose>
		</xsl:variable>

		<xsl:choose>

			<!-- javascript redirect, in body -->
			<xsl:when test="@inline = 'yes'">
				<xsl:copy-of select="http:redirect-javascript-inline(string($location), ui:arg, @target,@popup-location)"/>
			</xsl:when>

			<!-- javascript redirect -->
			<xsl:when test="@type = 'javascript'">
				<xsl:copy-of select="http:redirect-javascript(string($location), ui:arg, ui:cookie,@target)"/>
			</xsl:when>

			<!-- http redirect -->
			<xsl:otherwise>
				<xsl:copy-of select="http:redirect(string($location), ui:arg, ui:cookie)"/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
