
<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl html path env"
exclude-result-prefixes="ui html http func cred path env ve"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"  
  xmlns:html="http://www.swsoft.com/xsl/cp/html"
  xmlns:http="http://www.swsoft.com/xsl/cp/http"
  xmlns:func="http://exslt.org/functions"
  xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
  xmlns:path="http://www.swsoft.com/xsl/cp/path"
 	xmlns:env="http://www.swsoft.com/xsl/cp/env"  	
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
>
	
	<sw:include href="/layout/lib/html.xsl"/>
  <sw:include href="/lib/vt/env-core.xsl"/>  
  <sw:include href="/lib/cred-filter.xsl"/>    
  
  <xsl:template name="opresult">
  	<xsl:variable name="errors" select="sw:sesgettree('errors')"/>
		<xsl:choose>
			<xsl:when test="$errors or normalize-space(sw:sesget('msg')) or normalize-space(sw:sesget('sched'))">
				<tr>
				<td id="opresult_id">
					<table border="0" cellpadding="0" cellspacing="0" width="100%">
		
					<xsl:for-each select="$errors/error">
						<tr>
							<td class="ErrorBar" nowrap="1"><xsl:value-of select="text"/></td>
							<xsl:if test="details!=''">
							<td class="ErrorBar" align="right" nowrap="1"><a onmouseover="callTip('get_err_details',event)" onmouseout="callTip()" onclick="open_details('{$baseurl}/core/tasks/error-popup?pos={position()}'); return false" href="{$baseurl}/core/tasks/error-popup?pos={position()}"><sw:text>Details</sw:text></a></td>
							</xsl:if>
						</tr>
					 </xsl:for-each>
		
					 <xsl:if test="normalize-space(sw:sesget('msg'))">
						<tr>
						<td class="StatusBar" nowrap="1"><xsl:value-of select="sw:sesget('msg')"/></td>
						<td class="StatusBar" align="right" nowrap="1">&#160;</td>
						<xsl:value-of select="sw:sesput('msg', '')"/>
						</tr>
					 </xsl:if>
		
					 <xsl:if test="normalize-space(sw:sesget('sched'))">
						 <tr>
						<xsl:variable name="op_id" select="sw:sesget('operation_id')"/>	  
						<td class="StatusBar" nowrap="1"><xsl:value-of select="sw:sesget('sched')"/></td>
						<td class="StatusBar" align="right" nowrap="1"><a onmouseover="callTip('get_op_details',event)" onmouseout="callTip()" onclick="open_details('{$baseurl}/core/tasks/details-popup?id={$op_id}'); return false" href="{$baseurl}/core/tasks/details-popup?id={$op_id}"><sw:text>Details</sw:text></a></td>
						<xsl:value-of select="sw:sesput('sched', '')"/>
						</tr>
					 </xsl:if>	
					</table>  
				</td>
				</tr>
			</xsl:when>
			<xsl:otherwise>
				<tr><td id="opresult_id" style="display:none"></td></tr>	
			</xsl:otherwise>
		</xsl:choose>

  </xsl:template>


	<!-- box with stop sign -->
  <xsl:template name="stopSign">
	<xsl:param name="head"/>
	<xsl:param name="body"/>
	<xsl:param name="icon"/>
	<xsl:param name="width" select="'100%'"/>
	<!--|-->
	<table width="{$width}" cellpadding="0" cellspacing="0" border="0">
	  <tr>
		<td> 
		  <fieldset>
			<legend align="left" style="vertical-align:middle">
			<img src="/{$theme}/icons/{sw:if($icon,$icon,'stop_sign')}_32.gif" style="vertical-align:middle"/>
				<span style="vertical-align:middle"><xsl:value-of select="$head"/></span>
			</legend>
			<xsl:copy-of select="$body"/>
		  </fieldset>
		</td>
	  </tr>
	</table>
  </xsl:template>

  <!-- show info box -->
  <xsl:template name="infoBox">
	<xsl:param name="info"/>
	<xsl:param name="title"/>
	<fieldset class="noLegend">
		<xsl:if test="not(string($title))">
			<xsl:attribute name="class">noLegend</xsl:attribute>
		</xsl:if>
		<xsl:if test="string($title)">
			<legend><xsl:value-of select="$title"/></legend>
		</xsl:if>
	  <xsl:copy-of select="exsl:node-set($info)"/>
	</fieldset>	
  </xsl:template>

  <!-- raw html debug -->
  <xsl:template match="ui:raw">
	  <xsl:copy-of select="./child::node()"/>    
  </xsl:template>  

  <!-- hidden form input -->
	<xsl:template match="ui:hidden">
		<input type="hidden" name="{sw:if(@name,@name,@id)}" value="{@value}" id="{sw:if(@id,@id,@name)}"/>
	</xsl:template>  
  
  <!-- display svg imge -->
  <xsl:template match="ui:image-svg">
  	<http:image>
		<xsl:copy-of select="svg/@*"/>
  		<xsl:copy-of select="svg"/>
  	</http:image>
  </xsl:template>
  
  <!-- load tabs from xml-->
  <xsl:template match="ui:tab-bar">
  	<xsl:variable name="tabbar-id" select="@id"/> 
  	<xsl:variable name="screen-id" select="/ui:screen/@id"/>
  	<xsl:variable name="current-tab" select="@current-tab"/>
  	<xsl:variable name="current-subtab" select="@current-subtab"/>
  	<xsl:variable name="screen-tab-bar" select="."/>
	
		<xsl:variable name="current-bar-unsecured" select="
				sw:document('tabs.xml',sw:if($activeMode = 'vzcc', 'vzcc', 'vzpp'))/tab-bars/tab-bar[@id = $tabbar-id]
		"/>
		<xsl:variable name="current-bar" select="cred:filter-items($current-bar-unsecured)"/>
				
		<!-- We want tabs only in two cases:
			1) unsecured tab has no subtabs 
			2) secured and unsecured tabs both have subtabs
		-->
		<xsl:variable name="validtabs" select="$current-bar/tab[ 
			@id=$current-bar-unsecured/tab[not(tab)]/@id  or (@id=$current-bar-unsecured/tab[tab]/@id and tab)
		]"/>
			
		<xsl:variable name="validtabs-count" select="count($validtabs)"/>
		
		<xsl:variable name="current-tab-obj" select="$validtabs[@tab=$current-tab]"/>
	
		<xsl:if test="$validtabs">					
			<xsl:variable name="tabs-tree">
				<xsl:for-each select="$current-bar">
					<ui:tab-bar-custom>
						<xsl:copy-of select="@*"/>
						<xsl:attribute name="current-tab"><xsl:value-of select="$current-tab"/></xsl:attribute>
						<xsl:choose>
						<!-- Rule to decide: one line or many -->
							<xsl:when test="$validtabs-count &gt; $tab-limit">
								<!-- Multi-line tabbar -->
								<xsl:variable name="tablines-count" select="round(count($validtabs) div $tab-limit)"/>
								<xsl:variable name="tabs-inline" select="round(count($validtabs) div $tablines-count)"/>
								<xsl:for-each select="$validtabs[(position() mod $tabs-inline) = 0]">
									<xsl:variable name="rowstart-position" select="$tabs-inline * (position() - 1) + 1"/>
									<xsl:variable name="rowend-position" select="$tabs-inline * position()"/>
									<ui:tab-row>
										<xsl:attribute name="tab-width"><xsl:value-of select="round(100 div $tabs-inline)"/>%</xsl:attribute>
										<xsl:for-each select="$validtabs[(position() &gt; ($rowstart-position - 1)) and (position() &lt; ($rowend-position + 1))]">
											<xsl:call-template name="one-tab"/>
										</xsl:for-each>
									</ui:tab-row>		
								</xsl:for-each>
								<!-- last tabrow (if needed) -->
								<xsl:if test="($validtabs-count mod $tabs-inline) &gt; 0">
									<ui:tab-row>
										<xsl:attribute name="tab-width"><xsl:value-of select="round(100 div ($validtabs-count mod $tabs-inline))"/>%</xsl:attribute>
										<xsl:for-each select="$validtabs[position() &gt; ($validtabs-count - ($validtabs-count mod $tabs-inline))]">
											<xsl:call-template name="one-tab"/>									
										</xsl:for-each>
									</ui:tab-row>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<!-- Single-line tabbar -->
								<xsl:for-each select="$validtabs">
									<xsl:call-template name="one-tab"/>
								</xsl:for-each>
							</xsl:otherwise>
						</xsl:choose>
						<!-- Prepare Subtabs if needed -->
						<xsl:if test="$current-tab-obj and $current-subtab!=''">
							<ui:subtabs current="{$current-subtab}">
								<xsl:choose>
									<xsl:when test="$screen-tab-bar/@merge-mode='custom-subtabs'">
										<xsl:copy-of select="$screen-tab-bar/ui:tab"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:copy-of select="$current-tab-obj/tab"/>
									</xsl:otherwise>
								</xsl:choose>							
							</ui:subtabs>
						</xsl:if>
					</ui:tab-bar-custom>
				</xsl:for-each>
			</xsl:variable>
			<xsl:variable name="tabs-nodes" select="exsl:node-set($tabs-tree)"/>
			<xsl:apply-templates select="$tabs-nodes/*"/>
		</xsl:if>
		<xsl:if test="not($validtabs)">
			<div id="noTabs"></div>
		</xsl:if>
  </xsl:template>
  
  <xsl:template name="show-subtabs">
		<xsl:param name="current"/>
		<xsl:param name="tabs"/>
		<div class="subTabs">
			<table cellpadding="0" cellspacing="0" border="0" style="margin-top:3px; height: 20px;">
				<tr>
					<xsl:for-each select="$tabs">
						<xsl:if test="position()!=1">
							<td class="subTabSpacer">|</td>	
						</xsl:if>
						<xsl:variable name="href">
							<xsl:call-template name="href">
								<xsl:with-param name="href" select="@href"/>
							</xsl:call-template>
						</xsl:variable>					
						<td valign="middle" class="subTab{sw:if(@tab=$current, 'Active','')}" onmouseover="this.className = 'subTabOver{sw:if(@tab=$current, 'Active','')}'; callTip('{@tip}', event)" onmouseout="this.className = 'subTab{sw:if(@tab=$current, 'Active','')}'; callTip('')" onclick="document.location.href = '{$href}'">
							<nobr><xsl:value-of select="sw:text-subst(@title)"/></nobr>
						</td>
					</xsl:for-each>
				</tr>
			</table>
		</div>
	</xsl:template>
  
	<xsl:template name="one-tab">
		<!-- Preprocess one tab -->
		<xsl:variable name="tabs" select="tab"/>		
		<xsl:variable name="href-src" select="sw:if(@href,@href,$tabs[1]/@href)"/>
		<xsl:variable name="href">
			<xsl:call-template name="href">
				<xsl:with-param name="href" select="$href-src"/>
			</xsl:call-template>
		</xsl:variable>
		<!-- usual, small tab -->
		<ui:tab>
			<xsl:copy-of select="@*[name() != 'title' and name() != 'href']"/>
			<xsl:if test="string($href)!=''">
				<xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
			</xsl:if>
			<xsl:value-of select="sw:text-subst(@title)"/>
		</ui:tab>
	</xsl:template>
  
	<!-- display tabs -->
	<xsl:template match="ui:tab-bar-custom">
  		<xsl:variable name="current-tab" select="@current-tab"/>
  		
  		<xsl:choose>
			<xsl:when test="not(.//ui:tab)">
				<div id="noTabs"></div>
			</xsl:when>
			<xsl:otherwise>
				<div id="screenTabs">
					<xsl:choose>
						<xsl:when test="ui:tab-row">
							<!-- Multi-line tabbar -->				
							<xsl:for-each select="ui:tab-row[not(ui:tab/@tab = $current-tab)]">
								<div class="tabsUpper">
									<ul >
										<xsl:apply-templates select="*"/>
									</ul>
								</div>
							</xsl:for-each>
							<!-- Selected tab always at bottom -->					
							<xsl:for-each select="ui:tab-row[ui:tab/@tab = $current-tab]">
								<div class="tabsLower">
									<ul>
										<xsl:apply-templates select="ui:tab"/>
									</ul>
								</div>
							</xsl:for-each>					
						</xsl:when>
						<xsl:otherwise>
							<!-- Single-line tabbar -->
							<div class="tabs">
								<ul>
									<xsl:apply-templates select="ui:tab"/>
								</ul>
							</div>
						</xsl:otherwise>
					</xsl:choose>
				</div>
				<xsl:for-each select="ui:subtabs">
					<xsl:call-template name="show-subtabs">
						<xsl:with-param name="current" select="@current"/>
						<xsl:with-param name="tabs" select="*"/>
					</xsl:call-template>		
				</xsl:for-each>
				<xsl:if test="not(ui:subtabs)">
					<div class="noSubTabs"></div>
				</xsl:if>		
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
  
	<xsl:template match="ui:js-tab" mode="tabs">
		<xsl:param name="current-tab"/>
		
		<xsl:value-of select="''"/>	
		<li onclick="setTab(this)">
			<xsl:if test="@tab = $current-tab">
				<xsl:attribute name="id">current</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="class">
				<xsl:choose>
					<xsl:when test="position() = 1">first</xsl:when>
					<xsl:when test="position() = last()">last</xsl:when>
					<xsl:otherwise>middle</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
	  		<xsl:if test="@tip">
				<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip"/>',event)</xsl:attribute>
  				<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
				</xsl:if>			
			<a href="#" onclick="return false" id="{@tab}">
				<span><xsl:value-of select="@title"/></span>
			</a>				
		</li>
	</xsl:template>
	
	<xsl:template match="ui:js-tab" mode="content">
		<xsl:param name="current-tab"/>
	
		<div id="content_{@tab}" class="favoritesBlock{sw:if( (@tab != $current-tab ),'Hidden','')}">
			<xsl:apply-templates select="ui:favorites"/>
		</div>
	</xsl:template>	
	
	<xsl:template match="ui:tab">
		<xsl:variable name="selected" select="sw:if(/ui:tab-bar-custom/@current-tab, /ui:tab-bar-custom/@current-tab=@tab, @selected='true')"/>
		<xsl:value-of select="''"/>
		
		<xsl:variable name="href">
			<xsl:choose>
				<xsl:when test="ui:tab"><xsl:value-of select="@href"/></xsl:when>
				<xsl:when test="@href"><xsl:value-of select="@href"/></xsl:when>
				<xsl:when test="@tab"><xsl:value-of select="$requesturl"/>?tab=<xsl:value-of select="@tab"/></xsl:when>
				<xsl:otherwise>
					<sw:die>
						Error in ui:tab  
						Both @tab and @href are empty.
					</sw:die>
				</xsl:otherwise>
			</xsl:choose>					
		</xsl:variable>
		
		<xsl:choose>
			<!-- multi-liner -->
			<xsl:when test="../@tab-width">				
				<li style="width:{../@tab-width}" onclick="location.href='{$href}'" onmouseover="">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="position() = 1">first</xsl:when>
							<xsl:when test="position() = last()">last</xsl:when>
							<xsl:otherwise>middle</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
			  		<xsl:if test="@tip">
						<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip"/>',event)</xsl:attribute>
		  				<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
					</xsl:if> 					
					<xsl:if test="$selected">
						<xsl:attribute name="id">current</xsl:attribute>
					</xsl:if>
					<a>
						<span><xsl:value-of select="."/></span>
					</a>
				</li>			
			</xsl:when>
			<!-- single-liner -->
			<xsl:otherwise>
				<li>
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="position() = 1">first</xsl:when>
							<xsl:when test="position() = last()">last</xsl:when>
							<xsl:otherwise>middle</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:if test="$selected">
						<xsl:attribute name="id">current</xsl:attribute>
					</xsl:if>
					<a href="{$href}">
			  		<xsl:if test="@tip">
							<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip"/>',event)</xsl:attribute>
		  				<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
						</xsl:if>  			
						<span><xsl:value-of select="."/></span>
					</a>
				</li>			
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>  
  
  <!-- text element -->
  <xsl:template match="ui:text">
	<xsl:copy-of select="node()[not(self::ui:*)]"/>
	<xsl:apply-templates select="ui:*"/>
  </xsl:template>  
  
   <!-- text element -->
  <xsl:template match="ui:text-disabled">
  	<span class="inactive">
		<xsl:copy-of select="node()[not(self::ui:*)]"/>
		<xsl:apply-templates select="ui:*"/>
	</span>
  </xsl:template> 
  
	<!-- space element -->
  <xsl:template match="ui:text-space">
	&#160;
  </xsl:template>
  
  <!-- text element -->
  <xsl:template match="ui:icon">
	<img border="0" height="{sw:if(@size,@size,16)}" width="{sw:if(@size,@size,16)}">
		<xsl:choose>
			<xsl:when test="contains(@name,'.gif')">
				<xsl:attribute name="src"><xsl:value-of select="concat('/',$theme,'/icons/',@name)"/></xsl:attribute>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="src"><xsl:value-of select="concat('/',$theme,'/icons/',@name,sw:if(@big='true','_32.gif','_16.gif'))"/></xsl:attribute>
			</xsl:otherwise>
		</xsl:choose>    	
		<xsl:if test="@tip">
				<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip"/>',event)</xsl:attribute>
  			<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
			</xsl:if>
	</img>
  </xsl:template>  
  
  <!-- link element -->
  <xsl:template match="ui:link">
	<a>
	  <xsl:copy-of select="@*[name() != 'tip']"/>
	  <xsl:if test="@tip">
		<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip"/>',event)</xsl:attribute>
		<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
	  </xsl:if>
	  <xsl:copy-of select="node()[not(self::ui:*)]"/>
	  <xsl:apply-templates select="ui:*"/>
	</a>
  </xsl:template>  

  <!-- link element on localized text -->
  <xsl:template match="ui:i18n-link">
	  <xsl:variable name="a-tag">
		<a>
		  <xsl:copy-of select="@*[name() != 'tip']"/>
		  <xsl:if test="@tip">
			<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip"/>',event)</xsl:attribute>
			<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
		  </xsl:if>
		</a>
		</xsl:variable>
		<sw:text select="string(.)">
			<xsl:with-param name="custom"	select="@custom"/>
			<xsl:with-param name="aopen"	select="html:tag-open($a-tag)"/>
			<xsl:with-param name="aclose" select="html:tag-close($a-tag)"/>	
		</sw:text>
  </xsl:template>  

	<!-- copy all children or/and process ui:* elements -->
	<xsl:template name="ui:process-children">
		<xsl:for-each select="node()">
			<xsl:choose>
				<xsl:when test="self::ui:*">
					<xsl:apply-templates select="."/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="."/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="ui:show-button">
		<xsl:param name="btn"/>
		<div>
		<xsl:attribute name="class">
			<xsl:choose>
				<xsl:when test="contains($http-user-agent,'Safari')">SafariButton</xsl:when>			
				<xsl:when test="contains($http-user-agent,'MSIE')">IEButton</xsl:when>
				<xsl:when test="contains($http-user-agent,'Firefox')">FireFoxButton</xsl:when>
				<xsl:when test="contains($http-user-agent,'Opera')">OperaButton</xsl:when>
				<xsl:otherwise>IEButton</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
		<xsl:if test="$btn/@id">
			<xsl:attribute name="id"><xsl:value-of select="$btn/@id"/>Button</xsl:attribute>
		</xsl:if>
		<!-- Class definition -->
		<xsl:variable name="class">
			<xsl:choose>
				<xsl:when test="$btn/@html-class">
					<xsl:value-of select="$btn/@html-class"/>
				</xsl:when>		
				<xsl:when test="$btn/@width and $btn/@width &gt; 91">FormButton125</xsl:when>
				<xsl:when test="$btn/@type='ok'">FormButtonOk</xsl:when>
				<xsl:when test="$btn/@type='cancel'">FormButtonCancel</xsl:when>
				<xsl:when test="$btn/@type='next'">FormButtonNext</xsl:when>
				<xsl:when test="$btn/@type='back'">FormButtonPrev</xsl:when>              
				<xsl:when test="$btn/@type='short'">FormButtonShort</xsl:when>              
				<xsl:otherwise>FormButton</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- /Class definition -->		
		<table cellpadding="0" cellspacing="0" border="0" class="{$class}{sw:if($btn/@disabled='true','_disabled','')}">
			<tr>
			<td class="buttonLeft"><img src="/{$theme}/images/1x1.gif" border="0"/></td>
		
			<td class="buttonCenter"><input name="{sw:if($btn/@name,$btn/@name,$btn/@id)}" id="{$btn/@id}" value="{$btn/.}">	
				
			<xsl:if test="$btn/@tip">
				<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="$btn/@tip"/>',event)</xsl:attribute>
				<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
			</xsl:if>		
			<xsl:attribute name="type">
				<xsl:choose>
					<xsl:when test="$btn/@html-type"><xsl:value-of select="$btn/@html-type"/></xsl:when>
					<xsl:when test="$btn/@do-submit='false'">button</xsl:when>
					<xsl:otherwise>submit</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:if test="$btn/@disabled='true'">
				<xsl:attribute name="disabled">disabled</xsl:attribute>
			</xsl:if>
			<!-- OnClick JavaScript -->
			<xsl:choose>
				<xsl:when test="$btn/@disabled='true'">
					<!-- Do nothing -->
					<xsl:attribute name="onclick">
						return false;
					</xsl:attribute>
				</xsl:when>
	
				<xsl:when test="$btn/@onclick">
					<xsl:copy-of select="$btn/@onclick"/>
				</xsl:when>
				<xsl:when test="$btn/@type = 'cancel'">
					<xsl:variable name="ret-href" select="path:last-href()"/>      
					<xsl:attribute name="onclick">
						window.location.href='<xsl:value-of select="$ret-href"/>';return false;
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="on-press-ok">
						<xsl:if test="$btn/@type='ok' or $btn/@type='next'">
							if(!formCheckEmpty()){return false;};
						</xsl:if>
						<xsl:if test="$btn/@id='ok'">
							<xsl:value-of select="//ui:event[@type='on-press-ok']"/>
						</xsl:if>
					</xsl:variable>
					<xsl:variable name="condition_token">
						<xsl:choose>
							<xsl:when test="string($btn/@confirmation)">confirm('<xsl:value-of select="sw:html-escape($btn/@confirmation)"/>')</xsl:when>
							<xsl:otherwise>1!=0</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="action_token">
						<xsl:choose>
							<xsl:when test="$btn/@sandclock = 'false' or (name()='ui:action' and not($btn/@sandclock)) or (not($btn/@sandclock) and $btn/@type = 'cancel')"></xsl:when>
							<xsl:otherwise>showSandclock();</xsl:otherwise>					  
						</xsl:choose>
					</xsl:variable>
					<xsl:attribute name="onclick">
						<xsl:value-of select="$on-press-ok"/>
						<xsl:value-of select="$btn/@script"/>
						if (<xsl:value-of select="$condition_token"/>){
							<xsl:value-of select="$action_token"/>
							<xsl:choose>
								<xsl:when test="$btn/@submit-href">
									document.defaultForm.action='<xsl:value-of select="$btn/@submit-href"/>';return doSubmit();
									window.location.href='<xsl:value-of select="$btn/@submit-href"/>';return false;
								</xsl:when> 
								<xsl:otherwise>
									beforeSubmit();
								</xsl:otherwise>
							</xsl:choose>
							return true;
						}else{
							return false
						}; 
					</xsl:attribute>				
				</xsl:otherwise>
			</xsl:choose>
			<!-- /OnClick JavaScript -->
		</input></td>
		<td class="buttonRight"><img src="/{$theme}/images/1x1.gif" border="0"/></td></tr>
		</table>
		</div>
	</xsl:template>
	
  <xsl:template match="ui:action-link">
  	<xsl:variable name="href" select="@href"/>  	
		<xsl:choose>
			<xsl:when test="@disabled = 'true'">
		  	<img src="/{$theme}/icons/arr_gt.gif" width="12" height="11" border="0"/>
  			<xsl:value-of select="."/>
  		</xsl:when>
  		<xsl:otherwise>
		  	<a href="{@href}">
				<xsl:copy-of select="@target"/>
				<img src="/{$theme}/icons/arr_gt.gif" width="12" height="11" border="0"/></a>
  			<a href="{@href}">
				<xsl:copy-of select="@target"/>
				<xsl:value-of select="."/></a>
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:template>  


  <!-- javascript block -->
  <xsl:template match="ui:java-script">
	<script language="JavaScript">
	  <xsl:copy-of select="./child::node()"/>    
	</script>
  </xsl:template>  

	<!-- show bar-graph -->
	<xsl:template match="ui:meter">
		<xsl:call-template name="showMeter">
			<xsl:with-param name="mcolor" select="sw:if(@level, $scale/mark[@level = 0]/color, @mcolor)"/>
			<xsl:with-param name="f" select="@fraction"/>
			<xsl:with-param name="width" select="@width"/>			
		</xsl:call-template>
	</xsl:template>
	
	<!-- show bar-graph -->
	<xsl:template match="ui:bar">
		<xsl:if test="not( number(@fraction)=0 and @hide-zero='yes')">
			<xsl:call-template name="showBar">
				<xsl:with-param name="mcolor" select="sw:if(@level, $scale/mark[@level = 0]/color, @mcolor)" />
				<xsl:with-param name="f" select="@fraction" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<!-- display resource bar with, probably, alerts -->
	<xsl:template match="ui:resource-bar">
		<table cellpadding="0" class="none">
			<tr>
				<xsl:call-template name="ui:show-resource-bar"/>
			</tr>
		</table>
	</xsl:template>


	
  <!-- show box with alert note -->
  <xsl:template match="ui:alert">
	<table cellpadding="0" cellspacing="0" border="0">
		<xsl:call-template name="html:calc-width">
		 <xsl:with-param name="control" select="."/>
		<xsl:with-param name="error" select="'ui:buttons should be a child of ui:block or ui:browse'"/>
	  </xsl:call-template>			    
	  <tr>
		<td>
		  <fieldset class="noLegend">
			<table cellpadding="0" cellspacing="0" border="0">
			  <tr>
				<td valign="center" style="padding-right:5px"><img src="/{$theme}/icons/{sw:if(@icon,@icon,'exclamation')}_32.gif" width="32" height="32" border="0" /></td>
				<td valign="top">
				  <xsl:copy-of select="child::node()"/>
				</td>
			  </tr>
			</table>
		  </fieldset>
		</td>
	  </tr>
	</table>
	<br/>
  </xsl:template>	
  
  <xsl:template match="ui:request-status" name="ui:request-status">
	  <xsl:param name="src" select="src"/>
	  <xsl:param name="title" select="title"/>
	  
		<xsl:variable name="icon">
		  <xsl:choose>
			<xsl:when test="$src = 'OPEN'">env_state_inact</xsl:when>
			<xsl:when test="$src = 'PROCESSING'">env_state_starting</xsl:when>
			<xsl:when test="$src = 'COMPLETED'">env_state_running</xsl:when>
			<xsl:otherwise>env_stopped</xsl:otherwise>
		  </xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="tip">
		  <xsl:choose>
			<xsl:when test="$src = 'OPEN'">request_open</xsl:when>
			<xsl:when test="$src = 'PROCESSING'">request_processing</xsl:when>
			<xsl:when test="$src = 'COMPLETED'">request_completed</xsl:when>
			<xsl:otherwise>request_unknown</xsl:otherwise>
		  </xsl:choose>
		</xsl:variable>
	
		<nobr>
			<img src="/{$theme}/icons/{$icon}.gif" width="16" height="16" hspace="5" onmouseover="callTip('{$tip}',event)" onmouseout="callTip()"/>
			<xsl:value-of select="$title"/>
		</nobr>
	
  </xsl:template>
  
  <xsl:template match="ui:tree-help">
    <!-- actually needs only for help toc, maybe to move? -->

	<style type="text/css">
	.TocItemImage {
	  	width: 16px;
	  	padding:2px;
	}
	.TocItem .TocItemText {
		padding: 2px;
	}
	.TocItem .TocItemText a:link{
		color:#0F0F0F;
	}
	.TocItem .TocItemText a:visited{
		color: #800080;
	}
	.TocItem .TocItemText a:hover,
	.TocItem .TocItemText a:active{
		text-decoration: underline;
	}
	.MenuItemActive, .MenuItemActive {
		/* */
	}
	</style>
	
		<xsl:apply-templates select="." mode="menu-tree">
			<xsl:with-param name="id-supplied" select="'true'"/>
			<xsl:with-param name="section_id" select="'1'"/>
  			<xsl:with-param name="parent" select="'toc'"/>
  			<xsl:with-param name="css-prefix" select="'Toc'"/>
  			<xsl:with-param name="open-all-branches" select="@open-all-branches"/>
			<xsl:with-param name="default_target" select="sw:if(@target, @target, $def_target)"/>
			
 		</xsl:apply-templates>
		<script type="text/javascript">
		var activeElementId = '';
		var delimeter = /_/;
		var itemStr = 'item_';

		function _callTip(){
		//just a plug
		}
	
	  	function selectMenuItem(){
		//just a plug
		}

	        img_open = new Image();
	        img_close = new Image();
	        img_open.src = '/<xsl:value-of select="$theme"/>/images/open_tree.gif';
	        img_close.src = '/<xsl:value-of select="$theme"/>/images/close_tree.gif';

        			
	  		<!-- xsl:apply-templates select="." mode="menu-tree-js"/ -->
  		</script>
  </xsl:template>
	
</xsl:stylesheet>				
