<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw voc exsl vt html"
exclude-result-prefixes="voc ui html env hn units vt"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:html="http://www.swsoft.com/xsl/cp/html"
  xmlns:env     ="http://www.swsoft.com/xsl/cp/env"	
  xmlns:hn	="http://www.swsoft.com/xsl/cp/hn"
  xmlns:units="http://www.swsoft.com/xsl/cp/units"  
  xmlns:vt	="http://www.swsoft.com/xsl/cp/vt"
  >
  	
  	<sw:include href="/layout/lib/html.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>

	<!-- show task details info -->
	<xsl:template match="ui:cluster">		
		<table cellpadding="2" cellspacing="0" border="0" width="100%">
			<tr>
				<td width="70%" valign="top">
					<fieldset class="applications">
						<div class="applications">
							<xsl:call-template name="show-units">
							 	<xsl:with-param name="display-mode" select="'page'"/>
							 	<xsl:with-param name="selected-item" select="string(@selected-item)"/>
								<xsl:with-param name="units" select="ui:cluster-unit"></xsl:with-param>
							</xsl:call-template>
						</div>
					</fieldset>
				</td>
				<td width="30%" valign="top">
					<fieldset class="applications">
						<xsl:call-template name="menu"/>							
					</fieldset>
				</td>
			</tr>
			<xsl:if test="string(@selected-item) != ''">
				<script type="text/javascript">
					init();
				</script>
			</xsl:if>
		</table>
  </xsl:template>
  
	<xsl:template name="show-units">
		<xsl:param name="units"/>
		<xsl:param name="display-mode"/><!-- page / menu -->
		<xsl:param name="selected-item"/>				
		<xsl:param name="section_id"/> <!-- only for menu -->
		<xsl:param name="level" select="0"/>				
		<xsl:param name="parent"/>

		<xsl:variable name="unit-home" select="sw:if($display-mode = 'page','farm_tree','farm_list')"/>
		<xsl:variable name="env-home" select="sw:if($display-mode = 'page','unit','unit')"/>
		<xsl:variable name="hn-home" select="sw:if($display-mode = 'page','unit','unit')"/>
		<xsl:variable name="is-show-ve" select="boolean(sw:sesgetstr('menu-depth') = 'ves')"/>
		<xsl:variable name="envs" select="env:get-env($units/@env-eid)"/>

		<div>
			<xsl:if test="$display-mode = 'page'"><xsl:attribute name="class">TreeBlock</xsl:attribute></xsl:if>
			<xsl:for-each select="$units">		

				<xsl:variable name="prefix">
					<xsl:choose>
						<xsl:when test="$parent='infrastructure.units'">i</xsl:when>
						<xsl:when test="$parent='logical.units'">l</xsl:when>
						<xsl:when test="$parent='other'">b</xsl:when>
						<xsl:otherwise>a</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>

				<xsl:variable name="id">
					<xsl:choose>
						<!-- Convert item ID from symbolic form to DN -->
						<xsl:when test="@id='infrastructure' or @id='logical'">
							<xsl:value-of select="units:tree-dn(@id)"/>
						</xsl:when>
						<!-- Leave original ID -->
						<xsl:otherwise>
							<xsl:value-of select="@id"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				
				<xsl:variable name="item-id" select="$id"/>
				<xsl:variable name="index" select="position()"/>
			
				<xsl:variable name="have-children" select="sw:if(following-sibling::*[1]/@level &gt; @level, 'true', 'false')"/>
				<xsl:variable name="level-diff" select="following-sibling::*[1]/@level - @level"/>
				<xsl:variable name="full-level" select="$level + @level"/>

				<xsl:variable name="div-tag">
					<div id="{$item-id}" class="TreeBranch{sw:if(not(@open = 'true'), 'Closed', 'Open')}"/>
				</xsl:variable>

				<xsl:copy-of select="html:tag-open($div-tag)"/>

				<table cellpadding="0" cellspacing="0" border="0" width="100%" id="item-{$item-id}" class="{sw:if($display-mode = 'menu', 'MenuItem', 'TreeItem')}">
					<tr>
						<xsl:if test="$full-level &gt; 1">
							<td style="width:{($full-level - 1) * 14}px"><img src="/{$theme}/images/1x1.gif" border="0" width="{($full-level - 1) * 14}" height="16"/></td>
						</xsl:if>
						<td  style="width:16px;" align="right" class="{sw:if($display-mode = 'menu', 'MenuTreeNode', 'TreeNode')}">
							<xsl:choose>						
								<xsl:when test="substring-before(following-sibling::*[1]/@id, @id)">
									<xsl:if test="@open = 'true'">
										<img src="/{$theme}/images/close_tree.gif" style="cursor:hand;cursor:pointer" onclick="treeClick('{$item-id}')"  id="img-{$item-id}" border="0" width="16" height="16"/>
									</xsl:if>
									<xsl:if test="not(@open = 'true')">												
										<img src="/{$theme}/images/open_tree.gif" style="cusor:hand;cursor:pointer" onclick="treeClick('{$item-id}')"  id="img-{$item-id}" border="0" width="16" height="16"/>
									</xsl:if>
								</xsl:when>
								<xsl:when test="(@type = 'hn.core.vt') and $is-show-ve">
									<img src="/{$theme}/images/open_tree.gif" style="cusor:hand;cursor:pointer" 
										onclick="treeClick('{$item-id}');loadVE('{sw:base64-encode(units:dn2parent($id))}','{sw:base64-encode($item-id)}','{sw:base64-encode(@env-eid)}','{$full-level}')"  
										id="img-{$item-id}" border="0" width="16" height="16"
									/>
								</xsl:when>										
								<xsl:otherwise>
									<img src="/{$theme}/images/1x1.gif" id="img-{$item-id}"  border="0" width="16" height="16"/>
								</xsl:otherwise>
							</xsl:choose>
						</td>
						<!--..dnd.. do not change ***[space]=[space]'[data]';*** construction - is critical for dnd-->
						<xsl:variable name="onclick-js">
							cluster_unit_parent_dn = '<xsl:value-of select="sw:escape(sw:base64-encode(substring-after($id,',')))"/>';
							cluster_unit_id_plain = '<xsl:value-of select="$item-id"/>';
							cluster_unit_id = '<xsl:value-of select="sw:escape(sw:base64-encode($id))"/>';
							cluster_unit_type = '<xsl:value-of select="@type"/>';
							cluster_unit_eid = '<xsl:value-of select="sw:escape(sw:base64-encode(@env-eid))"/>';
							cluster_unit_descr = '<xsl:value-of select="sw:html-escape(sw:text(ui:description/child::node()),'escape-quote')"/>';
							cluster_dnd_id = '<xsl:value-of select="$id"/>';
							cluster_dnd_parent_dn = '<xsl:value-of select="substring-after($id,',')"/>';
							clusterSelectUnit();
						</xsl:variable>

						<xsl:variable name="plat2">
							<xsl:value-of select="env:env2platform($envs/env[eid=string(current()/@env-eid)])"/>
						</xsl:variable>
																					
						<xsl:variable name="move_type">
							<xsl:choose>
								<xsl:when test="@type = 'hn.core.vt'">
									<xsl:choose>
										<xsl:when test="$parent='logical.units'">logical.hn.vz.vt</xsl:when>
										<xsl:otherwise>hn.vz.vt</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:when test="@type = 'env.core.vt'">logical.ve.vz.vt</xsl:when>
								<xsl:when test="@type = 'unit'">
									<xsl:choose>
										<xsl:when test="$parent='infrastructure.units'">unit.infrasctructure.farm</xsl:when>
										<xsl:when test="$parent='logical.units'">unit.logical.farm</xsl:when>
										<xsl:when test="$parent='other'">other</xsl:when>
									</xsl:choose>
								</xsl:when>
							</xsl:choose>
						</xsl:variable>

						<xsl:variable name="oncontext">
							<xsl:choose>
								<xsl:when test="@type = 'hn.core.vt'">
									<xsl:choose>
										<xsl:when test="vt:is-platform-windows($plat2)">windows.left.hn.vz.vt</xsl:when>
										<xsl:otherwise>linux.left.hn.vz.vt</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:when test="@type = 'env.core.vt'">
									<xsl:choose>
										<xsl:when test="vt:is-platform-windows($plat2)">windows.ve.vz.vt</xsl:when>
										<xsl:otherwise>linux.ve.vz.vt</xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:when test="@type = 'unit'">
									<xsl:choose>
										<xsl:when test="$parent='infrastructure.units'">unit.vz.vt</xsl:when>
										<xsl:when test="$parent='logical.units'">logical.vz.vt</xsl:when>
										<xsl:otherwise></xsl:otherwise>
									</xsl:choose>
								</xsl:when>
								<xsl:otherwise></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>

						<td id="icon_{$index}"  class="{sw:if($display-mode = 'menu', 'MenuItemImage', 'TreeItemImage')}">
							<a href="#" id="{$prefix}_image_{$index}"
								name="drag_get"
								onmouseover="mRM=1"
								onmouseout="mRM=0"
							>
								<xsl:if test="$oncontext!=''">
									<xsl:attribute name="oncontextmenu">rML('<xsl:value-of select="$oncontext"/>','<xsl:value-of select="@id"/>','')</xsl:attribute>
								</xsl:if>
								<xsl:attribute name="onmousedown">
									moveDIV('<xsl:value-of select="$prefix"/>_title_','<xsl:value-of select="$prefix"/>_img_title_','<xsl:value-of select="$index"/>',event,'64:<xsl:value-of select="sw:base64-encode($onclick-js)"/>','@::<xsl:value-of select="$move_type"/>@::<xsl:value-of select="$plat2"/>@::<xsl:value-of select="@env-eid"/>')
								</xsl:attribute>
								<img src="/{$theme}/icons/{@icon}" id="{$prefix}_img_title_{$index}" onmouseover="customTitle('{$prefix}_img_title_{$index}','vz_hn_ve_tab')" border="0" width="16" height="16"/>
							</a>
						</td>
						<!-- Show Title -->
						<td nowrap="nowrap" id="title_{$index}" class="{sw:if($display-mode = 'menu', 'MenuItemText', 'TreeItemText')}">
							<a href="#" id="{$prefix}_title_{$index}"
								name="drag_get"
								onmouseover="mRM=1;customTitle('{$prefix}_title_{$index}','vz_hn_ve_tab')"
								onmouseout="mRM=0"
							>
								<xsl:if test="$oncontext!=''">
									<xsl:attribute name="oncontextmenu">rML('<xsl:value-of select="$oncontext"/>','<xsl:value-of select="@id"/>','')</xsl:attribute>
								</xsl:if>
								<xsl:attribute name="onmousedown">
									moveDIV('<xsl:value-of select="$prefix"/>_title_','<xsl:value-of select="$prefix"/>_img_title_','<xsl:value-of select="$index"/>',event,'64:<xsl:value-of select="sw:base64-encode($onclick-js)"/>','@::<xsl:value-of select="$move_type"/>@::<xsl:value-of select="$plat2"/>@::<xsl:value-of select="@env-eid"/>@::root-<xsl:value-of select="$item-id"/>')
								</xsl:attribute>
								<xsl:value-of select="@title"/>
							</a>
							<xsl:variable name="alert_icon" select="$envs/env[eid=string(current()/@env-eid)]/alert"/>
							<span id="{$prefix}_{$index}_alert_{@env-eid}">
								<span>
								<xsl:if test="@env-eid">
									<xsl:choose>
										<xsl:when test="$alert_icon = 3"><img src="/{$theme}/icons/alert_red_left_16.gif" border="0" width="16" height="16"/></xsl:when>
										<xsl:when test="$alert_icon = 2"><img src="/{$theme}/icons/alert_red_left_16.gif" border="0" width="16" height="16"/></xsl:when>
										<xsl:when test="$alert_icon = 1"><img src="/{$theme}/icons/alert_yellow_left_16.gif" border="0" width="16" height="16"/></xsl:when>
									</xsl:choose>
								</xsl:if>
								</span>
								<div class="hidden"><xsl:value-of select="@env-state"/></div>
							</span>
						</td>
						<!-- /Show Title -->
					</tr>
				</table>
				<xsl:if test="@type = 'hn.core.vt'">
					<div id="dynamic_clock_{sw:base64-encode($item-id)}">
						<img src="/{$theme}/images/1x1.gif" border="0" width="{($full-level + 1)* 14}" height="16"/><img width="16" id="loading_indicator_{$item-id}" border="0" height="16" src="/{$theme}/icons/indicator.gif"/>&#160;<sw:text>Loading</sw:text>&#160;
						<input type="hidden" name="on_demand_{sw:base64-encode($item-id)}" id="on_demand_{sw:base64-encode($item-id)}" value="0"/>
					</div>
					<div id="dynamic_units_{sw:base64-encode($item-id)}" style="color:#444444; display:none">
						<table cellspacing="0" cellpadding="0" border="0">
						<tr><td valign="top">
						<img src="/{$theme}/images/1x1.gif" border="0" width="{($full-level + 1)* 14}" height="16"/><img width="16" border="0" height="16" src="/{$theme}/icons/alert_red_left_16.gif"/>&#160;</td><td><sw:text>Failed to get a list of Containers.</sw:text>&#160;
						</td></tr></table>
					</div>					
				</xsl:if>
				<xsl:choose>
					<xsl:when test="$level-diff &gt; 0"><!-- do nothing --></xsl:when>
					<xsl:when test="$level-diff &lt; 1">
						<xsl:call-template name="close-div">
							<xsl:with-param name="div-tag" select="$div-tag"/>
							<xsl:with-param name="div-count" select="$level-diff"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:when test="position() = last()">
						<!-- finish -->
						<xsl:call-template name="close-div">
							<xsl:with-param name="div-tag" select="$div-tag"/>
							<xsl:with-param name="div-count" select="1 - @level"/>
						</xsl:call-template>					
					</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</div>				
		<script type="text/javascript">		
		img_open = new Image();
		img_close = new Image();
		img_open.src = '/<xsl:value-of select="$theme"/>/images/open_tree.gif';
		img_close.src = '/<xsl:value-of select="$theme"/>/images/close_tree.gif';	
		var cluster_baseurl='<xsl:value-of select="$baseurl"/>';
		var cluster_mode='<xsl:value-of select="$display-mode"/>';
		var menu_section = '<xsl:value-of select="$section_id"/>';
		var unit_home = '<xsl:value-of select="$unit-home"/>';
		var env_home = '<xsl:value-of select="$env-home"/>';
		var hn_home = '<xsl:value-of select="$hn-home"/>';

		var cluster_prev_unit_id_plain='';
		var cluster_prev_unit_type='';
		var cluster_unit_parent_dn='';
		var cluster_unit_id_plain=0;
		var cluster_unit_id='';
		var cluster_unit_type='';
		var cluster_unit_eid='';
		var cluster_unit_descr='';
		
		<![CDATA[
			function clusterSelectUnit(){
				var menu_info = document.getElementById('menu_info');
				var actions_id = '';
				var actions = null;
				var info = '';
				var item_table = null;
				var item_el_id = 'item-'+cluster_unit_id_plain;
					
				actions_id = 	'actions_' + cluster_unit_type;				
				
				<!-- Update description -->
				info = info + cluster_unit_descr;
			
				]]>
				if(cluster_mode=='menu'){
					parent.menu.showSelectedItem(item_el_id);

					if(cluster_unit_type=='unit' || cluster_unit_type=='rootunit'){
						parent.main.location.href=cluster_baseurl+'/farmdir/unitman/units/index?id='+cluster_unit_id;
					}else if(cluster_unit_type=='hn.core.vt'){
						parent.main.location.href=cluster_baseurl+'/vt/hns/hn?context=unit&amp;id='+cluster_unit_eid+'&amp;parent-dn='+cluster_unit_parent_dn;
					}else if(cluster_unit_type=='env.core.vt'){
						parent.main.location.href=cluster_baseurl+'/vzdir/infrman/envs/env?context=unit&amp;id='+cluster_unit_eid+'&amp;parent-dn='+cluster_unit_parent_dn;
					}else{						
					}
				}
				<![CDATA[
				if(cluster_mode=='page'){
					<!-- Deselect prev. actions -->
					if(cluster_prev_unit_type!='' && cluster_prev_unit_type!=cluster_unit_type){
						actions=document.getElementById('actions_' + cluster_prev_unit_type);					
						actions.style.display='none';
					}
					if(cluster_prev_unit_id_plain){
						item_table = document.getElementById('item-'+cluster_prev_unit_id_plain);
						item_table.className='TreeItem';
					}
					<!-- /Deselect prev. actions -->
					
					<!-- Update actions menu -->
					if(actions_id != ''){
						item_table = document.getElementById(item_el_id);
						item_table.className='TreeItemActive';
						
						menu_info.innerHTML = info;
						
						document.getElementById('actions_caption').style.display='block';
						
						if(cluster_prev_unit_type!=cluster_unit_type){
							actions=document.getElementById(actions_id);					
							actions.style.display='block';
						}
					}
					<!-- /Update actions menu -->
				}
				
				cluster_prev_unit_id_plain = cluster_unit_id_plain;
				cluster_prev_unit_type = cluster_unit_type;
			}
			<!-- Unit Actions -->
			function clusterUnitAddChilds(){				
				document.defaultForm.action = cluster_baseurl+'/farmdir/unitman/units/add?parent='+cluster_unit_id;
				document.defaultForm.submit();
			}
			function clusterUnitManage(){				
				document.defaultForm.action = cluster_baseurl+'/farmdir/unitman/units/unit?id='+cluster_unit_id;
				document.defaultForm.submit();
			}
			function clusterVZEnvManage(){
				document.defaultForm.action = cluster_baseurl+'/vzdir/infrman/envs/env?branch=env-home,'+env_home+'&amp;id='+cluster_unit_eid;
				document.defaultForm.submit();
			}
			function clusterVZEnvStart(){
				document.defaultForm.action = cluster_baseurl+'/vzdir/infrman/envs/ctl?start_ve=1&id='+cluster_unit_eid;
				alert(document.defaultForm.action);
				document.defaultForm.submit();
			}
			function clusterVZEnvStop(){
				document.defaultForm.action = cluster_baseurl+'/vzdir/infrman/envs/ctl?stop_ve=1&id='+cluster_unit_eid;
				document.defaultForm.submit();
			}
			function clusterVZHNManage(){
				document.defaultForm.action = cluster_baseurl+'/vt/hns/hn?branch=vz-hn-home,'+hn_home+'&id='+cluster_unit_eid;
				document.defaultForm.submit();
			}
			function clusterRemove(){				
				]]>
				if(!confirm('<sw:text>Are you sure you want to remove this item?</sw:text>')){
						return false;
				}
				<![CDATA[
				document.defaultForm.action = cluster_baseurl+'/farmdir/unitman/units/remove?unit-id='+cluster_unit_id+'&amp;unit-type='+cluster_unit_type;
				document.defaultForm.submit();
			}
			<!-- /Unit Actions -->
			]]>
			
		
			<xsl:if test="$selected-item!=''">
				<xsl:variable name="s-position" select="count($units[@id = $selected-item]/preceding-sibling::*) + 1"/>

				function init(){
					initTree('<xsl:value-of select="$selected-item"/>');

					cluster_unit_id_plain = '<xsl:value-of select="$units[position() = $s-position]/@id"/>';
					cluster_unit_id = '<xsl:value-of select="sw:base64-encode($units[position() = $s-position]/@id)"/>';
					cluster_unit_type = '<xsl:value-of select="$units[position() = $s-position]/@type"/>';
					cluster_unit_eid = '<xsl:value-of select="sw:base64-encode($units[position() = $s-position]/@env-eid)"/>';
					cluster_unit_descr = '<xsl:value-of select="sw:html-escape(sw:text($units[position() = $s-position]/ui:description/child::node()),'escape-quote')"/>';
					clusterSelectUnit();return false;					
					
				}
			</xsl:if>
		</script>		
	</xsl:template>
	
	<xsl:template name="menu">		
		<div style="padding:5px; line-height:150%">			
			<!-- Info -->
			<div style="font-weight: bold;">
				<sw:text>Item Details</sw:text>
			</div>
			<div id="menu_info">
				<div style="">
					<sw:text>No item selected</sw:text>
				</div>
			</div>
			<!-- Actions -->
			<div id="actions_caption" style="font-weight: bold;display:none;">
				<br/>				
				<sw:text>Item Actions</sw:text>				
			</div>
			<!-- Root Unit -->			
			<div id="actions_rootunit" style="display:none;">
				<!-- add childs -->
				<a href="/" onclick="clusterUnitAddChilds();return false;"><img
					 src="/{$theme}/icons/add.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterUnitAddChilds();return false;">Add Items</a>
				<br/>
				<!-- modify unit -->
				<a href="/" onclick="clusterUnitManage();return false;"><img
					 src="/{$theme}/icons/fm_props_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterUnitManage();return false;">Modify</a>
				<br/>					
			</div>
			<!-- /Root Unit -->
			<!-- Unit -->			
			<div id="actions_unit" style="display:none;">
				<!-- add childs -->
				<a href="/" onclick="clusterUnitAddChilds();return false;"><img
					 src="/{$theme}/icons/add.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterUnitAddChilds();return false;">Add Items</a>
				<br/>
				<!-- modify unit -->
				<a href="/" onclick="clusterUnitManage();return false;"><img
					 src="/{$theme}/icons/fm_props_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterUnitManage();return false;">Modify</a>
				<br/>			
				<!-- delete unit -->
				<a href="/" onclick="clusterRemove();return false;"><img
					 src="/{$theme}/icons/delete_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterRemove();return false;">Delete</a>
				<br/>							
			</div>
			<!-- /Unit -->
			<!-- VZ HN -->			
			<div id="actions_vzhn" style="display:none;">			
				<!-- manage hn -->
				<a href="/" onclick="clusterVZHNManage();return false;"><img
					 src="/{$theme}/icons/fm_props_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterVZHNManage();return false;">Manage</a>
				<br/>			
				<!-- remove hn -->
				<a href="/" onclick="clusterRemove();return false;"><img
					 src="/{$theme}/icons/delete_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterRemove();return false;">Remove</a>
				<br/>							
			</div>
			<!-- VZ ENV -->			
			<div id="actions_vzenv" style="display:none;">			
				<!-- manage env -->
				<a href="/" onclick="clusterVZEnvManage();return false;"><img
					 src="/{$theme}/icons/fm_props_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterVZEnvManage();return false;">Manage</a>
				<br/>			
				<!-- remove env -->
				<a href="/" onclick="clusterRemove();return false;"><img
					 src="/{$theme}/icons/delete_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterRemove();return false;">Remove</a>
				<br/>
				<!-- /remove env -->
				<br/>
				<!-- start env -->
				<a href="/" onclick="clusterVZEnvStart();return false;"><img
					 src="/{$theme}/icons/env_start_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterVZEnvStart();return false;">Start</a>
				<br/>
				<!-- /start env -->
				<!-- stop env -->
				<a href="/" onclick="clusterVZEnvStop();return false;"><img
					 src="/{$theme}/icons/env_stop_16.gif" width="16" height="16"
				/></a>&#160;
				<a href="/" onclick="clusterVZEnvStop();return false;">Stop</a>
				<br/>
				<!-- /stop env -->
			</div>
			<!-- /Unit -->
		</div>
	</xsl:template>
	
	<xsl:template name="close-div">
		<xsl:param name="div-tag"/>
		<xsl:param name="div-count"/>

		<xsl:copy-of select="html:tag-close($div-tag)"/>
		<xsl:if test="$div-count &lt; 0">
			<xsl:call-template name="close-div">
				<xsl:with-param name="div-tag" select="$div-tag"/>
				<xsl:with-param name="div-count" select="$div-count + 1"/>
			</xsl:call-template>	
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
