<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw voc exsl local html env"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
  xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:html="http://www.swsoft.com/xsl/cp/html"    	
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
>

	<sw:include href="/layout/lib/html.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/> 
	<sw:include href="/lib/cred-filter.xsl"/>

	<xsl:template match="ui:dashboard-compact">
		<table  cellpadding="0" cellspacing="0" border="0" class="dashboardCompact"> 
			<tr>
				<xsl:variable name="tr-tag"><tr/></xsl:variable>
				<xsl:for-each select="ui:dashboard-item">
				
					<xsl:variable name="disabled" select="
						@check-op-obj and not(
							voc:check-current-object-operation(
								@check-op-obj,@check-op-operator,@check-op-cmd,@check-op-subcmd
							)
						)
					"/>										
				
				
					<td width="250" valign="top" class="dashboardItem">
						<fieldset>
							<legend><xsl:value-of select="@title"/>&#160;</legend>
							<table border="0" cellpadding="0" cellspacing="0">
								<tr>
									<td valign="top">
										<img src="/{$theme}/icons/{@icon}_32.gif" class="icon32"/>
									</td>
									<td valign="top">
										<xsl:for-each select="ui:action-link">
										
											<xsl:choose>
												<xsl:when test="$disabled">
													<span class="disabledLink"><xsl:value-of select="sw:text(string(.))"/></span>
												</xsl:when>
												<xsl:otherwise>
													<nobr>
														<a href="{@href}" class="q4">
															<xsl:copy-of select="@target"/>
															<img src="/{$theme}/images/alink.gif" class="q0"/>
															<font class="q5"><xsl:value-of select="sw:text(string(.))"/></font>
														</a>
													</nobr>                
												</xsl:otherwise>
											</xsl:choose>
											<xsl:if test="position() != last()"><br/></xsl:if>
										</xsl:for-each>
									</td>
								</tr>
							</table>
						</fieldset>
					</td>
					<xsl:if test="not(position() mod 2)">
						<xsl:copy-of select="html:tag-close($tr-tag)"/>
						<xsl:copy-of select="html:tag-open($tr-tag)"/>
					</xsl:if>
				</xsl:for-each>
			</tr>
		</table>
	</xsl:template>

<xsl:template match="ui:summary-row">
	<table width="100%" cellpadding="0" cellspacing="0" border="0"> 
 		<tr>
			<xsl:variable name="cell-with" select="100 div (count(ui:summary-block) + count(ui:summary-placeholder))"/>
			<xsl:for-each select="ui:summary-block">
				<td width="{$cell-with}%" valign="top">
					<xsl:apply-templates select="."/>
				</td>
				<xsl:if test="position() != last()">
					<td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>
				</xsl:if>
			</xsl:for-each>
			<xsl:for-each select="ui:summary-placeholder">
				<td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>
				<td width="{$cell-with}%"><img src="/{$theme}/images/1x1.gif" width="1" height="1"/></td>
			</xsl:for-each>
		</tr>
	</table>
</xsl:template>

<xsl:template match="ui:summary-cols">
	<table width="100%" cellpadding="0" cellspacing="0" border="0"> 
 		<tr>
			<xsl:variable name="col-with" select="100 div (count(ui:summary-col) + count(ui:summary-placeholder))"/>
			<xsl:for-each select="ui:summary-col">
				<td width="{$col-with}%" valign="top">
					<xsl:apply-templates select="."/>
				</td>
				<xsl:if test="position() != last()">
					<td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>
				</xsl:if>
			</xsl:for-each>
			<xsl:for-each select="ui:summary-placeholder">
				<td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>
				<td width="{$cell-with}%"><img src="/{$theme}/images/1x1.gif" width="1" height="1"/></td>
			</xsl:for-each>
		</tr>
	</table>
</xsl:template>
  
<xsl:template match="ui:summary-col">
	<xsl:apply-templates select="ui:summary-block"/>
</xsl:template>
  
  
<xsl:template match="ui:summary-block">
	<div class="summaryBlock">
		<xsl:if test="@width">
			<xsl:attribute name="style">width:<xsl:call-template
				 name="html:calc-width">
					<xsl:with-param name="control" select="."/>
					<xsl:with-param name="as-text" select="'1'"/>
				</xsl:call-template>
			</xsl:attribute>
		</xsl:if>
		<xsl:if test="@title">
			<table cellpadding="0" cellspacing="0" border="0" width="100%" class="summaryTitle">
				<tr>
					<td class="qE">
						<b><xsl:value-of select="@title"/></b>
					</td>
				</tr>
			</table>
		</xsl:if>
		<div class="summaryContent">
			<xsl:choose>
				<xsl:when test="ui:tally">
					<table cellpadding="0" cellspacing="0" border="0" width="100%">
						<tr>  		
				  			<xsl:apply-templates select="ui:tally"/>
				  			<xsl:apply-templates select="ui:action-links"/>		  			
						</tr>
					</table>
				</xsl:when>
				<xsl:when test="ui:table"><xsl:apply-templates select="ui:table"/></xsl:when>
				<xsl:otherwise><xsl:apply-templates select="*"/></xsl:otherwise>
			</xsl:choose>
			<xsl:if test="ui:summary-bottomlink">
				<div style="margin:1px 5px 5px 5px; border-top:1px solid #91A7B4; padding-top:3px">
					<xsl:for-each select="ui:summary-bottomlink">
						<span style="padding-right:5px;">
							<xsl:if test="@icon">
								<a href="{@href}">
									<xsl:choose>
										<xsl:when test="contains(@icon,'.')">
											<img src="/{$theme}/icons/{@icon}" hspace="5"/>
										</xsl:when>
										<xsl:otherwise>
											<img src="/{$theme}/icons/{@icon}_16.gif" hspace="5"/>	
										</xsl:otherwise>
									</xsl:choose>
								</a>
							</xsl:if>
							<xsl:if test="@title">
								<a href="{@href}" style="font-weight:normal"><xsl:value-of select="@title"/></a>
							</xsl:if>
						</span>
					</xsl:for-each>
				</div>
			</xsl:if>
		</div>
	</div>
</xsl:template>

<xsl:template match="ui:summary-generic">
	<table cellpadding="0" cellspacing="0" border="0" width="100%">
		<xsl:variable name="is-icon" select="sw:if(item/@icon, true(), false())"/>
		<xsl:variable name="is-action-links" select="sw:if(item/action-link, true(), false())"/>
		<xsl:variable name="is-wrap" select="item/@wrap"/>
		<xsl:variable name="label-width" select="sw:if(@label-width,@label-width,'180')"/>
		<xsl:variable name="action-width" select="sw:if(@action-width,@action-width,'120')"/>	
		<xsl:for-each select="item">
			<tr>
				<xsl:if test="@group='true'">
					<xsl:attribute name="class">sOddRow</xsl:attribute>
				</xsl:if>

			<xsl:choose>
				<!--content group 2 td-->
				<xsl:when test="content">
					<td colspan="3" width="{sw:if(item/action-link, '67%', '50%')}">
						<xsl:choose>
							<xsl:when test="content/ui:*"><xsl:apply-templates select="content/*"/></xsl:when>
							<xsl:otherwise><xsl:copy-of select="content/child::node()"/></xsl:otherwise>
						</xsl:choose>
					</td>
				</xsl:when>
				
				<!--label, icon and value tds-->
				<xsl:otherwise>
				<td nowrap="nowrap"  width="{$label-width}">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="@group='true'">label q1</xsl:when>
							<xsl:when test="@hicon">q1</xsl:when>
							<xsl:when test="last() = 1">qG label</xsl:when>
							<xsl:when test="position() = 1">q7 label</xsl:when>
							<xsl:when test="position() = last()">q8 label</xsl:when>
							<xsl:otherwise>q9 label</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:if test="@hicon">
						<xsl:choose>
							<xsl:when test="contains(@hicon,'.')">
								<img class="q6" src="/{$theme}/icons/{@hicon}"/>
							</xsl:when>
							<xsl:when test="@hicon='empty'">
								<img class="q1" src="/{$theme}/images/1x1.gif"/>
							</xsl:when>
							<xsl:otherwise>
								<img class="q6" src="/{$theme}/icons/{@hicon}_16.gif"/>	
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
					<xsl:value-of select="@label"/>
					<xsl:if test="@lines">
						<xsl:call-template name="local:line-breaks">
							<xsl:with-param name="lines" select="@lines"/>
						</xsl:call-template>
					</xsl:if>
				</td>
				<td width="16" valign="top">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="last() = 1">qG_</xsl:when>
							<xsl:when test="position() = 1">q7_</xsl:when>
							<xsl:when test="position() = last()">q8_</xsl:when>
							<xsl:otherwise>q9_</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>				
					<span>
						<xsl:if test="@icon-id">
							<xsl:attribute name="id"><xsl:value-of select="@icon-id"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="$is-icon = 'true'">
							<xsl:if test="@icon">
								<xsl:choose>
									<xsl:when test="contains(@icon,'.')">
										<img class="q6" src="/{$theme}/icons/{@icon}"/>
									</xsl:when>
									<xsl:otherwise>
										<img class="q6" src="/{$theme}/icons/{@icon}_16.gif"/>	
									</xsl:otherwise>
								</xsl:choose>
							</xsl:if>
							<xsl:if test="not(@icon)">
								<img class="q6" src="/{$theme}/images/1x1.gif"/>
							</xsl:if>
						</xsl:if>				
					</span>
				</td>
				<td>
					<xsl:if test="@value-width">
						<xsl:attribute name="width"><xsl:value-of select="@value-width"/></xsl:attribute>
					</xsl:if>				
					<xsl:if test="@id">
						<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
					</xsl:if>
					<xsl:choose>
						<xsl:when test="$is-wrap=true()"></xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="nowrap">nowrap</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="last() = 1">qG_</xsl:when>
							<xsl:when test="position() = 1">q7_</xsl:when>
							<xsl:when test="position() = last()">q8_</xsl:when>
							<xsl:otherwise>q9_</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:choose>
						<xsl:when test="value/ui:*"><xsl:apply-templates select="value/*"/></xsl:when>
						<xsl:otherwise><xsl:copy-of select="value/child::node()"/></xsl:otherwise>
					</xsl:choose>
				</td>
				</xsl:otherwise>
			</xsl:choose>

				<xsl:if test="$is-action-links = 'true'">
					<td nowrap="nowrap" width="{$action-width}">
						<xsl:attribute name="class">
							<xsl:choose>
								<xsl:when test="position() = 1">actionLink q7</xsl:when>
								<xsl:when test="position() = last()">actionLink q8</xsl:when>
								<xsl:otherwise>actionLink q9</xsl:otherwise>
							</xsl:choose>
						</xsl:attribute>
						<xsl:choose>
							<xsl:when test="action-link">
								<xsl:choose>
									<xsl:when test="action-link[@disabled='true']">
										<span class="disabledLink">
											<img src="/{$theme}/images/alink.gif" class="q0"/>
											<xsl:value-of select="action-link"/>
										</span>
									</xsl:when>
									<xsl:otherwise>
										<a href="{action-link/@href}" class="q4">
											<img src="/{$theme}/images/alink.gif" class="q0"/>
											<font class="q5"><xsl:value-of select="action-link"/></font>
										</a>
									</xsl:otherwise>
								</xsl:choose>
					  		</xsl:when>
					  		<xsl:otherwise>&#160;</xsl:otherwise>
						</xsl:choose>
					</td>
				</xsl:if>
			</tr>
		</xsl:for-each>	
	</table>
</xsl:template>

<xsl:template name="local:line-breaks">
	<xsl:param name="$lines"/>
	
	<xsl:if test="$lines &gt; 0">
		<br/>
		<xsl:call-template name="local:line-breaks">
			<xsl:with-param name="lines" select="$lines -1"/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>


	<xsl:template match="ui:summary-tasks">
	
		<xsl:variable name="folder-type" select="@folder-type"/>	

		<!-- Prepare Screen ID -->
		<xsl:variable name="screen-id" select="$screen-root/ui:screen/@id"/>

		<!-- Load dashboards -->
		<xsl:variable name="dashboards" select="cred:filter-items(
			sw:document($dashboard-file, $dashboard-source)/dashboards/dashboard[@type='tasks' and @screen-id = $screen-id]
		)"/>	
		
				
		<!-- Show every dashboard -->
		<xsl:variable name="tr-tag"><tr/></xsl:variable>
		<xsl:for-each select="$dashboards[item]">

			<xsl:variable name="reset-paths" select="@reset-paths='true'"/>

			<table width="100%" cellpadding="0" cellspacing="0">
				<xsl:if test="@name">
					<tr class="sOddRow">
						<td colspan="3" class="label q1">
							<xsl:value-of select="sw:text(@name)"/>
						</td>
					</tr>
				</xsl:if>
				<tr>
					<td>
					<div class="q2">
					<table width="100%" border="0"><tr>

						<xsl:for-each select="item[contains($folder-type,@folder-type) or not(@folder-type)]">
						
							<xsl:variable name="disabled" select="
								@check-op-obj and not(
									voc:check-current-object-operation(
										@check-op-obj,@check-op-operator,@check-op-cmd,@check-op-subcmd
									)
								)
							"/>
												
						
							<xsl:variable name="href"><xsl:call-template name="href"><xsl:with-param name="reset-paths" select="$reset-paths"/></xsl:call-template></xsl:variable>
							<xsl:variable name="button-id">
								<xsl:if test="@check-op-obj!='' and @check-op-operator!='' and @check-op-cmd!=''"><xsl:value-of select="@check-op-obj"/>|<xsl:value-of select="@check-op-operator"/>|<xsl:value-of select="@check-op-cmd"/></xsl:if>
							</xsl:variable>
							<td width="33%" nowrap="nowrap">
								<xsl:variable name="onclick">
									<xsl:if test="@confirmation">if (!confirm('<sw:text select="@confirmation"/>')) return false;</xsl:if>
								</xsl:variable>
								<a>
									<xsl:if test="not($disabled)"><xsl:attribute name="style">display:none</xsl:attribute></xsl:if>
									<xsl:if test="$button-id!=''"><xsl:attribute name="name"><xsl:value-of select="$button-id"/>_off</xsl:attribute></xsl:if>
									<xsl:variable name="icon-disabled">
										<xsl:choose>
											<xsl:when test="contains(@icon,'_16')"><xsl:value-of select="substring-before(@icon,'_16')"/>_disabled_16</xsl:when>
											<xsl:otherwise><xsl:value-of select="@icon"/>_disabled</xsl:otherwise>
										</xsl:choose>
									</xsl:variable>
									<img src="/{$theme}/icons/{$icon-disabled}.gif" class="q3"/>
									<span class="disabledLink"><sw:text select="string(text)"/></span>
								</a>
								<a class="q4">
									<xsl:if test="@confirmation">
										<xsl:attribute name="onclick"><xsl:value-of select="$onclick"/></xsl:attribute>
									</xsl:if>								
									<xsl:if test="$disabled"><xsl:attribute name="style">display:none</xsl:attribute></xsl:if>
									<xsl:if test="$button-id!=''"><xsl:attribute name="name"><xsl:value-of select="$button-id"/>_on</xsl:attribute></xsl:if>
									<xsl:copy-of select="@target"/>
									<xsl:attribute name="href">
									<xsl:choose>
										<xsl:when test="@oneclick='true'">javascript:top_open_href(0,'<xsl:value-of select="$href"/>','','true','')</xsl:when>
										<xsl:otherwise><xsl:value-of select="$href"/></xsl:otherwise>
									</xsl:choose>
									</xsl:attribute>
									<img src="/{$theme}/icons/{@icon}.gif" class="q3"/>
									<span class="q5"><sw:text select="string(text)"/></span>
								</a>
							</td>
							<xsl:if test="not(position() mod 3)">
								<xsl:copy-of select="html:tag-close($tr-tag)"/>
								<xsl:copy-of select="html:tag-open($tr-tag)"/>
							</xsl:if>		
						</xsl:for-each>
						<xsl:if test="(count(item) mod 3)">
							<td width="33%">&#160;</td>
							<xsl:if test="(count(item)+1) mod 3">
								<td width="33%">&#160;</td>
							</xsl:if>
						</xsl:if>						
					</tr></table>
					</div>									
					</td>
				</tr>
			</table>
		</xsl:for-each>
	</xsl:template>

<xsl:template match="ui:tally">
	<td style="padding:10px 8px 3px 8px;" valign="top" width="{100 div count(../ui:tally)}%">
		<table cellpadding="2" cellspacing="0"  width="100%" style="border-bottom:{sw:if(ui:tally-row,'1px solid #91A7B4','none')}">
			<tr>
				<td width="{sw:if(ui:tally-row, 100, 50)}%"><!-- bad hardcode here, find a better way! -->
					<span class="label"><xsl:value-of select="@title"/></span>
				</td>
  				<xsl:if test="ui:tally-sum/@icon">
					<td width="16">
						<img src="/{$theme}/icons/{ui:tally-sum/@icon}_16.gif"/>
					</td>
				</xsl:if>
				<xsl:if test="ui:tally-sum">
					<xsl:if test="ui:tally-row">
						<td align="right" nowrap="nowrap">
							<sw:text>Total:</sw:text>
						</td>
					</xsl:if>
					<td align="right">
	 					<xsl:choose>
							<xsl:when test="ui:tally-sum/@href and ui:tally-sum/.!='0'">
								<a href="{ui:tally-sum/@href}"><xsl:value-of select="ui:tally-sum"/></a>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="ui:tally-sum"/>
							</xsl:otherwise>	
	  					</xsl:choose>
					</td>
					<xsl:if test="not(ui:tally-row)">
						<td width="50%">
							<img src="/{$theme}/images/1x1.gif" width="1" height="1" border="0"/>
						</td>
					</xsl:if>
				</xsl:if>
				<xsl:if test="not(ui:tally-sum)">
					<td>&#160;</td>
				</xsl:if>
			</tr>
		</table>
		<xsl:if test="ui:tally-row">
	  		<table cellpadding="0" cellspacing="1" width="100%" style="margin-top:4px;">
	  			<xsl:for-each select="ui:tally-row">
		  			<tr>
		  				<td width="16">
		  					<xsl:if test="@icon">
			  					<img class="q6" src="/{$theme}/icons/{@icon}_16.gif"/>
		  					</xsl:if>
		  				</td>
		  				<td width="100%">
		  					<xsl:if test="not(@wrap = true())">
		  						<xsl:attribute name="nowrap">1</xsl:attribute>
		  					</xsl:if>
		  					<xsl:value-of select="@title"/>
		  				</td>
		  				<td align="right" valign="top">
		  					<xsl:choose>
			  					<xsl:when test="@href and .!='0'">
			  						<a href="{@href}"><xsl:value-of select="."/></a>
			  					</xsl:when>
				  				<xsl:otherwise>
					  				<xsl:value-of select="."/>
				  				</xsl:otherwise>
				  			</xsl:choose>
		  				</td>
	  				</tr>
	  			</xsl:for-each>
			</table>
		</xsl:if>
	</td>
	<xsl:if test="position() != last()">
		<td>
			<img src="/{$theme}/images/1x1.gif" width="1" height="1"/>
		</td>
	</xsl:if>  
</xsl:template>

<xsl:template match="ui:table">
	<table cellpadding="0" cellspacing="0" border="0" width="100%" class="sTable">
		<tr>
			<xsl:variable name="col-width" select="concat(100 div count(col-header),'%')"/>
			<xsl:for-each select="col-header">
				<th width="{sw:if(@width, @width, $col-width)}" align="{@align}">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="position() != last() and not(@border)">qA label</xsl:when>
							<xsl:otherwise>qB label</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:copy-of select="./child::node()"/>
				</th>
			</xsl:for-each>
		</tr>
		<xsl:for-each select="row">
			<tr class="{sw:if(position() mod 2,'sEvenRow','sOddRow')}">
				<xsl:for-each select="col">
					<xsl:variable name="pos" select="position()"/>
					<td nowrap="nowrap" align="{../../col-header[position() = $pos]/@align}">
					<xsl:if test="@id">
						<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
					</xsl:if>
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="position() != last() and not(@border)">qA</xsl:when>
							<xsl:otherwise>qB</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
						<xsl:if test="@icon">
							<img src="/{$theme}/icons/{@icon}_16.gif" class="qC"/>
						</xsl:if>
						<xsl:if test="ui:*"><xsl:apply-templates select="*"/></xsl:if>
						<xsl:if test="not(ui:*)"><xsl:copy-of select="node()"/></xsl:if>
						  
						<!-- xsl:copy-of select="./child::node()"/ -->
					</td>
				</xsl:for-each>
			</tr>
		</xsl:for-each>
	</table>	
</xsl:template>

<xsl:template match="ui:simple-table">
	<div>
		<xsl:if test="not(@no-padding='true')">
			<xsl:attribute name="style">padding:5px</xsl:attribute>
		</xsl:if>
		<table cellpadding="0" cellspacing="0" border="0" width="100%">
			<xsl:for-each select="row">
				<tr style="height:20px;{@style}">
					<xsl:if test="@class">
						<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
					</xsl:if>
					<xsl:for-each select="col">
						<td nowrap="nowrap" style="padding-left:3px;{@style}">
							<xsl:copy-of select="@*[name() != 'style']"/>
							<xsl:if test="ui:*"><xsl:apply-templates select="*"/></xsl:if>
							<xsl:if test="not(ui:*)">
								<xsl:copy-of select="node()"/>
							</xsl:if>
						</td>
					</xsl:for-each>
				</tr>
			</xsl:for-each>
		</table>
	</div>
</xsl:template>

<xsl:template match="ui:meter-blockBefore">
		<xsl:if test="@before">
			<xsl:value-of select="@before"/>
		</xsl:if>
</xsl:template>

<xsl:template match="ui:meter-blockAfter">
		<xsl:value-of select="@after"/>
</xsl:template>

<xsl:template match="ui:meter-blockMeter">
 		<xsl:call-template name="showMeter">
					<xsl:with-param name="alert" select="sw:if(@alert, @alert, '0')"/>
					<xsl:with-param name="f" select="sw:if(@fraction &gt; 1,1,@fraction)"/>
		</xsl:call-template>
</xsl:template>

<xsl:template match="ui:meter-block">
	<table border="0" cellpadding="0" cellspacing="0" width="170">
		<tr>
			<xsl:if test="@before">
				<td width="50%" nowrap="nowrap" align="right"><xsl:value-of select="@before"/></td>
			</xsl:if>
			<td class="qD">
				<xsl:call-template name="showMeter">
					<xsl:with-param name="alert" select="sw:if(@alert, @alert, '0')"/>
					<xsl:with-param name="f" select="sw:if(@fraction &gt; 1,1,@fraction)"/>
				</xsl:call-template>
			</td>
			<td align="left" width="{sw:if(@before,'50','100')}%" nowrap="nowrap"><xsl:value-of select="@after"/></td>
		</tr>
	</table>	
</xsl:template>
  
  <xsl:template match="ui:action-links">
  	<td width="165" class="actionLink" style="padding:10px; width:155px" valign="top">
  		<xsl:for-each select="ui:action-link">
  			<div class="alink" style="clear:both;padding-bottom:2px;">
	  			<a href="{@href}">
					<xsl:copy-of select="@target"/>
					<img src="/{$theme}/images/alink.gif" hspace="2"/></a>
  				<a href="{@href}">
					<xsl:copy-of select="@target"/>
					<xsl:value-of select="."/></a>  		
  			</div>
  		</xsl:for-each>
  		<img src="/{$theme}/images/1x1.gif" width="165" height="1" border="0"/>
  	</td>
  </xsl:template>	

</xsl:stylesheet>
