<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw voc exsl"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:exsl="http://exslt.org/common"
    xmlns:sw="http://www.swsoft.com/xsl/cp"
    xmlns:ui="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
  >
  <sw:include href="../lib/vt/env-core.xsl"/>
	<sw:include href="../lib/vocabulary.xsl"/>
	<xsl:variable name="operations" select="voc:get('operations', env:make-platform-ref(sw:local-hn-eid()))|sw:document('operations.xml')/operations/operation"/>

  <!-- transform vzagent Operation to better presentation -->
  <xsl:template match="task-op" name="task-op">
    <xsl:variable name="opid" select="string(.)"/>
    <xsl:variable name="p" select="$operations[id = $opid]"/>
		<xsl:variable name="desc" select="string(sw:if($p, $p/short, .))"/>
		<!-- first try to translate operation with vzagent-vocabulary translation matrix -->
		<xsl:variable name="vza-desc" select="sw:text($desc, 'vzagent-vocabulary')"/>
		<!-- if it fails use vzcp translation of fallback to original string -->
		<xsl:copy-of select="sw:if($vza-desc = $desc, sw:text($desc), $vza-desc)"/>
  </xsl:template>

	<!-- show task status -->
  <xsl:template match="task-status" name="task-status">
    <nobr>
      <xsl:choose>
        <xsl:when test=". = 1"><img onmouseover="callTip('task_started_icon',event)" onmouseout="callTip()" src="/{$theme}/icons/indicator.gif" class="qC"/><sw:text>Started</sw:text></xsl:when>
        <xsl:when test=". = 2"><img onmouseover="callTip('task_inprogress_icon',event)" onmouseout="callTip()" src="/{$theme}/icons/indicator.gif" class="qC"/><sw:text>In Progress</sw:text></xsl:when>
        <xsl:when test=". = 3"><img onmouseover="callTip('task_success_icon',event)" onmouseout="callTip()" src="/{$theme}/icons/state_completed.gif" class="qC"/><sw:text>Completed</sw:text></xsl:when>
        <xsl:when test=". = 4"><img onmouseover="callTip('task_failed_icon',event)" onmouseout="callTip()" src="/{$theme}/icons/state_failed.gif" class="qC"/><sw:text>Failed</sw:text></xsl:when>
        <xsl:otherwise><sw:text>Unknown</sw:text>(<xsl:value-of select="."/>)</xsl:otherwise>
      </xsl:choose>
    </nobr>
  </xsl:template>
  
	<!-- show task details info -->
	<xsl:template match="task-details">
		<xsl:variable name="popup-id" select="concat('tasks_list_',$ticketid)"/>
		<nobr>
			<a href="#none" class="q4" onmouseover="callTip('open_details',event)" onmouseout="callTip()" onclick="open_details('{$baseurl}/core/tasks/details-popup?id={../id}'),'{$popup-id}'">
				<img src="/{$theme}/icons/file_16.gif" class="qC"/>
				<font class="q5"><sw:text>Details</sw:text></font>
			</a>
		</nobr>
	</xsl:template>
  
  <!-- 
    show VEs assotiated with task
    required ../task-info-xml 
  -->
  <xsl:template match="task-ve">
  
    <xsl:variable name="envs" select="sw:node-set(../task-info-xml, true())/packet/message"/>
    <xsl:call-template name="ui:envs-by-message">
      <xsl:with-param name="envs" select="
        $envs/parameter[name = 'env'][parameter[name='type']/message != sw:base64-encode('generic')]"/>
    </xsl:call-template>

    </xsl:template> 
     
  <!-- 
    show HNs assotiated with task
    required ../task-info-xml 
  -->
  <xsl:template match="task-hn">
    <xsl:variable name="envs" select="sw:node-set(../task-info-xml, true())/packet/message"/>
    <xsl:call-template name="ui:envs-by-message">
      <xsl:with-param name="envs" select="
        $envs/parameter[name = 'env'][parameter[name='type']/message = sw:base64-encode('generic')]
        |
        $envs/parameter[name = 'source_env']"/>
    </xsl:call-template>
    
  </xsl:template> 
   
  <sw:include href="../lib/vocabulary.xsl"/>

</xsl:stylesheet>
