<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl html local"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:html="http://www.swsoft.com/xsl/cp/html"
  xmlns:local="http://www.swsoft.com/xsl/cp/local"
>

	<xsl:template match="ui:tree-selector" mode="plesk">
		<xsl:call-template name="local:tree-selector">
			<xsl:with-param name="mode" select="'plesk'"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="ui:tree-selector" mode="vzcp">
		<xsl:call-template name="local:tree-selector">
			<xsl:with-param name="mode" select="'vzcp'"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="ui:tree" mode="plesk">
		<xsl:call-template name="local:tree">
			<xsl:with-param name="mode" select="'plesk'"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template match="ui:tree" mode="vzcp">
		<xsl:call-template name="local:tree">
			<xsl:with-param name="mode" select="'vzcp'"/>
		</xsl:call-template>
	</xsl:template>
	
  <xsl:template name="local:tree-selector">
  	<xsl:param name="mode"/>
  	
  	<xsl:variable name="nodes-selected" select="ui:nodes-selected"/>
  	<xsl:variable name="nodes" select="ui:nodes"/>
  	<xsl:variable name="control-id" select="@id"/>
  	
  	<xsl:variable name="table-width">
  		<xsl:call-template name="html:calc-width">
				<xsl:with-param name="control" select="."/>
				<xsl:with-param name="as-text" select="true()"/>
			</xsl:call-template>
		</xsl:variable>

  	<xsl:variable name="selected-rtf">
  		<xsl:for-each select="$nodes/ui:node">
  			<xsl:call-template name="local:calc-nodes-sub">
  				<xsl:with-param name="node" select="." />
  				<xsl:with-param name="nodes-selected" select="$nodes-selected" />
  				<xsl:with-param name="parent-id" select="'/'" />
  			</xsl:call-template>
  		</xsl:for-each>
  	</xsl:variable>
  	
  	<xsl:variable name="selected" select="exsl:node-set($selected-rtf)" />
  	
  	<xsl:call-template name="local:show-nodes-sub">
 			<xsl:with-param name="nodes" select="$nodes/ui:node"/>
 			<xsl:with-param name="nodes-selected" select="$selected"/>
 			<xsl:with-param name="control-id" select="$control-id"/>
 			<xsl:with-param name="deep" select="number(0)"/>
 			<xsl:with-param name="open-depth" select="sw:if(number(@open-depth)!='NaN', @open-depth, -1)"/>
			<xsl:with-param name="parent-id" select="'/'"/>   			
			<xsl:with-param name="table-width" select="$table-width"/>
 		</xsl:call-template>
 		
 		<script type="text/javascript">

			//--- create speedup arrays;
			var img_path_array = new Array();
			var img_path_array_obj = new Array();
			var img_path_array_sub = new Array();
			var img_path_array_hdp = new Array();
			
			var o=document.getElementsByName('update_check');
			for(var i=0;i&lt;o.length;i++){
				img_path_array.push(o[i].id);
				img_path_array_obj.push(o[i]);
				var child_id = o[i].id.substr(4,o[i].id.length-1);
				img_path_array_sub.push(child_id);
				img_path_array_hdp.push(document.getElementById('hidden_'+child_id));
			}
			
			function switchNode(id,new_state){
			
				var div = document.getElementById('div_'+id);
				var img = document.getElementById('img_'+id);
				var hidden = document.getElementById('hidden_'+id);
				var arg_new_state = new_state;
				
				var path='/<xsl:value-of select="$theme"/>/icons/';
				var new_state;
				var new_img;
				var new_tip;
				
				var curr_state = img.src.indexOf('_not.gif')>-1?'off':'on';
				
				// Some pre-operations
				if(new_state==''){
					// switch state
					new_state=curr_state=='off'?'on':'off';
				}
				if(new_state=='custom'){
					// check childs
					new_state=checkChilds(id);
					//alert(new_state);
				}
				// @Some pre-operations
				
				if(new_state=='on'){
					new_img='selected_yes.gif';
				}
				if(new_state=='off'){
					new_img='selected_not.gif';
				}
				if(new_state=='custom'){
					new_img='selected_part.gif';
				}

				hidden.value = new_state!='off'?id:'';
				var path_new_img = path+new_img;
				img.src=path_new_img;
				
				// We need to switch all childs to new self status
				if(arg_new_state==''){
					var id_full = 'img_'+id + '/';
					var pass_state = new_state!='off';
					for(var i=0;i &lt; img_path_array.length; i++){
						if(img_path_array[i].indexOf(id_full)==0){
							img_path_array_obj[i].src = path_new_img;
							img_path_array_hdp[i].value = pass_state?img_path_array_sub[i]:'';
						}
					}
				}
				
				// We need to switch parent to custom state
				{
					var parent_id = calcParent(id);
					if(parent_id!=''){
						switchNode(parent_id,'custom');
					}
				}
				
			
			}

			function checkMaster(id, masterId) {
				var div = document.getElementById('div_'+id);
				var img = document.getElementById('img_'+id);
				var hidden = document.getElementById('hidden_'+id);
				var curr_state = img.src.indexOf('_not.gif')>-1?'off':'on';
				
				if (curr_state != 'off') {
					var imgM = document.getElementById('img_'+masterId);
					var curr_stateM = imgM.src.indexOf('_not.gif')>-1?'off':'on';
					
					if (curr_stateM == 'off') {
						switchNode(masterId, '');
					}
				}
			}
			
			function uncheckMaster(id, parentId) {
				var div = document.getElementById('div_'+id);
				var img = document.getElementById('img_'+id);
				var hidden = document.getElementById('hidden_'+id);
				var curr_state = img.src.indexOf('_not.gif')>-1?'off':'on';
				
				if (curr_state == 'off') {
					var imgM = document.getElementById('img_'+parentId);
					var curr_stateM = imgM.src.indexOf('_not.gif')>-1?'off':'on';
					
					if (curr_stateM != 'off') {
						switchNode(parentId, '');
					}
				}
			}
			
			function checkChilds(id){
				var id_full = 'img_'+id + '/';
				var count_all=0;
				var count_on=0;
				var count_off=0;
				var count_custom=0;
				//
				for(var i=0; i&lt; img_path_array.length; i++){
					if(img_path_array[i].indexOf(id_full)==0){
						count_all++;
						if(img_path_array_obj[i].src.indexOf('_not.gif')>-1){
							count_off++;
						}else{
							if(img_path_array_obj[i].src.indexOf('_yes.gif')>-1){
								count_on++;
							}else{
								count_custom++;
							}
						}
					}
				}
				//
				//alert('id='+id+' custom='+count_custom+' count_off='+count_off+' count_on='+count_on);
				
				// custom state
				if(count_custom!=0 || (count_off!=0 &amp;&amp; count_on!=0)){
					return 'custom';
				}
				// all childs OFF
				if(count_on==0){
					return  'off';
				}
				
				// all childs ON
				return 'on';
			}
			
			function calcParent(id){
				ids = id.split('/');
				if(ids.length==2){
					return '';
				}
				var parent_id='';
				for(i=0;i&lt;(ids.length-1);i++){
					parent_id = (i!=0?(parent_id+'/'):'')+ids[i];
				}
				return parent_id;
			}

			function switchBlock(id,new_state){
			
				var div = document.getElementById('div_'+id);
				var img = document.getElementById('imgb_'+id);
				
				if(!img){
					return;
				}
				
				var path='/<xsl:value-of select="$theme"/>/images/';
				var new_img;
				var new_tip;
				
				if( new_state=='open' || img.src.indexOf('open_tree.gif')>-1){
					// open
					if(new_state=='open' || new_state==''){
						new_img='close_tree.gif';
						new_tip='';
						div.style.display='block';
					}
				}
				if(new_state=='close' || img.src.indexOf('close_tree.gif')>-1){
					// close
					if(new_state=='close' || new_state==''){
						new_img='open_tree.gif';
						div.style.display='none';
						new_tip='';
					}
				}
				
				img.src=path+new_img;
				img.onmouseover="callTip('"+new_tip+"',event)";
			}
		</script>
		
  </xsl:template>

  <xsl:template name="local:calc-nodes-sub">
  	<xsl:param name="node" />
  	<xsl:param name="nodes-selected" />
  	<xsl:param name="parent-id" />

  	<xsl:variable name="id" select="concat($parent-id, $node/ui:id)" />

  	<xsl:choose>
  		<xsl:when test="$nodes-selected/ui:node[ui:id=$id]">
  			<xsl:choose>
  				<xsl:when test="$node/ui:node">
  					<xsl:variable name="selected-rtf">
  						<xsl:for-each select="$node/ui:node">
  							<xsl:call-template name="local:calc-nodes-sub">
  								<xsl:with-param name="node" select="." />
  								<xsl:with-param name="nodes-selected" select="$nodes-selected" />
  								<xsl:with-param name="parent-id" select="concat($id, '/')" />
  							</xsl:call-template>
  						</xsl:for-each>
  					</xsl:variable>
  					<xsl:variable name="children" select="exsl:node-set($selected-rtf)/*" />
  					<xsl:variable name="count" select="count($children)" />

  					<xsl:choose>
  						<xsl:when test="$count=0">
  							<on id="{$id}" />
  						</xsl:when>
  						<xsl:otherwise>
  							<xsl:copy-of select="$children" />
  							<xsl:choose>
  								<xsl:when
  									test="count($children[name()='off'])=$count or count($children[name()='on'])=$count">
  									<on id="{$id}" />
  								</xsl:when>
  								<xsl:otherwise>
  									<custom id="{$id}" />
  								</xsl:otherwise>
  							</xsl:choose>
  						</xsl:otherwise>
  					</xsl:choose>
  				</xsl:when>
  				<xsl:otherwise>
  					<on id="{$id}" />
  				</xsl:otherwise>
  			</xsl:choose>
  		</xsl:when>
  		<xsl:otherwise>
  			<off id="{$id}" />
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:template>

  <xsl:template name="local:show-nodes-sub">
		<xsl:param name="nodes"/>
		<xsl:param name="nodes-selected"/>
		<xsl:param name="control-id"/>
		<xsl:param name="deep"/>
		<xsl:param name="parent-id"/>
		<xsl:param name="table-width"/>
		<xsl:param name="open-depth" select="0"/>
		
		
		<xsl:variable name="opened" select="$deep &lt; $open-depth + 1" />

		<!-- there must be only one -->
		<xsl:variable name="master" select="($nodes[@master='true']/ui:id)[1]" />
		<xsl:variable name="master-id" select="sw:if($master, concat($parent-id, $master), '')" />
		<xsl:variable name="parent-node-id" select="substring($parent-id, 1, string-length($parent-id) - 1)" />
		
		
		<xsl:for-each select="$nodes">
			<xsl:variable name="id" select="concat($parent-id,ui:id)"/>
			<xsl:variable name="state" select="sw:if($nodes-selected/*[@id=$id], name($nodes-selected/*[@id=$id]), 'off')"/>
			
			<xsl:variable name="icon">
				<xsl:choose>
					<xsl:when test="$state='on'">selected_yes.gif</xsl:when>
					<xsl:when test="$state='off'">selected_not.gif</xsl:when>
					<xsl:when test="$state='custom'">selected_part.gif</xsl:when>
				</xsl:choose>
			</xsl:variable>
			
			<input type="hidden" id="hidden_{$id}" name="{$control-id}">
				<xsl:if test="$state!='off'">
					<xsl:attribute name="value"><xsl:value-of select="$id"/></xsl:attribute>
				</xsl:if>
			</input>
			<table cellpadding="2" cellspacing="0" border="0">
				<xsl:attribute name="width"><xsl:value-of select="$table-width"/></xsl:attribute>
				<tr>
					<td>
						<!-- Show Level Offset -->
						<xsl:if test="$deep!=0">
							<img src="/{$theme}/images/1x1.gif" width="{$deep * 13}" height="1"/>
						</xsl:if>
					</td>
					<td valign="top">
						<xsl:if test="ui:node">
							<a style="cursor:hand; cursor:pointer" onclick="switchBlock('{$id}','')"><img id="imgb_{$id}" src="/{$theme}/images/{sw:if($opened,'close','open')}_tree.gif" width="16" height="16" style="vertical-align:middle; margin-left: 2px; margin-bottom:2px" onmouseover="callTip('{sw:text('Click here to expand or close sub-items.')}',event)" onmouseout="callTip('')"/></a>
						</xsl:if>
						<xsl:if test="not(ui:node)">
							<img id="imgb_{$id}" src="/{$theme}/images/1x1.gif" width="16" height="16" style="vertical-align:middle; margin-left: 2px; margin-bottom:2px" />
						</xsl:if>					
					</td>
					<xsl:variable name="switch">switchNode('<xsl:value-of select="$id"/>','')<xsl:choose>
							<xsl:when test="$master!='' and not(@master)">||checkMaster('<xsl:value-of select="$id"/>','<xsl:value-of select="$master-id"/>')</xsl:when>
							<xsl:when test="$master!='' and @master">||uncheckMaster('<xsl:value-of select="$id"/>','<xsl:value-of select="$parent-node-id"/>')</xsl:when>
						</xsl:choose></xsl:variable>
					<td valign="top">
						<!-- Show status Icon -->
						<a style="cursor:hand; cursor:pointer" onclick="{$switch}"><img name="update_check" id="img_{$id}" onmouseover="callTip('{sw:text('Click here to enable or disable this item.')}',event)" onmouseout="callTip('')" src="/{$theme}/icons/{$icon}" width="15" height="15"/></a>
					</td>
					<td width="100%">
						<!-- Show description -->
						<a style="cursor:hand; cursor:pointer; text-decoration: none;color:#000000;">
							<!-- Show tool tip -->
							<xsl:if test="ui:tip-text">
								<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="ui:tip-text"/>',event)</xsl:attribute>
								<xsl:attribute name="onmouseout">callTip('')</xsl:attribute>
							</xsl:if>
							<!-- /Show tool tip -->
							<xsl:choose>
								<!-- Open/Close Childs -->
								<xsl:when test="ui:node">
									<xsl:attribute name="onclick">switchBlock('<xsl:value-of select="$id"/>','')</xsl:attribute>
								</xsl:when>
								<!-- Switch Childs -->
								<xsl:otherwise>
									<xsl:attribute name="onclick"><xsl:value-of select="$switch" /></xsl:attribute>
								</xsl:otherwise>
								<!-- /Switch Childs -->
							</xsl:choose>
							<xsl:apply-templates select="ui:title/node()"/>
						</a>
					</td>
		  </tr>
		</table>
		
		<xsl:if test="ui:node">
			<div id="div_{$id}">
				<xsl:if test="not($opened)">
					<xsl:attribute name="style">display:none;</xsl:attribute>
				</xsl:if>
			  <xsl:call-template name="local:show-nodes-sub">
		   			<xsl:with-param name="nodes" select="ui:node"/>
		   			<xsl:with-param name="nodes-selected" select="$nodes-selected"/>
		   			<xsl:with-param name="control-id" select="$control-id"/>
		   			<xsl:with-param name="deep" select="$deep + 1"/>
		   			<xsl:with-param name="parent-id" select="concat($id,'/')"/>
		   			<xsl:with-param name="table-width" select="$table-width"/>
		   			<xsl:with-param name="open-depth" select="$open-depth"/>
		   		</xsl:call-template>
	   		</div>
	   	</xsl:if>
		</xsl:for-each>
		
	</xsl:template>


  <xsl:template name="local:tree">
  	<xsl:param name="mode" />

  	<xsl:variable name="nodes" select="ui:nodes" />

  	<xsl:variable name="table-width">
  		<xsl:call-template name="html:calc-width">
  			<xsl:with-param name="control" select="." />
  			<xsl:with-param name="as-text" select="true()" />
  		</xsl:call-template>
  	</xsl:variable>

  	<xsl:call-template name="local:show-tree-nodes-sub">
  		<xsl:with-param name="nodes" select="$nodes/ui:node" />
  		<xsl:with-param name="deep" select="number(0)" />
  		<xsl:with-param name="table-width" select="$table-width" />
  	</xsl:call-template>

  	<xsl:call-template name="local:switcher-script" />


  </xsl:template>

  <xsl:template name="local:show-tree-nodes-sub">
		<xsl:param name="nodes"/>
		<xsl:param name="deep"/>
		<xsl:param name="table-width"/>
		
		<xsl:for-each select="$nodes">
			<xsl:variable name="uid" select="sw:generate-id()" />
			<xsl:variable name="id" select="concat(sw:if(ui:id, ui:id, 'id'), '_', $uid)" />
			<xsl:variable name="img-id" select="concat('img_', $uid)" />
			
			<table cellpadding="2" cellspacing="0" border="0">
				<xsl:attribute name="width"><xsl:value-of select="$table-width"/></xsl:attribute>
				<tr>
					<td>
						<!-- Show Level Offset -->
						<xsl:if test="$deep!=0">
							<img src="/{$theme}/images/1x1.gif" width="{$deep * 13}" height="1"/>
						</xsl:if>
					</td>
					<xsl:variable name="switch">switchBlockLocal('<xsl:value-of select="$id"/>','<xsl:value-of select="$img-id"/>')</xsl:variable>
					<td valign="top">
						<xsl:choose>
							<xsl:when test="ui:node">
								<a style="cursor:hand; cursor:pointer" onclick="{$switch}"><img id="{$img-id}" src="/{$theme}/icons/arr_gt.gif" width="12" height="11" style="vertical-align:middle; margin-left: 2px;margin-top:2px; margin-bottom:2px" onmouseover="callTip('{sw:text('Click here to expand or close sub-items.')}',event)" onmouseout="callTip('')"/></a>
							</xsl:when>
							<xsl:otherwise>
								<img src="/{$theme}/images/1x1.gif" width="13" height="1"/>
							</xsl:otherwise>
						</xsl:choose>
					</td>
					<td width="100%">
						<!-- Show description -->
						<xsl:choose>
							<!-- check for <ui:title nohref="yes"> -->
							<xsl:when test="ui:title/@nohref">
								<xsl:apply-templates select="ui:title/node()"/>
							</xsl:when>
							<xsl:otherwise>
								<a style="cursor:hand; cursor:pointer; text-decoration: none;color:#000000;" onclick="{$switch}">
								<!-- Show tool tip -->
									<xsl:if test="ui:tip-text">
										<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="ui:tip-text"/>',event)</xsl:attribute>
										<xsl:attribute name="onmouseout">callTip('')</xsl:attribute>
									</xsl:if>
									<!-- /Show tool tip -->
									<xsl:apply-templates select="ui:title/node()"/>
								</a>
							</xsl:otherwise>
						</xsl:choose>
					</td>
		 	 	</tr>
			</table>
		
			<xsl:if test="ui:node">
				<div id="{$id}">
					<xsl:choose>
						<xsl:when test="not(@collapsed) or @collapsed='true'">
							<xsl:attribute name="style">display:none;</xsl:attribute>
						</xsl:when>
					</xsl:choose>
				  <xsl:call-template name="local:show-tree-nodes-sub">
			   			<xsl:with-param name="nodes" select="ui:node"/>
			   			<xsl:with-param name="deep" select="$deep + 1"/>
			   			<xsl:with-param name="table-width" select="$table-width"/>
			   		</xsl:call-template>
		   		</div>
		   	</xsl:if>
		</xsl:for-each>
	</xsl:template>
  
  
  	<xsl:template name="local:switcher-script">
		<script language="JavaScript">
			function switchBlockLocal(blockId, imgId){		
				s = document.getElementById(blockId);
				o = document.getElementById(imgId);
				if(s.style.display=='none'){
					s.style.display='block';
					o.src="<xsl:value-of select="concat('/',$theme,'/icons/arr_opened.gif')"/>";
				}else{
					s.style.display='none';
					o.src="<xsl:value-of select="concat('/',$theme,'/icons/arr_gt.gif')"/>";
				}				
				return false;
			}				
		</script>
	</xsl:template>
  
</xsl:stylesheet>
