<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl path vem cred env local format func"
	exclude-result-prefixes="ui str vem html func path cred env vt local user date ve hn format"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"  
  xmlns:str		="http://exslt.org/strings"
  xmlns:vem		="http://www.swsoft.com/xsl/cp/vem"  
  xmlns:html	="http://www.swsoft.com/xsl/cp/html"
  xmlns:func	="http://exslt.org/functions"
  xmlns:path	="http://www.swsoft.com/xsl/cp/path"  
  xmlns:cred	="http://www.swsoft.com/xsl/cp/cred" 
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
  xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
  xmlns:local		="http://www.swsoft.com/xsl/cp/local"
  xmlns:user	="http://www.swsoft.com/xsl/cp/user"
  xmlns:date	="http://exslt.org/dates-and-times"
	xmlns:ve		="http://www.swsoft.com/xsl/cp/ve"
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"	
	xmlns:global	="http://www.swsoft.com/xsl/cp/global" 		
  >
  
  <sw:include href="lib/env.xsl"/>

  <sw:include href="../lib/vt/env-core.xsl"/>
  <sw:include href="../lib/vt/ve-core.xsl"/>
  <sw:include href="../lib/vt/hn-core.xsl"/>  
  <sw:include href="../lib/cred.xsl"/>
	<sw:include href="../lib/core/user-attrs.xsl"/>  
 	<sw:include href="/lib/utils/format-datetime.xsl"/>
 	<sw:include href="/lib/utils/format-resusage.xsl"/>
	
	<!-- bar-graphs in list CPU, Disk, Memory -->
	<xsl:template match="env-disk|env-memory|env-cpu"> 					
		<xsl:variable name="proc" select="."/>
		<xsl:variable name="pshow" select="format-number($proc, '0')"/>
		<xsl:call-template name="showMeter">
			<xsl:with-param name="mcolor" select="1"/>
			<xsl:with-param name="f" select="round($proc div 10) div 10"/>
		</xsl:call-template>
		<xsl:value-of select="concat(' ',$pshow,'%')"/>
	</xsl:template> 
	
	
	<xsl:template match="license-date|ui:license-date">
		<xsl:choose>
			<xsl:when test=".='unlimited' or .=''">
				<nobr><sw:text>Never</sw:text></nobr>
			</xsl:when>
			<xsl:otherwise>
				<nobr><xsl:value-of select="format:date-time(sw:vzatime2utime(.))"/></nobr>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
	
	<xsl:template match="license-expiration|ui:license-expiration">
		<xsl:variable name="status" select="sw:if(@status,@status,../status)"/>
		<xsl:choose>
			<xsl:when test=".='unlimited' or .=''">
				<nobr><sw:text>Never</sw:text></nobr>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="res">
					<nobr><xsl:value-of select="format:date-time(sw:vzatime2utime(.))"/></nobr>
				</xsl:variable>		
				<xsl:choose>
					<xsl:when test="$status='EXPIRED'">
						<strike>
							<xsl:copy-of select="$res"/>
						</strike>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$res"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
	
	<xsl:template match="license-class|ui:license-class">
		<xsl:variable name="status-option" select="../../../ui:cols/ui:column[@id='license-class']/ui:filter-option[@value=current()]"/>
		<nobr>
			<xsl:value-of select="sw:if($status-option,$status-option/@title,.)"/>
		</nobr>
	</xsl:template>	
	
	<xsl:template match="license-status|ui:license-status">
		<xsl:variable name="status-option" select="../../../ui:cols/ui:column[@id='license-status']/ui:filter-option[@value=current()]"/>
		<xsl:variable name="icon" select="sw:if(@icon,@icon,$status-option/@icon)"/>
		<nobr>
			<img src="/{$theme}/icons/{$icon}" border="0" width="16" height="16"/>&#160;<xsl:value-of select="sw:if(@icon,.,$status-option/@title)"/>
		</nobr>
	</xsl:template>	
	
	<xsl:template match="job-next-start|ui:job-next-start">
		<xsl:choose>
			<xsl:when test=".!=''">
				<xsl:choose>
					<!-- Coming from Form -->
					<xsl:when test="name()='ui:job-next-start'">
						<xsl:value-of select="format:date-time(sw:vzatime2utime(sw:time2vzatime(.)))"/>
					</xsl:when>
					<!-- Coming from Browse -->
					<xsl:otherwise>
						<xsl:value-of select="format:date-time(sw:vzatime2utime(.))"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="sw:text('n/a')"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	
	<xsl:template match="job-category|ui:job-category">
		<xsl:variable name="info" select="local:find-field-info(.,'job-category',.)"/>	
		<xsl:choose>
			<xsl:when test="$info">
				<xsl:value-of select="$info/@title"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:text>
					<xsl:with-param name="category" select="."/>
					Uknown category "%category"
				</sw:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
	
	<xsl:template match="job-category-icon|ui:job-category-icon">
		<xsl:variable name="info" select="local:find-field-info(.,'job-category',.)"/>	
		<xsl:variable name="icon">
			<xsl:choose>
				<xsl:when test="$info">
					<xsl:value-of select="$info/@icon"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'task_16.gif'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<img src="/{$theme}/icons/{$icon}" border="0" width="16" height="16"/>
	</xsl:template>
	
	<xsl:template match="job-enabled">
		<img src="/{$theme}/icons/{sw:if(. = 1, 'green','grey')}_16.gif" border="0" width="16" height="16" onmouseover="callTip('{sw:if(. = 1, 'job_enabled','job_disabled')}',event)" onmouseout="callTip()"/>		
	</xsl:template>
	
	<func:function name="local:find-field-info">
		<xsl:param name="tree"/>
		<xsl:param name="field-id"/>
		<xsl:param name="field-value"/>
		
		<xsl:variable name="browse-cols" select="$tree/../../../ui:cols"/>
		
		<xsl:choose>
			<xsl:when test="$browse-cols">
				<func:result select="$browse-cols/ui:column[@id=$field-id]/ui:filter-option[@value=$field-value]"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="options" select="//ui:data-options"/>
				<xsl:choose>
					<xsl:when test="$options">
						<func:result select="$options[@id=$field-id]/ui:filter-option[@value=$field-value]"/>
					</xsl:when>
					<xsl:otherwise>
						<sw:die>
							No description for field-id '<xsl:value-of select="$field-id"/>' and field-value '<xsl:value-of select="$field-value"/>'
						</sw:die>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	<xsl:template match="hn-vt-type">		
		<xsl:variable name="class" select="$global:classes/class[@super-type='hn.vt' and vt-vza-type=current()]"/> 
		<xsl:variable name="vt-icon">
			<xsl:choose>
				<xsl:when test="$class">
					<xsl:value-of select="$class/vt-icon"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$global:classes/class[@vzcp-type='hn.core.vt']/vt-icon"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<img src="/{$theme}/icons/{$vt-icon}_16.gif" border="0" width="16" height="16"/>
	</xsl:template>
	
	<xsl:template match="ve-vt-type">
		<xsl:variable name="vt-icon"
			select="$global:classes/class[@super-type='ve.vt' and @vza-type=current()]/vt-icon"
		/>
		<img src="/{$theme}/icons/{$vt-icon}_16.gif" border="0" width="16" height="16"/>
	</xsl:template>
	
	
	<xsl:template match="vt-type">
		<!-- TODO: Globalize this! -->
		<xsl:variable name="vt-icon">
			<xsl:choose>
				<xsl:when test=". = 'virtuozzo'">vz</xsl:when>
				<xsl:when test=". = 'vmware'">vmware</xsl:when>
				<xsl:when test=". = 'xen'">xen</xsl:when>
				<xsl:otherwise>
					<xsl:text>unknown</xsl:text>
					<xsl:message>Unknown Virtualization Technology: <xsl:value-of select="."/></xsl:message>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<img src="/{$theme}/icons/platform_{$vt-icon}_16.gif" border="0" width="16" height="16"/>
	</xsl:template>
	
	<xsl:template match="platform-os|ui:platform-os">
		<!-- TODO: Globalize this! -->
		<xsl:variable name="os-icon">
			<xsl:choose>
				<xsl:when test="starts-with(sw:lc(.),'linux')">/icons/os_lin_16</xsl:when>
				<xsl:when test="starts-with(sw:lc(.),'windows')">/icons/os_win_16</xsl:when>
				<xsl:otherwise>/images/1x1</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<img src="/{$theme}{$os-icon}.gif" border="0" width="16" height="16"/>	
	</xsl:template>
	
	<xsl:template match="icon"> 		
		<img src="/{$theme}/icons/{.}" border="0" width="16" height="16"/>
	</xsl:template> 

	<xsl:template match="role-default"> 		
		<xsl:choose>
			<xsl:when test=".='1'">
				<sw:text>Built-in</sw:text>
			</xsl:when>
			<xsl:otherwise>
				<sw:text>User-defined</sw:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template> 
	
	<!-- display item id with, probably, (default) notion -->
	<xsl:template match="sample-name"> 
		<xsl:copy-of select="."/> 
		<xsl:if test="../ui:row/sample-name/@default">	(<b><sw:text>default</sw:text></b>)</xsl:if>
	</xsl:template> 
	
	<!-- display item id with, probably, (default) notion -->
	<xsl:template match="backup-ve-title"> 
		<xsl:copy-of select="."/> 
		<xsl:if test="../ui:row/sample-name/@default">	(<sw:text>deleted</sw:text>)</xsl:if>
	</xsl:template> 
	
	
	<xsl:template match="ve-backup-type|ui:ve-backup-type">
		<xsl:variable name="info" select="local:find-field-info(.,'ve-backup-type',.)"/>	
		<xsl:choose>
			<xsl:when test="$info">
				<xsl:value-of select="$info/@title"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:text>
					<xsl:with-param name="type" select="."/>
					Unknown type: %type
				</sw:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
	
	<!-- Display Application Name -->
	<xsl:template match="app-name"> 	
		<xsl:value-of select="."/>	
		<xsl:if test="@default">	(<b><sw:text>default</sw:text></b>)</xsl:if>
	</xsl:template>
	
	<xsl:template match="template-name"> 	
		<nobr><xsl:value-of select="sw:app-id2title(., ../template-version)"/></nobr>
	</xsl:template>
	
	<xsl:template match="installed">
		<xsl:variable name="cookies" select="../../../ui:cookies" />
		<xsl:choose>
			<xsl:when test="$cookies/row/env/eid=string(.)">
				<sw:text>Yes</sw:text>
			</xsl:when>
			<xsl:otherwise>
				<sw:text>No</sw:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Display VE Sample Name&Description. VE dashboard uses it -->
	<xsl:template match="ve-tmpl-name"> 
		<xsl:copy-of select="."/> 
		<br/>
		<xsl:choose>
			<xsl:when  test="../ui:row/comment!=''">
				<span class="inactive"><xsl:value-of select="/ui:row/comment"/></span>
			</xsl:when>
			<xsl:otherwise>
				<span class="inactive">description n/a</span>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	  
	<!-- display os-template -->
  <xsl:template match="os_template"> 
    <xsl:value-of select="sw:if(substring-after(., '/')!='',.,substring-before(., '/'))"/>
  </xsl:template> 

	<!-- display ve-template, usin in velist -->
  <xsl:template match="ve-template"> 
  	<xsl:choose>
  		<xsl:when test=".!=''">
  			<xsl:copy-of select="."/>
  			<xsl:if test="../ve-customized='1'">
					<span class="inactive" onmouseover="callTip('ve_customized',event)" onmouseout="callTip('')"><sw:text>*</sw:text></span>
				</xsl:if>
  		</xsl:when>
  		<xsl:otherwise>
  			
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:template> 

	<!-- 
		show vzenv "Enabled" column cell 
		p.s. vzpp-enabled should contain "disabled", so it will showing as inversed
	-->
  <xsl:template match="ve-enabled">
    <xsl:variable name="icon">
      <xsl:choose>
        <xsl:when test=". = 0">green</xsl:when>
        <xsl:when test=". = ''">green</xsl:when>
        <xsl:otherwise>grey</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="tip">
      <xsl:choose>
        <xsl:when test=". = 0">ve_enabled</xsl:when>
        <xsl:when test=". = ''">ve_enabled</xsl:when>
        <xsl:otherwise>ve_disabled</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <img src="/{$theme}/icons/{$icon}_16.gif" width="16" height="16" hspace="5" onmouseover="callTip('{$tip}',event)" onmouseout="callTip()"/>
  </xsl:template>
  
  <!-- 
		show request "Status" column cell
	-->
  <xsl:template match="request-status">  
  	<xsl:variable	name="cookies" select="../../../ui:cookies"/>
  	<xsl:call-template name="ui:request-status">  		
  		<xsl:with-param name="src" select="."/>
  		<xsl:with-param name="title" select="$cookies/status[@value=current()]/@title"/>
  	</xsl:call-template>    
  </xsl:template>

	<!-- 
		show vzenv "Enabled" column cell 
		p.s. vzpp-enabled should contain "disabled", so it will showing as inversed
	-->
  <xsl:template match="vzpp-enabled">
  
    <xsl:variable name="icon">
      <xsl:choose>
        <xsl:when test=". = 0">autostart_yes</xsl:when>
        <xsl:otherwise>autostart_no</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="tip">
      <xsl:choose>
        <xsl:when test=". = 0">vzpp_enabled</xsl:when>
        <xsl:otherwise>vzpp_disabled</xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <img src="/{$theme}/icons/{$icon}.gif" width="16" height="16" hspace="5" onmouseover="callTip('{$tip}',event)" onmouseout="callTip()"/>
  </xsl:template>
  
  <!-- 
  	Uses on "VEs" screen.
		Show "OS template" column cell 
	-->
  <xsl:template match="base_set">
  	<xsl:copy-of select="sw:app-id2title(.)"/>  		
  </xsl:template>
  
  <!-- 
  	Uses on "VE Sample" screen.
		Show "Download" column cell 
	-->
  <xsl:template match="envsample-download">
    <a href="{concat($baseurl,'/vzdir/infrman/envsamples/download?id=',sw:base64-encode(.))}"><img src="/{$theme}/icons/download_16.gif" width="16" height="16" hspace="5" onmouseover="callTip('download_envsample',event)" onmouseout="callTip()"/></a>
  </xsl:template>
  
  <!-- 
  	Uses on "VE Files/Actions" screen.
		Show "Download" column cell 
	-->
  <xsl:template match="file-actions">
  	<xsl:variable	name="cookies" select="../../../ui:cookies"/>
		<xsl:variable	name="backup-browser" select="$cookies/backup-browser"/>
  	<nobr>
  		<xsl:choose>
  			<!-- no creds -->
  			<xsl:when test="not(props)">							
			</xsl:when>
  			<!-- .. -->
	  		<xsl:when test="../level-up">					
			</xsl:when>
			<!-- volume -->
			<xsl:when test="../file-type &gt; 15 and ../file-type &lt; 22">
			</xsl:when>
			<xsl:otherwise>
				<a href="{concat($baseurl,'/vzdir/infrman/envs/files/props?file-name=',str:encode-uri(sw:base64-encode(../file-name), true()))}"><img src="/{$theme}/icons/fm_props_16.gif" width="16" height="16" onmouseover="callTip('props_file',event)" onmouseout="callTip()"/></a>
			</xsl:otherwise>
		</xsl:choose>
	  	<xsl:choose>
				<!-- no creds -->
				<xsl:when test="not(download)">
        </xsl:when>
	  		<!-- .. -->
	  		<xsl:when test="../level-up">					
				</xsl:when>
				<!-- volume -->
				<xsl:when test="../file-type &gt; 15 and ../file-type &lt; 22">
				</xsl:when>
	  		<xsl:when test="../file-type='4'">
	  			&#160;<img src="/{$theme}/icons/download_disabled_16.gif" width="16" height="16" onmouseover="callTip('download_folder',event)" onmouseout="callTip()"/>
				</xsl:when>
				<xsl:when test="../file-size = 0 and $backup-browser">
	  			&#160;<img src="/{$theme}/icons/download_disabled_16.gif" width="16" height="16" onmouseover="callTip('download_magic_symlink',event)" onmouseout="callTip()"/>
				</xsl:when>				
				<xsl:otherwise>
			  	&#160;<a href="{concat($baseurl,$cookies/url-to-download,'?fm-name=',str:encode-uri(sw:base64-encode(../file-name), true()),'&amp;fm-size=',../file-size)}"><img src="/{$theme}/icons/download_16.gif" width="16" height="16" onmouseover="callTip('download_file',event)" onmouseout="callTip()"
			  	/></a>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:choose>
				<!-- no creds -->
  			<xsl:when test="not(edit)">					
				</xsl:when>
	  		<!-- .. -->
	  		<xsl:when test="../level-up">					
				</xsl:when>
				<!-- volume -->
				<xsl:when test="../file-type &gt; 15 and ../file-type &lt; 22">
				</xsl:when>
	  		<xsl:when test="../file-type='4' or not(../file-editable)">
	  			&#160;<img src="/{$theme}/icons/fm_edit_disabled_16.gif" width="16" height="16" onmouseover="callTip('edit_binary',event)" onmouseout="callTip()"/>
				</xsl:when>
				<xsl:otherwise>
			  	&#160;<a href="{concat($baseurl,'/vzdir/infrman/envs/files/edit?file-name=',str:encode-uri(sw:base64-encode(../file-name), true()))}"><img src="/{$theme}/icons/fm_edit_16.gif" width="16" height="16" onmouseover="callTip('edit_file',event)" onmouseout="callTip()"
			  	/></a>
				</xsl:otherwise>
			</xsl:choose>
		</nobr>
  </xsl:template>

  
  <!-- 
  	Uses on "VE Files" screen.
		Show "Size" column cell 
	-->
  <xsl:template match="file-size">
  	<nobr>
		  <xsl:choose>
		  	<xsl:when test="../level-up">		  		
		  	</xsl:when>
		  	<!-- volume -->
				<xsl:when test="../file-type &gt; 15 and ../file-type &lt; 22">		  		
		  		&lt;<sw:text>volume</sw:text>&gt;
		  	</xsl:when>
		  	<!-- 10 sym.link -->
		  	<xsl:when test="../file-type='8' or ../file-type='22' or ../file-type='10'">
		  		<xsl:value-of select="format:int2bytes(., 'kbyte', 'no', '#,##0.00')"/>&#160;<sw:text>KB</sw:text>
		  	</xsl:when>
		  	<xsl:when test="../file-type='4'">
		  		&lt;<sw:text>dir</sw:text>&gt;
		  	</xsl:when>
		  	<xsl:otherwise>
		  		<sw:text>unknown</sw:text>
		  	</xsl:otherwise>
		  </xsl:choose>
    </nobr>
  </xsl:template>
  
  <!-- 
  	Uses on "VE Files" screen.
		Show "Name" column cell 
	-->
  <xsl:template match="file-name">
		<xsl:variable	name="default-type" select="../../../ui:cookies/mimetypes/default/type"/>
  	<nobr>
		  <xsl:choose>
		  	<xsl:when test="../level-up">
					<a href="?path={sw:base64-encode(../level-up)}"
							onmouseover="callTip('file_dir',event)" onmouseout="callTip()"
					><xsl:value-of select="."/></a>
		  	</xsl:when>
		  	<!-- volume  or directory -->
		  	<xsl:when test="../file-type='4' or (../file-type &gt; 15 and ../file-type &lt; 22)">
					<a href="?path={str:encode-uri(sw:base64-encode(concat(../path,'/',.)), true())}"
							onmouseover="callTip('file_dir',event)" onmouseout="callTip()"
					><xsl:value-of select="."/></a>
		  	</xsl:when>
		  	<xsl:when test="../file-type='8' or ../file-type='22'">
					<!--<xsl:variable name="extension" select="sw:lc(sw:re-match(../file-name,'\.([^.]+)$',i)[2])"/>
					<xsl:variable name="selected-type" select="../../../ui:cookies/mimetypes/user/type[extension = $extension]"/>
					<xsl:variable name="mimetype" select="sw:if(not($selected-type != ''),$default-type,$selected-type)"/>
					<a href="{$baseurl}/vzdir/infrman/envs/files/download?fm-name={sw:base64-encode(.)}&amp;fm-size={../file-size}"
						onmouseover="callTip('{$mimetype/tip}',event)" onmouseout="callTip()">
						--><xsl:value-of select="."/>
					<!--</a>-->
		  	</xsl:when>
		  	<xsl:otherwise>
						<!--<a href="{$baseurl}/vzdir/infrman/envs/files/download?fm-name={sw:base64-encode(.)}&amp;fm-size={../file-size}"
								onmouseover="callTip('{$default-type/tip}',event)" onmouseout="callTip()">
							--><xsl:value-of select="."/>
						<!--</a>-->
		  	</xsl:otherwise>
		  </xsl:choose>
    </nobr>
  </xsl:template>
  
  <!-- 
  	Uses on "VE Files" screen.
		Show "Icon" column cell 
	-->
  <xsl:template match="file-icon">
		<xsl:variable	name="default-type" select="../../../ui:cookies/mimetypes/default/type"/>
		<xsl:variable	name="disable-download" select="../../../ui:cookies/disable-download"/>		
		<xsl:variable	name="cookies" select="../../../ui:cookies"/>
		<xsl:variable	name="backup-browser" select="$cookies/backup-browser"/>
		<xsl:variable	name="url2down" select="$cookies/url-to-download"/>
		
		<xsl:variable name="data">
			<xsl:choose>
		  	<!-- level up -->
		  	<xsl:when test="../level-up">
		  		<a href="?path={sw:base64-encode(../level-up)}"><img
						 src="/{$theme}/icons/uplevel.gif" width="16" height="16" 
						 onmouseover="callTip('file_up',event)" onmouseout="callTip()"
					/></a>		  		
		  	</xsl:when>
		  	<!-- volume, f.e. 'c:' -->
		  	<xsl:when test="../file-type &gt; 15 and ../file-type &lt; 22">
					<a href="?path={str:encode-uri(sw:base64-encode(concat(../path,'/',.)), true())}"><img
						 src="/{$theme}/icons/file_dir.gif" width="16" height="16" 
						 onmouseover="callTip('file_dir',event)" onmouseout="callTip()"
					/></a>		  		
		  	</xsl:when>
		  	<!-- folder -->
		  	<xsl:when test="../file-type='4'">
					<a href="?path={str:encode-uri(sw:base64-encode(concat(../path,'/',.)), true())}"><img
						 src="/{$theme}/icons/file_dir.gif" width="16" height="16" 
						 onmouseover="callTip('file_dir',event)" onmouseout="callTip()"
					/></a>		  		
		  	</xsl:when>
		  	<xsl:when test="(../file-type='8' or ../file-type='22')">
		  		<xsl:variable name="extension" select="../file-ext"/>
					<xsl:variable name="selected-type" select="../../../ui:cookies/mimetypes/user/type[extension = $extension]"/>
					<xsl:variable name="mimetype" select="sw:if(not($selected-type != ''),$default-type,$selected-type)"/>
					<xsl:choose>
						<xsl:when test="$backup-browser and (../file-size = 0 or $disable-download)">
							<!-- in backup browsing not allow download files with zero size or disabled
									 besacuse it's may be magic symlinks -->
							<img src="/{$theme}/icons/{$mimetype/icon}.gif" width="16" height="16" 
								onmouseover="callTip('{concat($mimetype/tip,'_nonactive')}')" onmouseout="callTip()"/>
						</xsl:when>
						<xsl:when test="$backup-browser and not(../file-size = 0 or $disable-download)">
							<!-- in backup browsing allow download -->
							<a href="{$baseurl}{$url2down}?fm-name={str:encode-uri(sw:base64-encode(.), true())}&amp;fm-size={../file-size}">
								<img src="/{$theme}/icons/{$mimetype/icon}.gif" width="16" height="16" 
								 onmouseover="callTip('{$mimetype/tip}',event)" onmouseout="callTip()"
							/></a>							
						</xsl:when>
						<xsl:when test="not($backup-browser) and $disable-download">
							<!-- in filemanager browsing download disabled -->
							<img src="/{$theme}/icons/{$mimetype/icon}.gif" width="16" height="16" 
								onmouseover="callTip('{concat($mimetype/tip,'_nonactive')}')" onmouseout="callTip()"/>
						</xsl:when>
						<xsl:when test="not($backup-browser) and not($disable-download)">
							<!-- in filemanager browsing download enabled -->
							<a href="{$baseurl}{$url2down}?fm-name={str:encode-uri(sw:base64-encode(.), true())}&amp;fm-size={../file-size}">
								<img src="/{$theme}/icons/{$mimetype/icon}.gif" width="16" height="16" 
								 onmouseover="callTip('{$mimetype/tip}',event)" onmouseout="callTip()"
							/></a>							
						</xsl:when>
					</xsl:choose>
		  	</xsl:when>
		  	<xsl:otherwise>
		  		<img src="/{$theme}/icons/{$default-type/icon}.gif" width="16" height="16" onmouseover="callTip('{$default-type/tip}',event)" onmouseout="callTip()"/>
		  	</xsl:otherwise>
		  </xsl:choose>
		</xsl:variable>
  	<nobr>
			<xsl:copy-of select="$data"/>
    </nobr>
  </xsl:template>

	<!-- show alert type -->
  <xsl:template match="alert-category">
		<xsl:choose>
			<xsl:when test=". = 'resource_alert'"><sw:text>Resource</sw:text></xsl:when>
			<xsl:when test=". = 'server_group_alert'"><sw:text>Group</sw:text></xsl:when>
			<xsl:when test=". = 'license_alert'"><sw:text>License</sw:text></xsl:when>
			<xsl:otherwise><sw:text>General</sw:text></xsl:otherwise>
		</xsl:choose>
  </xsl:template>

	<!-- show alert severity description -->
  <xsl:template match="alert-type">
    <xsl:variable name="zone">
      <xsl:choose>
        <xsl:when test=". = 'green'"><sw:text>Green zone</sw:text></xsl:when>
        <xsl:when test=". = 'yellow'"><sw:text>Yellow zone</sw:text></xsl:when>
        <xsl:when test=". = 'red'"><sw:text>Red zone</sw:text></xsl:when>
        <xsl:when test=". = 'black'"><sw:text>Red zone</sw:text></xsl:when>
        <xsl:otherwise><sw:text>Unknown zone</sw:text></xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:variable name="class">
      <xsl:choose>
        <xsl:when test=". = 'green'">green</xsl:when>
        <xsl:when test=". = 'yellow'">yellow</xsl:when>
        <xsl:when test=". = 'red'">red</xsl:when>
        <xsl:when test=". = 'black'">red</xsl:when>
      </xsl:choose>
    </xsl:variable>
    <nobr>
      <img src="/{$theme}/icons/alert_{$class}.gif" width="16" height="16" hspace="5" onmouseover="callTip('{$class}_zone',event)" onmouseout="callTip()"/>
      <span onmouseover="callTip('{$class}_zone',event)" onmouseout="callTip()"><xsl:value-of select="$zone"/></span>
    </nobr>
  </xsl:template>

	<!-- show alert type icon -->
  <xsl:template match="hn-alert-type-icon">
    <xsl:variable name="class">
      <xsl:choose>
        <xsl:when test=". = 0">green</xsl:when>
        <xsl:when test=". = 1">yellow</xsl:when>
        <xsl:when test=". = 2">red</xsl:when>
        <xsl:when test=". = 3">red</xsl:when>
      </xsl:choose>
    </xsl:variable>

    <img src="/{$theme}/icons/alert_{$class}.gif" width="16" height="16" hspace="5" onmouseover="callTip('{$class}_hn_zone',event)" onmouseout="callTip()"/>
  </xsl:template>

	<!-- show alert type icon -->
  <xsl:template match="alert-type-icon">
    <xsl:variable name="class">
      <xsl:choose>
        <xsl:when test=". = 0">green</xsl:when>
        <xsl:when test=". = 1">yellow</xsl:when>
        <xsl:when test=". = 2">red</xsl:when>
        <xsl:when test=". = 3">red</xsl:when>
      </xsl:choose>
    </xsl:variable>

    <img src="/{$theme}/icons/{$class}_16.gif" width="16" height="16" hspace="5" onmouseover="callTip('{$class}_zone',event)" onmouseout="callTip()"/>
  </xsl:template>


	<!-- show link to help id for specific qos -->
  <xsl:template match="qos-help-id">
    <a href="javascript:open_help('{$baseurl}/help?topic=resources&amp;a={.}')" onmouseover="callTip('get_help_resource',event)" onmouseout="callTip()"><xsl:value-of select="."/></a>
  </xsl:template>
   
	<xsl:template match="alert-ve-title">
		<xsl:choose>
			<xsl:when test="../alert-category != 'resource_alert'"/>
			<xsl:otherwise>				
				<xsl:call-template name="env-link">
					<xsl:with-param name="content-type" select="'title'"/>
					<xsl:with-param name="eid-arg" select="../ve-eid"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template> 
	
	<xsl:template match="rpm-status">
		<nobr>
			<xsl:choose>
				<xsl:when test=".=1">
					<sw:text>Update Found</sw:text>
				</xsl:when>
				<xsl:otherwise>
					<ui:text-disabled>
						<sw:text>Up-to-date</sw:text>
					</ui:text-disabled>
				</xsl:otherwise>
			</xsl:choose>
		</nobr>
	</xsl:template>
	
	
	<!--
		Context
			Required
				@eid-node or @eid or content(for env-eid-link)
				@vza-type-node or @type or @vza-type or content(for env-title-link)
				@title-node or @title				
			Optional
				@show-icon=true|false
		Input 
			options  -
	-->
	<xsl:template match="env-eid-link|env-title-link|ui:env-eid-link|ui:eid-title-link" name="env-link">
		<xsl:param name="options" select="."/>
		<xsl:param name="eid-arg" select="''"/>
		<xsl:param name="content-type" select="''"/><!--'eid' or 'title' -->
		
		<xsl:variable name="eid">
			<xsl:choose>
				<xsl:when test="$eid-arg!=''">				
					<xsl:value-of select="$eid-arg"/>
				</xsl:when>
				<xsl:when test="self::env-eid-link or self::ui:env-eid-link or $content-type='eid'">
					<xsl:value-of select="."/>
				</xsl:when>
				<xsl:when test="$options/@eid-node">
					<xsl:value-of select="../*[name()=$options/@eid-node]"/>
				</xsl:when>
				<xsl:when test="$options/@eid">
					<xsl:value-of select="$options/@eid"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="type">
			<xsl:choose>
				<xsl:when test="$options/@vza-type-node">
					<xsl:variable name="vza-type" select="../*[name()=$options/@vza-type-node]"/>
					<xsl:value-of select="$global:classes/class[@vza-type=$vza-type]/@vzcp-type"/>
				</xsl:when>
				<xsl:when test="$options/@vza-type">
					<xsl:value-of select="$global:classes/class[@vza-type=$options/@vza-type]/@vzcp-type"/>
				</xsl:when>
				<xsl:when test="$options/@type">
					<xsl:value-of select="$options/@type"/>
				</xsl:when>
				<xsl:when test="$eid!='' and $eid!=$env:empty-eid">
					<xsl:variable name="info" select="env:eid2info($eid)"/>
					<xsl:value-of select="$info/obj-type"/>					
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
				
		<xsl:variable name="title">
			<xsl:choose>
				<xsl:when test="self::env-title-link or self::ui:env-title-link  or $content-type='title'">
					<xsl:value-of select="."/>
				</xsl:when>
				<xsl:when test="$options/@title-node">
					<xsl:value-of select="../*[name()=$options/@title-node]"/>
				</xsl:when>
				<xsl:when test="$options/@title">
					<xsl:value-of select="$options/@title"/>
				</xsl:when>
				<xsl:when test="$eid!='' and $eid!=$env:empty-eid">
					<xsl:variable name="info" select="env:eid2info($eid)"/>
					<xsl:choose>
						<xsl:when test="$info/title!=''">
							<xsl:value-of select="$info/title"/>					
						</xsl:when>
						<xsl:otherwise>
							<sw:text>n/a</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>n/a</sw:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:choose>
			<!-- ID is unknown -->
			<xsl:when test="$eid=''">
				<xsl:value-of select="$title"/>
			</xsl:when>
			<!-- Type is uknown -->
			<xsl:when test="$type=''">
				<xsl:value-of select="$title"/>
			</xsl:when>
			<!-- EID and Title are both known  -->
			<xsl:otherwise>
				<xsl:variable name="href">
					<xsl:value-of select="sw:html-escape(concat(
						$baseurl,
						$global:classes/class[@vzcp-type=$type]/actions/action[@id='open']/@href,
						'?id=',
						sw:base64-encode($eid)
					),'escape-quote')"/>
				</xsl:variable>			
				<a onclick="openFromPopup('{$href}')" href="#none">
					<xsl:value-of select="$title"/>
				</a>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>


	<!-- display ID of ENV or ENV range with link to ENV home page -->
	<xsl:template match="ui:env-list|env-list">
		<xsl:for-each select="*">
			<xsl:apply-templates select="."/>
			<xsl:if test="position() != last()">
				<xsl:text>, </xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template> 
	
	<!-- display envs list with link by vza message parameters -->
	<xsl:template name="ui:envs-by-message" match="ui:envs-by-message">
		<xsl:param name="envs" select="*"/>
		
		<xsl:variable name="objs" >
			<ui:env-list>
				<xsl:for-each select="$envs">					
					<xsl:variable name="b64eid" select="string(parameter[name = 'eid']/message)"/>
					
					<!-- do not show duplicate objects -->
					<xsl:if test="not(preceding-sibling::parameter/parameter[name = 'eid']/message = $b64eid)">
						<ui:env-eid-link 
							title="{sw:base64-decode(parameter[name = 'title']/message)}"
							vza-type="{sw:base64-decode(parameter[name = 'type']/message)}"
						>
							<xsl:value-of select="sw:base64-decode($b64eid)"/>
						</ui:env-eid-link>
					</xsl:if>
				</xsl:for-each>
			</ui:env-list>
		</xsl:variable>
		<xsl:apply-templates select="exsl:node-set($objs)/ui:env-list"/>
	</xsl:template>
	
	
	<!--
		Shows link for login into VZPP
	-->
	<xsl:template match="vzpp-login">
		<xsl:variable name="vzpp-offline-default" select="string(../../../ui:cookies/vzpp-offline-default)"/>
		<xsl:variable name="my-ip" select="sw:if(vt:is-local-platform-windows(), $request/http_request/env/parameter[name = 'LOCAL_ADDR']/value, $request/http_request/env/parameter[name = 'SERVER_ADDR']/value)"/>
		<xsl:choose>
			<xsl:when test="vt:is-local-platform-windows() and ../ips!='' and (../offline_management=1 or ../offline_management='yes')	and not(../ips = $my-ip)">
				<a href="/vz/cp/panel/vzpp?id={../id}&amp;hw-node={../hw-node}" target="_blank"><img border="0" onmouseover="callTip('click_login_vzpp',event)" onmouseout="callTip()" src="/{$theme}/icons/vzpp_16.gif" width="16" height="16" hspace="5" class="veState"/></a>
			</xsl:when>				
			<xsl:when test="(vt:is-platform-linux(vt:local-platform())) and ../ips!='' and (../offline_management=1 or ../offline_management='yes') and (../offline_service = 'vzpp' or (../offline_service = '' and $vzpp-offline-default != 0)) and not(../ips = $my-ip)">
	  		<a href="/vz/cp/panel/vzpp?id={../id}&amp;hw-node={../hw-node}" target="_blank"><img border="0" onmouseover="callTip('click_login_vzpp',event)" onmouseout="callTip()" src="/{$theme}/icons/vzpp_16.gif" width="16" height="16" hspace="5" class="veState"/></a>
	  	</xsl:when>
	  	<xsl:otherwise>
	  		<img border="0" onmouseover="callTip('vzpp_disabled',event)" onmouseout="callTip()" src="/{$theme}/icons/vzpp_disabled_16.gif" width="16" height="16" hspace="5" class="veState"/>
	  	</xsl:otherwise>
	  </xsl:choose>
	</xsl:template>

	<!--
		Shows demo link for login into VZPP
	-->
	<xsl:template match="vzpp-login-demo">
		<xsl:variable name="vzpp-offline-default" select="string(../../../ui:cookies/vzpp-offline-default)"/>
		<xsl:variable name="my-ip" select="sw:if(vt:is-local-platform-windows(), $request/http_request/env/parameter[name = 'LOCAL_ADDR']/value, $request/http_request/env/parameter[name = 'SERVER_ADDR']/value)"/>
		<xsl:choose>
			<xsl:when test="vt:is-local-platform-windows() and ../ips!='' and (../offline_management=1 or ../offline_management='yes')	and not(../ips = $my-ip)">
				<a href="/vz/cp/panel/vzpp?id={../id}&amp;hw-node={../hw-node}"><img border="0" onmouseover="callTip('click_login_vzpp',event)" onmouseout="callTip()" src="/{$theme}/icons/vzpp_16.gif" width="16" height="16" hspace="5" class="veState"/></a>
			</xsl:when>				
			<xsl:when test="(vt:is-platform-linux(vt:local-platform())) and ../ips!='' and (../offline_management=1 or ../offline_management='yes') and (../offline_service = 'vzpp' or (../offline_service = '' and $vzpp-offline-default != 0)) and not(../ips = $my-ip)">
	  		<a href="/vz/cp/panel/vzpp?id={../id}&amp;hw-node={../hw-node}"><img border="0" onmouseover="callTip('click_login_vzpp',event)" onmouseout="callTip()" src="/{$theme}/icons/vzpp_16.gif" width="16" height="16" hspace="5" class="veState"/></a>
	  	</xsl:when>
	  	<xsl:otherwise>
	  		<img border="0" onmouseover="callTip('vzpp_disabled',event)" onmouseout="callTip()" src="/{$theme}/icons/vzpp_disabled_16.gif" width="16" height="16" hspace="5" class="veState"/>
	  	</xsl:otherwise>
	  </xsl:choose>		
	</xsl:template>

	<xsl:template match="period">	
		<xsl:value-of select="../period-for-show"/>
	</xsl:template>

	<xsl:template match="ui:operation-problem">						
			
		<xsl:choose>
			<xsl:when test="ui:compact-mode">
				<xsl:call-template name="local:operation-problem-content"/>
			</xsl:when>
			<xsl:otherwise>
				<table cellpadding="0" cellspacing="0" border="0">
					<xsl:call-template name="html:calc-width">
						<xsl:with-param name="control" select="."/>
					</xsl:call-template>	
					<tr><td width="100%">	
						
						<!--<fieldset>
							<legend align="left" style="vertical-align:middle">
								<sw:text>Operation is unavailable</sw:text>
								<span style="vertical-align:middle">
								</span>
							</legend>    
							<br/>-->
							<xsl:call-template name="local:operation-problem-content"/>
						<!--</fieldset>-->
					</td></tr>
				</table>
			</xsl:otherwise>
		</xsl:choose>
				
  </xsl:template>	
  
  <xsl:template name="local:operation-problem-content">
  
  	<xsl:variable name="compact-mode" select="boolean(ui:compact-mode)"/>
  	<xsl:variable name="disable-links" select="boolean(ui:disable-links)"/>
  
  	<b><xsl:copy-of select="ui:descr"/></b>
		<br/>
		<br/>
		<!-- Reasons -->
		<sw:text>Possible reasons</sw:text><br/>
		<ul>
			<xsl:for-each select="ui:reason">
				<li><xsl:copy-of select="."/></li>
			</xsl:for-each>
			<xsl:choose>
				<xsl:when test="ui:type='wrong-env-state'">
					<!-- Wrong VE state -->
					<xsl:choose>
						<xsl:when test="ui:required-state">
							<li>
								<xsl:call-template name="ui:construct-ve-status">
									<xsl:with-param name="state" select="ui:env-state"/>
									<xsl:with-param name="transition" select="ui:env-transition"/>
									<xsl:with-param name="is_small" select="1"/>
								</xsl:call-template>
								<xsl:variable name="required-states">
									<xsl:for-each select="ui:required-state">
										<xsl:variable name="required-state" select="."/>
										<xsl:if test="position()!=1">,&#160;</xsl:if>
										<sw:text domain="vzagent-vocabulary" select="name($env-state/*[.=$required-state])"/>
									</xsl:for-each>										
								</xsl:variable>
								<sw:text>
									<xsl:with-param name="required-states" select="$required-states"/>
									To perform the requested operation, the Container should be in the %{required-states} state.
								</sw:text>
							</li>
						</xsl:when>
						<xsl:otherwise>
							<li>
								<sw:text>An unknown system error has occurred.</sw:text>
							</li>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<!-- /Wrong VE state -->
				<!-- VZA Error -->
				<xsl:when test="ui:type='vza-error'">
					<li><sw:text>Virtuozzo was misconfigured.</sw:text></li>
				</xsl:when>
				<!-- /VZA Error -->
			</xsl:choose>
		</ul>
		<!-- /Reasons -->
		<!-- Solution-->
		<sw:text>Possible solutions</sw:text><br/>
		<ul>
			<xsl:for-each select="ui:solution">
				<li><xsl:apply-templates select="."/></li>
			</xsl:for-each>
			<xsl:if test="ui:type='wrong-env-state'">
				<xsl:choose>
					<xsl:when test="ui:env-transition=$env-trans/stopping">
						<li><sw:text>Wait for the Container to stop and try the required operation again.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-transition=$env-trans/starting">
						<li><sw:text>Wait for the Container to start and try to perform the required operation again.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-transition=$env-trans/creating">
						<li><sw:text>Wait for the Container to be created and try to perform the required operation again.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-transition=$env-trans/mounting">
						<li><sw:text>Wait for the Container to be mounted and try to perform the required operation again.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-transition=$env-trans/migrating">
						<li><sw:text>Wait for the Container to migrate and try to perform the required operation again.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-transition=$env-trans/restoring">
						<li><sw:text>Wait for the Container to be restored and try to perform the required operation again.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-transition=$env-trans/backing-up">
						<li><sw:text>Wait for the Container to be backed up and try to perform the required operation again.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-state=$env-state/unexist">
						<li><sw:text>The Container was deleted. Select another Container for this operation.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-transition=$env-trans/stopping and ui:required-state[.=$env-state/down]">
						<li><sw:text>The Container is stopping right now. Please wait for it to stop and try the required operation again.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-transition!='' and ui:env-transition!=0">
						<li><sw:text>Wait for the operation currently performed on the Container to be completed.</sw:text></li>
					</xsl:when>
					<xsl:when test="ui:env-state=$env-state/repairing">
						<xsl:choose>
							<xsl:when test="ui:required-state[.=$env-state/running] and not (ui:required-state[.=$env-state/down])">
								<li>
									<xsl:choose>
										<xsl:when test="not($disable-links)">
											<sw:text>
												<xsl:with-param name="url-open">
													&lt;a href="<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/repair')"/>"&gt;
												</xsl:with-param>
												<xsl:with-param name="url-close">&lt;/a&gt;</xsl:with-param>
												%{url-open}Exit the repair mode%{url-close} and start the Container.
											</sw:text>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>
												Exit the repair mode and start the Container.
											</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</li>
							</xsl:when>
							<xsl:otherwise>
								<li>
									<xsl:choose>
										<xsl:when test="not($disable-links)">
											<a href="{concat($baseurl,'/vzdir/infrman/envs/repair')}">
												<sw:text>
													Exit the repair mode.
												</sw:text>
											</a>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>
												Exit the repair mode.
											</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</li>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<!-- Load some additional info -->
						<sw:die test="not(ui:env-eid)">
							'ui:operation-problem/eid' node should be specified.
						</sw:die>									
						<xsl:variable name="ve-config" select="env:get-env(string(ui:env-eid))/env/virtual_config"/>
						<!-- /Load some additional info -->

						<xsl:choose>
							<xsl:when test="not($ve-config)">
								<xsl:if test="not($disable-links)">
									<li><a href="{$baseurl}/vzdir/infrman/envs/index"><sw:text>Return to the Containers list and select another Container.</sw:text></a></li>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<!-- Start VE -->
								<xsl:if test="ui:required-state[.=$env-state/running]">
									<xsl:choose>
										<xsl:when test="ui:env-transition=$env-state/starting">
											<li><sw:text>The Container is starting at the moment. Please wait for the Container to start and try to perform the required operation again.</sw:text></li>
										</xsl:when>
										<xsl:when test="$ve-config/disabled='1'">
											<xsl:choose>
												<xsl:when test="$activeMode = 'vzcc'">
													<li>
														<sw:text>Clear the "Disable Container start" checkbox on the Container Configuration/Preferences screen to be able to start the Container.</sw:text>
													</li>
												</xsl:when>
												<xsl:otherwise>
													<li>
														<sw:text>The Container startup has been disabled. Contact your provider to start the Container.</sw:text>
													</li>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:when>
										<xsl:otherwise>	
											<!-- Hint to start VE -->
											<xsl:choose>
												<xsl:when test="cred:check-env('vzcp.env.manage.start_stop',string(ui:env-eid))">
													<li>
														<xsl:choose>
															<xsl:when test="not($disable-links)">
																<a href="{$baseurl}/vzdir/infrman/envs/ctl?start_ve=yes"><sw:text>Start Container</sw:text></a>
															</xsl:when>
															<xsl:otherwise>
																<sw:text>Start Container</sw:text>
															</xsl:otherwise>
														</xsl:choose>
													</li>
												</xsl:when>
												<xsl:otherwise>
													<li><sw:text>Ask your service provider to start the Container.</sw:text></li>
												</xsl:otherwise>
											</xsl:choose>
											<!-- /Hint to start VE -->
										</xsl:otherwise>
									</xsl:choose>
								</xsl:if>
								<!-- /Start VE -->
								<xsl:if test="ui:required-state[.=$env-state/down]">
									<!-- Hint to stop VE -->
									<xsl:choose>
										<xsl:when test="cred:check-env('vzcp.env.manage.start_stop',string(ui:env-eid))">
											<li>
												<xsl:choose>
													<xsl:when test="not($disable-links)">
														<a href="{$baseurl}/vzdir/infrman/envs/ctl?stop_ve=yes"><sw:text>Stop Container</sw:text></a>
													</xsl:when>
													<xsl:otherwise>
														<sw:text>Stop Container</sw:text>
													</xsl:otherwise>
												</xsl:choose>
											</li>
										</xsl:when>
										<xsl:otherwise>
											<li><sw:text>Ask your service provider to stop the Container.</sw:text></li>
										</xsl:otherwise>
									</xsl:choose>
									<!-- /Hint to stop VE -->																						
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<!-- VZA Error -->
			<xsl:if test="ui:type='vza-error'">
				<li><sw:text>Call the Hardware Node administrator for support.</sw:text></li>
			</xsl:if>
			<!-- /VZA Error -->
		</ul>
		<!-- /Solution-->
		<xsl:if test="not($disable-links) and not(/ui:screen/ui:properties/ui:refresh-type='none')">
			<sw:text>Other possible actions</sw:text>
			<ul>
				<li><a href="{path:href(path:last(path:get()))}"><sw:text>Refresh this page</sw:text></a></li>
				<xsl:if test="ui:type='vza-error'">
					<li><a href="#" onclick="showReport()" onmouseover="callTip('error_details',event)" onmouseout="callTip()"><span id="reportlink"><sw:text>Show Technical Details</sw:text></span></a></li>
				</xsl:if>
			</ul>
		</xsl:if>
		<xsl:if test="ui:type='vza-error'">
			<div id="report" style="display:none;">
				<sw:text>Technical Details</sw:text><br/><br/>
				<sw:text>
					<xsl:with-param name="code" select="ui:vza-error/code"/>
					VZAgent returns error #%{code}</sw:text>
				<xsl:choose>
					<xsl:when test="ui:vza-error/message">:&#160;"<xsl:value-of select="ui:vza-error/message"/>"
					</xsl:when>
					<xsl:otherwise>.</xsl:otherwise>
				</xsl:choose>
				<script>
					function showReport(){
						s = document.getElementById('report');
						link = document.getElementById('reportlink');
						if(s.style.display=='none'){
							s.style.display='block';
							link.innerHTML='<sw:text>Hide Technical Details</sw:text>';
						}else{
							s.style.display='none';
							link.innerHTML='<sw:text>Show Technical Details</sw:text>';
						}
						return false;
					}
				</script>
			</div>
		</xsl:if>
	</xsl:template>

	<!-- show operation progress message -->
  <xsl:template match="ui:operation-progress">
  	
  	<xsl:variable name="ve-state" select="ve:context-state()"/>
  	<xsl:variable name="ve-transition" select="ve:context-transition()"/>
  
  	<xsl:if test="$ve-transition!=''">
  	
	  	<table cellspacing="0" cellpadding="0" border="0">
		    <xsl:call-template name="html:calc-width">
					<xsl:with-param name="control" select="."/>
				</xsl:call-template>
				<tr><td width="100%">
			    <fieldset>
			      <legend><sw:text>Current Operation Information</sw:text></legend>
			      <table cellspacing="0" cellpadding="0" border="0" width="100%">
			      	<tr><img src="/{$theme}/images/1x1.gif" width="15" height="3"/></tr>
			        <tr>
			          <td nowrap="1">
			            <xsl:call-template name="ui:current-ve-status"/>
			          </td>
			          <td width="100%"><img src="/{$theme}/images/1x1.gif" width="15" height="1"/></td>
			        </tr>
			      </table>
			    </fieldset>
			   </td></tr>
			 </table>
			  
		</xsl:if>
  </xsl:template>	
  
  <xsl:template match="system-up2date">
  	<xsl:choose>
  		<xsl:when test="major &gt; 0">
  			<sw:text>Major update found</sw:text>
  		</xsl:when>
  		<xsl:when test="minor &gt; 0">
  			<sw:text>
  				<xsl:with-param name="count" select="minor"/>
  				%{count} minor update(s) found</sw:text>
  		</xsl:when>
  		<xsl:when test="templates &gt; 0">
  			<sw:text>
  				<xsl:with-param name="count" select="templates"/>
  				%{count} template update(s) found</sw:text>
  		</xsl:when>
  		<xsl:when test="minor|major|templates">
  			<sw:text>Up-to-date</sw:text>
  		</xsl:when>
  		<xsl:otherwise>
  			<sw:text>n/a</sw:text>
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:template>
  
  <xsl:template match="last-update-time">
  	<xsl:choose>
  		<xsl:when test="timestamp">
  			<xsl:value-of select="format:date-time(date:seconds(sw:vzatime2time(timestamp)))" />
  		</xsl:when>
  		<xsl:otherwise>
  			<sw:text>Not checked</sw:text>
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:template>

	<xsl:template match="vn-availability">
		<xsl:variable name="icon">
			<xsl:choose>
				<xsl:when test="@status = 'not configured'">connect_status_disconnected</xsl:when>
				<xsl:when test="@status = 'local'">connect_status_locally</xsl:when>
				<xsl:when test="@status = 'connected'">connect_status_ok</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<nobr>
			<img src="/{$theme}/icons/{$icon}_16.gif" border="0" width="16" height="16"/>&#160;<xsl:value-of select="."/>
		</nobr>
	</xsl:template>
	
	<xsl:template match="eth-id">
		<nobr><xsl:if test="../ui:row/type = 'net_vlanType'"><img src="/{$theme}/images/1x1.gif" border="0" width="16" height="1"/></xsl:if><xsl:copy-of select="."/></nobr>
	</xsl:template>
</xsl:stylesheet>
