<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func form"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:form="http://www.swsoft.com/xsl/cp/form"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"  
  xmlns:func="http://exslt.org/functions"
  >

	<!-- Function to restore data from list -->
	<xsl:template name="form:restore-list">
		<xsl:param name="code"/>
		<xsl:param name="row-node-name" select="'row'"/>
		<xsl:param name="def-values"/>
		<!--|-->
		<xsl:variable name="def-values-tree" select="exsl:node-set($def-values)"/>
		<xsl:variable name="total-control" select="concat($code,'_total')"/>
		<xsl:variable name="names-control" select="concat($code,'_names')"/>
		<!--|-->
		<xsl:variable name="all-values" select="sw:split(sw:param($code),'(')"/>
		<xsl:variable name="total" select="sw:param($total-control)"/>
		<xsl:variable name="names" select="sw:split(sw:param($names-control),'|')"/>
		<!--|-->
		<xsl:for-each select="$all-values">
			<xsl:variable name="values" select="sw:split(.,'|')"/>
			<xsl:choose>
				<!-- all row controls are empty -->
				<xsl:when test="not($values[.!=''])">
				</xsl:when>
				<!-- return controls values in separated rows -->
				<xsl:when test="$row-node-name!=''">
					<xsl:element name="{$row-node-name}">
						<xsl:for-each select="$values">
							<xsl:variable name="pos" select="position()"/>
							<xsl:element name="{$names[$pos]}">
								<xsl:choose>
									<xsl:when test=". = ''">
										<xsl:value-of select="$def-values-tree/*[name()=$names[$pos]]"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="."/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:element>
						</xsl:for-each>
					</xsl:element>
				</xsl:when>
				<!-- return controls values in one row -->
				<xsl:otherwise>
					<xsl:for-each select="$values">
						<xsl:variable name="pos" select="position()"/>
						<xsl:element name="{$names[$pos]}">
							<xsl:choose>
								<xsl:when test=". = ''">
									<xsl:value-of select="$def-values-tree/*[name()=$names[$pos]	]"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:element>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>		
	</xsl:template>
	<!-- /Function to restore data from list -->

	<!-- Attention - You should use separate-tables="true" for ui:rows -->
	<xsl:template name="form:show-list">
		<xsl:param name="config"/><!-- 
			code
			add-script
			ui:row
			ui:new-row
			required(true|false)
			add_label
			remove_label
			focus			
		-->
		<!--|-->		
		<xsl:variable name="conf" select="exsl:node-set($config)"/>		
		<xsl:variable name="c" select="string($conf/code)"/>
		<!--|-->
		<xsl:variable name="rows_">
			<xsl:copy-of select="$conf/ui:row"/>
			<xsl:if test="not($conf/ui:row)">
				<xsl:for-each select="$conf/ui:new-row">
					<ui:row>
						<xsl:copy-of select="$conf/ui:new-row/*"/>
					</ui:row>
				</xsl:for-each>
			</xsl:if>
			<ui:row reserve="1">
				<xsl:copy-of select="$conf/ui:new-row/*"/>
			</ui:row>
		</xsl:variable>
		
		<xsl:variable name="rows" select="exsl:node-set($rows_)"/>		
		<xsl:variable name="count" select="count($rows/ui:row)"/>			
		<xsl:variable name="controls" select="$rows/ui:row[1]/ui:*[@id!='']"/>			
		<xsl:variable name="first-control" select="string($controls[1]/@id)"/>			
		
		<!-- Post Internal Data -->
	  <ui:row>
			<xsl:copy-of select="sw:getItemsListJS($c,string($conf/empty_value),$first-control,$conf,$controls)"/>
			<script type="text/javascript">	
				var total_<xsl:value-of select="$c"/>=<xsl:value-of select="$count - 1"/>;
				var counter_<xsl:value-of select="$c"/>=<xsl:value-of select="$count - 1"/>;
				var last_<xsl:value-of select="$c"/>=<xsl:value-of select="$count - 1"/>;
				var names_<xsl:value-of select="$c"/>=new Array(
					<xsl:for-each select="$controls">
						<xsl:if test="position()>1">,</xsl:if>
						'<xsl:value-of select="@id"/>'
					</xsl:for-each>
				);
			</script>
			<input type="hidden" id="{$c}" name="{$c}"/>
			<input type="hidden" id="{$c}_total" name="{$c}_total"/>
			<input type="hidden" id="{$c}_names" name="{$c}_names"/>
			<ui:event type="onsubmit">Submit<xsl:value-of select="$c"/>();</ui:event>
		</ui:row>
		
		<!-- Post Rows -->		
		<xsl:for-each select="$rows/ui:row">			
			<xsl:variable name="row" select="."/>
			<xsl:variable name="row-pos" select="position()"/>
			<xsl:variable name="reserve" select="@reserve"/>
			<xsl:variable name="id" select="sw:if($reserve,'zzz',position())"/>
			<ui:row id="{concat('row_',$c,'_',$id)}">					
				<xsl:if test="$reserve">
					<xsl:attribute name="div_id">template_<xsl:value-of select="$c"/></xsl:attribute>
					<xsl:attribute name="div_display">none</xsl:attribute>
					<xsl:attribute name="span_after_id">end_<xsl:value-of select="$c"/>_zzz</xsl:attribute>
				</xsl:if>
				<xsl:variable name="is-empty" select="not(ui:*[
					(
						(self::ui:cell-input and @value!='') or
						(self::ui:cell-list and @value!='') or
						(self::ui:cell-selector and @code-value!='')
					)
						and (not(self::ui:cell-file))
					])"
				/>
				<xsl:variable name="always-del" select="count(ui:*[self::cell-input])&gt;1"/>
				<xsl:for-each select="ui:*">
					<xsl:variable name="name" select="name()"/>
					<xsl:element name="{$name}">
						<xsl:copy-of select="@*"/>
						<xsl:variable name="new-id" select="concat(@id,'_',$c,'_',$id)"/>
						<!-- Programme @onchange logic, we want to show Del button if control receive some value -->
						<xsl:choose>
							<xsl:when test="self::ui:cell-input or self::ui:cell-selector">
								<xsl:attribute name="onchange">
									updateDel<xsl:value-of select="$c"/>('<xsl:value-of select="$id"/>',this.value,0);
								</xsl:attribute>
							</xsl:when>
							<xsl:when test="self::ui:cell-list">
								<xsl:attribute name="onchange">
									updateDel<xsl:value-of select="$c"/>('<xsl:value-of select="$id"/>','x',0);
								</xsl:attribute>
							</xsl:when>
						</xsl:choose>
						<!--/-->
						<xsl:if test="@name">
							<xsl:attribute name="name"><xsl:value-of select="concat(@name,'_',$c,'_',$id)"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="@id">
							<xsl:attribute name="id"><xsl:value-of select="$new-id"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="@link-onclick and contains(@link-onclick,'$id')">
							<xsl:attribute name="link-onclick">
								<xsl:value-of select="concat(
									substring-before(@link-onclick,'$id'),$new-id,substring-after(@link-onclick,'$id')
								)"/>
							</xsl:attribute>
						</xsl:if>

						<xsl:variable name="rid" select="'??id??'"/>
						<xsl:choose>
							<xsl:when test="not(@process-node='true')">
								<xsl:copy-of select="node()"/>
							</xsl:when>
							<xsl:when test="contains(.,$rid)">								
								<xsl:value-of disable-output-escaping="yes" select="concat(
									substring-before(.,$rid),
									concat(@id,'_',$c,'_',$id),
									substring-after(.,$rid)
								)"/>
							</xsl:when>
							<xsl:otherwise>															
								<xsl:copy-of select="node()"/>							
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="position()=last()">
							<nobr>
								<img src="/{$theme}/images/1x1.gif" width="3" height="1"/>
								<a style="cursor:hand; cursor:pointer" onclick="Add{$c}()">
									<img 
										id="{concat('v_',$c,'_add_',$id)}"
										onmouseover="callTip('{sw:html-escape($conf/add_label,'escape-all')}',event)"
										onmouseout="callTip('')"
										width="16" height="16" src="/{$theme}/icons/item_add.gif"
									>
										<xsl:if test="$row-pos &lt; ($count - 1) and not($reserve)">
											<xsl:attribute name="style">display:none;</xsl:attribute>
										</xsl:if>
									</img>
								</a>		  					
								<img
									id="{concat('v_',$c,'_adde_',$id)}" 
									src="/{$theme}/images/1x1.gif" width="16" height="16">
									<xsl:if test="not($row-pos &lt; ($count - 1) and not($reserve))">
										<xsl:attribute name="style">display:none;</xsl:attribute>
									</xsl:if>
								</img>
								<!--|-->
								<img src="/{$theme}/images/1x1.gif" width="3" height="1"/>
								<a style="cursor:hand; cursor:pointer" onclick="Remove{$c}('{$id}')">
									<img 
										id="{concat('v_',$c,'_del_',$id)}"
										border="0"
										onmouseover="callTip('{sw:html-escape($conf/remove_label,'escape-all')}',event)"
										onmouseout="callTip('')"
										width="16" height="16" src="/{$theme}/icons/item_delete.gif"
									>
										<xsl:if test="not($always-del) and $is-empty and $id!='zzz'">
											<xsl:attribute name="style">display:none;</xsl:attribute>
										</xsl:if>
									</img>
								</a>
								<img 
									id="{concat('v_',$c,'_dele_',$id)}"
									width="16" height="16" src="/{$theme}/images/1x1.gif"
								>
									<xsl:if test="not(not($always-del) and $is-empty and $id!='zzz')">
										<xsl:attribute name="style">display:none;</xsl:attribute>
									</xsl:if>
								</img>
								<xsl:text> </xsl:text>
							</nobr>
						</xsl:if>
					</xsl:element>
				</xsl:for-each>
			</ui:row>
		</xsl:for-each>
		<!-- /Post Rows -->		
		
		<!--- Add row with internal data -->		
		<ui:row div_id="add_bar_{$c}">
			<xsl:if test="$conf/focus='1' and $first-control[self::ui:cell-input or self::ui:cell-list]">
				<script type="text/javascript">	
					if(counter_<xsl:value-of select="$c"/>==1){
						v = document.getElementById('v_<xsl:value-of select="concat($first-control,'_',$c)"/>_1');
						if ( checkShow('v_<xsl:value-of select="concat($first-control,'_',$c)"/>_1') ) v.focus();
						v.select();
					}
				</script>
			</xsl:if>
		</ui:row>		
		
		<!--|-->
	</xsl:template>

	<func:function name="sw:getItemsListJS">
		<xsl:param name="code"/>
		<xsl:param name="empty_value"/>
		<xsl:param name="first-control-name"/>
		<xsl:param name="config"/>
		<xsl:param name="controls"/>
		<!--|-->
		<xsl:variable name="res_src">
			<sw:text lang="C" disable-text-normalize="yes">
			<xsl:with-param name="f" select="$code"/>
			<xsl:with-param name="e" select="$empty_value"/>
			<xsl:with-param name="v" select="$first-control-name"/>			
			<xsl:with-param name="add-script" select="$config/add-script"/>
			<xsl:with-param name="reset_controls_code">
				<xsl:for-each select="$controls">		
					v=document.getElementById('<xsl:value-of select="@id"/>_<xsl:value-of select="$code"/>_'+id);
					<xsl:choose>
						<xsl:when test="self::ui:cell-input or self::ui:cell-file">
							v.value='';
						</xsl:when>
						<xsl:when test="self::ui:cell-list">
							v.selectedIndex=0;
						</xsl:when>
						<xsl:when test="self::ui:cell-selector">
							v.value='';
							v=document.getElementById('<xsl:value-of select="@id"/>_<xsl:value-of select="$code"/>_'+id+'_title');							
							v.value='';
						</xsl:when>
					</xsl:choose>
				</xsl:for-each>
			</xsl:with-param>
			<![CDATA[
				<script type="text/javascript">	
				
				var disabled%{f}=false;
							
				function updateDel%{f}(id,text_value,skip_total_check){
					if( skip_total_check!=1 && total_%{f} > 1){
						return;
					}
					icon=document.getElementById('v_%{f}_del_'+id);
					icone=document.getElementById('v_%{f}_dele_'+id);					
					if(text_value!=''){
						icon.style.display='';
						icone.style.display='none';
					}else{
						icon.style.display='none';
						icone.style.display='';
					}
				}
				
				function Remove%{f}(id){
					if(disabled%{f}){
						return false;
					}
					f = document.getElementById('%{v}_%{f}_'+1);
					if(f.type=='text'){
						if ( checkShow('%{v}_%{f}_'+1) ) f.focus();
					}					
					row=document.getElementById('row_%{f}_'+id);
					if(row){
						if(total_%{f}>1){
							row.style.display='none';
							total_%{f} = total_%{f}-1;
							
							if(last_%{f}==id){
								// oops, user removed row with "add" icon
								for(i=parseInt(id)-1;i>0;i--){
									srow=document.getElementById('row_%{f}_'+i);
									if(srow && srow.style.display!='none'){
										// hide empty image
										eicon=document.getElementById('v_%{f}_adde_'+i);
										eicon.style.display='none';
										//
										sicon=document.getElementById('v_%{f}_add_'+i);
										sicon.style.display='';
										last_%{f} = i;
										break;
									}
								}
							}
						}else{
							%{reset_controls_code}
							updateDel%{f}(id,'',0);							
						}
					}
				}
				function disable_%{f}(new_state){
					disabled%{f}=new_state;
					for(i=1;i<=counter_%{f};i++){  												
						row=document.getElementById('row_%{f}_'+i);
						if(row && row.style.display!='none'){				
							for(n=0;n<names_%{f}.length;n++){
								v=document.getElementById(names_%{f}[n]+'_%{f}_'+i);
								if(v){
									v.disabled=new_state;
								}
							}
						}
					}
				}
				function Submit%{f}(){
					res='';  		
					total = 0;
					for(i=1;i<=counter_%{f};i++){  												
						row=document.getElementById('row_%{f}_'+i);
						if(row && row.style.display!='none'){							
							total++;
							if(total>1){
								res = res + '(';
							}
							for(n=0;n<names_%{f}.length;n++){
								v=document.getElementById(names_%{f}[n]+'_%{f}_'+i);
								if(v){
									if(n>0){
										res = res + '|';
									}
									res = res + v.value;
								}
							}
						}						
					}
					names='';
					for(n=0;n<names_%{f}.length;n++){
						names= names + (n>0?'|':'') + names_%{f}[n];
					}
					document.getElementById('%{f}').value=res;
					document.getElementById('%{f}_names').value=names;
					document.getElementById('%{f}_total').value=total;
  			}
				function Add%{f}(){
					if(disabled%{f}){
						return false;
					}

					%{add-script}
										
					new_counter = counter_%{f}+1;

					template_div = document.getElementById('template_%{f}');
					re = /(zzz)/g;
					new_row_html = template_div.innerHTML.replace(re,new_counter);
					
					new_rows_div = document.getElementById('end_%{f}_'+counter_%{f});
					if(!new_rows_div){
						add_bar_div = document.getElementById('add_bar_%{f}');
						add_bar_div.innerHTML=new_row_html+add_bar_div.innerHTML;
					}else{
						new_rows_div.innerHTML=new_rows_div.innerHTML+new_row_html;
					}
					counter_%{f} = new_counter;
					f = document.getElementById('%{v}_%{f}_'+new_counter);
					if(f.type=='text'){
						if ( checkShow('%{v}_%{f}_'+new_counter) ) f.focus();
						f.select();
					}
					
					total_%{f}= total_%{f}+1;
					
					// hide current "add" icon 
					last_icon = document.getElementById('v_%{f}_add_'+last_%{f});					
					if(last_icon){
						eicon = document.getElementById('v_%{f}_adde_'+last_%{f});	
						eicon.style.display="";
						last_icon.style.display="none";
						updateDel%{f}(last_%{f},'x',1);
					}
					last_%{f} = new_counter;
				}
				</script> 
				]]>
			</sw:text>
		</xsl:variable>
		<func:result select="$res_src"/>
	</func:function>

</xsl:stylesheet>
