<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func html date local"
  exclude-result-prefixes="ui html func date local"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"  
  xmlns:html="http://www.swsoft.com/xsl/cp/html"
  xmlns:func="http://exslt.org/functions"
  xmlns:date="http://exslt.org/dates-and-times"
  xmlns:local="http://www.swsoft.com/xsl/cp/local"  
>
	<sw:include href="/layout/lib/html.xsl"/>
	
	<xsl:template name="local:inject-form-method">
		<xsl:choose>
			<xsl:when test="/ui:screen/ui:properties/ui:form-get">
				<xsl:attribute name="method">get</xsl:attribute>
        <xsl:if test="not(@action)"><xsl:attribute name="action"></xsl:attribute></xsl:if>		
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="method">post</xsl:attribute>
				<xsl:attribute name="enctype">multipart/form-data</xsl:attribute>				
				<xsl:attribute name="action">
		      <xsl:choose>
		      	<xsl:when test="not(@action)">
		      		<xsl:value-of select="'?post=1'"/>
		      	</xsl:when>
		      	<xsl:otherwise>
		      		<xsl:value-of select="@action"/>		      	
		      	</xsl:otherwise>
		      </xsl:choose>
				</xsl:attribute>        
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

  <!-- Insert "open" tag for default form -->
	<xsl:template name="default-form-open">
		<xsl:choose>
			<xsl:when test="/ui:screen/ui:properties/ui:no-default-form">
			</xsl:when>
			<xsl:otherwise>  			
		    <xsl:variable name="form-tag">
		    	<form>
	    			<xsl:call-template name="local:inject-form-method"/>		    	
						<xsl:if test="not(/ui:screen/ui:properties/ui:form)">
							<xsl:attribute name="name">defaultForm</xsl:attribute>
							<xsl:attribute name="id">defaultForm</xsl:attribute>	
						</xsl:if>
						<xsl:for-each select="/ui:screen/ui:properties/ui:form">
		    			<xsl:copy-of select="@*" />
		    			<xsl:choose>
			    			<xsl:when test="not(@name or @id)">
			    				<xsl:attribute name="name">defaultForm</xsl:attribute>
			    				<xsl:attribute name="id">defaultForm</xsl:attribute>
			    			</xsl:when>
			    			<xsl:when test="not(@id)">
		    					<xsl:attribute name="id" select="@name"/> 
			    			</xsl:when>
			    			<xsl:when test="not(@name)">
		    					<xsl:attribute name="name" select="@id"/> 
			    			</xsl:when>
			    		</xsl:choose>			    		
		    			<xsl:variable name="submit-events" select="//ui:event[@type='onsubmit']" />
		    			<xsl:if test="$submit-events">
		    				<xsl:attribute name="onsubmit">
		    					<xsl:for-each select="$submit-events">
		    						<xsl:value-of select="." />
		    					</xsl:for-each>
		    					<xsl:copy-of select="@submit" />
		    				</xsl:attribute>
		    			</xsl:if>
			    	</xsl:for-each>		    			
	    		</form>
		    </xsl:variable>
		    <xsl:copy-of select="html:tag-open($form-tag)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Insert "close" tag for default form -->
	<xsl:template name="default-form-close">
		<xsl:choose>
			<xsl:when test="//ui:properties/ui:no-default-form">
			</xsl:when>
			<xsl:otherwise>  			
				<xsl:variable name="form-tag">
					<form/>
				</xsl:variable>
				<xsl:copy-of select="html:tag-close($form-tag)"/>
			</xsl:otherwise>  			
		</xsl:choose>
	</xsl:template>

  <!-- insert form open aka XML hack -->
  <xsl:template mode="form-open" match="ui:form">
    <xsl:variable name="form-tag">
      <form>
   			<xsl:call-template name="local:inject-form-method"/>
        <xsl:copy-of select="@*"/>
        <xsl:choose>
        	<xsl:when test="not(@name or @id)">
        		<xsl:attribute name="name">defaultForm</xsl:attribute>
        		<xsl:attribute name="id">defaultForm</xsl:attribute>
        	</xsl:when>
        	<xsl:when test="not(@id)">
        		<xsl:attribute name="id" select="@name" />
        	</xsl:when>
        	<xsl:when test="not(@name)">
        		<xsl:attribute name="name" select="@id" />
        	</xsl:when>
        </xsl:choose>
        <xsl:variable name="submit-events" select="//ui:event[@type='onsubmit']"/>					
      	<xsl:if test="$submit-events">
        	<xsl:attribute name="onsubmit">
        		<xsl:for-each select="$submit-events">
        			<xsl:value-of select="."/>
        		</xsl:for-each>
        		<xsl:copy-of select="@submit"/>
        	</xsl:attribute>
        </xsl:if>
      </form>
    </xsl:variable>
    <xsl:copy-of select="html:tag-open($form-tag)"/>
  </xsl:template>

  <!-- insert form close aka XML hack -->
  <xsl:template mode="form-close" match="ui:form">
    <xsl:variable name="form-tag"><form/></xsl:variable>
    <xsl:copy-of select="html:tag-close($form-tag)"/>
  </xsl:template>

  <!-- open <div> tag conditially -->
	<xsl:template name="html:div-open">    
		<xsl:if test="@div_id">
    	<xsl:variable name="div-tag">
	    	<div id="{@div_id}"  style="vertical-align:middle;{
	    		sw:if( @div_display,concat('display:',@div_display,';'),'' )
	    	}{
	    		sw:if( @div-height,concat('height:',@div-height,';'),'' )
	    	}">
	    	</div>
	    </xsl:variable>
      <xsl:copy-of select="html:tag-open($div-tag)"/>
		</xsl:if>    
	</xsl:template>
	

  <!-- close </div> tag conditially -->
  <xsl:template name="html:div-close">    
    <xsl:if test="@div_id">
    	<xsl:variable name="div-tag"><div/></xsl:variable>
      <xsl:copy-of select="html:tag-close($div-tag)"/>
    </xsl:if>    
  </xsl:template>     
  
  <xsl:template name="html:calc-width">
  	<xsl:param name="control"/>
  	<xsl:param name="default" select='600'/>
  	<xsl:param name="use-def-width" select="false()"/>
  	<xsl:param name="error"/>
  	<xsl:param name="as-text" select="false()"/>
  	
  	<xsl:variable name="parent-block" select="ancestor::*[name()='ui:block']"/>
  	<xsl:variable name="parent-rows" select="ancestor::*[starts-with(name(),'ui:rows-') or name()='ui:desktop-rows']"/>
  	
  	<xsl:if test="not($parent-block) and not($parent-rows) and not($control/@width) and not($use-def-width)">
	  	<xsl:message terminate="yes">
	  		Error in html:calc-width: 	<xsl:value-of select="$error"/>
	  		Looks parents in session.
	  		<xsl:if test="sw:sesput('parents',ancestor::*)"/>
	  		<xsl:if test="sw:sesput('control',$control)"/>
	  		<xsl:if test="sw:sesput('parents','')"/>
	  		<xsl:if test="sw:sesput('control','')"/>
			</xsl:message>
		</xsl:if>
		
		<xsl:variable name="width-src">
			<xsl:choose>
				<xsl:when test="$parent-rows">full</xsl:when>
				<xsl:when test="$parent-block/@width"><xsl:value-of select="$parent-block/@width"/></xsl:when>
				<xsl:when test="$control/@width"><xsl:value-of select="$control/@width"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$default"/></xsl:otherwise>
			</xsl:choose>
		
		
		</xsl:variable>
		<xsl:variable name="width">
			<xsl:choose>
				<xsl:when test="$width-src = 'none'"></xsl:when>
				<xsl:when test="$width-src = 'max'">700</xsl:when>
				<xsl:when test="$width-src = 'full'">100%</xsl:when>					
				<xsl:otherwise><xsl:value-of select="$width-src"/></xsl:otherwise>
			</xsl:choose>				
		</xsl:variable>
		
		<xsl:choose>
			<xsl:when test="$width = ''"></xsl:when>
			<xsl:when test="$as-text"><xsl:value-of select="$width"/><xsl:if test="not(substring($width,string-length($width)) = '%')">px;</xsl:if></xsl:when>
			<xsl:otherwise><xsl:attribute name="width"><xsl:value-of select="$width"/></xsl:attribute></xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
  
	<xsl:template name="html:rows-closing-js-onclick">
		<sw:text lang="C"> 
			<xsl:with-param name="id" select="@name"/>
			v=h.value==1?'block':'none';document.getElementById('%{id}_span').style.display=v;
		</sw:text> 
	</xsl:template>  
  
 	<xsl:template name="html:js-onclick">
 		<xsl:variable name="code" select="sw:if(@type='checkbox','checked','checked')"/>

    <!-- enable/disable fields -->
    <xsl:for-each select="ui:control-slave">
    	<xsl:choose>
    		<xsl:when test="@action='hide'">
    			showObjExt('<xsl:value-of select="."/>',<xsl:if test="@inverse='true'">!</xsl:if><xsl:value-of select="$code"/>);
    		</xsl:when>
    		<xsl:otherwise>
		    	<xsl:text>document.getElementById('</xsl:text><xsl:value-of select="."/><xsl:text>').disabled</xsl:text><xsl:value-of select="sw:if(@inverse='true','=','=!')"/><xsl:value-of select="$code"/><xsl:text>;</xsl:text>
		   	</xsl:otherwise>
		   </xsl:choose>
    </xsl:for-each>

    <!-- all other onclick attributes -->
    <xsl:value-of select="@onclick"/><xsl:text>;</xsl:text>
  </xsl:template>
	
	
	<xsl:template match="ui:event">			
	</xsl:template>

  <xsl:template match="ui:row-favorites">
		<xsl:variable name="cookie" select="string($request/http_request/cookies/parameter[name = 'vzcp-favorites-tab']/value)"/>
		<xsl:if test="not($cookie)">
			<script language="Javascript">setCookie("vzcp-favorites-tab",'<xsl:value-of select="ui:js-tab[1]/@id"/>', 2E12);</script>
		</xsl:if>
		<tr>
			<td>
				<div id="screenTabs">
					<div class="tabs">
						<ul>
							<xsl:apply-templates select="*" mode="tabs">
								<xsl:with-param name="current-tab" select="sw:if($cookie,$cookie,ui:js-tab[1]/@id)"/>
							</xsl:apply-templates>
						</ul>
					</div>	
				</div>
				<div class="favorites">
					<xsl:apply-templates select="*" mode="content">
						<xsl:with-param name="current-tab" select="sw:if($cookie,$cookie,ui:js-tab[1]/@id)"/>
					</xsl:apply-templates>
				</div>
			</td>
		</tr>
  </xsl:template>	
	
	<xsl:template match="ui:rows-section">    
		<table cellpadding="0" cellspacing="0" >
			<tr>
				<td>
					<img src="/{$theme}/images/1x1.gif" width="20" height="1"/>
				</td>
				<td width="100%">
					<fieldset id="{@id}">
						<xsl:attribute name="style">
							<xsl:if test="not(@show-border='true')">border:0px solid black;</xsl:if>
							<xsl:if test="@show-border='true'">border-bottom:1px solid gray;border-top:0px solid gray;</xsl:if>
							<xsl:if test="@hidden='true'">display:none;</xsl:if>
						</xsl:attribute>
						<xsl:if test="@height">
							<xsl:attribute name="style">height:<xsl:value-of select="@height"/>px;overflow:auto;</xsl:attribute>
						</xsl:if>
						<xsl:if test="@title">
						  <legend style="margin-left: -2px;"><xsl:value-of select="@title"/></legend>
						</xsl:if>
						<xsl:apply-templates select="*"/>
					</fieldset>
				</td>
				<td>
					<img src="/{$theme}/images/1x1.gif" width="10" height="1"/>
				</td>
			</tr>
			<tr>
				<td colspan="3">
					<img src="/{$theme}/images/1x1.gif" width="10" height="10"/>
				</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template match="ui:div">    
		<xsl:param name="args" select="/.."/> 
		<div id="{@id}">
			<xsl:attribute name="style">
				<xsl:if test="@hidden!='true'">display:block;</xsl:if>
				<xsl:if test="@hidden='true'">display:none;</xsl:if>
				<xsl:if test="@height">height:<xsl:value-of select="@height"/>px;overflow:auto;</xsl:if>
			</xsl:attribute>
			<xsl:apply-templates select="*">
				<xsl:with-param name="args" select="$args"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>
	
  <xsl:template match="ui:row">
    <xsl:param name="args" select="/.."/>
    
    <sw:die test="@required">
    	Oooo. 
    	@required can be used only for ui:cell
    </sw:die>
    
    <xsl:variable name="separate-tables" select="ancestor::ui:rows/@separate-tables='true'"/>
   
    <xsl:variable name="table-tag">
   		<xsl:variable name="mode-edit" select="ancestor::ui:block/@mode='edit'"/>					      		
			<table cellpadding="{sw:if($mode-edit,3,3)}" cellspacing="0" border="0" class="none">
				<xsl:if test="not(@table-width='none')">
					<xsl:attribute name="width"><xsl:value-of select="sw:if(@table-width,@table-width,'100%')"/></xsl:attribute>
				</xsl:if>
			</table>
    </xsl:variable>    
    
    <xsl:call-template name="html:div-open"/>        
    
    <xsl:if test="$separate-tables">
			<xsl:copy-of select="html:tag-open($table-tag)"/>
		</xsl:if>
		
    
    <xsl:choose>

      <!-- have no cells -->
      <xsl:when test="not(ui:cell) and not(*[ starts-with(name(),'ui:cell')])">
        <xsl:copy-of select="node()[not(self::ui:*)]"/>
        <xsl:apply-templates select="ui:*"/>
      </xsl:when>

      <!-- has cells -->
      <xsl:otherwise>
      
        <!-- row definition -->
        <tr>
          <xsl:if test="@class">
          	<xsl:copy-of select="@class"/>
          </xsl:if>
          <xsl:if test="@style">
          	<xsl:copy-of select="@style"/>
          </xsl:if>
          
          <xsl:if test="@type='head'">
            <xsl:attribute name="class">subHeader</xsl:attribute>
          </xsl:if>

          <!-- hide if desired -->
		      <xsl:if test="@hide=1">
	        	<xsl:attribute name="style">display:none;</xsl:attribute>
	        </xsl:if>

          <!-- highlight error row -->
          <xsl:variable name="has-error" select="child::*/@id = $args/error/control"/>
          
       	
          <xsl:if test="@contains-error or $has-error">
            <xsl:attribute name="class">RowError</xsl:attribute>
          </xsl:if>

					<xsl:variable name="first-control-src" select="child::*[
						(name()='ui:cell-selector') 						
						or (name()='ui:cell-list-selector')
						or (name()='ui:cell-input-phone') 
						or (name()='ui:cell-input-name') 
						or (name()='ui:cell-file') 
						or (name()='ui:cell-list') 
						or (name()='ui:cell-list-picker') 
						or (name()='ui:cell-radio') 
						or (name()='ui:cell-input') 
						or (name()='ui:cell-inputblock') 
						or (name()='ui:cell-dashboard-item')
						or (@type and @type!='custom' and name()!='ui:cell-text' and name()!='ui:cell-label' )][1]"/>
					<xsl:variable name="first-control-id" select="$first-control-src/@id"/>
          <xsl:variable name="first-control">
          	<xsl:if test="$first-control-id">
	            <first-control>
	              <xsl:value-of select="$first-control-id"/>
	            </first-control>
	           </xsl:if>
          </xsl:variable>
          
          <xsl:choose>          
          	<xsl:when test="@id">
          		<xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
          	</xsl:when>
          	<xsl:when test="$first-control-id">
          		<xsl:attribute name="id">row__<xsl:value-of select="$first-control-id"/></xsl:attribute>
          	</xsl:when>
          </xsl:choose>
          
          <!-- iterate cells -->
          <xsl:apply-templates select="ui:*">
            <xsl:with-param name="args" select="$args|exsl:node-set($first-control)"/>
          </xsl:apply-templates>
        </tr>
      </xsl:otherwise>
      
    </xsl:choose>
              
    <xsl:if test="$separate-tables">
			<xsl:copy-of select="html:tag-close($table-tag)"/>
		</xsl:if>

    <xsl:if test="@span_after_id">
      <span id="{@span_after_id}"/>
    </xsl:if>
    
    <xsl:call-template name="html:div-close"/>    

  </xsl:template>

  <xsl:template match="ui:cell|ui:cell-text|ui:cell-actions|ui:cell-value|ui:cell-selector|
  	ui:cell-list-selector|ui:cell-inputblock|ui:cell-input|ui:cell-file|
  	ui:cell-list-picker|
  	ui:cell-list|ui:cell-radio|ui:cell-check|
  	ui:cell-label|ui:cell-input-phone|ui:cell-input-name|
  	ui:cell-button|ui:cell-buttons|ui:cell-dashboard-item
  ">
    <xsl:param name="args" select="/.."/>
    
    <xsl:variable name="type">
    	<xsl:choose>
    		<xsl:when test="starts-with(name(),'ui:cell-')">
    			<xsl:value-of select="substring-after(name(),':')"/>
    		</xsl:when>
    		<xsl:otherwise>
    			<xsl:value-of select="@type"/>
    		</xsl:otherwise>
    	</xsl:choose>
    </xsl:variable>
    <xsl:variable name="name" select="sw:if(@name!='',@name,@id)"/>
    
    <xsl:variable name="need-row-offset" select="(../@offset &gt; 0) and (position() = 1)"/>
    <xsl:variable name="need-nowrap" select="((../@type = 'head') and (not(@nowrap)) or (@nowrap='1') or @offset &gt; 0 or $need-row-offset or self::ui:cell-selector)"/>
    
    <xsl:variable name="td-tag">
      <td>
      	<xsl:copy-of select="@onmouseover"/>
      	<xsl:copy-of select="@onmouseout"/>
        <xsl:if test="@tdstyle='title' or $type='cell-label'">
          <xsl:attribute name="width">180px</xsl:attribute>
          <xsl:attribute name="valign">top</xsl:attribute>
        </xsl:if>
        <xsl:if test="name()='ui:cell-value'">
        	<!--<xsl:attribute name="width">100%</xsl:attribute>-->
        	<xsl:attribute name="align">left</xsl:attribute>
        </xsl:if>
        <xsl:copy-of select="@colspan|@align"/>
        <xsl:if test="not(@align)">
          <xsl:attribute name="align">left</xsl:attribute>
        </xsl:if>
        <xsl:if test="$type = 'cell-label' or not($type!='')">
        	<xsl:copy-of select="@id"/>
        </xsl:if>
        <xsl:if test="@cell-width">
        	<xsl:attribute name="width"><xsl:value-of select="@cell-width"/></xsl:attribute>
        </xsl:if>
        <xsl:if test="@cell-style">
        	<xsl:attribute name="style"><xsl:value-of select="@cell-style"/></xsl:attribute>
        </xsl:if>
        <xsl:if test="$need-nowrap">
					<xsl:attribute name="nowrap">1</xsl:attribute>
        </xsl:if>
        <xsl:if test="$type = 'cell-dashboard-item' or @cell-valign='top'">
					<xsl:attribute name="valign">top</xsl:attribute>
        </xsl:if>        		
      </td>
    </xsl:variable>
    		
		<xsl:variable name="td-nowrap">
			<nobr/>
    </xsl:variable>

    <xsl:if test="not(@open) or @open='true'">
      <xsl:copy-of select="html:tag-open($td-tag)"/>
    </xsl:if>
    
    <xsl:if test="$need-nowrap">
    	<xsl:copy-of select="html:tag-open($td-nowrap)"/>
    </xsl:if>

    <!-- cell offeset -->
    <xsl:if test="@offset &gt; 0">
      <img src="/{$theme}/images/1x1.gif" width="{@offset * 10}" height="1"/>
    </xsl:if>

    <!-- row offset -->
    <xsl:if test="$need-row-offset">
      <img src="/{$theme}/images/1x1.gif" width="{../@offset * 10}" height="1"/>
    </xsl:if>

    <xsl:call-template name="html:div-open"/>

		<xsl:if test="not(@id) and @name and $type and $type!='cell-label' and $type!='cell-radio'">
			<xsl:message>
				Context data before sw:die - 
				<sw:text select="."/>
			</xsl:message>
			<sw:die>
				You should specify @id attribute for ui:cell/@name='<xsl:value-of select="@name"/>'
			</sw:die>
		</xsl:if>

    <xsl:choose>
      <xsl:when test="$type = 'cell-label' or $type='cell-text' or not($type!='')">
      	<xsl:variable name="master">
	        <xsl:choose>
	        	<xsl:when test="@label"><xsl:value-of select="@label"/></xsl:when>
	          <xsl:when test="$args/first-control"><xsl:value-of select="$args/first-control"/></xsl:when>	          
	        </xsl:choose>
	      </xsl:variable>
	      <xsl:choose>
        	<xsl:when test="$master!=''">
            <label for="{$master}">
            	<xsl:apply-templates select="ui:*"/>
          	  <xsl:copy-of select="node()[not(self::ui:*)]"/>
            </label>
          </xsl:when>          
          <xsl:otherwise>						
						<xsl:apply-templates select="ui:*"/>
            <xsl:copy-of select="node()[not(self::ui:*)]"/>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="
        	(((
        		../@required='true' 
        		or ../ui:*/@required='true'
        		) and  ( (position() = 1) or $type='cell-label' or $type='cell-text' )
        		and ( $type!='cell-text' or node()!='.')
        		)
        		or @show-aster='true'
        	) and not(@show-aster='false')
        ">
		      <img src="/{$theme}/images/1x1.gif" width="5" height="1"/><font color="#FF0000">*</font>
		    </xsl:if>
      </xsl:when>
		
			<!-- actions -->
      <xsl:when test="($type = 'cell-actions')">
      	<table cellpadding="0" cellspacing="0" border="0">      	
	        <xsl:for-each select="ui:action-link">
	        	<tr><td>
	        		<xsl:apply-templates select="."/>
	        	</td></tr>
	        </xsl:for-each>
				</table>
			</xsl:when>

		 	<!-- textarea -->
      <xsl:when test="($type = 'cell-inputblock')">
        <textarea name="{$name}">
          <xsl:copy-of select="@*[
          	name() != 'disabled'
          	and name() != 'tip' 
          	and name() != 'cell-width' 
          	and name() != 'width'
          ]"/>
          <xsl:attribute name="cols">
		        <xsl:choose>
		        	<xsl:when test="@width"><xsl:value-of select="@width"/></xsl:when>
		        	<xsl:otherwise>40</xsl:otherwise>
		        </xsl:choose>
          </xsl:attribute>
          <xsl:if test="@tip">
          	<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip"/>', event)</xsl:attribute>
          	<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
          </xsl:if>
          <xsl:if test="@disabled='true'">
            <xsl:attribute name="disabled"/>
          </xsl:if>
          <xsl:copy-of select="node()"/>
        </textarea>
      </xsl:when>
	
      <!-- text, password -->
      <xsl:when test="($type = 'cell-input')">
        <input name="{$name}">        
          <xsl:copy-of select="@*[name() != 'disabled' 
          	and name() != 'tip' 
          	and name() != 'cell-width' 
          	and name() != 'width'
          ]"/>
          <xsl:if test="@mode-password='true'">
						<xsl:attribute name="type">password</xsl:attribute>
          </xsl:if>
          <xsl:if test="@tip">
          	<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip"/>', event)</xsl:attribute>
          	<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
          </xsl:if>
          <xsl:choose>
	          <xsl:when test="@width">
	            <xsl:attribute name="class">FlatInputFlow</xsl:attribute>
	            <xsl:attribute name="size"><xsl:value-of select="@width"/></xsl:attribute>
	          </xsl:when>
	          <!--
	          <xsl:when test="@width and @width &lt; 20">
	            <xsl:attribute name="class">FlatInputFlow</xsl:attribute>
	            <xsl:attribute name="size"><xsl:value-of select="@width"/></xsl:attribute>
	          </xsl:when>
	          <xsl:when test="@width and @width &gt; 80">
	            <xsl:attribute name="class">FlatInputFlow</xsl:attribute>
	            <xsl:attribute name="size"><xsl:value-of select="@width"/></xsl:attribute>
	          </xsl:when>
	          -->
	          <xsl:otherwise>
	            <xsl:attribute name="class">FlatInput</xsl:attribute>
	          </xsl:otherwise>
	        </xsl:choose>
          <xsl:if test="@disabled='true'">
            <xsl:attribute name="disabled"/>
          </xsl:if>
        </input>
        <xsl:copy-of select="node()"/>
        <xsl:if test="@alone-in-form = 'yes' and contains($http-user-agent,'MSIE')">
          <input type="text" size="1" style="display:none"/>
        </xsl:if>
      </xsl:when>
      
      <!-- 	list-selector  -->
      <xsl:when test="($type = 'cell-list-selector')">
				<xsl:variable name="arr" select="concat('Arr_',@id)"/>      
      	<xsl:variable name="left-title" select="sw:if(@header-left,@header-left,sw:text('Available'))"/>
      	<xsl:variable name="right-title" select="sw:if(@header-right,@header-right, sw:text('Selected'))"/>
      	<xsl:variable name="size" select="sw:if(@size,@size, 6)"/>
      	<xsl:variable name="src-item-select" select="ui:item-select"/>
      	<xsl:variable name="items-selected">
      		<xsl:copy-of select="ui:item[@selected = 'true']"/>
    			<xsl:for-each select="ui:item-select">
    				<xsl:variable name="value" select="@value"/>
    				<xsl:copy-of select="../ui:item[@value = $value]"/>
    			</xsl:for-each>
      	</xsl:variable>
      	<xsl:variable name="items-avail" select="
      		ui:item[not(@selected = 'true') and not(@value=$src-item-select/@value)]
      	"/>

				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<!-- header -->
					<tr>
						<td width="50%"><xsl:value-of select="$left-title"/></td>
						<td><img src="/{$theme}/images/1x1.gif" width="60" height="1"/></td>
						<td width="50%"><xsl:value-of select="$right-title"/></td>
					</tr>
					<!-- /header -->
						<tr>
							<!-- left list -->
							<td valign="top" width="50%">
								<select id="{@id}_left" name="{@id}_left" multiple="1" size="{$size}" width="100%" style="width:100%" ondblclick="moveRight('{@id}')">
									<xsl:for-each select="$items-avail">
										<option value="{@value}">
											<xsl:if test="string(@value) = ''"><xsl:attribute name="style">color:#555555</xsl:attribute></xsl:if>
											<xsl:value-of select="."/>
										</option>
									</xsl:for-each>
								</select>
							</td>
							<!-- /left list -->
							<!-- h_buttons -->
							<td align="center">
								<table cellpadding="" cellspacing="4" border="0">
									<tr>
										<td>
											<xsl:variable name="btn">
												<ui:button id="{@id}_right_button" onclick="moveRight('{@id}')" type="short" do-submit="false">&gt;&gt;</ui:button>
						        	</xsl:variable>
											<xsl:call-template name="ui:show-button">
												<xsl:with-param name="btn" select="exsl:node-set($btn)/ui:button"/>
											</xsl:call-template>						
										</td>
									</tr>
									<tr>
										<td>
											<xsl:variable name="btn">
												<ui:button id="{@id}_left_button" onclick="moveLeft('{@id}')" type="short" do-submit="false">&lt;&lt;</ui:button>
											</xsl:variable>
											<xsl:call-template name="ui:show-button">
												<xsl:with-param name="btn" select="exsl:node-set($btn)/ui:button"/>
											</xsl:call-template>
										</td>
									</tr>
								</table>
							</td>
							<!-- /h_buttons -->
							<!-- right list -->
							<td valign="top" width="50%">
							<select id="{@id}_right" name="{@id}" multiple="1" size="{$size}" width="100%" style="width:100%" ondblclick="moveLeft('{@id}')">
								<xsl:for-each select="exsl:node-set($items-selected)/ui:item">
									<option value="{@value}">
										<xsl:if test="string(@value) = ''"><xsl:attribute name="style">color:#555555</xsl:attribute></xsl:if>
										<xsl:value-of select="."/>
									</option>
								</xsl:for-each>
							</select>
							</td>
						<!-- /right list -->
						<script language="JavaScript">
							<xsl:value-of select="$arr"/> = new Array();		
							moveCheckLR('<xsl:value-of select="@id"/>');		
						</script>
					</tr>
					
					<xsl:if test="@sort-logic='true' or @updown-left='true' or @updown-right='true'">
						<tr>
							<xsl:if test="@sort-logic='true'">
								<script language="JavaScript">
									<xsl:for-each select="ui:item">
										<xsl:variable name="i" select="position() - 1"/>
										<xsl:value-of select="$arr"/>[<xsl:value-of select="$i"/>] = new Array();
										<xsl:value-of select="$arr"/>[<xsl:value-of select="$i"/>][0] = '<xsl:value-of select="sw:if(@value = ../ui:item-select/@value,1,0)"/>';
										<xsl:value-of select="$arr"/>[<xsl:value-of select="$i"/>][1] = 	'<xsl:value-of select="@value"/>';
										<xsl:value-of select="$arr"/>[<xsl:value-of select="$i"/>][2] = 	'<xsl:value-of select="."/>';
									</xsl:for-each>
								</script>
							</xsl:if>
				
						<!-- Up/Down butons -->
						<td align="center">
							<xsl:if test="@sort-logic='false' or @updown-left='true'">
								<table cellpadding="3" cellspacing="0" border="0">
									<tr>
										<td>
											<xsl:variable name="btn">
	      					  		<ui:button onclick="moveLeftUp('{@id}')" tip="btn_up" do-submit="false"><sw:text>Up</sw:text></ui:button>
						        	</xsl:variable>
											<xsl:call-template name="ui:show-button">
												<xsl:with-param name="btn" select="exsl:node-set($btn)/ui:button"/>
											</xsl:call-template>
										</td>
										<td>
											<xsl:variable name="btn">
				      		  		<ui:button onclick="moveLeftDown('{@id}')" tip="btn_down" do-submit="false"><sw:text>Down</sw:text></ui:button>
			      			  	</xsl:variable>
											<xsl:call-template name="ui:show-button">
												<xsl:with-param name="btn" select="exsl:node-set($btn)/ui:button"/>
											</xsl:call-template>
										</td>						
									</tr>
								</table>
							</xsl:if>
						</td>
						<td>&#160;</td>
						<td align="center">
							<xsl:if test="@sort-logic='true' or @updown-right='true'">
								<table cellpadding="3" cellspacing="0" border="0">
									<tr>
										<td>
											<xsl:variable name="btn">
	      					  		<ui:button onclick="moveRightUp('{@id}')" tip="btn_up" do-submit="false"><sw:text>Up</sw:text></ui:button>
						        	</xsl:variable>
											<xsl:call-template name="ui:show-button">
												<xsl:with-param name="btn" select="exsl:node-set($btn)/ui:button"/>
											</xsl:call-template>
										</td>
										<td>
											<xsl:variable name="btn">
				      		  		<ui:button onclick="moveRightDown('{@id}')" tip="btn_down" do-submit="false"><sw:text>Down</sw:text></ui:button>
			      			  	</xsl:variable>
											<xsl:call-template name="ui:show-button">
												<xsl:with-param name="btn" select="exsl:node-set($btn)/ui:button"/>
											</xsl:call-template>
										</td>						
									</tr>
								</table>
							</xsl:if>
							</td>
						</tr>
					</xsl:if>
				</table>
			
			</xsl:when>
      
      <!-- 	selector  -->
      <xsl:when test="($type = 'cell-selector')">
      	<xsl:choose>
      		<xsl:when test="@code-width">
      			<input type="text" size="{@code-width}" maxlength="{@code-maxlength}" 
      				id="{@id}" name="{$name}" value="{@code-value}" class="FlatInputFlow"
      			>
	         		<xsl:copy-of select="@*[name()='onchange']"/>
						</input>
						&#160;
      		</xsl:when>
      		<xsl:otherwise> 
      			<input type="hidden" value="{@code-value}" id="{@id}" name="{$name}">
	         		<xsl:copy-of select="@*[name()='onchange']"/>
      			</input>
      		</xsl:otherwise>
      	</xsl:choose>
        <input type="text" disabled="1" name="{concat(@id,'_title')}" id="{@id}_title">
          <xsl:copy-of select="@*[name()!='onchange' and 
          	name()!='id' and name()!='name' and name() != 'disabled' 
          	and name() != 'onmouseover' and name() != 'onmouseout']"
          />
          <xsl:if test="@width">
            <xsl:attribute name="class">FlatInputFlow</xsl:attribute>
            <xsl:attribute name="size"><xsl:value-of select="@width"/></xsl:attribute>
          </xsl:if>
          <xsl:if test="not(@width)">
            <xsl:attribute name="class">FlatInput</xsl:attribute>
          </xsl:if>
        </input>
        &#160;
        <!--
        <xsl:variable name="btn">
        	<ui:button onclick="{@link-onclick}" tip="{@link-tip}" do-submit="false">
        		<xsl:value-of select="@link-caption"/>
        	</ui:button>
        </xsl:variable>
        <xsl:call-template name="ui:show-button">
        	<xsl:with-param name="btn" select="exsl:node-set($btn)/ui:button"/>
        </xsl:call-template>
        -->
	      <a href="#" onclick="{@link-onclick};return false"						
				><img 
					onmouseover="callTip('{@link-tip}',event)" onmouseout="callTip('')"
					src="/{$theme}/icons/file_manager_16.gif" border="0" width="16" height="16"/></a>		
				<xsl:if test="@unset-tip">
					&#160;
					<a href="#" 
						onclick="defaultForm.{@id}.value='';defaultForm.{@id}_title.value='';"						
					><img 
						onmouseover="callTip('{@unset-tip}',event)" onmouseout="callTip('')"
						src="/{$theme}/icons/delete_16.gif" border="0" width="16" height="16"/></a>
				</xsl:if>			
				<xsl:copy-of select="node()"/>
      </xsl:when>
      
      <!-- 	phone control  -->
      <xsl:when test="($type = 'cell-input-phone')">
      	+&#160;
    		<input type="text" size="3" maxlength="4" 
    			onmouseover="callTip('phone_code',event)" onmouseout="callTip('')"      		
  				id="{@id}_code" name="{$name}_code" value="{@value-code}" class="FlatInputFlow"
  			>
					<xsl:if test="@disabled='true'"><xsl:attribute name="disabled"/></xsl:if>
  			</input>&#160;
    		(&#160;<input type="text" size="5" maxlength="10" 
    			onmouseover="callTip('phone_area',event)" onmouseout="callTip('')"      		
  				id="{@id}_area" name="{$name}_area" value="{@value-area}" class="FlatInputFlow"
  			>
					<xsl:if test="@disabled='true'"><xsl:attribute name="disabled"/></xsl:if>
  			</input>&#160;)&#160;
  			<input type="text" size="10" maxlength="10" 
    			onmouseover="callTip('phone_number',event)" onmouseout="callTip('')"      		
  				id="{@id}_number" name="{$name}_number" value="{@value-number}" class="FlatInputFlow"
  			>
					<xsl:if test="@disabled='true'"><xsl:attribute name="disabled"/></xsl:if>
  			</input>&#160;
  			<sw:text>Ext</sw:text>&#160;<input type="text" size="3" maxlength="10" 
    			onmouseover="callTip('phone_ext',event)" onmouseout="callTip('')"      		
  				id="{@id}_ext" name="{$name}_ext" value="{@value-ext}" class="FlatInputFlow"
  			>
					<xsl:if test="@disabled='true'"><xsl:attribute name="disabled"/></xsl:if>
  			</input>
      </xsl:when>
      
      <!-- 	user's name control  -->
      <xsl:when test="($type = 'cell-input-name')">
    		<input type="text" size="10" maxlength="255" 
    			onmouseover="callTip('name_first',event)" onmouseout="callTip('')"      		
    			id="{@id}_first" name="{$name}_first" value="{@value-first}" class="FlatInputFlow"
  			>
					<xsl:if test="@disabled='true'"><xsl:attribute name="disabled"/></xsl:if>
  			</input>&#160;  			  		
  			
    		<input type="text" size="10" maxlength="255" 
    			onmouseover="callTip('name_last',event)" onmouseout="callTip('')"      		
    			id="{@id}_last" name="{$name}_last" value="{@value-last}" class="FlatInputFlow"
  			>
					<xsl:if test="@disabled='true'"><xsl:attribute name="disabled"/></xsl:if>
  			</input>
  			    		
      </xsl:when>
      
      <!-- combo box -->
      <xsl:when test="$type = 'cell-list'">
        <xsl:call-template name="local:show-list">
        	<xsl:with-param name="name" select="$name"/>
        </xsl:call-template>
        <xsl:copy-of select="node()[name()!='ui:list-item']"/>
      </xsl:when>
      
      <!-- multirow selectable list with Add/Remove buttons -->
      <xsl:when test="$type = 'cell-list-picker'">
	      <xsl:call-template name="local:show-list">
	      	<xsl:with-param name="name" select="$name"/>        	
	      	<xsl:with-param name="is-multiple" select="true()"/>        	
	      </xsl:call-template>	        	       
				<br/><br/>
				<div class="uiActions">
					<xsl:choose>
						<xsl:when test="@script-add">
							<xsl:variable name="btn-add">
								<ui:button onclick="{@script-add};return false"
									tip="{sw:if(@add-tip,@add-tip,'add_items')}" do-submit="false">
										<xsl:value-of select="sw:if(@add-title,@add-title,sw:text('Add'))"/>						
								</ui:button>
							</xsl:variable>
							<xsl:call-template name="ui:show-button">
								<xsl:with-param name="btn" select="exsl:node-set($btn-add)/ui:button"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="ui:list-add-button">
							<xsl:for-each select="ui:list-add-button">
								<xsl:variable name="add-btn">
									<xsl:element name="ui:button">
										<xsl:copy-of select="@*[name() != 'do-submit']"/>
										<xsl:attribute name="do-submit">
											<xsl:value-of
												select="sw:if(current()/@do-submit,current()/@do-submit,'false')"/>
										</xsl:attribute>
										<xsl:value-of select="title"/>
									</xsl:element>
								</xsl:variable>
								<xsl:call-template name="ui:show-button">
									<xsl:with-param name="btn" select="exsl:node-set($add-btn)/ui:button"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:when>
						<xsl:otherwise/>
					</xsl:choose>
					<xsl:variable name="btn-remove">
			  		<ui:button onclick="listDelete('{$name}')" tip="remove_items" do-submit="false">
			  			<sw:text>Remove Selected</sw:text>
			  		</ui:button>
	      	</xsl:variable>
					<xsl:call-template name="ui:show-button">
						<xsl:with-param name="btn" select="exsl:node-set($btn-remove)/ui:button"/>
					</xsl:call-template>
				</div>
      </xsl:when>
      
      
   
      <!-- radio/checkbox-->
      <xsl:when test="($type = 'cell-radio') or ($type = 'cell-check')">
        <nobr>
         <input type="{sw:if($type='cell-radio','radio','checkbox')}" name="{$name}">
          	<xsl:choose>
          		<xsl:when test="@value"><xsl:copy-of select="@value"/></xsl:when>
          		<xsl:otherwise>
          			<xsl:attribute name="value">1</xsl:attribute>
          		</xsl:otherwise>
          	</xsl:choose>

            <!-- inject onclick attribute -->
            <xsl:attribute name="onclick">
            	<xsl:call-template name="html:js-onclick"/>
            </xsl:attribute>
            
            <!-- checked status -->
            <xsl:if test="@checked = 'true'">
              <xsl:attribute name="checked"/>
            </xsl:if>
            
            <xsl:copy-of select="@*[name() != 'value' and name() != 'checked' and name() != 'onclick' and name() != 'type']"/>
          </input> 
          <!--
          <img src="/{$theme}/images/1x1.gif" width="5" height="1"/>
          -->
          <xsl:copy-of select="./child::node()[not(self::ui:*)]"/>
        </nobr>
      </xsl:when>
      
      
      <!-- file -->
      <xsl:when test="($type = 'cell-file')">
        <nobr>
          <input name="{$name}" type="file">
            <xsl:copy-of select="@*"/>
          </input> 
          <img src="/{$theme}/images/1x1.gif" width="5" height="1"/>
          <xsl:copy-of select="./child::node()"/>
        </nobr>
      </xsl:when>
      
       <!-- file -->
      <xsl:when test="($type = 'traffic')">
      	<xsl:call-template name="ui:post-traffic-control">
      		<xsl:with-param name="name" select="$name"/>
      		<xsl:with-param name="value" select="@value"/>
      		<xsl:with-param name="one-date" select="@one-date"/>
      		<xsl:with-param name="from-date" select="@from-date"/>
      		<xsl:with-param name="to-date" select="@to-date"/>
      		<xsl:with-param name="tip" select="@tip"/>
					<xsl:with-param name="selector" select="@selector"/>
      	</xsl:call-template>
      </xsl:when>
      
      <!-- date -->
      <xsl:when test="($type = 'date')">
      	<xsl:call-template name="ui:post-date-control">
      		<xsl:with-param name="name" select="$name"/>
      		<xsl:with-param name="value" select="@value"/>
      		<xsl:with-param name="tip" select="@tip"/>
      		<xsl:with-param name="content" select="./child::node()"/>
      	</xsl:call-template>
      	<!-- check for screen properties -->
      	<xsl:if test="not(/ui:screen/ui:properties/ui:contains-date-control)">
      		<xsl:message terminate="yes">
					  Error in ui:cell/@type='date' - ui:screen/ui:properties/ui:contains-date-control is undefined			  		
			  		<xsl:if test="sw:sesput('parents',ancestor::*)"/>
					</xsl:message>
      	</xsl:if>
      </xsl:when>
      
      <!-- button -->
	<xsl:when test="($type = 'cell-button')">
		<xsl:call-template name="ui:show-button">
			<xsl:with-param name="btn" select="."/>
		</xsl:call-template>
      </xsl:when>
      
     <!-- multiple buttons in single cell -->
	<xsl:when test="($type = 'cell-buttons')">
		<div class="uiActions" style="margin:0">
			<xsl:for-each select="ui:button">
				<xsl:call-template name="ui:show-button">
					<xsl:with-param name="btn" select="."/>
				</xsl:call-template>			
			</xsl:for-each>
		</div>
      </xsl:when>      
     
      <xsl:when test="($type = 'cell-dashboard-item')">
      	<table width="100%" cellpadding="1" cellspacing="0" border="0">
      		<tr>
		      	<td valign="top">
					<a href="{@href}" onmouseover="callTip('{@tip}',event)" onmouseout="callTip()">
						<xsl:if test="@target">
							<xsl:attribute name="target"><xsl:value-of select="@target"/></xsl:attribute>
						</xsl:if>
						<img src="/{$theme}/icons/{@icon}_32.gif" class="qF"/>
					</a>
				</td>
				<td width="100%" valign="top">
					<a href="{@href}" onmouseover="callTip('{@tip}',event)" onmouseout="callTip()">
						<xsl:if test="@target">
							<xsl:attribute name="target"><xsl:value-of select="@target"/></xsl:attribute>
						</xsl:if>
						<b><sw:text select="@title"/></b>
					</a>
					<br/>
					<sw:text select="string(.)"/>
				</td>
      		</tr>
      	</table>
      </xsl:when>
      
	<!-- other else - copy contents-->
	<xsl:otherwise>
	<xsl:copy-of select="node()[not(self::ui:*)]"/>
        <xsl:apply-templates select="ui:*"/>
			</xsl:otherwise>
    </xsl:choose>

    <xsl:call-template name="html:div-close"/>    
    
    <xsl:if test="custom_after">
      <xsl:copy-of select="custom_after/child::node()"/>
    </xsl:if>

		<xsl:if test="$need-nowrap">
    	<xsl:copy-of select="html:tag-close($td-nowrap)"/>
    </xsl:if>
    
    <xsl:if test="@hard-width">
	    <br/><img src="/{$theme}/images/1x1.gif" width="{@hard-width}" height="0"/>
	  </xsl:if>


    <xsl:if test="not(@close) or (@close='true')">
      <xsl:copy-of select="html:tag-close($td-tag)"/>
    </xsl:if>

  </xsl:template>
  
  <!-- show common list -->
  <xsl:template name="local:show-list">
  	<xsl:param name="name"/>  	
  	<xsl:param name="is-multiple" select="false()"/>
  	<select name="{$name}">
	    <xsl:copy-of select="@*[not(self::value) and not(self::disabled) and not(self::width)]"/>
	    <xsl:if test="$is-multiple">	    	
	    	<xsl:attribute name="multiple"/>
	    </xsl:if>
	    <xsl:if test="@disabled='true'">
	      <xsl:attribute name="disabled"/>
	    </xsl:if>
	    <xsl:if test="not(@class)">
	    	<xsl:if test="@width">
	      	<xsl:attribute name="class">FlatSelectFlow</xsl:attribute>
	    	</xsl:if>
	    	<xsl:if test="not(@width)">
	      	<xsl:attribute name="class">FlatSelect</xsl:attribute>
	    	</xsl:if>
	    </xsl:if>          	
	    <xsl:variable name="value">
	    	<xsl:choose>
	    		<xsl:when test="@value!=''">
	    			<!-- current item was specified -->
	    			<xsl:value-of select="@value"/>
	    		</xsl:when>
	    		<xsl:otherwise>
	    			<!-- search first non-disabled item and make it current -->
	    			<xsl:value-of select="ui:list-item[not(@disabled='true')][1]/@id"/>
	    		</xsl:otherwise>
	    	</xsl:choose>
	    </xsl:variable>
	    <xsl:for-each select="ui:list-item">
	    	<option>
	    		<!-- post @style-->
	    		<xsl:choose>
	    			<xsl:when test="@disabled='true' or @grayed='true'">
							<xsl:choose>
								<xsl:when test="@color">
									<xsl:attribute name="style">color:<xsl:value-of select="@color"/></xsl:attribute>
								</xsl:when>
								<xsl:otherwise>
									<xsl:attribute name="style">color:#777777</xsl:attribute>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
					</xsl:choose>
					<!-- post @value -->
					<xsl:choose>
	    			<xsl:when test="@disabled='true'">
	    			<xsl:attribute name="value"><xsl:value-of select="''"/></xsl:attribute>							
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="value"><xsl:value-of select="@id"/></xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					
					<xsl:if test="not(@disabled='true') and $value and $value=@id">
						<xsl:attribute name="selected">1</xsl:attribute>
					</xsl:if>
	      	<xsl:value-of select="@title"/>
	      </option>
	    </xsl:for-each>
	  </select>
  </xsl:template>
  
  <!-- javascript check for inputs -->
  <xsl:template match="ui:control-slave">
  	<xsl:if test="not(@inverse='true')">
	    <script type="text/javascript">
	        <sw:text lang="C">
	          <xsl:with-param name="refid" select="."/>
	          <xsl:with-param name="myid" select="../@id"/>
	          <xsl:with-param name="expr" select="sw:if(@inverse='true','=','=!')"/>
			 			document.getElementById('%{refid}').disabled %{expr} (document.getElementById('%{myid}').checked);
	        </sw:text>
	    </script>
	  </xsl:if>
  </xsl:template>
  
  <!-- 
  	Post "Date" picker
  -->
	<xsl:template name="ui:post-date-control">
		<xsl:param name="value"/>
		<xsl:param name="name"/>
		<xsl:param name="tip"/>
		<xsl:param name="on-key-press"/>
		<xsl:param name="content" select="/.."/>
		<!--|-->
		<nobr>
			<input style="vertical-align: middle;" id="{$name}" name="{$name}" size="9" value="{$value}">
				<xsl:if test="$on-key-press">
					<xsl:attribute name="onKeyPress"><xsl:value-of select="$on-key-press"/></xsl:attribute>
				</xsl:if>
				<xsl:if test="$tip">
					<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="$tip"/>')</xsl:attribute>
					<xsl:attribute name="onmouseout">callTip('')</xsl:attribute>
				</xsl:if>
			</input>
			<img src="/{$theme}/images/1x1.gif" width="1" height="1"/>
			<a style="cursor:hand; cursor:pointer" onClick="showDate('{$name}')"><img src="/{$theme}/icons/dates.gif" width="16" height="18" style="vertical-align: middle;" onmouseover="callTip('browse_select_date',event)" onmouseout="callTip('')" border="0"/></a>
		</nobr>
		<xsl:copy-of select="$content"/>
		<br/>
		<img src="/{$theme}/images/1x1.gif" width="1" height="1" style="vertical-align:auto"/>
		<div id="{$name}_div" class="calendar"></div>
		<!--|-->
	</xsl:template>  
	
	<!-- 
  	Post "Period" picker
  -->
	<xsl:template name="ui:post-traffic-control">
		<xsl:param name="value" select="date:date()"/>
		<xsl:param name="from-date" select="date:date()"/>
		<xsl:param name="to-date" 	select="date:date()"/>
		<xsl:param name="one-date"	select="date:date()"/>
		<xsl:param name="name"/>
		<xsl:param name="tip"/>
		<xsl:param name="selector" select="'month'"/>
		<xsl:variable name="period-rtf">
			<period>
				<id>from-to</id>
				<label><sw:text>Period</sw:text></label>
			</period>
			<period>
				<id>day</id>
				<label><sw:text>Day</sw:text></label>
			</period>
			<period>
				<id>month</id>
				<label><sw:text>Month</sw:text></label>
			</period>
			<period>
				<id>year</id>
				<label><sw:text>Year</sw:text></label>
			</period>
		</xsl:variable>
		<xsl:variable name="period" select="exsl:node-set($period-rtf)"/>
	
		<!-- fix curretn date -->
		<xsl:variable name="date-date" select="date:date()"/>

		<!-- current round value of selectors -->
		<xsl:variable name="round-year-selected">
			<xsl:value-of select="concat(date:year($value),'-01-01')"/>
		</xsl:variable>
		<xsl:variable name="round-year-month-selected">
			<xsl:value-of select="concat(date:year($value),'-',format-number(date:month-in-year($value),'00'),'-01')"/>
		</xsl:variable>

		<!-- for show in popup selector of month and year -->
		<xsl:variable name="total-years" select="3"/>
		<xsl:variable name="total-months">
			<xsl:value-of select="($total-years -1) * 12 + date:month-in-year($date-date)"/>
		</xsl:variable>

		<!-- shift date to past -->
		<xsl:variable name="round-year-start">
			<xsl:value-of select="concat(date:year($date-date),'-01-01')"/>
		</xsl:variable>
		<xsl:variable name="round-year-month-start">
			<xsl:value-of select="concat(date:year($date-date),'-',format-number(date:month-in-year($date-date),'00'),'-01')"/>
		</xsl:variable>

		<!--|-->
		<table>
		<tr><td>
			<select name="{concat('period-selector',$name)}" id="{concat('block-period-selector',$name)}" onchange="trafficSwitch('{$name}')">
				<xsl:for-each select="$period/period">
					<option value="{id}">
						<xsl:if test="id = $selector">
							<xsl:attribute name="selected"/>
						</xsl:if>
						<xsl:value-of select="label"/>				
					</option>
				</xsl:for-each>
			</select>
			&#160;
		</td>
		<td>
			<!-- Day selector -->
			<div id="block-period-day{@name}" style="display:none">
				<xsl:call-template name="ui:post-date-control">
					<xsl:with-param name="name" select="concat('period-day',@name)"/>
					<xsl:with-param name="value" select="$one-date"/>
				</xsl:call-template>
			</div>
			<!-- /Day selector -->
			<!-- Month selector -->
			<div>
				<select class="FlatSelectFlow" style="width:130px;" type="combo" name="{concat('period-month',$name)}" id="{concat('block-period-month',$name)}">
					<xsl:call-template name="get-month">
						<xsl:with-param name="selected-value" select="$round-year-month-selected"/>
						<xsl:with-param name="start-date" select="$round-year-month-start"/>
						<xsl:with-param name="total-months" select="$total-months"/>
					</xsl:call-template>
				</select>
			</div>
			<!-- /month selector -->
			<!-- year selector -->
			<div>
				<select class="FlatSelectFlow" style="display:none;width:65px;" type="combo" name="{concat('period-year',$name)}" id="{concat('block-period-year',$name)}" >
					<xsl:call-template name="get-year">
						<xsl:with-param name="selected-value" select="$round-year-selected"/>
						<xsl:with-param name="start-date" select="$round-year-start"/>
						<xsl:with-param name="total-years" select="$total-years"/>
					</xsl:call-template>
				</select>
			</div>
			<!-- /year selector -->			
			<!-- from-to selector -->
			<div id="block-period-from-to{@name}" style="display:none">
				<table><tr> 
				<td>&#160;<xsl:value-of select="sw:text('from')"/></td>
				<td>
					<xsl:call-template name="ui:post-date-control">
	  	  		<xsl:with-param name="name" select="concat('period-from-date',@name)"/>
		    		<xsl:with-param name="value" select="$from-date"/>
		    	</xsl:call-template>
				</td>
				<td>&#160;<xsl:value-of select="sw:text('to')"/></td>
				<td>
					<xsl:call-template name="ui:post-date-control">
		    		<xsl:with-param name="name" select="concat('period-to-date',@name)"/>
	  	  		<xsl:with-param name="value" select="$to-date"/>
	    		</xsl:call-template>
				</td>
				</tr></table>
	    </div>
			<!-- /from-to selector -->			

		</td>
		<td>
			<img src="/{$theme}/images/1x1.gif" width="1" height="22"/>
		</td>
		</tr>
		</table>
		<script language="JavaScript"> 
		function trafficSwitch(name){
			s=document.getElementById('block-period-selector'+name);
			if(s.value=='month'){
				v=document.getElementById('block-period-year'+name).style.display = 'none'
				v=document.getElementById('block-period-month'+name).style.display = 'block'
				v=document.getElementById('block-period-day'+name).style.display = 'none'
				v=document.getElementById('block-period-from-to'+name).style.display = 'none'
			}
			if(s.value=='year'){
				v=document.getElementById('block-period-year'+name).style.display = 'block'
				v=document.getElementById('block-period-month'+name).style.display = 'none'
				v=document.getElementById('block-period-day'+name).style.display = 'none'
				v=document.getElementById('block-period-from-to'+name).style.display = 'none'
			}
			if(s.value=='day'){
				v=document.getElementById('block-period-year'+name).style.display = 'none'
				v=document.getElementById('block-period-month'+name).style.display = 'none'
				v=document.getElementById('block-period-day'+name).style.display = 'block'
				v=document.getElementById('block-period-from-to'+name).style.display = 'none'
			}
			if(s.value=='from-to'){
				v=document.getElementById('block-period-year'+name).style.display = 'none'
				v=document.getElementById('block-period-month'+name).style.display = 'none'
				v=document.getElementById('block-period-day'+name).style.display = 'none'
				v=document.getElementById('block-period-from-to'+name).style.display = 'block'
			}
		}
		trafficSwitch('<xsl:value-of select="$name"/>');
		</script>
		<!--|-->
	</xsl:template>  

	<xsl:template name="get-month">
		<xsl:param name="selected-value"/>
		<xsl:param name="start-date"/>			
		<xsl:param name="total-months" select="24"/>
		<option>
			<xsl:if test="$selected-value = $start-date">
				<xsl:attribute name="selected"/> 
			</xsl:if>
			<xsl:attribute name="value">
				<xsl:value-of select="$start-date"/>
			</xsl:attribute>
			<xsl:value-of select="date:year($start-date)"/>&#160;<xsl:value-of select="sw:strftime(date:seconds($start-date),'%B', 'GMT')"/>
		</option>			
		<xsl:variable name="next-total-months" select="$total-months - 1"/>
		<xsl:variable name="next-start-date" select="date:add($start-date,string('-P1M'))"/>
		<xsl:if test="$next-total-months &gt; 0">
			<xsl:call-template name="get-month">
				<xsl:with-param name="selected-value" select="$selected-value"/>
				<xsl:with-param name="start-date" select="$next-start-date"/>  
				<xsl:with-param name="total-months" select="$next-total-months"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template name="get-year">
		<xsl:param name="selected-value"/>
		<xsl:param name="start-date"/>			
		<xsl:param name="total-years" select="2"/>
		<option>
      <xsl:if test="$selected-value = $start-date">
        <xsl:attribute name="selected"/> 
      </xsl:if>
      <xsl:attribute name="value">
        <xsl:value-of select="$start-date"/>
      </xsl:attribute>
      <xsl:value-of select="date:year($start-date)"/>
    </option>     
		<xsl:variable name="next-total-years" select="$total-years - 1"/>
		<xsl:variable name="next-start-date" select="date:add($start-date,string('-P1Y'))"/>
		<xsl:if test="$next-total-years &gt; 0">
			<xsl:call-template name="get-year">
				<xsl:with-param name="selected-value" select="$selected-value"/>
				<xsl:with-param name="start-date" select="$next-start-date"/>  
				<xsl:with-param name="total-years" select="$next-total-years"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

  <xsl:template name="set-js-browser-pref-onlogin">  
    <input type="hidden" name="js_mode" 	value="0"/>    
    <input type="hidden" name="java_mode" value="'notdef'"/>    
    <script language="JavaScript">
      <xsl:if test="$activeMode != 'plesk'">
	try{
        if <![CDATA[(self.opener && self.opener.name.length > 0)]]>{
           self.location.href="<xsl:value-of select="$baseurl"/>/http/403";
        }
	}
	catch(e){
		//access denied, will do nothing
	};
      </xsl:if>
      document.forms[0].js_mode.value = 'JavaScript';	
    </script>
    <script  language="JavaScript1.1">
      document.forms[0].js_mode.value = '1.1';    
    </script>
    <script  language="JavaScript1.2">
      document.forms[0].js_mode.value = '1.2';    
    </script>
    <script  language="JavaScript1.3">
      document.forms[0].js_mode.value = '1.3';    
    </script>
    <script  language="JavaScript1.4">
      document.forms[0].js_mode.value = '1.4';
    </script>    
    <script  language="JavaScript">
			<![CDATA[
			if (is.ie && !is.ie4 && !is.opera) {
		  	document.forms[0].java_mode.value = 'notdef';
			} else {
		  	document.forms[0].java_mode.value = (window.navigator.javaEnabled() ? 'enabled' : 'disabled');
			}
			]]>
    </script>    
		
  </xsl:template>
  
  <!-- Return row open/close state -->
	<func:function name="sw:get-row-state">
		<xsl:param name="row"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="not($row/@id)">
				<func:result select="0"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="screen-id" select="$row/ancestor::ui:screen/@id"/>				
				<xsl:variable name="row-id" select="$row/@id"/>
				<xsl:variable name="session-id" select="concat($screen-id,'-row-',$row-id)"/>
				<xsl:variable name="session-status" select="string(sw:sesget($session-id))"/>
				<xsl:variable name="post-status" select="string($request/http_request/post/parameter[name = $row-id]/value)"/>
				<!--|-->
		  	<func:result>  		
		  		<xsl:choose>
		  			<!-- copy status -->
		  			<xsl:when test="$row/@status">
		  				<xsl:value-of select="$row/@status"/>
		  			</xsl:when>
		  			<xsl:when test="true()">
		  				<xsl:value-of select="$row/@status-def"/>
		  			</xsl:when>
		  			<!-- get status from form submit -->
		  			<xsl:when test="$post-status">
		  				<xsl:value-of select="$post-status"/>		  				
		  				<xsl:if test="$session-status!=$post-status and $post-status!=$row/@status-def">
		  					<!-- Change status in session -->
		  					<xsl:if test="sw:sesput($session-id,$post-status)"/>
		  				</xsl:if>
		  			</xsl:when>
		  			<!-- get status from session -->
		  			<xsl:when test="$session-status">
		  				<xsl:value-of select="$session-status"/>
		  			</xsl:when>      			
		  			<!-- get default status  -->
		  			<xsl:when test="$row/@status-def">
		  				<xsl:value-of select="$row/@status-def"/>
		  			</xsl:when>      			
		  			<xsl:otherwise>      				
		  				<xsl:value-of select="1"/>
		  			</xsl:otherwise>      			
		  		</xsl:choose>      		
		  	</func:result>
		  </xsl:otherwise>
		 </xsl:choose>
	</func:function>
  
  <xsl:template name="ui:post-do-submit">
  	<script>
  		function formCheckEmpty(){
	  		<xsl:variable name="required-controls" select="//ui:row/ui:*[
	  			@required = 'true' and (
	  				@type='text' or @type='password' 
	  				or @type='date' 
	  				or name()='ui:cell-selector'
	  				or name()='ui:cell-file'
	  				or name()='ui:cell-list'
	  				or name()='ui:cell-list-picker'
	  				or name()='ui:cell-input'
						or name()='ui:cell-inputblock'
	  			)]"/>	  	
	  		//
	  		<xsl:if test="$required-controls">
	  			// clear old errors
	  			var aRows = document.body.getElementsByTagName("TR");
	  			var oRow = null;
	  			for(var iRow = 0; iRow &lt; aRows.length;iRow++){
	  				oRow = aRows[iRow];
	  				if(oRow.className=='RowError'){
	  					oRow.className = '';
	  				}
	  			}
	  			//
var errors = 0;
var row;
var obj=null;
	  			<xsl:for-each select="$required-controls">
obj = document.getElementById('<xsl:value-of select="@id"/>');
if(obj &amp;&amp; !obj.disabled &amp;&amp; 
<xsl:choose>
	<xsl:when test="name()='ui:cell-list' or name()='ui:cell-list-picker'">
obj.options[obj.selectedIndex].value==''
 	</xsl:when>
 	<xsl:otherwise>
obj.value==''
	</xsl:otherwise>
</xsl:choose>
){
	row=document.getElementById('row__<xsl:value-of select="@id"/>');
	if(row){
		row.className = 'RowError';
	}
	errors++;
}
	  			</xsl:for-each>
	  			if(errors){	  				
	  				alert('<sw:text>Some of the required fields are empty.</sw:text>');
	  				return false;
	  			}
	  		</xsl:if>
	  		return true;
		  }
		  
			function beforeSubmit(){
				fillMultiSelects();
	  		fillCollector();
		  	<xsl:variable name="submit-events" select="//ui:event[@type='onsubmit']"/>					
		  	<xsl:if test="$submit-events">
	    		<xsl:for-each select="$submit-events">
	    			<xsl:value-of select="."/>
	    		</xsl:for-each>
		    ;</xsl:if>
		    
				<![CDATA[
				if(document.defaultForm.method=='get' && document.defaultForm.action.indexOf('?')>0){
					actionString2hiddenInputs(document.defaultForm);
				}
				if (G_event.is_IE && document.defaultForm.method!='post') {
					var o = document.getElementsByTagName('input');
					var s=document.defaultForm.action;
					for (var i=0;i<o.length;i++) {
						if (o[i].name)
							s+='&'+o[i].name+'='+o[i].value;
					}
					if (s.length>1500) {document.defaultForm.method='post';}
				}
				]]>
		    
		    return false;
		  }
	  	function doSubmit(){
	  		beforeSubmit();
				document.defaultForm.submit();
				return false;
		   }
		</script>
  </xsl:template>
  
  <xsl:template name="ui:show-datetime-js">
  	<script language="JavaScript">  	  	  	
		<xsl:variable name="date-error">
			<sw:text>
				<xsl:with-param name="result" select="time:web-compose('2004','3','1')"/>
				The date format is invalid. The appropriate format for March 1, 2004 is %{result}.
			</sw:text>
		</xsl:variable>
  		var date_error = '<xsl:value-of select="sw:html-escape($date-error,'escape-quote')"/>';
			var date_id='';
			var date_value='';
			var date_y='';
			var date_m='';
			var date_d='';			
			var date_theme = "<xsl:value-of select="$theme"/>";
			var date_months=new Array(
			<xsl:for-each select="exsl:node-set($datetime)/datetime/months/month">
				"<xsl:value-of select='.'/>",
			</xsl:for-each>
				"");
			var date_weekdays=new Array(
				<xsl:for-each select="exsl:node-set($datetime)/datetime/week_days_short/day">
					"<xsl:value-of select='.'/>",
				</xsl:for-each>
				"");
			<![CDATA[  
			function hideDate(){
				s=document.getElementById(date_id+'_div');
				s.innerHTML = '';
				s.style.display = "none";
				date_id = '';				
				switchCombos(true);
			}
			function showDate(id){
				if(id==date_id){				
					hideDate();
					return false;
				}
				if(id!=date_id && date_id!=''){
					hideDate();					
				}
				sd=document.getElementById(id);
				if(!parseDate(sd.value)){
					alert(date_error);
					return false;
				}
				date_id = id;				
				s=document.getElementById(date_id+'_div');
				s.innerHTML=makeDateControl();
				s.style.display = "block";				
				switchCombos(false);
			}
			function parseDate(date){			
				return validateDate(date);
			}
			function todayDate(){
				d = new Date();
				date_m = d.getMonth()+1; 
				date_d = d.getDate();
				date_y = d.getFullYear();
					
				setDate();
				hideDate();
			}
			function resetDate(){				
				date_y = 0;
				setDate();
				hideDate();
			}
			function setDate(){
				if(date_y==0){
					date_value = '';
				}else{
					var m=date_m.toString().length>1?date_m.toString():('0'+date_m.toString());
					var d=date_d.toString().length>1?date_d.toString():('0'+date_d.toString());
					date_value = date_y.toString()+'-'+m+'-'+d;
				}			
				s=document.getElementById(date_id);
				s.value=date_value;
				if ( checkShow(date_id) ) s.focus();
			}
			function selectDay(day,month,year){
				date_d = day;
				date_m = month;
				date_y = year;
				setDate();
				hideDate();
			}
			function prevMonth(){								
				if(--date_m==0){
					date_m = 12;
					--date_y;
				}			
				updateMonth();
				showDays();
			}
			function nextMonth(){								
				if(++date_m>12){
					date_m = 1;
					++date_y;
				}			
				updateMonth();
				showDays();
			}
			function updateMonth(){													
				html = getHTMLDateMonth();
				s=document.getElementById('date_month');
				s.innerHTML=html;
			}
			function showDays(){													
				s=document.getElementById('date_days');
				s.innerHTML = getHTMLDateWeeks();
			}
			function getHTMLDateMonth(){													
				html = date_months[date_m-1]+', '+date_y;
				return html;
			}
			
			function calcWeekDay(val_day,val_month,val_year){			
				var val1 = parseInt(val_day, 10)
				var val2 = parseInt(val_month, 10)
				var val2x = parseInt(val_month, 10)
				var val3 = parseInt(val_year, 10)			
				if (val2 == 1) {
					val2x = 13;
					val3 = val3-1
				}
				if (val2 == 2) {
					val2x = 14;
					val3 = val3-1
				}
				var val4 = parseInt(((val2x+1)*3)/5, 10)
				var val5 = parseInt(val3/4, 10)
				var val6 = parseInt(val3/100, 10)
				var val7 = parseInt(val3/400, 10)
				var val8 = val1+(val2x*2)+val4+val3+val5-val6+val7+2
				var val9 = parseInt(val8/7, 10)
				var val0 = val8-(val9*7)

				val = val0 > 1 ? (val0-1):(6 + val0); 
				return val;
   		}
   		
   		function calcMonthDays(date_m_,date_y_,next_first_w){
				var fw = calcWeekDay(1,date_m_,date_y_);			
				return ( next_first_w<fw?(7+next_first_w-fw):(next_first_w-fw) ) + 28;
   		}
   		
			function getHTMLDateWeeks(){
				//
				var fw = calcWeekDay(1,date_m,date_y);			
				//
				var wday=0;
				var week=0;
				var dd=0;
				var day = 0;
				//				
				dd_prevm = date_m>1?(date_m-1):12;
				dd_prevy = date_m>1?date_y:(date_y-1);
				dd_prevd = calcMonthDays(dd_prevm,dd_prevy,fw);
				//
				//
				dd_nextm = date_m < 12?(date_m+1):1;
				dd_nexty = date_m < 12?date_y:(date_y+1);

				//
				d = calcWeekDay(1,dd_nextm,dd_nexty);
				endm =  ( d<fw?(7+d-fw):(d-fw) ) + 28;
				//
				html = "";
				//html += "<table style='background-color:#FFFFFF;' cellpadding=0 cellspacing=0 border=0 width='100%'><tr><td>";
				html += "<table cellpadding=3 cellspacing=1 border=0 width='100%'>";
				
				html += "<tr>";
				
				for(i=0;i<(date_weekdays.length-1);i++){
					html += "<td align='center'>"+date_weekdays[i]+"</td>";
				}
				html += "</tr>";
				// endm - days in month, fw - first day of week (1 -7)  for current month
				// endm + fw-1 - it's total days for show (include  days from prev month).
				total_days = endm + fw-1;
				if ( total_days % 7  == 0) {
						// no need one more rows for show last week.
						need_week = total_days / 7
					} else {
						// add one more rows for last week.
						need_week = Math.floor(total_days / 7) + 1;
				}
				for( i=1;i<=need_week*7;i++ ){					
					dd = 0;
					if(fw>i){
						day = (dd_prevd - fw) + i + 1;
						dd = -1;
					};
					if(i>=fw && (i-fw) < endm ){
						day = i-fw+1;
					}
					if(i>=fw && (i-fw) >= endm ){
						day = (i - fw) - endm+1;
						dd = 1;
					};
					
					if(++wday>7){
						if(week>1){
							html += '</tr>';
						}
						html += '<tr>';
						week++;
						wday = 1;
					}
					html += '<td align="center" style="background-color:';
					
					html += (day==date_d && dd==0)?'#FBE694':(dd==0?'#FFFFFF':'#FFFFEE') 
					
					html += ';" onClick="selectDay(';
					if(dd==0){
						html += day  +','+date_m+','+date_y;
					}
					if(dd<0){
						html += day  +','+dd_prevm+','+dd_prevy;
					}	
					if(dd>0){
						html += day  +','+dd_nextm+','+dd_nexty;
					}	
					html += ');return false"><a href="#">'+day+'</a></td>';
				}
				if(wday>1){
					html += '</tr>';
				}
				html += "</table>";
				//html += "</td></tr></table>";
				return html;
			}
			function makeDateControl(){			
				//				
				//
				var html='';
				///////////////// post HTML ///////////////////////
				html += "<table cellpadding=0 cellspacing=0 border=0 width='100%'>";
				html += "<tr style='background-color:#ABBEEF'>";
				html += '<td><img src="/'+date_theme+'/images/1x1.gif" width="14" height="14" border="0"/></td>';
			]]>				
				html += '<td width="100%" align="center"><b><xsl:value-of select="sw:html-escape(sw:text('Select date'),'escape-all')"/></b></td>';
			
				html += '<td><a onClick="hideDate()"><img src="/{$theme}/icons/close.gif" width="14" height="14" alt="{sw:text('Close the date selector')}" border="0"/></a></td>';
			<![CDATA[  
				html += "</tr>";
				html += '<tr><td colspan="3"><img src="/'+date_theme+'/images/1x1.gif" width="1" height="4"/></td></tr>';
				html += "</table>";												
				html += "<table cellpadding=0 cellspacing=0 border=0 width='100%'>";
				html += "<tr>";
				
				html += "<td width='20%' align='right'>&nbsp;<a href='#' onClick='prevMonth();return false'><img src='/"+date_theme+"/icons/arr_lt.gif' width='12' height='11' border='0'/></a>&nbsp;</td>";
				html += "<td width='60%'align='center'><span id='date_month'>"+getHTMLDateMonth()+"</span></td>";
				html += "<td width='20%' align='left'>&nbsp;<a href='#' onClick='nextMonth();return false'><img src='/"+date_theme+"/icons/arr_gt.gif' width='12' height='11' border='0'/></a>&nbsp;</td>";				
				html += "</tr>";
				html += '<tr><td colspan="3"><img src="/'+date_theme+'/images/1x1.gif" width="1" height="4"/></td></tr>';
				html += "</table>";
				//////////
				html += '<span id="date_days">';
				html += getHTMLDateWeeks();
				html += '</span>';
				//////////
				html += "<table cellpadding=0 cellspacing=0 border=0 width='100%'>";
				html += '<tr><td colspan="1"><img src="/'+date_theme+'/images/1x1.gif" width="1" height="4"></td></tr>';
				html += "<tr><td width='100%' align='center'>";
			]]>
				html += '&#160;<a href="#" onClick="todayDate();return false"><xsl:value-of select="sw:html-escape(sw:text('Today'),'escape-all')"/></a>&#160;';				
				html += '&#160;<a href="#" onClick="resetDate();return false"><xsl:value-of select="sw:html-escape(sw:text('Clear'),'escape-all')"/></a>&#160;';
			<![CDATA[				
				html += "</td></tr>";
				html += '<tr><td colspan="1"><img src="/'+date_theme+'/images/1x1.gif" width="1" height="4"></td></tr>';
				html += "</table>";
				///////////////////////////////////////////////////
				]]>
				return html;
			}
		</script>
	</xsl:template>
  
	<xsl:template match="ui:download-box">
		<xsl:variable name="my-width">
			<xsl:call-template name="html:calc-width">
				<xsl:with-param name="control" select="."/>
				<xsl:with-param name="as-text" select="'1'"/>
			</xsl:call-template>							
		</xsl:variable>
		<div style="width:{$my-width}">
			<xsl:call-template name="download-box"/>
		</div>	
	</xsl:template>
	
	<xsl:template match="ui:desktop-block">
		<xsl:param name="args" select="/.."/>
		<xsl:if test="ui:desktop-col/ui:desktop-rows">		
			<table border="0" width="100%" cellpadding="0" cellspacing="0" class="Desktop">
				<tr>
					<xsl:for-each select="ui:desktop-col">
						<td valign="top" width="50%">
							<xsl:apply-templates select="*"/>
						</td>
						<xsl:if test="position() != last()">
							<td class="desktopSpacer"><img src="/{$theme}/images/1x1.gif" width="1" height="1"/></td>
						</xsl:if>
					</xsl:for-each>
				</tr>
			</table>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="ui:desktop-rows">
		<xsl:variable name="cookie-name" select="concat('vzcp-desktop-',@id)"/>
	  	<xsl:variable name="flag" select="string($request/http_request/cookies/parameter[name = $cookie-name]/value)"/>
		<div class="{sw:if($flag = 'closed', 'DesktopRowsClosed','DesktopRows')}" id="{@id}">
		
		<div class="drHeaderArea">
			<table width="100%" cellspacing="0" cellpadding="0" border="0" onclick="switchDBox('{@id}');return false;" class="drHeader">
				<tr>
					<td class="main"><xsl:value-of select="@title"/></td>
					<td class="misc" align="right">
						<div class="drOpenButton" id="bid-show-dBox">
							      <img src="/{$theme}/images/1x1.gif" width="1" height="1"/>
						</div>
						<div class="drCloseButton" title="Minimize">
							<img src="/{$theme}/images/1x1.gif" width="1" height="1"/>
						</div>
					</td>
				</tr>
			</table>
		</div>
		<div class="drContent">
			<table  width="100%" cellspacing="0" cellpadding="0" border="0">
				<xsl:apply-templates select="*[name() != 'ui:desktop-footer']"/>
			</table>
		</div>
		<table  width="100%" cellspacing="0" cellpadding="0" border="0" class="drFooter">
			<tr>
				<td width="100%" style="padding-left:10px;padding-right:10px;">
					<xsl:if test="ui:desktop-footer/@align"><xsl:attribute name="align"><xsl:value-of select="ui:desktop-footer/@align"/></xsl:attribute></xsl:if>
					<xsl:copy-of select="ui:desktop-footer/child::node()"/>
					<xsl:if test="not(ui:desktop-footer)">&#160;</xsl:if>
				</td>
			</tr>
		</table>		
		</div>
	</xsl:template> 
</xsl:stylesheet>
