<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:show="http://www.swsoft.com/xsl/cp/show"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn"	
  xmlns:local		="http://www.swsoft.com/xsl/cp/local"	
>

	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	
  <!--========================== VIRTUAL ENVIRONMENTS  TEMPLATES ======================================-->	

	<!-- Transform vzagent state/transition pair to text/icon presentation 
  	Context
  		text() - VE state, VZA numeric value
  		../transition - VE transition, VZA numeric value
  		../old-transition - VE old transition, VZA numeric value (OPTIONAL)
  -->
  <xsl:template match="ve-old-status">
		<xsl:choose>
			<xsl:when test=".=''">&#160;</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="ui:construct-ve-status">
					<xsl:with-param name="state" select="." />
					<xsl:with-param name="transition" select="../old-transition/text()" />
					<xsl:with-param name="trans-show-state" select="../transition=../old-transition" />
	  		</xsl:call-template>	
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>  	
	
	<!-- Transform vzagent state/transition pair to text/icon presentation 
  	Context
  		text() - VE state, VZA numeric value
  		../transition - VE transition, VZA numeric value
  		../old-transition - VE old transition, VZA numeric value (OPTIONAL)
  -->
  <xsl:template match="ve-status">
	<xsl:choose>
		<xsl:when test=".=''"><nobr>&#160;</nobr></xsl:when>
		<xsl:otherwise><nobr>
			<xsl:call-template name="ui:construct-ve-status">
			  <xsl:with-param name="state" select="." />
			  <xsl:with-param name="transition" select="../transition/text()" />
			  <xsl:with-param name="trans-show-state" select="../transition=../old-transition" />
			</xsl:call-template></nobr>
		</xsl:otherwise>
	</xsl:choose>
  </xsl:template>
  
  <xsl:template match="env-state-check-alt">
	<xsl:variable name="transition" select="../transition/text()"/>
	<xsl:choose>
		<xsl:when test="$transition != '' and $transition != 0"><xsl:value-of select="$transition"/></xsl:when>
		<xsl:otherwise><xsl:value-of select="../ve-status/text()"/></xsl:otherwise>
	</xsl:choose>
  </xsl:template>

 <!-- Transform vzagent state/transition pair to text/icon presentation 
  	Context
  		@state - VE state, VZA numeric value
  		@transition - VE transition, VZA numeric value
  -->
  <xsl:template match="ui:ve-status">
		<xsl:call-template name="ui:construct-ve-status">
			<xsl:with-param name="state" select="@state" />
			<xsl:with-param name="transition" select="@transition" />
		</xsl:call-template>	
  </xsl:template>   
  
	<!-- Transform current VE status to text/icon presentation 
		Arguments
			is-compact
				true: Short name (Running, Down, etc,)
				false: Long phrase
		No context.
	-->
	<xsl:template match="ui:current-ve-status" name="ui:current-ve-status">
		<xsl:param name="is-compact" select="false()"/>	
		<xsl:call-template name="ui:construct-ve-status">
			<xsl:with-param name="state" select="ve:context-state()" />
			<xsl:with-param name="transition" select="ve:context-transition()" />
			<xsl:with-param name="is_small" select="sw:if($is-compact,'0','1')"/>			
		</xsl:call-template>	
	</xsl:template> 
  
	<!--  	
		Transform vzagent state/transition pair to text/icon presentation 
	-->
  <xsl:template name="ui:construct-ve-status">
  	<xsl:param name="state"/>
		<xsl:param name="transition"/>
		<xsl:param name="trans-show-state" select="false()"/>
		<xsl:param name="is_small" select="0"/>
		<xsl:param name="show-icon" select="true()"/>
		<xsl:param name="show-text" select="true()"/>
		<!--|-->
		
		<xsl:variable name="trans-info" select="$ve:trans[vza-value=$transition]"/>
		<xsl:variable name="state-info" select="ve:state2info($state)"/>
		
		<xsl:variable name="obj-title"><sw:text>Container</sw:text></xsl:variable>
		<xsl:variable name="obj-tip" select="sw:lc($obj-title)"/>
		
		<!--|-->
		
		<xsl:choose>
			<!-- no state - mean deleted VE -->		
			<xsl:when test="$transition and  ($transition != $env-trans/none) and $transition!=''">
				<xsl:if test="$show-icon">
				<xsl:choose>
					<xsl:when test="$transition = $env-trans/stopping"><img src="/{$theme}/icons/{$ve:trans[vza-value=$env-trans/stopping]/icon}" class="qC"/></xsl:when>
					<xsl:when test="$transition = $env-trans/starting"><img src="/{$theme}/icons/{$ve:trans[vza-value=$env-trans/starting]/icon}" class="qC"/></xsl:when>
					<xsl:when test="$transition = $env-trans/migrating"><img src="/{$theme}/icons/{$ve:trans[vza-value=$env-trans/migrating]/icon}" class="qC"/></xsl:when>
					<xsl:otherwise>
						<xsl:variable name="t-text">
							<xsl:choose>
								<xsl:when test="$transition = $env-trans/unknown">
									<sw:text>						
										<xsl:with-param name="obj" select="$obj-title"/>
										The %{obj} is performing an unknown operation at the moment. It may continue for some time.
									</sw:text>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>						
										<xsl:with-param name="obj" select="$obj-title"/>
										<xsl:with-param name="trans" select="$trans-info/text"/>
										The %{obj} is %{trans} at the moment. It may continue for some time.
									</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<img src="/{$theme}/icons/env_state_other.gif" alt="{$t-text}" title="{$t-text}" class="qC"/>
					</xsl:otherwise>		  
				</xsl:choose>
				</xsl:if>
				<xsl:if test="$show-text">
					<xsl:call-template name="local:status2title">
						<xsl:with-param name="obj" select="$obj-title"/>
						<xsl:with-param name="title" select="concat(sw:if($is_small=1,$trans-info/text,$trans-info/text-capitalized),sw:if($trans-show-state and $state!='-',concat(', ',$state-info/text),''))"/>
						<xsl:with-param name="is_small" select="$is_small" />
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<!-- VE exists -->
			<xsl:otherwise>
				<!-- Show icon -->
				<xsl:if test="$show-icon">
					<xsl:choose>
						<xsl:when test="$state = $env-state/unknown"><img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/unknown]/icon}" class="qC"/></xsl:when>
						<xsl:when test="$state = $env-state/running"><img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/running]/icon}" class="qC"/></xsl:when>
						<xsl:when test="$state = $env-state/mounted"><img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/mounted]/icon}" class="qC"/></xsl:when>
						<xsl:when test="$state = $env-state/repairing"><img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/repairing]/icon}" class="qC"/></xsl:when>
						<xsl:when test="$state = $env-state/down"><img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/down]/icon}" class="qC"/></xsl:when>					
						<xsl:when test="$state = $env-state/unexist"><img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/unexist]/icon}" class="qC"/></xsl:when>				
						<xsl:when test="$state = $env-state/suspended"><img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/suspended]/icon}" class="qC"/></xsl:when>				
						<xsl:when test="$state='-'"><img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/suspended]/icon}" class="qC"/></xsl:when>
						<xsl:otherwise>
							<xsl:variable name="s-text">
								<xsl:choose>
									<xsl:when test="$state='' or $state=$env-state/unexist">
										<sw:text>
											<xsl:with-param name="obj" select="$obj-title"/>
											The %{obj} does not exist.
										</sw:text>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>
											<xsl:with-param name="obj" select="$obj-title"/>
											<xsl:with-param name="state" select="$state-info/text"/>
											The %{obj} is %{state} at the moment.  It is not fully operational.
										</sw:text>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:variable>
							<img src="/{$theme}/icons/{$ve:state[vza-value=$env-state/offline]/icon}" alt="{sw:text($s-text)}" title="{sw:text($s-text)}" class="qC"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				<!-- Show text -->
				<xsl:if test="$show-text">
					<xsl:call-template name="local:status2title">
						<xsl:with-param name="obj" select="$obj-title"/>
						<xsl:with-param name="title" select="sw:if($is_small=1,$state-info/text,$state-info/text-capitalized)"/>
						<xsl:with-param name="is_small" select="$is_small" />
					</xsl:call-template>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>
  
	<!-- Sub-Template for status/transition word -->
	<xsl:template name="local:status2title">
		<xsl:param name="obj" select="'VE'"/>		
		<xsl:param name="title" select="''"/>		
		<xsl:param name="is_small" select="1" />

		<xsl:choose>
			<xsl:when test="$is_small = 1">
				<xsl:variable name="pre-title">
					<span class="small">
						<sw:text>
							<xsl:with-param name="obj" select="$obj"/>
							<xsl:with-param name="ve">
								<b><xsl:value-of select="string($title)"/></b>
							</xsl:with-param>
							The %{obj} is %{ve} at the moment.
						</sw:text>
					</span>
				</xsl:variable>
				<xsl:value-of select="$pre-title"/>
			</xsl:when>
			<xsl:when test="$title = '-' or $title = ''">
				<font color="#808080"><sw:text>non-existent</sw:text></font>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="string($title)"/>
			</xsl:otherwise>			
		</xsl:choose>
	</xsl:template> 
  
  <!--========================== HARDWARE NODE TEMPLATES ======================================-->

	<!-- Transform HN state to text/icon presentation 
  	Context
  		text() - HN state, VZA numeric value
  -->
  <xsl:template match="hn-status">

		<xsl:call-template name="local:construct-hn-status">
			<xsl:with-param name="state" select="."/>
		</xsl:call-template>
		
  </xsl:template> 
  
 	<!-- Transform HN state to text/icon presentation 
  	Arguments
  		state - HN state, VZA numeric value
  		show-icon - true(default)/false
  		show-text - true(default)/false
  	Result
  		HTML
  -->
  <xsl:template name="local:construct-hn-status">
	  <xsl:param name="state"/>
		<xsl:param name="show-icon" select="true()"/>
		<xsl:param name="show-text" select="true()"/>	  
	  
		<xsl:variable name="state-info" select="hn:state2info($state)"/>

		<xsl:if test="$show-icon or $show-text"><nobr>		
		
			<!-- Show icon -->
			<xsl:if test="$show-icon">
				<img 
					onmouseover="callTip('{$state-info/tip}',event)" onmouseout="callTip()" 
					src="/{$theme}/icons/{$state-info/icon}" class="qC"
				/>
			</xsl:if>
			
			<!-- Show text -->
			<xsl:if test="$show-text">
				<xsl:value-of select="$state-info/text-capitalized"/>
			</xsl:if>
		
		</nobr></xsl:if>
		
  </xsl:template> 

  <!--========================== COMMON HN and VE TEMPLATES ======================================-->

	<!-- Transform vzagent state/transition pair to text/icon presentation , common for VE and HN
		Context
		text() - VE or HN state, VZA numeric value
		../env-transition -  transition, VZA numeric value
		../old-env-transition - ENV old transition, VZA numeric value (OPTIONAL)
	-->
	<xsl:template match="old-env-status">
		<xsl:variable name="obj-type">
			<xsl:choose>
				<xsl:when test="../obj-type = 'generic'">
					<xsl:value-of select="'hn.vz.vt'"/>
				</xsl:when>
				<xsl:when test="../obj-type = 'virtuozzo'">
					<xsl:value-of select="'ve.vz.vt'"/>
				</xsl:when>
			</xsl:choose>				
		</xsl:variable>			 

		<xsl:choose>
			<xsl:when test=".=''">&#160;</xsl:when>
			<xsl:when test="$obj-type = 'hn.vz.vt'"> 
				<xsl:call-template name="local:construct-hn-status">
					<xsl:with-param name="state" select="."/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="ui:construct-ve-status">
					<xsl:with-param name="state" select="." />
					<xsl:with-param name="transition" select="../old-env-transition/text()"/>
					<xsl:with-param name="trans-show-state" select="../env-transition=../old-env-transition"/>
				</xsl:call-template>	
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>  	
	
	<!-- Transform vzagent state/transition pair to text/icon presentation 
		Context
		text() - ENV state, VZA numeric value
		../env-transition - VE transition, VZA numeric value
		../old-transition - VE old transition, VZA numeric value (OPTIONAL)
	-->
	<xsl:template match="env-status">
		<xsl:variable name="obj-type">
			<xsl:choose>
				<xsl:when test="../obj-type = 'generic'">
					<xsl:value-of select="'hn.vz.vt'"/>
				</xsl:when>
				<xsl:when test="../obj-type = 'virtuozzo'">
					<xsl:value-of select="'ve.vz.vt'"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test=".=''"><nobr>&#160;</nobr></xsl:when>
			<xsl:when test="$obj-type = 'hn.vz.vt'">
				<xsl:call-template name="local:construct-hn-status">
					<xsl:with-param name="state" select="."/>
				</xsl:call-template>			
			</xsl:when>
			<xsl:otherwise><nobr>
				<xsl:call-template name="ui:construct-ve-status">
					<xsl:with-param name="state" select="." />
					<xsl:with-param name="transition" select="../env-transition/text()"/>
					<xsl:with-param name="trans-show-state" select="../env-transition=../old-env-transition"/>
				</xsl:call-template></nobr>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
