<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func path units url"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:func="http://exslt.org/functions"
  xmlns:path="http://www.swsoft.com/xsl/cp/path"
  xmlns:units="http://www.swsoft.com/xsl/cp/units"
  xmlns:url="http://www.swsoft.com/xsl/cp/url"
>

	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/utils/url.xsl"/>

  <xsl:param name="path:session-variable" select="concat('path-',$activeMode)"/>
	
	<!--
		Set branch value.
		Arguments
			branch-id
			branch-value
		Result
			none
	-->
	<func:function name="path:set-branch">
		<xsl:param name="branch-id"/>
		<xsl:param name="branch-value"/>		
		<xsl:if test="sw:sesputstr(concat('branch-',$branch-id),string($branch-value))"/>
	</func:function>

	<!-- get current path, from session -->
	<func:function name="path:get">
		<xsl:variable name="path" select="sw:sesgettree($path:session-variable)/path"/>
		<func:result select="$path"/>
	</func:function>

	<!-- get previous element of path -->
	<func:function name="path:prev">
		<xsl:param name="path"/>
		<xsl:variable name="ret" select="$path[not(@hidden)][position() = last()-1]"/>
		<func:result select="$ret"/>
	</func:function>

	<!-- get current element of path -->
	<func:function name="path:last">
		<xsl:param name="path"/>
    <func:result select="$path[position() = last()]"/>
	</func:function>

	<!-- get href of element of path -->
	<func:function name="path:href">
		<xsl:param name="path"/>
		<func:result select="concat($baseurl, path:extend-url-lf(url:extend($path/@href,'tab-force=default')) )"/>
	</func:function>
	
	<!-- Add ?_lf=1 to URL -->
	<func:function name="path:extend-url-lf">
		<xsl:param name="url"/>
		<func:result select="url:extend($url,'_lf=1')"/>
	</func:function>	

  <xsl:variable name="path:top">
	  <xsl:choose>
	
	    <!-- Plesk mode -->
	    <xsl:when test="$layout = 'plesk-integrated'">
	      <path id="07.01.01.04" href="/panel/plesk/index" tip="index_screen" title="{sw:text('Top')}"/>
	    </xsl:when>
	  
	    <!-- VzCC mode -->
	    <xsl:when test="starts-with($layout, 'vzcc')">
	      <path id="00.00.00.00" href="/vmwaredir/infrman/envs/index" tip="index_screen" title="{sw:text('Top')}" hidden="1"/>
	    </xsl:when>
	  
	    <!-- VzCP mode -->
	    <xsl:when test="$activeMode='vzcp'">
	      <path id="03.00.00.05.00" href="/core/desktop/index" tip="index_screen" title="{sw:text('Desktop')}"/>
	    </xsl:when>
	
	  </xsl:choose>    
  </xsl:variable>

	<func:function name="path:find-screen">
		<xsl:param name="id"/>
		<xsl:param name="init-screen" select="false()"/>
		<xsl:param name="check-branch" select="false()"/>
		<xsl:param name="branch-id" select="''"/>
		<xsl:param name="deep" select="1"/>
		
		<xsl:variable name="debug" select="false()"/>
		
		
		<xsl:if test="$init-screen">			
			<!-- put some string into session -->
			<xsl:variable name="ses-get" select="$request/http_request/get/parameter[ name='_sesput' ]/value"/>		
			<xsl:if test="$ses-get!=''">
				<xsl:if test="sw:sesputstr(
					substring-before($ses-get,','),
					substring-after($ses-get,',')
				)"/>
			</xsl:if>
			<!-- check directions from GET -->
			<xsl:for-each select="$request/http_request/get/parameter[ name='branch' ]/value">
				<xsl:if test="path:set-branch(substring-before(.,','),substring-after(.,','))"/>
			</xsl:for-each>
			<!-- /check directions from GET -->
			<!-- check Units DN from GET -->
			<xsl:variable name="parent-dn-get" select="$request/http_request/get/parameter[ name='parent-dn' ]/value"/>		
			<xsl:if test="$parent-dn-get!=''">
				<xsl:if test="units:set-current-dn(sw:base64-decode($parent-dn-get))"/>
			</xsl:if>
			<!-- /check Units DN from GET -->
		</xsl:if>
		
		<xsl:variable name="screens-res" select="$screens-repository//screen[@id=$id]"/>
		
		<xsl:if test="$init-screen and count($screens-res)=1">
			<!-- store branch -->
			<xsl:for-each select="$screens-res/branch">
				<xsl:if test="path:set-branch(@id,@direct)"/>
			</xsl:for-each>
			<!-- /store branch -->		
		</xsl:if>

		
		<xsl:variable name="screen-res" select="$screens-res[
			(
				not(@parent-id) and not(parent)
			) or
			(
				@parent-id and path:find-screen( string(@parent-id),false(),true(),'',$deep+1 )
			) or
			(
				parent and parent[path:find-screen( string(@id),false(),true(),string(@branch),$deep+1  )]
			)
		]"/>
				
		
		<xsl:if test="$init-screen and count($screens-res)!=1">
			<!-- store branch -->
			<xsl:for-each select="$screen-res/branch">
				<xsl:if test="path:set-branch(@id,@direct)"/>
			</xsl:for-each>
			<!-- /store branch -->		
		</xsl:if>

		<xsl:variable name="branchs" select="$screen-res/branch[$branch-id='' or $branch-id=@id]"/>

		<xsl:if test="$debug and ($deep=1 or $deep=2)">
			<xsl:if test="sw:sesput('xxxxxxxxxxxxx-DEEP',$deep)"/>
			<xsl:if test="sw:sesput('xxxxxxxxxxxxx-screen-res',$screen-res)"/>
			<xsl:if test="sw:sesput('xxxxxxxxxxxxx-branch-id',$branch-id)"/>		
			<xsl:if test="sw:sesput('xxxxxxxxxxxxx-branchs',$branchs)"/>
		</xsl:if>
		

		<xsl:choose>
			<xsl:when	test="count($screen-res)=1 and $branch-id=''">
				<func:result select="$screen-res"/>			
			</xsl:when>
			<xsl:when	test="$branchs and $check-branch">
				<xsl:choose>
					<xsl:when test="						
						$branchs[sw:sesgetstr(concat('branch-',@id))=@direct]
					">
						<func:result select="$screen-res"/>			
					</xsl:when>
					<xsl:otherwise>
						<func:result select="/.."/>			
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$screen-res"/>			
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="path:screens-path-parent">
		<xsl:param name="child-screen"/>
		
		<xsl:variable name="parent-id" select="string($child-screen/@parent-id)"/>
		
		<func:result>
			<xsl:choose>
				<xsl:when test="$parent-id!=''">
					<xsl:variable name="parent-screen" select="path:find-screen($parent-id,false(),false())"/>
					<xsl:copy-of select="path:screens-path-parent($parent-screen)"/>			
					<path id="{$parent-id}" href="{substring-after($parent-screen/@href, '/vz/cp')}" title="{$parent-screen/@title}">
						<xsl:copy-of select="$parent-screen/@units-path"/>
					</path>
				</xsl:when>
				<xsl:when test="$child-screen/parent">
					<xsl:for-each select="$child-screen/parent">
						<xsl:variable name="parent-screen" select="path:find-screen(@id,false(),true(),@branch)"/>
						<xsl:if test="$parent-screen">
							<xsl:copy-of select="path:screens-path-parent($parent-screen)"/>
							<path id="{@id}" href="{substring-after($parent-screen/@href, '/vz/cp')}" title="{$parent-screen/@title}">
								<xsl:copy-of select="$parent-screen/@units-path"/>
							</path>
						</xsl:if>
					</xsl:for-each>
				</xsl:when>
			</xsl:choose>
		</func:result>
					
	</func:function>
	
	<func:function name="path:screens-path">
		
		<xsl:variable name="res-rtf">
			<screen id="{$screen-root/@id}">
				<xsl:copy-of select="path:screens-path-parent($screen-info)"/>
			</screen>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)/screen"/>
		
	</func:function>

	<!-- get base path, reseted if need -->
	<func:function name="path:calculate-base">
		<xsl:param name="path-id"/>

		<xsl:choose>

			<!-- we have path=reset get parameter -->
			<xsl:when test="$activeMode != 'vzccc' or $request/http_request/get/parameter[name = 'path' and value = 'reset']">
				<func:result select="path:screens-path()/path"/>
			</xsl:when>			

			<!-- left menu item was clicked -->
			<xsl:when test="sw:re-test($request/http_request/env/parameter[name = 'HTTP_REFERER']/value, '/menu$')">
				<func:result select="path:screens-path()/path"/>
			</xsl:when>

			<!-- all other no reset required -->
			<xsl:otherwise>
				<xsl:variable name="path-old" select="sw:sesgettree($path:session-variable)/path"/>
				<func:result select="path:cut-current($path-old, $path-id)"/>
			</xsl:otherwise>

		</xsl:choose>
	</func:function>


	<!-- Update current patch and store it in session 
		Arguments:
			ref to ui:screen
		Results:
		 nodeset with new updated path
	-->
  <func:function name="path:update-current">
    <xsl:param name="screen"/>
      
    <xsl:choose>
    	<!-- Should calc new path and save it as current -->
			<xsl:when test="$screen/@id">
				<func:result select="path:calculate($screen)"/>
			</xsl:when>
			<!-- Return old path -->
			<xsl:otherwise>
				<func:result select="path:get()"/>
			</xsl:otherwise>
    </xsl:choose>
    
  </func:function>
	
  <!-- 
       calculate path 
       args: node-set - $screen description
    -->
  <func:function name="path:calculate">
    <xsl:param name="screen"/>

    <!-- current screen id -->
    <xsl:variable name="id" select="$screen/@id"/>

    <!-- path without curent screen -->
		<xsl:variable name="path" select="path:calculate-base($id)"/>

    <xsl:variable name="newRTF">
        <!-- add top path node -->
        <xsl:if test="not($path)">
          <xsl:copy-of select="path:initial($screen/@id)"/>
        </xsl:if>

        <xsl:if test="$screen/@id != exsl:node-set($path:top)/path/@id">
          <path id="{$id}">
          
						<xsl:copy-of select="$screen/@units-path"/>
            <xsl:copy-of select="$screen/@title"/>
            <xsl:copy-of select="$screen/@tip"/>
					
						<xsl:choose>
	            <xsl:when test="$screen/@href">
	            	<xsl:attribute name="href">
	                <xsl:value-of select="substring-after($screen/@href, '/vz/cp')"/>
	              </xsl:attribute>
	            </xsl:when>
	            <xsl:otherwise>
	              <xsl:attribute name="href">
	                <xsl:value-of select="sw:html-unescape(concat(
	                                      substring-after($requesturl, $baseurl), sw:if(string-length($request/http_request/env/parameter[name = 'QUERY_STRING']/value), '?', ''), $request/http_request/env/parameter[name = 'QUERY_STRING']/value))"/>
	              </xsl:attribute>
	          	</xsl:otherwise>	          
            </xsl:choose>
            <xsl:if test="not($screen/@tip)">
              <xsl:attribute name="tip">
                <xsl:value-of select="$screen/@id"/>
              </xsl:attribute>
            </xsl:if>
          </path>
        </xsl:if>
    </xsl:variable>

    <!-- add new element to path -->
    <xsl:variable name="ret" select="$path|exsl:node-set($newRTF)/path"/>

    <!-- store new path in session -->
    <xsl:if test="sw:sesput($path:session-variable, $ret)"/>

    <func:result select="$ret"/>
  </func:function>

  <!-- Get initial path for screen -->
  <func:function name="path:initial">
    <xsl:param name="id"/>

    <func:result>
      <!-- top -->
      <xsl:copy-of select="$path:top"/>

      <!-- check for sub-menu item -->
      <xsl:variable name="smenu" select="(sw:document($menu-file, $menu-source)//submenu[item/screen/@id = $id][@href])[1]"/>
      <xsl:if test="$smenu">
        <xsl:variable name="href" select="sw:if(contains($smenu/@href, '$baseurl'), substring-after($smenu/@href, '$baseurl'), $smenu/@href)"/>
        <path id="{$smenu/@screen-id}" href="{$href}" tip="{$smenu/@tip}" title="{sw:text($smenu/@name)}"/> 
      </xsl:if>
    </func:result>

  </func:function>

  <!-- cut current path -->
  <func:function name="path:cut-current">
		<xsl:param name="path"/>
		<xsl:param name="id"/>

    <xsl:choose>
      <!-- empty path - return empty nodeset -->
      <xsl:when test="exsl:object-type($path) != 'node-set'">
        <func:result select="/.."/>
      </xsl:when>

      <!-- return all parent paths -->
      <xsl:when test="$path[@id = $id]">
        <func:result select="$path[@id = $id][1]/preceding-sibling::path"/>
      </xsl:when>

      <!-- we have no this screen in path - return same path -->
      <xsl:otherwise>
        <func:result select="$path"/>
      </xsl:otherwise>

    </xsl:choose>
  </func:function>

  
  <!-- show path html -->
  <func:function name="path:display">
    <xsl:param name="path"/>
    <xsl:param name="screen"/>
    <func:result>
      <!-- show path elements -->
      <xsl:for-each select="$path[not(@hidden)]">
        <xsl:if test="position() != 1">
          <xsl:text> &gt; </xsl:text>
        </xsl:if>
        <a onmouseover="callTip('{@tip}',event)" onmouseout="callTip()" href="{path:href(.)}">
          <xsl:value-of select="sw:text-subst(@title)"/>
        </a>
      </xsl:for-each>
    </func:result>
  </func:function>

	<!-- Transform raw path to more extended presentation with dn-based items converted in something more usable.
		Arguments
			path-raw - ref to raw path
		Result
			Extended path
	-->
	<func:function name="path:raw2ext">
		<xsl:param name="path-raw"/>
		<xsl:choose>
			<!-- We should transform some part items -->
			<xsl:when test="$path-raw[@units-path]">
				<xsl:variable name="path-rtf">
					<xsl:variable name="dn" select="units:current-dn()"/>
					<xsl:variable name="dns" select="units:dn2nodes($dn)"/>	
					<xsl:variable name="last-unit" select="$path-raw[@units-path and position()=last()]"/>
					<xsl:for-each select="$path-raw">
					<xsl:choose>
						<!-- Base units path -->
						<xsl:when test="@units-path='base'">
							<xsl:for-each select="$dns/dn">
								<xsl:sort select="@index" order="descending" data-type="number"/>
								<xsl:if test="position()&gt;=$units:top-level and (position()!=last())">
									<xsl:variable name="now" select="."/>
									<path id="10.00.00.01.05" title="{$now/@title}" 
										href="/farmdir/unitman/units/index?id={sw:base64-encode($now/@full-dn)}"
									/>
								</xsl:if>
							</xsl:for-each>
						</xsl:when>
						<!-- /Base units path -->
						<xsl:when test="@units-path='unit'">
							<path title="{$dns/dn[1]/@title}">
								<xsl:copy-of select="@*[not(self::title)]"/>
								</path>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<func:result select="exsl:node-set($path-rtf)/*"/>
			</xsl:when>
			<!-- Path is ok  -->
			<xsl:otherwise>
				<func:result select="$path-raw"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

  <!-- check if screen with ID there is in path -->
  <func:function name="path:check">
    <xsl:param name="screen-id"/>
    <func:result select="path:get()[@id = $screen-id]"/>
  </func:function>
  
  <!-- check if screen with ID there is in path -->
  <func:function name="path:last-href">
    <xsl:variable name="path" select="path:prev(path:get())"/>      
    <func:result select="sw:if($path,path:href($path),path:href(path:last($path)))"/>
  </func:function>
  

</xsl:stylesheet>
    
