<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<!--
	Schema of internal template/function calls.
	
ui:show-toolbar
	|-> load-repository
	|
	|-> construct-items
	|				|-> calc-screen-toolbar-context
	|				|-> construct-global-items
	|				|				|-> calc-screen-newobj-buttons
	|				|				|				|-> cred:filter-items	
	|				|				|-> browse-buttons2toolbar-buttons (commented)
	|				|				|-> cred:filter-items
	|				|				|-> toolbars2items
	|				|								|->check-current-context
	|				|-> construct-objtype-items
	|				|				|-> cred:filter-items
	|				|				|-> calc-screen-toolbars
	|				|				|-> toolbars2items
	|				|								|->check-current-context
	|				|-> construct-screen-items
	|								|-> cred:filter-items
	|								|-> calc-screen-toolbar-ids
	|								|-> toolbars2items
	|												|->check-current-context
	|
	|-> transform-items2html
					|
					|=> transform-tab2html
					|=> transform-item2html <.............................
					|				|-> check-item-operation-availability        .
					|				|=> transform-child-item2html                .
					|				|=> transform-top-item-2html
					|				|=> inner-html                 .
					|				|-> post-menu-div-html .......................
					|-> post-js
		
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local voc env func"
	exclude-result-prefixes="func ui local set voc cred global env"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:func	="http://exslt.org/functions"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:set="http://exslt.org/sets" 
  xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
  xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
  xmlns:global="http://www.swsoft.com/xsl/cp/global"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
>
	<sw:include href="/lib/vocabulary.xsl"/> 
	<sw:include href="/lib/cred-filter.xsl"/> 	
	
	<xsl:variable name="local:debug" select="false()"/>
	
	<!-- (PUBLIC) SHOW SCREEN TOOLBARS -->
	<xsl:template name="ui:show-toolbar">		
		
		<!-- Load toolbars repository -->
		<xsl:variable name="repository" select="local:load-toolbars-repository()"/>
		
		<!-- Calc current context -->
		<xsl:variable name="context" select="local:calc-screen-toolbar-context()"/>

		<!-- Construct current toolbars -->
		<xsl:variable name="toolbar-items" select="local:construct-items($repository,$context)"/>
		
		<!-- Print debug information -->
		<xsl:if test="$local:debug">
			<xsl:if test="sw:sesput('xxxxxxxxxxxxxxxxxxxxxx-result',$toolbar-items)"/>
		</xsl:if>		
		
		<!-- Show toolbars -->
		<xsl:call-template name="local:transform-items2html">
			<xsl:with-param name="items" select="$toolbar-items"/>
			<xsl:with-param name="context" select="$context"/>	
		</xsl:call-template>
  	
	</xsl:template>
	<!-- / (PUBLIC) SHOW SCREEN TOOLBARS -->
	
	<!-- (INTERNAL) LOAD TOOLBARS REPOSITORY AND PASS IT THROUGH SECURITY CHECK -->
	<func:function name="local:load-toolbars-repository">
		<func:result select="sw:document('toolbars.xml',sw:if($activeMode = 'vzcc', 'vzcc', 'vzpp'))"/>
	</func:function>
	
	<!-- CONSTRUCT SCREEN CURRENT TOOLBARS -->
	<func:function name="local:construct-items">
		<xsl:param name="repository"/>
		<xsl:param name="context"/>

		<xsl:variable name="items-rtf">			
		
			<!-- 1. Construct global items -->
			<xsl:call-template name="local:construct-global-items">
				<xsl:with-param name="repository" select="$repository"/>
				<xsl:with-param name="context" select="$context"/>
			</xsl:call-template>
			<!-- /Construct global toolbars -->
			
			<!-- 2. Construct object toolbars -->
			<xsl:call-template name="local:construct-objtype-items">
				<xsl:with-param name="repository" select="$repository"/>
				<xsl:with-param name="context" select="$context"/>
			</xsl:call-template>
			<!-- /Construct object toolbars -->
			
			<!-- 3. Construct screen toolbars, requiested from screen by ID  -->
			<xsl:call-template name="local:construct-screen-items">
				<xsl:with-param name="repository" select="$repository"/>
				<xsl:with-param name="context" select="$context"/>
			</xsl:call-template>			
			<!-- /Construct screen toolbars, requiested from screen by ID  -->
	

		</xsl:variable>		
		
		<func:result select="exsl:node-set($items-rtf)"/>
	</func:function>	
	<!-- /CONSTRUCT SCREEN CURRENT TOOLBARS -->
	
	<!--  Calculate current screen toolbar context -->
	<func:function name="local:calc-screen-toolbar-context">
		<xsl:variable name="screen" select="$screen-info"/>
		<xsl:variable name="context">
			<xsl:for-each select="$screen[1]/ancestor-or-self::*/toolbar[@context]">
				<xsl:if test="position()=last()">
					<xsl:value-of select="@context"/>		
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		
		<!-- Print debug information -->
		<xsl:if test="$local:debug">
			<xsl:if test="sw:sesput('xxxxxxxxxxxxxxxxxxxxxx-screen-toolbar-context',$context)"/>
		</xsl:if>		
		
		<func:result select="string($context)"/>		
	</func:function>
	<!--  /Calculate current screen toolbar context -->
	
	<!--  Calculate current screen toolbar object-types  -->	
	<func:function name="local:calc-screen-toolbar-obj-types">
		<xsl:variable name="screen" select="$screen-info"/>

		<xsl:variable name="obj-types-rtf">
			<xsl:for-each select="$screen">

				<xsl:for-each select="ancestor-or-self::*/toolbar[@obj-type]">
					<obj-type><xsl:value-of select="@obj-type"/></obj-type>
				</xsl:for-each>	
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="set:distinct(exsl:node-set($obj-types-rtf)/obj-type)"/>
	</func:function>
	<!--  /Calculate current screen toolbar object-types  -->	
	
	<!--  Calculate current screen toolbar IDs  -->	
	<func:function name="local:calc-screen-toolbar-ids">

		<xsl:variable name="toolbar-ids-rtf">
			<xsl:for-each select="$screen-root/ui:screen/ui:toolbar">
				<id><xsl:value-of select="@id"/></id>
			</xsl:for-each>	
		</xsl:variable>
		
		<func:result select="exsl:node-set($toolbar-ids-rtf)/id"/>
	</func:function>
	<!--  /Calculate current screen toolbar IDs  -->	

	<!-- Get all New Obj' browse buttons from screen -->
	<func:function name="local:calc-screen-newobj-buttons">
		<func:result select="cred:filter-items($screen-root/ui:screen//ui:browse-buttons/ui:button[@new-obj-title])"/>
	</func:function>
	<!-- /Get all New Obj' browse buttons from screen -->

	<!-- Transform browse buttons to toolbar buttons -->
	<func:function name="local:browse-buttons2toolbar-buttons">
		<xsl:param name="buttons"/>
		
		<!-- 
		Was 
			<ui:button new-obj-title="{sw:text('Task')}" icon="scheduler_task_new" submit-href="manage?mode=new" require-items="false" sandclock="false" tip="new_job">
				<sw:text>New Task</sw:text>
			</ui:button>
			
		Will
			<button id="new.security.user" label="User" tip="new_user" icon="user_new">
				<click href="/vz/cp/sysdir/securman/users/manage?cmd=new"/>
			</button> 
		-->
		
		<func:result>
			<xsl:for-each select="$buttons">
				<button id="ui.browse-button{position()}" label="{@new-obj-title}" tip="{@tip}" 
					icon="{@icon}" sort-order="1" top="true"
				>
					<xsl:copy-of select="@*[self::sandclock or self::disabled]"/>
					<click href="{@submit-href}"/>
				</button>
			</xsl:for-each>
		</func:result>		
	</func:function>
	<!-- /Transform New Obj' browse buttons to toolbar buttons -->
		
	<!-- SHOW GLOBAL ITEMS -->
	<xsl:template name="local:construct-global-items">					
		<xsl:param name="repository"/>
		<xsl:param name="context"/>
		
		<xsl:variable name="toolbars-rtf">
			<!-- Inject screen content for 'New Obj' browse buttons into global 'New' toolbar -->		
			<xsl:if test="$global:move-newobj-btn-2toolbar">
				<xsl:variable name="new-buttons" select="local:calc-screen-newobj-buttons()"/>
				<xsl:if test="$new-buttons">
					<toolbar id="new.browse-buttons" group="new" type="global" label="Global Actions">
						<button-menu id="new.browse-buttons" group="new" label="New">
							<xsl:copy-of select="local:browse-buttons2toolbar-buttons($new-buttons)"/>
							<button id="toolbar.global.tab" type="tab" top="true"/>			
						</button-menu>
					</toolbar>
				</xsl:if>
			</xsl:if>
			<!-- /Inject screen content for 'New Obj' browse buttons into global 'New' toolbar -->
			<xsl:copy-of select="cred:filter-items($repository/toolbars/toolbar[@type='global'],'RTF')"/>
		</xsl:variable>
			
		<xsl:call-template name="local:toolbars2items">
			<xsl:with-param name="toolbars" select="exsl:node-set($toolbars-rtf)/*"/>
			<xsl:with-param name="context" select="$context"/>	
		</xsl:call-template>
		
		<!-- Separate global items from all other -->
		<button id="toolbar.global.tab" type="tab"/>
		
	</xsl:template>
	<!-- /SHOW GLOBAL ITEMS -->
	
	<!-- SHOW OBJTYPE ITEMS -->
	<xsl:template name="local:construct-objtype-items">				
		<xsl:param name="repository"/>
		<xsl:param name="context"/>
					
		<!-- Get all object types related to current screen -->
		<xsl:variable name="screen-obj-types" select="local:calc-screen-toolbar-obj-types()"/>
		
		<!-- Print debug information -->
		<xsl:if test="$local:debug">
			<xsl:if test="sw:sesput('xxxxxxxxxxxxxxxxxxxxxx-calculates-objec-types',$screen-obj-types)"/>
		</xsl:if>		
				
		<!-- Handle every object type, find associated toolbars and transform them to buttons and menus -->
		<xsl:for-each select="$screen-obj-types">
		
			<xsl:call-template name="local:toolbars2items">
				<xsl:with-param name="toolbars" select="cred:filter-items($repository/toolbars/toolbar[@obj-type=current()])"/>
				<xsl:with-param name="context" select="$context"/>			
			</xsl:call-template>
		</xsl:for-each>
		<!--/-->

	</xsl:template>
	<!-- /SHOW OBJTYPE ITEMS -->
	
	<!-- CONSTRUCT SCREEN TOOLBAR ITEMS -->
	<xsl:template name="local:construct-screen-items">				
		<xsl:param name="repository"/>
		<xsl:param name="context"/>
					
		<!-- Get all object types related to current screen -->
		<xsl:variable name="toolbar-ids" select="local:calc-screen-toolbar-ids()"/>
		
		<!-- Print debug information -->
		<xsl:if test="$local:debug">
			<xsl:if test="sw:sesput('xxxxxxxxxxxxxxxxxxxxxx-calculates-toolbar-ids',$toolbar-ids)"/>
		</xsl:if>		
	
				
		<!-- Handle every object type, find associated toolbars and transform them to buttons and menus -->
		<xsl:for-each select="$toolbar-ids">
			<xsl:call-template name="local:toolbars2items">
				<xsl:with-param name="toolbars" select="cred:filter-items($repository/toolbars/toolbar[@id=current()])"/>
				<xsl:with-param name="context" select="$context"/>			
			</xsl:call-template>	
		</xsl:for-each>
		<!--/-->

	</xsl:template>
	<!-- /CONSTRUCT SCREEN TOOLBAR ITEMS -->
	
	<xsl:template name="local:toolbars2items">
		<xsl:param name="toolbars"/>
		<xsl:param name="context"/>
		
		<xsl:variable name="all-items" select="$toolbars/*"/>
			
			<xsl:for-each select="$all-items">

				<xsl:choose>
					<!-- Copy group-able button-menu -->
					<xsl:when test="self::button-menu and not(button[string(@type)!='tab'])">
						<!-- Skip empty button menus -->
					</xsl:when>
					<xsl:when test="self::button-menu and @group">
						<xsl:variable name="group" select="@group"/>
						
						<!-- Find group first definition -->
						<xsl:if test="not(preceding::button-menu[@group=$group])">
							<!-- Copy first menu definition -->
							<xsl:element name="button-menu">
								<xsl:copy-of select="@*"/>
								<xsl:if test="not(@sort-order)">
									<xsl:copy-of select="../@sort-order"/>
								</xsl:if>
								
								<!-- Resort all menu button from this group -->
								<xsl:for-each select="$toolbars/button-menu[@group=$group]/button">
									<xsl:sort select="not(@top='true')" />
									<!-- Copy resorted button -->
									<xsl:copy-of select="."/>
								</xsl:for-each>
								<!-- /Resort all menu button from this group -->
								
							</xsl:element>
							<!-- /Copy first menu definition -->
						</xsl:if>
					</xsl:when>
					<!-- Copy non-grouped buttons and menus -->
					<xsl:otherwise>
						<xsl:element name="{name()}">
							<xsl:copy-of select="@*"/>
							<xsl:copy-of select="*"/>							
							<xsl:if test="not(@sort-order)">
								<xsl:copy-of select="../@sort-order"/>
							</xsl:if>
						</xsl:element>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
	
	</xsl:template>
	
	<!--  Calculate button context -->
	<func:function name="local:check-current-context">
		<xsl:param name="context"/>
		<func:result select="ancestor-or-self::*[@context=$context]"/>				
	</func:function>
	<!--  /Calculate button context -->

	
	<!--
		Transform items(buttons and menus) to resulted HTML.
		Arguments:
			items - nodeset of <button> and <button-menu>
			contexxt - current context
		Result:
			Toolbar HTML 
	-->
	<xsl:template name="local:transform-items2html">
		<xsl:param name="items"/>
		<xsl:param name="context"/>
			
		<!-- Open upper-level table -->
		<table width="100%" cellspacing="0" cellpadding="0" border="0" bgcolor="#A5C5F1" background="/{$theme}/images/toolbar_bg.gif">
			<tr>
				<td class="t3">
					<table cellpadding="0" cellspacing="0" border="0" height="26">
						<tr valign="middle">
		<!-- /Open upper-level table -->
		
						<!-- Process every item and make HTML from its description -->
						<xsl:for-each select="$items/*[not(self::button and @type='tab') or not(preceding-sibling::button[1][@type='tab']) ]">						
							<xsl:sort select="@sort-order" data-type="number"/>
													
							<!-- Post HTML -->
							<td id="{@id}">
								<xsl:choose>
									<xsl:when test="self::button and @type='tab'">
										<xsl:if test="position()!=1 and position()!=last()">
											<xsl:call-template name="local:transform-tab2html"/>
										</xsl:if>
									</xsl:when>
									<xsl:when test="self::button or self::button-menu">
										<xsl:call-template name="local:transform-item2html">
											<xsl:with-param name="context" select="$context"/>
										</xsl:call-template>
									</xsl:when>
									<xsl:when test="self::security">
										<!-- Explicit security element -->
									</xsl:when>
									<xsl:otherwise>
										<xsl:message>WRONG TOOLBAR ITEM <sw:text select="."/></xsl:message>
										<sw:die test="$local:debug"/>
									</xsl:otherwise>
								</xsl:choose>
							</td>

							<!-- /Post HTML -->
							
						</xsl:for-each>
						<!-- /Process every item and make HTML from its description -->
		
		<!-- Close upper-level table -->
						</tr>
					</table>
				</td>
			</tr>
  	</table>
		<!-- /Close upper-level table -->

		<!-- Post JavaScript functions -->		
  	<xsl:call-template name="local:post-js"/>

	</xsl:template>
	
	<!--
		Transform separator(vertical or horisontal line) to HTML
		Arguments
		Context
			ref to toolbar/separator
		Output
			HTML
	-->	
	<xsl:template name="local:transform-tab2html">	
		<xsl:variable name="on-top" select="not(../self::button-menu)"/>

		<xsl:choose>
			<xsl:when test="$on-top">
				<img src="/{$theme}/images/toolbar_separator.gif" width="3" height="19"  border="0"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="height">10</xsl:attribute>
				<xsl:attribute name="valign">middle</xsl:attribute>
				<hr class="separator"/>
			</xsl:otherwise>				
		</xsl:choose>
	</xsl:template>
	<!--
		Transform ONE item to HTML
		Arguments
			button-mode  (optional)
			context
		Context
			ref to toolbar/button-menu
		Output
			HTML
	-->	
	<xsl:template name="local:transform-item2html">	
		<xsl:param name="button-mode" select="$toolbar-mode"/>
		<xsl:param name="context" select="$context"/>

		<xsl:variable name="is-child" select="boolean(../self::button-menu)"/>
		
		<!-- Prepare ref to currently operated button. It is button itself or first child button in button-menu -->
		<!--<xsl:variable name="btn-context" select="button[@context=$context]"/>
		<xsl:variable name="current-btn" select="sw:if(self::button,., sw:if($btn-context,$btn-context,button[1]) )"/>-->
		<xsl:variable name="btn-context" select="."/>
		<xsl:variable name="current-btn" select="."/>

		
		<!-- Is button enabled for click -->
		<xsl:variable name="enabled" select="
			not($current-btn/@disabled='true') and (not($current-btn/@check-op-obj) or local:check-item-operation-availability($current-btn))
		"/>
		
		<!-- Precalc href and onclick-js -->
		<xsl:variable name="btn-href" select="sw:if($current-btn/click,$current-btn/click/@href,$current-btn/submit/@href)"/>
		<xsl:variable name="btn-onclick-js" select="sw:if($current-btn/click, $current-btn/click/@onclick-js, $current-btn/submit/@onsubmit-js)"/>
		<xsl:variable name="btn-target" select="$current-btn/@target"/>		
		<xsl:variable name="btn-oneclick" select="$current-btn/@oneclick"/>
		<xsl:variable name="btn-confirm" select="$current-btn/click/@confirmation"/>		
		
		<!-- Call item2html transformation -->
		<xsl:choose>
			<xsl:when test="$is-child">
				<xsl:call-template name="local:transform-child-item2html">
					<xsl:with-param name="enabled" select="$enabled"/>
					<xsl:with-param name="href" select="$btn-href"/>
					<xsl:with-param name="onclick-js" select="$btn-onclick-js"/>
					<xsl:with-param name="target" select="$btn-target"/>	
					<xsl:with-param name="oneclick" select="$btn-oneclick"/>
					<xsl:with-param name="btn-confirm" select="$btn-confirm"/>
				</xsl:call-template>
				<xsl:call-template name="local:inner-html">
					<xsl:with-param name="enabled" select="$enabled"/>
					<xsl:with-param name="button-mode" select="$button-mode"/>			
					<xsl:with-param name="current-btn" select="$current-btn"/>
				</xsl:call-template>				
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="button-id">
					<xsl:if test="@check-op-obj!='' and @check-op-operator!='' and @check-op-cmd!=''"><xsl:value-of select="@check-op-obj"/>|<xsl:value-of select="@check-op-operator"/>|<xsl:value-of select="@check-op-cmd"/></xsl:if>
				</xsl:variable>

				<xsl:choose>
					<xsl:when test="$button-id!=''">
					
				<a href="#none" name="{$button-id}_off" style="text-decoration:none;display:{sw:if($enabled,'none','block')}">
					<xsl:call-template name="local:transform-top-item2html">
						<xsl:with-param name="enabled" select="false()"/>
						<xsl:with-param name="href" select="$btn-href"/>
						<xsl:with-param name="onclick-js" select="$btn-onclick-js"/>
						<xsl:with-param name="target" select="$btn-target"/>
						<xsl:with-param name="oneclick" select="$btn-oneclick"/>
					</xsl:call-template>
					<div class="actionInnerBlock">
						<xsl:call-template name="local:inner-html">
							<xsl:with-param name="enabled" select="false()"/>
							<xsl:with-param name="button-mode" select="$button-mode"/>
							<xsl:with-param name="current-btn" select="$current-btn"/>
						</xsl:call-template>
						<img src="/{$theme}/images/1x1.gif" width="1" height="19"/>
						<xsl:if test="self::button-menu">
							<xsl:call-template name="local:post-menu-div-html">
								<xsl:with-param name="context" select="$context"/>
							</xsl:call-template>
						</xsl:if>
					</div>
				</a>

				<a href="#none" name="{$button-id}_on" style="text-decoration:none;display:{sw:if(not($enabled),'none','block')}">
					<xsl:call-template name="local:transform-top-item2html">
						<xsl:with-param name="enabled" select="true()"/>
						<xsl:with-param name="href" select="$btn-href"/>
						<xsl:with-param name="onclick-js" select="$btn-onclick-js"/>
						<xsl:with-param name="target" select="$btn-target"/>
						<xsl:with-param name="oneclick" select="$btn-oneclick"/>
					</xsl:call-template>
					<div class="actionInnerBlock">
						<xsl:call-template name="local:inner-html">
							<xsl:with-param name="enabled" select="true()"/>
							<xsl:with-param name="button-mode" select="$button-mode"/>
							<xsl:with-param name="current-btn" select="$current-btn"/>
						</xsl:call-template>
						<img src="/{$theme}/images/1x1.gif" width="1" height="19"/>
						<xsl:if test="self::button-menu">
							<xsl:call-template name="local:post-menu-div-html">
								<xsl:with-param name="context" select="$context"/>
							</xsl:call-template>
						</xsl:if>
					</div>
				</a>

					</xsl:when>
					<xsl:otherwise>

					<xsl:call-template name="local:transform-top-item2html">
						<xsl:with-param name="enabled" select="$enabled"/>
						<xsl:with-param name="href" select="$btn-href"/>
						<xsl:with-param name="onclick-js" select="$btn-onclick-js"/>
						<xsl:with-param name="target" select="$btn-target"/>
						<xsl:with-param name="oneclick" select="$btn-oneclick"/>
					</xsl:call-template>
					<div class="actionInnerBlock">
						<xsl:call-template name="local:inner-html">
							<xsl:with-param name="enabled" select="$enabled"/>
							<xsl:with-param name="button-mode" select="$button-mode"/>
							<xsl:with-param name="current-btn" select="$current-btn"/>
						</xsl:call-template>
						<img src="/{$theme}/images/1x1.gif" width="1" height="19"/>
						<xsl:if test="self::button-menu">
							<xsl:call-template name="local:post-menu-div-html">
								<xsl:with-param name="context" select="$context"/>
							</xsl:call-template>
						</xsl:if>
					</div>

					</xsl:otherwise>
				</xsl:choose>
					
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Call item2html transformation -->
		
	</xsl:template>
	<!-- /local:transform-item2html -->
	

	<!-- Common Inner HTML for one item: icon and text
		Context
			ref to item
		Output
			HTML
	-->
	<xsl:template name="local:inner-html">
		<xsl:param name="enabled"/>
		<xsl:param name="button-mode"/>			
		<xsl:param name="current-btn"/>	

		<!-- Post button text and icon. Common for top and child iterm -->
		<xsl:choose>
			<!-- Post enabled item -->		
			<xsl:when test="$enabled">
				<xsl:if test="contains($button-mode,'icon')">
					<img id="img_{@id}" src="/{$theme}/icons/{$current-btn/@icon}_16.gif" class="t4"/>
				</xsl:if>
				<xsl:if test="contains($button-mode,'text')">
 					<span id="text_{@id}" class="actionLabel"><xsl:value-of select="sw:text(@label)"/></span>
				</xsl:if>
			</xsl:when>
			<!-- /Post enabled item -->	
			<!-- Post disabled item -->
			<xsl:otherwise>
				<xsl:if test="contains($button-mode,'icon')">
					<img id="img_{@id}" src="/{$theme}/icons/{$current-btn/@icon}_disabled_16.gif" class="t4"/>
				</xsl:if>
				<xsl:if test="contains($button-mode,'text')">
					<span id="text_{@id}" class="actionLabelDisabled"><xsl:value-of select="sw:text(@label)"/></span>
				</xsl:if>
			</xsl:otherwise>
			<!-- /Post disabled item -->			
		</xsl:choose>
	</xsl:template>

	<!--
		Transform child item, to HTML
		Context
			ref to item
		Output
			HTML (attributes for parent element)
	-->	
	<xsl:template name="local:transform-child-item2html">	
		<xsl:param name="enabled"/>
		<xsl:param name="href"/>
		<xsl:param name="onclick-js"/>
		<xsl:param name="target"/>
		<xsl:param name="oneclick"/>
		<xsl:param name="btn-confirm"/>
		
		<!-- Append some attributes to upper level TD -->
		<xsl:choose>
			<xsl:when test="$enabled">		
				<xsl:attribute name="class">t0</xsl:attribute>
			</xsl:when>
			<xsl:otherwise>		
				<xsl:attribute name="class">t1</xsl:attribute>	
			</xsl:otherwise>
		</xsl:choose>

		<!-- Set @onlick -->
		<xsl:if test="$enabled">
			<xsl:attribute name="onclick">
				<xsl:if test="$btn-confirm">
					if (!confirm('<sw:text select="$btn-confirm"/>')) return false;					
				</xsl:if>
				<xsl:choose>
					<xsl:when test="$href!='#'">
						child_open_href('<xsl:value-of select="$href"/>','<xsl:value-of select="$target"/>','<xsl:value-of select="$oneclick"/>');stop_act=1;event.cancelBubble=true;return false;
					</xsl:when>
					<xsl:otherwise>
						stop_act=1;
						<xsl:value-of select="$onclick-js"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>						
		</xsl:if>
		
		<xsl:variable name="menu-id" select="../@id"/>		

		<xsl:if test="$enabled">
			<xsl:attribute name="onmouseover">a_D(this);callTip('<xsl:value-of select="@tip" />',event);event.cancelBubble=true;</xsl:attribute>
			<xsl:attribute name="onmouseout">p_D(this);callTip('')</xsl:attribute>	
		</xsl:if>
		<xsl:if test="not($enabled)">
			<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip" />_disabled',event);event.cancelBubble=true;</xsl:attribute>
			<xsl:attribute name="onmouseout">callTip('')</xsl:attribute>
		</xsl:if>

		
		
		
	</xsl:template>
	
	<!--
		Transform top item to HTML
		Context
			ref to toolbar item
		Output
			HTML (attributes for parent element)
	-->
	<xsl:template name="local:transform-top-item2html">	
		<xsl:param name="enabled"/>
		<xsl:param name="href"/>
		<xsl:param name="onclick-js"/>	
		<xsl:param name="target"/>
		<xsl:param name="oneclick"/>
		
		<!-- Append some attributes to upper level TD -->
		<xsl:variable name="eid" select="sw:ve-eid()"/>	

		<xsl:choose>
			<xsl:when test="$enabled">
				<xsl:attribute name="class">actionPassive</xsl:attribute>			
				<!-- href -->
				<xsl:attribute name="onclick">
					<xsl:choose>				
						<xsl:when test="self::button-menu">
							showBtnMenu('<xsl:value-of select="@id"/>'); stop_act = 1; return false;
						</xsl:when>
						<xsl:when test="$href!='#'">
							top_open_href(stop_act, '<xsl:value-of select="$href"/>','<xsl:value-of select="$target"/>','<xsl:value-of select="$oneclick"/>','')
						</xsl:when>
						<xsl:otherwise>
							if(stop_act==1) {
								stop_act = 0;
								return true;
							} 
							stop_act = 0;
							<xsl:value-of select="$onclick-js"/>
						</xsl:otherwise>
					</xsl:choose>					
				
				
				</xsl:attribute>
				
				<!-- mouse move -->
				<xsl:attribute name="onmouseover">actionActive(this);callTip('<xsl:value-of select="@tip" />',event)</xsl:attribute>
				<xsl:attribute name="onmouseout">callTip('');
					<xsl:choose>
						<!-- Has childs -->
						<xsl:when test="self::button-menu">
							if (document.getElementById('<xsl:value-of select="@id"/>')) {
								if (document.getElementById('<xsl:value-of select="@id"/>_bar')) {
									if (document.getElementById('<xsl:value-of select="@id"/>_bar').style.visibility == 'visible') return false;
								}		
							}
							actionPassive(this);
						</xsl:when>
						<!-- simple top item -->
						<xsl:otherwise>
								actionPassive(this);
						</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				
			</xsl:when>
			<xsl:otherwise>
				<xsl:attribute name="class">actionDisabled t5</xsl:attribute>
				<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="@tip" />_disabled',event)</xsl:attribute>
				<xsl:attribute name="onmouseout">callTip('')</xsl:attribute>					
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	
	<!-- 
		Check operation availability for current 
		Context
			ref to toolbar button or button-menu item
		Result
			boolean
	-->
	<func:function name="local:check-item-operation-availability">
		<xsl:param name="btn"/>
		<xsl:choose>
			<xsl:when test="$btn/@check-op-obj">
				<func:result select="voc:check-current-object-operation(
					$btn/@check-op-obj,$btn/@check-op-operator,$btn/@check-op-cmd,$btn/@check-op-subcmd
				)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!--
		Post HTML for menu popup
		Context
			ref to button-menu
		Result
			HTML
	-->
	
	<xsl:template name="local:post-menu-div-html">	
		<xsl:variable name="menu-id" select="@id"/>

		<div id="{$menu-id}_bar" name="{$menu-id}_bar" class="t2">
			<script language="JavaScript">		
				topbar_buttons[ii] = "<xsl:value-of select='$menu-id'/>";
				ii++;
			</script>
			<table id="{$menu-id}_dropdown" name="{$menu-id}_dropdown" cellpadding="1" cellspacing="1" border="0" class="actionDropdownBlock">
				<xsl:for-each select="button[not(self::button and @type='tab') or not(preceding-sibling::button[1][@type='tab']) ]">
					<tr valign="middle">
						<td id="{@id}">
							<!-- Show one child -->							
							<xsl:choose>
								<!-- Show tab -->
								<xsl:when test="self::button and @type='tab'">
									<xsl:if test="position()!=1 and position()!=last()">
										<xsl:call-template name="local:transform-tab2html"/>
									</xsl:if>
								</xsl:when>
								<!-- Show button -->									
								<xsl:otherwise>									
									<xsl:call-template name="local:transform-item2html">
										<xsl:with-param name="button-mode" select="$toolbar-mode"/>
										<xsl:with-param name="context" select="$context"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:for-each>
			</table>
		<!-- Strech dropdown -->
		<script>		
			parent_id = "<xsl:value-of select='$menu-id'/>";
			dropdownlist_width = getImage(parent_id).clientWidth + 25;
			child_id = "<xsl:value-of select='$menu-id'/>_dropdown";
			if (document.getElementById(child_id)) {
				getLayer(child_id).style.width = dropdownlist_width;
			}
		</script>
		</div>
	</xsl:template>
	

	<xsl:template name="local:post-js">	
  	<script language="JavaScript">
		<![CDATA[
		// Open dropdown menu
		function showBtnMenu(id,theme){
			//Hide dropdown when clicked another tab/arrow
			if (prev_tab) {
				if (prev_tab.id != id) {
				//prev_tab.style.cssText = 'background-color:transparent; white-space:nowrap; cursor:pointer; cursor:hand; padding: 4px 4 4 8;';
				}				
			}
			var save_bar = true;
			if (current_bar != null) {
				save_bar = document.getElementById(current_bar.id);
				if(is.ie && !is.ie7 && current_bar.style.visibility != 'hidden'){
					switchCombos(true);
				}				
				current_bar.style.visibility = 'hidden';
				current_bar = null;
			}
			id_bar = id + "_bar";
			current_id = id;
			if (save_bar) {
				if (save_bar.id != id_bar) {
					current_bar = document.getElementById(id_bar);
					current_bar.style.visibility = 'visible';
					if(is.ie && !is.ie7){
						switchCombos(false);
					}
					prev_tab = document.getElementById(id);
				}
			}
			clicka = 0;
			return false;
		}
		
		//HighLight buttons in toolbar
		function actionActive(act) {
			act.className = 'actionActive';
			//Hide dropdown when mousover another tab
			if (prev_tab) {
				if (prev_tab.id != act.id) {			
					prev_tab.className = 'actionPassive';
					prev_tab_bar = document.getElementById(prev_tab.id + "_bar");
					if (is.ie && !is.ie7 && prev_tab_bar.style.visibility != 'hidden'){
						switchCombos(true);
					}					
					prev_tab_bar.style.visibility = 'hidden';
				}				
			}			
		}	
		function actionPassive(act) {
			act.className = 'actionPassive';
		}
		
		//HighLight actions/rows in dropdown submenu
		function a_D(act) {
			act.style.cssText='padding:1px 2px 1px 3px;background-color:white; border: 1px #6E89DD solid; white-space:nowrap; cursor:pointer; cursor:hand;';
		}	
		function p_D(act) {
			act.style.cssText='padding:2px 3px 2px 4px;background-color:transparent; white-space:nowrap; cursor:pointer;';
		}
		
		//HighLight arrow that open dropdown		
		function actionActive_arr(act) {
			act.className='actionDropdownArrowActive';
		}			
		function actionPassive_arr(act) {
			act.className='actionDropdownArrowPassive';
		}		
		
		//Move dropdowns in real screen coordinates x:y
		function relocate_dropdowns() {
			if (topbar_buttons.length) {
				var i;
				for (i = 0; i < topbar_buttons.length; i++) {
					topbar_buttons_divs_parent = topbar_buttons[i];
					topbar_buttons_divs_child  = topbar_buttons[i] + "_bar";
					document.getElementById(topbar_buttons_divs_child).style.left = getImagePageLeft(getImage(topbar_buttons[i])) + "px";
					document.getElementById(topbar_buttons_divs_child).style.top = getImagePageTop(getImage(topbar_buttons[i])) + 25 + "px";
				}
			}
		}
		
		//Open link/href for dropdown menu items
		function child_open_href(curr_href, cur_target, oneclick, name) {
			//---close dropdown anyway;
			if (current_bar != null) {
					if(is.ie && !is.ie7 && current_bar.style.visibility != 'hidden'){
						switchCombos(true);
					}
					current_bar.style.visibility = 'hidden';
					if (current_id) {
						document.getElementById(current_id).className = 'actionPassive';
					}
					current_bar = null;
			}
			//---Open link/href
			if (cur_target != '') {
				new_window = window.open(curr_href,cur_target,"");
				new_window.focus();
			} else {
				if (oneclick=='true') {
					java_put( curr_href, '', null, '', '' );
				} else {
					location.href= curr_href;
				}
			}
			return true;			
		}		
		
		//Open link/href for main toolbar buttons
		function top_open_href(cur_stop_act, curr_href, cur_target, oneclick, name) {
			stop_act = 0;
			if (cur_stop_act == 1) {
				return true;
			} else {
				if (cur_target != '') {
					new_window = window.open(curr_href,cur_target,"");
					new_window.focus();
				} else {
					if (oneclick=='true') {
						java_put( curr_href, '', null, '', '' );
					} else {
						location.href= curr_href;
					}
				}
			}
		}
		
		// Check "click" event - to hide current dropdown
		// Moved to vzcp_script.js (onload)
		]]>
		</script>
	</xsl:template>
	
</xsl:stylesheet>
    