<!--
  Copyright (c) Parallels, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred html func"
  exclude-result-prefixes="func error ui plesk cred html"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
	xmlns:func	="http://exslt.org/functions"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"    
	xmlns:plesk	="http://www.swsoft.com/xsl/cp/plesk"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:html 	="http://www.swsoft.com/xsl/cp/html"
  >

  <sw:include href="plesk/elements.xsl"/>
  <sw:include href="plesk/browse.xsl"/>
  <sw:include href="plesk/forms.xsl"/>
	<sw:include href="/lib/cred-filter.xsl"/>

  <sw:include href="../lib/dashboard.xsl"/> 

  <!-- plesk screen -->
  <xsl:template match="ui:screen" mode="layout-plesk">
    <html>
			<xsl:copy-of select="plesk:head(ui:head/*)"/>

      <xsl:variable name="background-style">
        <xsl:if test="$skinObj/background and @bg">
          <xsl:text>background-attachment:fixed; background-position: right bottom;background-repeat: no-repeat;background-image: </xsl:text>
          <xsl:value-of select="concat('url(/',$theme,'/images/bg_', @bg, '.gif);')"/>
        </xsl:if>
      </xsl:variable>      

      <body style="{$background-style}" onLoad="top.SetContext('{@id}'); onLoadPsa();">
        <table width="100%" cellspacing="0" cellpadding="0" border="0">
          <tr>
            <td>
							<xsl:call-template name="ui:show-toolbar"/>
              <xsl:call-template name="titlebar-plesk"/>
							<xsl:apply-templates select="ui:tab-bar-custom|ui:tab-bar"/>
	        		<xsl:if test="not(ui:tab-bar-custom/ui:tab) and not(ui:tab-bar)"><div id="noTabs"></div></xsl:if>              
              <xsl:call-template name="plesk-opresult"/>
							<xsl:if test="ui:properties/ui:description/@mandatory = 'yes' or true()">
								<xsl:apply-templates select="ui:properties/ui:description" mode="plesk"/>
							</xsl:if>
              <div class="screenBody">
								<xsl:choose>
									<xsl:when test="ui:properties/ui:width/@value = 'fixed'">
										<xsl:attribute name="style">width:680px</xsl:attribute>
									</xsl:when>
								</xsl:choose>        
								<xsl:call-template name="default-form-open"/>								
									<xsl:apply-templates select="ui:content/*" mode="plesk"/>
								<xsl:call-template name="default-form-close"/>
              </div>
    	    	</td>
          </tr>
        </table>
        <xsl:call-template name="sandclock"/>
        <xsl:if test="ui:properties/ui:js-tail">
        	<xsl:copy-of select="ui:properties/ui:js-tail/child::node()"/>
        </xsl:if>
        <xsl:if test="ui:properties/ui:contains-date-control">
        	<xsl:call-template name="ui:show-datetime-js"/>
        </xsl:if>
        <xsl:call-template name="ui:post-do-submit"/>
      </body>
    </html>
  </xsl:template>

  
  <xsl:template mode="plesk" match="ui:stop-sign">
    <fieldset>
       <legend align="left" style="vertical-align:middle">
					<img src="/{$theme}/icons/{sw:if(@icon,@icon,'stop_sign')}_32.gif" width="32" height="32" style="vertical-align:middle"/>
            <span style="vertical-align:middle"><xsl:value-of select="@head"/></span>
        </legend>    
      <xsl:call-template name="ui:process-children"/>
    </fieldset>
  </xsl:template>   
  
  <!-- login screen / restore password screen -->
  <xsl:template mode="layout-plesk" match="ui:front-screen">
    <html>
      <head>
        <title>
          VZPP Plesk - <xsl:value-of select="@title"/>
        </title>
        <script type="text/javascript" src="/vz/js/common_script.js"></script>
        <script type="text/javascript" src="/vz/js/browser.js"></script>
        <link rel="stylesheet" type="text/css" href="/{$theme}/plesk.css"/>
        <link rel="stylesheet" type="text/css" href="/{$theme}/common.css"/>        
        <link rel="stylesheet" type="text/css" href="/{$theme}/css_expand.css"/>
      </head>
      <body onload="autoFocus();">
    <script type="text/javascript">
      if (self != top)
        self.top.location = self.location;
      function callTip(){
      }
      function showSandclock(){
      }
      function beforeSubmit(){
      }
      function formCheckEmpty(){
      	return true;
      }
    </script>  
    <form method="post" action="{sw:if(@action,@action,'/vz/cp/login-wrapper')}" name="loginForm" id="loginForm">
      <br/> 
      <img src="/{$theme}/images/1x1.gif" width="1" height="50"/>
      <br/> 
      <table cellpadding="0" cellspacing="0" border="0" align="center">
		<!--js presence check-->
		<tr>
			<td style="padding-bottom:20px;color:red" align="center">
				<noscript><sw:text>JavaScript is disabled in your browser. For the correct operation of Plesk, please enable JavaScript.</sw:text></noscript>
			</td>
		</tr>
        <tr>
          <td colspan="2" id="loginTitle">
            <xsl:value-of select="@title"/>
          </td>
        </tr>
        <tr>
          <td>
            <table cellpadding="3" cellspacing="0" WIDTH="100%" border="0" class="FrontScreen">
              <xsl:if test="ui:error">
                <tr>
                  <td colspan="3" class="FormError">
                    <xsl:value-of select="ui:error"/>
                  </td>
                </tr>
              </xsl:if>
              <xsl:if test="ui:oldtext/@valign = 'top'">              
                <tr><td colspan="3" align="center"><img src="/{$theme}/images/1x1.gif" width="1" height="1"/></td></tr>
                <tr>
                  <td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>                
                  <td colspan="2" align="{ui:oldtext/@align}"><xsl:copy-of select="ui:oldtext/child::node()"/></td>
                </tr>
              </xsl:if>
              <xsl:for-each select="ui:input">
                <tr>
                  <td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>
                  <td width="50%" class="title"><xsl:value-of select="@title"/></td>
                  <td align="left" width="50%">
                    <xsl:choose>
                      <xsl:when test="(@type = 'text') or (@type='password')">
                        <input type="{@type}" name="{@name}" class="FlatInput">
                          <xsl:copy-of select="@*[name() != 'type' and name() != 'name']"/>
                        </input>
                      </xsl:when>
                      <xsl:when test="@type = 'combo'">
                        <select name="{@name}">
                          <xsl:copy-of select="@*[name() != 'type' and name() != 'name']"/>
                          <xsl:copy-of select="*"/>
                        </select>                      
                      </xsl:when>
                    </xsl:choose>
                  </td>
                </tr>                
              </xsl:for-each>
              <tr>
                <td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>
                <td colspan="2" style="padding:7px 7px 7px 0">
                  <table width="100%" border="0">
                    <tr>
                      <td colspan="2" style="padding:7px 7px 7px 0" align="left">
                        <xsl:apply-templates mode="vzcp" select="ui:bottom/*[name() = 'ui:oldtext']"/>
                        <div class="uiButtons">
                          <xsl:apply-templates mode="vzcp" select="ui:bottom/*[name() != 'ui:oldtext']"/>
                        </div>
                      </td>
                    </tr>
                  </table>
                </td>
              </tr>
            </table>
          </td>
        </tr>
        <tr>
        <td><img src="/{$theme}/images/1x1.gif" width="1" height="10"/></td>
	  </tr>
        <tr>
          <td>
            <table cellpadding="0" cellspacing="0" WIDTH="100%" border="0">
			<tr>
			  <!-- td>
		            <a href="http://www.swsoft.com" target="_blank">
		              <img src="/{$theme}/images/powered_by_virtuozzo.gif" width="88" height="31" border="0"/>
		            </a>
			  </td -->
		        <td align="right">
		          <small style="color:#999999">
		             <sw:text>Copyright &#169; 1999-2008 by Parallels<br/>All rights reserved</sw:text>
		          </small>
		        </td>
			</tr>
		</table>
	    </td>
        </tr>
      </table>
      <xsl:call-template name="set-js-browser-pref-onlogin"/>      
			<xsl:apply-templates select="ui:hidden"/>
    </form>
    </body>
  </html>

  </xsl:template>   
  
  
   
  <xsl:template name="plesk-opresult">

  	<xsl:variable name="errors" select="error:get()"/>
<xsl:choose>
	<xsl:when test="$errors or normalize-space(sw:sesget('msg')) or normalize-space(sw:sesget('sched'))">
	<div id="opresult_id">
      <div class="OpResult">
          <table border="0" cellpadding="0" cellspacing="0" width="100%">
			<xsl:for-each select="$errors/error">
				<tr>
					<td class="ErrorBar">
					  <table border="0" cellpadding="0" cellspacing="0" width="100%" class="ErrorBarNew">
						<tr>
							<td class="MsgBarPic" width="16px"><img src="/{$theme}/icons/op_error.gif"/></td>	                
							<td class="MsgBarMsg" nowrap="1">
								<span class="ErrorBarLetr"><xsl:value-of select="sw:text('Error:')"/></span>
								<xsl:value-of select="text"/>
								<xsl:if test="details!=''">
									(<a onmouseover="callTip('get_err_details',event)" onmouseout="callTip()" onclick="open_details('{$baseurl}/core/tasks/error-popup?pos={position()}'); return false" href="{$baseurl}/core/tasks/error-popup?pos={position()}"><sw:text>Details</sw:text></a>)
								</xsl:if>
							</td>
						</tr>
					  </table>
					</td>
				</tr>
            </xsl:for-each>

            <xsl:if test="normalize-space(sw:sesget('msg'))">
              <tr>
                <td class="StatusBar">
					<table border="0" cellpadding="0" cellspacing="0" width="100%" class="StatusBarNew">
						<tr>
							<td class="MsgBarPic" width="16px"><img src="/{$theme}/icons/op_ok.gif"/></td>
							<td class="MsgBarMsg" nowrap="1">
								<span class="StatusBarLetr"><xsl:value-of select="sw:text('Information:')"/></span>
								<xsl:value-of select="sw:sesget('msg')"/>
							</td>
						</tr>
					</table>
					<xsl:value-of select="sw:sesput('msg', '')"/>
				</td>
           	  </tr>
            </xsl:if>

            <xsl:if test="normalize-space(sw:sesget('sched'))">
            	<tr>
                <xsl:variable name="op_id" select="sw:sesget('operation_id')"/>
                <td class="StatusBar">
					<table border="0" cellpadding="0" cellspacing="0" width="100%" class="StatusBarNew">
						<tr>
							<td class="MsgBarPic" width="16px"><img src="/{$theme}/icons/op_ok.gif"/></td>
							<td class="MsgBarMsg" nowrap="1">
								<span class="StatusBarLetr"><xsl:value-of select="sw:text('Information:')"/></span>
								<xsl:value-of select="sw:sesget('sched')"/> 
								(<a onmouseover="callTip('get_op_details',event)" onmouseout="callTip()" onclick="open_details('{$baseurl}/core/tasks/details-popup?id={$op_id}'); return false" href="{$baseurl}/core/tasks/details-popup?id={$op_id}"><sw:text>Details</sw:text></a>)
							</td>
						</tr>
					</table>
					<xsl:value-of select="sw:sesput('sched', '')"/>
                </td>
              </tr>
            </xsl:if>	
            
          </table>
        </div>          
        </div>
    </xsl:when>
	<xsl:otherwise>
	  <div id="opresult_id" style="display:none"></div>	
	</xsl:otherwise>
</xsl:choose>

  </xsl:template>

  <xsl:template mode="plesk" match="ui:dashboard">
		
		<xsl:variable name="disabled" select="@disabled='true'"/>
		<xsl:variable name="force-tip" select="@force-tip"/>
		<xsl:variable name="reset-paths" select="@reset-paths='true'"/>
		
		<xsl:variable name="block-width">
			<xsl:call-template name="html:calc-width">
				<xsl:with-param name="control" select="."/>
				<xsl:with-param name="as-text" select="true()"/>
			</xsl:call-template>
		</xsl:variable>

	   <xsl:variable name="dashboard-tree">
      <xsl:choose>
            
        <!-- we have children - use it -->
        <xsl:when test="item">
					<xsl:variable name="validItems" select="cred:filter-items(item)"/>	
					<xsl:if test="$validItems">
	          <ui:actions>
	            <xsl:copy-of select="sw:if(@title, @title, /*/@title)"/>
	            <ui:actions-set>
	              <xsl:for-each select="$validItems">
	                <xsl:variable name="href"><xsl:call-template name="href"><xsl:with-param name="reset-paths" select="$reset-paths"/></xsl:call-template></xsl:variable>
	                <ui:action icon="{@icon}" href="{$href}" sandclock="false" tip="{@tip}">
	                	<xsl:if test="$disabled">
                      <xsl:attribute name="disabled">true</xsl:attribute>                      
                    </xsl:if>
                    <xsl:if test="@target">
                      <xsl:attribute name="target"><xsl:value-of select="@target"/></xsl:attribute>
                    </xsl:if>	                                    
                    <xsl:if test="$force-tip">
                    	<xsl:attribute name="tip"><xsl:value-of select="$force-tip"/></xsl:attribute>
                    </xsl:if>
                    <xsl:copy-of select="@auth-type"/>
	                  <sw:text select="@title"/>
	                </ui:action>
	              </xsl:for-each>
	            </ui:actions-set>
	          </ui:actions>
					</xsl:if>
        </xsl:when>
            
        <!-- we have no items - use dashboard by @id or current screen id -->
        <xsl:otherwise>
          <xsl:variable name="id" select="sw:if(@screen-id, @screen-id, /*/@id)"/>
            
          <xsl:for-each select="sw:document($dashboard-file, $dashboard-source)/dashboards/dashboard[(not(@type) or @type='dashboard') and ( @screen-id = $id or @director-id=$id)]">
						<xsl:variable name="validItems" select="cred:filter-items(item)"/>	
						<xsl:if test="$validItems">
	            <ui:actions title="{sw:text(@name)}">
	            	<xsl:if test="$block-width!=''">
	            		<xsl:attribute name="width"><xsl:value-of select="$block-width"/></xsl:attribute>
	            	</xsl:if>
	              <ui:actions-set>
	                <xsl:for-each select="$validItems">
	                  <xsl:variable name="href"><xsl:call-template name="href"><xsl:with-param name="reset-paths" select="$reset-paths"/></xsl:call-template></xsl:variable>
	                  <ui:action icon="{@icon}" href="{$href}" sandclock="false" tip="{@tip}">
	                  	<xsl:if test="$disabled">
	                      <xsl:attribute name="disabled">true</xsl:attribute>	                      
	                    </xsl:if>
	                    <xsl:if test="@target">
	                      <xsl:attribute name="target"><xsl:value-of select="@target"/></xsl:attribute>
	                    </xsl:if>
	                    <xsl:if test="$force-tip">
	                    	<xsl:attribute name="tip"><xsl:value-of select="$force-tip"/></xsl:attribute>
	                    </xsl:if>
	                    <xsl:copy-of select="@auth-type"/>
	                    <sw:text select="@title"/>
	                  </ui:action>
	                </xsl:for-each>
	              </ui:actions-set>
	            </ui:actions>
						</xsl:if>
          </xsl:for-each>
          
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:apply-templates select="exsl:node-set($dashboard-tree)" mode="plesk"/>

  </xsl:template>  

  <!-- show VE information block -->
  <xsl:template match="ui:env-info" mode="plesk">
    <xsl:variable name="my-width">
      <xsl:call-template name="html:calc-width">
      <xsl:with-param name="control" select=".."/>
      <xsl:with-param name="as-text" select="1"/>
    <xsl:with-param name="use-def-width" select="1"/>
    </xsl:call-template>							
  </xsl:variable>
  <div style="width:{$my-width}">  
  
  
    <fieldset>
      <legend><sw:text>Container Information</sw:text></legend>
      <table cellspacing="0" cellpadding="0" border="0" width="max">
        <tr>
          <td nowrap="1">
            <sw:text>
              <xsl:with-param name="hostname" select="sw:sesget('hostname')"/>
              Container %{hostname}
            </sw:text>
          </td>
          <td><img src="/{$theme}/images/1x1.gif" width="15" height="1"/></td>
          <td nowrap="1">
            <xsl:call-template name="ui:current-ve-status"/>
          </td>
          <td width="100%"><img src="/{$theme}/images/1x1.gif" width="15" height="1"/></td>
          <xsl:call-template name="ui:show-resource-bar"/>                          
        </tr>
      </table>
    </fieldset>
    </div>
  </xsl:template>

	<!-- display page head -->
	<func:function name="plesk:head">
		<xsl:param name="custom" select="/.."/>
		<!-- Current VE name -->
		<xsl:variable name="env-name">
			<xsl:choose>
				<xsl:when test="sw:sesget('hostname')"><xsl:value-of select="sw:sesget('hostname')"/></xsl:when>
				<xsl:otherwise>#<xsl:value-of select="sw:ve-eid()"/></xsl:otherwise>
			</xsl:choose>  
		</xsl:variable>
		<func:result>
			<head>
				<script language="JavaScript">
					<!-- Top priority JS -->
					function callTip(string_id){
						if (!top.showTip){
							return false;
						}
						if (string_id){
							top.showTip(string_id) 
						}else{
							top.showTip('<xsl:value-of select="current()/@id"/>');    
						}
					}
				</script>			
				<title>
					<sw:text>
						<xsl:with-param name="title" select="current()/@title"/>
						<xsl:with-param name="vename" select="$env-name"/>
						Parallels Power Panel - %{title} - %{vename}
					</sw:text>
				</title>
				<link rel="stylesheet" type="text/css" href="/{$theme}/plesk.css"/>
				<link rel="stylesheet" type="text/css" href="/{$theme}/common.css"/>        
				<link rel="stylesheet" type="text/css" href="/{$theme}/css_expand.css"/>        
				<script type="text/javascript" src="/psa/javascript/common.js"></script>
				<script type="text/javascript" src="/vz/js/common_script.js"></script>
				<script type="text/javascript" src="/vz/js/browser.js"></script>				
				<script type="text/javascript" src="/vz/js/toolbar_utils.js"></script>								
				<script>
					function callPageTitle(){
					top.mouse_move  
					<!-- top.setPageTitle('<xsl:value-of select="current()/@title"/>'); -->
					} 
					
					// help in popup

					function callHelp(){
					open_help('<xsl:value-of select="$baseurl"/>/help?topic=<xsl:value-of select="current()/@id"/>')
					}
				</script>
				<xsl:copy-of select="$custom"/>
			</head>
		</func:result>
	</func:function>
  
</xsl:stylesheet>
