<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:html="http://www.swsoft.com/xsl/cp/html"
  xmlns:func="http://exslt.org/functions"
>	

	<sw:include href="/layout/lib/html.xsl"/>
	
  <!-- form-related elements in plesk mode -->

  <!-- show resource group -->
  <xsl:template match="ui:resource-group" mode="plesk">
		<xsl:if test="columns/@resource and columns/@usage">
			<tr>
				<!-- print column title only if resource and usage specifyed -->
				<th align="left" width="150">
					<xsl:value-of select="columns/@resource"/>
				</th>
				<th width="15">&#160;</th>
				<th colspan="2" width="150"><xsl:value-of select="columns/@usage"/></th>
				<!-- Additional columns -->	
				<xsl:for-each select="column">
					<th align="{@align}"><xsl:value-of select="."/></th>
				</xsl:for-each>
			</tr>
		</xsl:if>

		<xsl:for-each select="resource">
			<tr>
			<td width="150">
				<xsl:value-of select="name"/>
			</td>
			<td width="15">
				<xsl:choose>
					<xsl:when test="fraction and ../columns/@alert = 'yes'">
						<a>
							<xsl:copy-of select="a/@*"/>
							<img src="/{$theme}/icons/{mark/icon}.gif" border="0" width="14" height="14" alt="{mark/alt}" title="{mark/alt}"/>
						</a>
					</xsl:when>
					<xsl:otherwise>&#160;</xsl:otherwise>
				</xsl:choose>
			</td>
			<xsl:if test="fraction">
				<td width="100">
					<xsl:call-template name="showMeter">
					<xsl:with-param name="mcolor" select="mark/color"/>				
					<xsl:with-param name="f" select="fraction"/>
					<xsl:with-param name="a">
						<xsl:copy-of select="a"/>
					</xsl:with-param>
					</xsl:call-template>				
				</td>
				<xsl:choose>
					<xsl:when test="fraction/special-status">
						<td width="50" align="center" nowrap="1"><xsl:value-of select="fraction/special-status"/></td>
					</xsl:when>
					<xsl:otherwise>
						<td width="50" align="right" nowrap="1"><xsl:value-of select="format-number(fraction,'0.0#%')"/></td>
					</xsl:otherwise>	
				</xsl:choose>	
			</xsl:if>
			<!-- Additional columns -->
			<xsl:for-each select="col">
				<td align="{@align}" width="86">
					<xsl:copy-of select="./child::node()"/>
				</td>
			</xsl:for-each>
			</tr>
		</xsl:for-each>
  </xsl:template>

  <!-- form tag -->
  <xsl:template match="ui:form" mode="plesk">
    <form>
      <xsl:copy-of select="@*"/>
      <xsl:if test="@name and not(@id)">
      	<xsl:attribute name="id" select="@name" />
      </xsl:if>
      <xsl:if test="not(@method)">
        <xsl:attribute name="method">POST</xsl:attribute>
      </xsl:if>
      <xsl:if test="not(@action)">
        <xsl:attribute name="action"></xsl:attribute>
      </xsl:if>
      <xsl:apply-templates select="*" mode="plesk"/>
    </form>
  </xsl:template>
  
	<xsl:template mode="plesk" match="ui:block">
		<xsl:param name="args" select="/.."/>
		<!--|-->
		<xsl:variable name="div-tag">
			<xsl:if test="@div-id">
				<div id="{@div-id}"/>
			</xsl:if>
		</xsl:variable>
		
		<xsl:if test="@div-id">
			<xsl:copy-of select="html:tag-open($div-tag)"/>
		</xsl:if>
		
		<!-- process all not input and buttons -->
		<xsl:apply-templates select="*" mode="plesk">
			<xsl:with-param name="args" select="$args|error:get()"/>
		</xsl:apply-templates>
		
		<xsl:if test="@div-id">
			<xsl:copy-of select="html:tag-close($div-tag)"/>
		</xsl:if>
		
		<!-- postprocess -->
		<xsl:apply-templates select="ui:rows//ui:control-slave"/>
		<!-- /postprocess -->

	</xsl:template>


	<xsl:template mode="plesk" match="ui:rows-offset">    
		<table width="100%" border="0">
			<tr><td>
				<img src="/{$theme}/images/1x1.gif" width="{@size * 10}" height="1"/>
			</td>
			<td width="100%">
				<xsl:apply-templates mode="plesk"/>
			</td>
			</tr>
		</table>
	</xsl:template>

	<xsl:template mode="plesk" match="ui:rows-title">    
	</xsl:template>


  <!-- iterate form  rows -->
  <xsl:template match="ui:rows" mode="plesk">
    <xsl:param name="args" select="/.."/>    

    <xsl:choose>

      <!-- have no rows defined -->
      <xsl:when test="not(ui:*)">
        <xsl:copy-of select="."/> <!-- XXX: xsl:apply-templates here ??? -->
      </xsl:when>
      
      <!-- have some ui:row elements -->
      <!-- Attribute "id" makes this block flippable -->
      <xsl:otherwise>
      	<xsl:variable name="status" select="sw:get-row-state(.)"/>
      	
      		<xsl:call-template name="html:div-open"/>
      		
      		<xsl:variable name="mode-edit" select="ancestor::ui:block/@mode='edit'"/>					      		
      		
	        <table cellpadding="{sw:if($mode-edit,5,3)}" cellspacing="0" border="0" class="{sw:if($mode-edit,'MainFormTable','Dashboard')}">
	          <xsl:call-template name="html:calc-width">
							<xsl:with-param name="control" select="."/>
						</xsl:call-template>		
	          <tr>
	            <td align="left" width="100%">
      	
			        <fieldset>
			          <xsl:if test="not(@title) and not(ui:rows-title)">
									<xsl:attribute name="class">noLegend</xsl:attribute>
			          </xsl:if>
				        <xsl:if test="@title or ui:rows-title">
				          <legend>
				          	<xsl:if test="@id">
				          	  <xsl:attribute name="style">cursor:hand; cursor:pointer; vertical-align:middle;</xsl:attribute>
				          	  <xsl:attribute name="onclick">flipBlock('<xsl:value-of select="@id"/>','/<xsl:value-of select="$theme"/>/icons/arr_');</xsl:attribute>
											   <xsl:variable name="block-tip" select="sw:if(@tip,@tip,'sh_ctrl')"/>
											   <xsl:attribute name="onmouseover">callTip('<xsl:value-of select="$block-tip"/>', event)</xsl:attribute>
											   <xsl:attribute name="onmouseout">callTip()</xsl:attribute>
				          	  <img src="/{$theme}/icons/arr_{sw:if($status = 1,'opened','gt')}.gif" border="0" id="{@id}_img" style="vertical-align:middle; margin-left: -12px; margin-right:2px"/>
				          	</xsl:if>          	
				          	<xsl:if test="@title"><xsl:value-of select="@title"/></xsl:if>
				          	<xsl:if test="ui:rows-title"><xsl:copy-of select="ui:rows-title/*"/></xsl:if>
				          	<xsl:if test="@alert-icon">
				          		<img src="/{$theme}/icons/{@alert-icon}.gif" width="16" height="16" border="0"/>      	
				          	</xsl:if>
				          	<xsl:if test="@alert-label">
				          		&#160;<xsl:value-of select="@alert-label"/>
				          	</xsl:if>
				          </legend>
				        </xsl:if>
				        <xsl:variable name="div-tag">
				        	<div id="show_{@id}" style="display:{sw:if($status = 1 or not(@id),'block','none')}"/>					
				        </xsl:variable>
				        <xsl:if test="@id">
				        	<xsl:copy-of select="html:tag-open($div-tag)"/>	        	
				        </xsl:if>

	              <!-- prepare some vars -->
								<xsl:variable name="separate-tables" select="@separate-tables='true'"/>
								<xsl:variable name="table-tag">
						      <table cellpadding="3" cellspacing="0" border="0">
						      	<xsl:if test="not(ui:browse)">
						      		<xsl:attribute name="class">none</xsl:attribute>
						      	</xsl:if>
						      	<xsl:if test="not(ui:row/@table-width='none')">
											<xsl:attribute name="width"><xsl:value-of select="sw:if(ui:row/@table-width,ui:row/@table-width,'100%')"/></xsl:attribute>
										</xsl:if>
									</table>
						    </xsl:variable>
						    <!-- /prepare some vars -->    
						    <xsl:if test="not($separate-tables)">
									<xsl:copy-of select="html:tag-open($table-tag)"/>
								</xsl:if>
	    					<!-- process childs -->
								<xsl:for-each select="ui:*">																										
									<xsl:apply-templates select="." mode="plesk">
										<xsl:with-param name="args" select="$args"/>											
									</xsl:apply-templates>
								</xsl:for-each>					
								<!-- /process childs -->		
								<xsl:if test="not($separate-tables)">
									<xsl:copy-of select="html:tag-close($table-tag)"/>
								</xsl:if>
	            
				        <xsl:if test="@id">
				        	<xsl:copy-of select="html:tag-close($div-tag)"/>	        	
				        </xsl:if>
				        <xsl:if test="@id">
									<div onclick="flipBlock('{@id}','/{$theme}/icons/arr_')" id="hide_{@id}" style="cursor:hand;display:{sw:if($status = 1 or not(@id),'none','block')}">
				        		<table cellpadding="10" cellspacing="0" border="0" class="MainFormTable">
				        			<tr>
				        				<td>        	  
				          				<xsl:value-of select="@closed-text"/>
				          			</td>
				          		</tr>
				          	</table>
					        </div>
					        <input type="hidden" name="{@id}" id="{@id}" value="{sw:if($status = 1,'1','0')}"/>
					     	</xsl:if>
			        </fieldset>
			        
			        </td>
	          </tr>
	       	</table>
	       	
	       	<xsl:call-template name="html:div-close"/>		
        
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>    

</xsl:stylesheet>
