<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl path func layout licensem sb cred vem hwm vzenv check str vzcc vzcp time error"
	exclude-result-prefixes="ui"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:http="http://www.swsoft.com/xsl/cp/http"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:vem="http://www.swsoft.com/xsl/cp/vem"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:path="http://www.swsoft.com/xsl/cp/path"
	xmlns:func="http://exslt.org/functions"
	xmlns:sb="http://www.swsoft.com/xsl/cp/sb"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
	xmlns:layout="http://www.swsoft.com/xsl/cp/layout"	
	xmlns:str="http://www.swsoft.com/xsl/cp/str"
	xmlns:vzcc="http://www.swsoft.com/xsl/cp/vzcc"
	xmlns:vzcp="http://www.swsoft.com/xsl/cp/vzcp"
	xmlns:time="http://www.swsoft.com/xsl/cp/time"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>

	<!-- for dynamic cred calculation -->
	<sw:include href="/lib/vz/vzenv-offline.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/sitebuilder.xsl"/>

	<xsl:output method="html" encoding="utf-8"/>
	<xsl:variable name="screen-root" select="/"/>
	<xsl:variable name="screens-repository" select="sw:document('screens.xml')"/>
	<xsl:variable name="screen-info" select="path:find-screen($screen-root/ui:screen/@id,true())"/>
	<xsl:variable name="layout:path-raw" select="path:update-current($screen-info)"/>	
	<xsl:variable name="layout:path-ext" select="path:raw2ext($layout:path-raw)"/>	
	
	
	<!-- compute screeen HTML contents -->
	<xsl:template name="process-screen">

		<xsl:if test="$screen-info"/>
		<xsl:if test="$layout:path-raw"/>		
		<xsl:if test="$layout:path-ext"/>		


		<xsl:variable name="actionurl" select="substring($requesturl,string-length($baseurl)+1)"/>
		<xsl:choose>

			<!-- Frameset redirect - only for 'yes' and only if old or new layout is framed-->
			<xsl:when test="$ticket and (sw:sesget('frameset_redirect') = 'yes')">
				<xsl:value-of select="sw:sesput('frameset_redirect','')"/>
				<xsl:call-template name="frameset_redirect"/>
			</xsl:when>

			<xsl:when test="$ticket and (($actionurl = '') or ($actionurl = '/'))">
				<xsl:choose>
					<xsl:when test="starts-with($layout, 'vzcc')">
						<xsl:call-template name="vzcc-frameset"/>
					</xsl:when>

					<xsl:otherwise>
						<xsl:call-template name="vzcp-frameset"/>
					</xsl:otherwise>

				</xsl:choose>
			</xsl:when>

			<xsl:otherwise>
				<!-- transform screen contents into resulting document -->
				<xsl:choose>
					<xsl:when test="$layout = 'vzcc-plesk'">
						<xsl:apply-templates select="/*" mode="layout-vzcc-plesk"/>
					</xsl:when>

					<!-- We use pp frameset, but cc-plesk layout (maybe need a new name)  -->
					<xsl:when test="$layout = 'vzcp-plesk'">
						<xsl:apply-templates select="/*" mode="layout-vzcp-plesk"/>
					</xsl:when>

					<xsl:when test="$layout = 'vzcc'">
						<xsl:apply-templates select="/*" mode="layout-vzcc"/>
					</xsl:when>

					<xsl:when test="$layout = 'plesk-integrated'">
						<xsl:apply-templates select="/*" mode="layout-plesk"/>
					</xsl:when>

					<xsl:when test="$layout = 'framed'">
						<xsl:apply-templates select="/*" mode="layout-framed"/>
					</xsl:when>

					<xsl:when test="$layout = 'non-framed'">
						<xsl:apply-templates select="/*" mode="layout-non-framed"/>
					</xsl:when>

					<xsl:otherwise>
						<xsl:apply-templates select="/*"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>

		<!-- Reset non-proceded errors (on ordinal screen)-->
		<xsl:if test="/ui:screen">
			<xsl:if test="error:reset()"/>
		</xsl:if>

	</xsl:template>

	<!-- default tempates for layout mode -> display mode -->
	<xsl:template match="ui:*" mode="layout-plesk">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select="." mode="plesk">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="ui:*" mode="layout-framed">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select="." mode="vzcp">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="ui:*" mode="layout-vzcc">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select="." mode="vzcc">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="ui:*" mode="layout-vzcc-plesk">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select="." mode="vzcc-plesk">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="ui:*" mode="layout-vzcp-plesk">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select="." mode="vzcc-plesk">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="ui:*" mode="layout-non-framed">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select="." mode="vzcp">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<!-- default tempates for display mode -> no mode -->
	<xsl:template match="ui:*" mode="plesk">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select=".">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="ui:*" mode="vzcc">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select="." mode="vzcp">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="ui:*" mode="vzcp">
		<xsl:param name="args" select="/.."/>
		<xsl:apply-templates select=".">
			<xsl:with-param name="args" select="$args"/>
		</xsl:apply-templates>
	</xsl:template>

	<!-- credentials -->
	<sw:include href="../lib/cred.xsl"/>

	<sw:include href="../http/document.xsl"/>

	<!-- screen layout definitions -->
	<sw:include href="/layout/basic.xsl"/>
	<sw:include href="/layout/plain.xsl"/>
	<sw:include href="/layout/framed.xsl"/>
	<sw:include href="/layout/popup.xsl"/>
	<sw:include href="/layout/simple-screen.xsl"/>
	<sw:include href="/layout/body-screen.xsl"/>


	<sw:include href="/lib/frameset_redirect.xsl"/>

	<!-- elements rendering -->
	<sw:include href="/layout/elements.xsl"/>
	<sw:include href="/layout/forms.xsl"/>

	<sw:include href="/layout/vzcp.xsl"/>
	<sw:include href="/layout/plesk.xsl"/>
	<sw:include href="/layout/vzcc.xsl"/>

	<!-- external renders -->
	<sw:include href="/layout/external.xsl"/>
	<sw:include href="/layout/ext-apps.xsl"/>
	<sw:include href="/layout/ext-tree.xsl"/>
	<sw:include href="/layout/ext-services.xsl"/>
	<sw:include href="/layout/ext-tasks.xsl"/>
	<sw:include href="/layout/ext-fwm.xsl"/>
	<sw:include href="/layout/ext-redirect.xsl"/>	
	<sw:include href="/layout/ext-favorites.xsl"/>
	<sw:include href="/layout/ext-summary.xsl"/>
	<sw:include href="/layout/ext-taskbar.xsl"/>	

	<!-- utility libraries -->
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/titlebar.xsl"/>
	<sw:include href="/lib/nav_menu.xsl"/>
	<sw:include href="/lib/download.xsl"/>

	<sw:include href="lib/toolbar.xsl"/>
	<sw:include href="lib/path.xsl"/>
	<sw:include href="lib/resources-bar.xsl"/>
	<sw:include href="lib/tree.xsl"/>
	<sw:include href="/lib/date-time.xsl"/>
	
	<sw:include href="/lib/swa/licensem.xsl"/>

	<!-- browse libraries -->
	<sw:include href="/lib/browse.xsl"/>

</xsl:stylesheet>
