<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl units func"
	exclude-result-prefixes="func ui vzcc vzcp units layout local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"    
	xmlns:vzcc="http://www.swsoft.com/xsl/cp/vzcc"
	xmlns:vzcp="http://www.swsoft.com/xsl/cp/vzcp"
	xmlns:units="http://www.swsoft.com/xsl/cp/units"
	xmlns:layout="http://www.swsoft.com/xsl/cp/layout"	
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"	
  >
	<sw:include href="/lib/core/units-core.xsl"/>  
	<sw:include href="vzcc/frameset.xsl"/>

<!-- vzcc screen -->
<xsl:template match="ui:screen" mode="layout-vzcc">
	<html>
		<xsl:copy-of select="vzcc:head(ui:head/*)"/>
		<xsl:call-template name="body-tag-open"/>
		<xsl:call-template name="tooltip-area"/>
		<xsl:call-template name="sandclock"/>
		<xsl:apply-templates select="." mode="vzcc">
			<xsl:with-param name="show-up-level" select="1"/>
		</xsl:apply-templates>
		<xsl:call-template name="local:sync-menu"/>
		<xsl:if test="ui:properties/ui:js-tail">
			<xsl:copy-of select="ui:properties/ui:js-tail/child::node()"/>
		</xsl:if>
		<xsl:if test="ui:properties/ui:contains-date-control">
			<xsl:call-template name="ui:show-datetime-js"/>
		</xsl:if>
		<xsl:call-template name="ui:post-do-submit"/>
		<xsl:call-template name="body-tag-close"/>
	</html>
</xsl:template>

<!-- vzcc screen, plesk mode-->
<xsl:template match="ui:screen" mode="layout-vzcc-plesk">
	<xsl:variable name="path" select="$layout:path-ext"/>
	<!-- Maximum level of left menu (static part) -->
	<html>
		<xsl:copy-of select="vzcc:head(ui:head/*)"/>

		<xsl:call-template name="body-tag-open"/>
		<xsl:call-template name="tooltip-area"/>
		<xsl:apply-templates select="." mode="vzcc-plesk"/>
		<xsl:call-template name="local:sync-menu"/>

		<xsl:if test="ui:properties/ui:js-tail">
			<xsl:copy-of select="ui:properties/ui:js-tail/child::node()"/>
		</xsl:if>
		<xsl:if test="ui:properties/ui:contains-date-control">
			<xsl:call-template name="ui:show-datetime-js"/>
		</xsl:if>
		<xsl:call-template name="ui:post-do-submit"/>
		<xsl:call-template name="sandclock"/>
		<xsl:call-template name="body-tag-close"/>
	</html>
</xsl:template>


<xsl:template name="local:sync-menu">
	<xsl:variable name="path" select="$layout:path-ext"/>
	<xsl:variable name="menu-depth" select="2"/>	
	<script language="JavaScript">
		function callNavigate(){
			<![CDATA[if (top.menu && top.menu.navigateMenu)]]>{
			<xsl:choose>
				<xsl:when test="$layout:path-ext//@units-path">
					<xsl:variable name="dn" select="units:current-dn()"/>
					<xsl:variable name="units" select="units:dn2nodes($dn)/dn[@value!='']"/>				
					<xsl:variable name="obj-type" select="sw:sesgetstr('units-obj-type')"/>
					<xsl:variable name="is-top" select="boolean(units:is-dn-top($dn))"/>
	
					var units_path = new Array(
						<xsl:for-each select="$units">
							<xsl:sort select="@index" order="descending"/>
							<xsl:if test="position()!=1">,</xsl:if>'<xsl:value-of select="sw:html-escape(@value,'escape-quote')"/>'
						</xsl:for-each>
					);
					<xsl:choose>
						<!-- Clicked on VE, located in another HN -->
						<xsl:when test="$obj-type='ve.vz.vt' and $layout:path-ext[position()=(last()-2)]/@units-path='unit'">
							top.menu.navigateMenuExt('<xsl:value-of select="$is-top"/>','<xsl:value-of select="$dn"/>','<xsl:value-of select="sw:ve-eid()"/>','<xsl:value-of select="sw:base64-encode(sw:hn-eid())"/>');
						</xsl:when>					
						<!-- Clicked on VE or HN, located in some unit-->
						<xsl:when test="$layout:path-ext[position()=(last()-1)]/@units-path='unit'">
							<xsl:if test="$obj-type!=''">
								<xsl:variable name="obj-id" select="sw:context-object-id($obj-type)"/>
								top.menu.navigateMenuExt('<xsl:value-of select="$is-top"/>','<xsl:value-of select="$dn"/>','<xsl:value-of select="sw:base64-encode($obj-id)"/>','');
							</xsl:if>
						</xsl:when>
						<!-- Clicked on unit -->		
						<xsl:when test="$layout:path-ext[position()=last()]/@units-path='unit'">
							<xsl:if test="$is-top">top.menu.navigateMenuExt('<xsl:value-of select="$is-top"/>','<xsl:value-of select="sw:if(units:is-tree-logical($dn),units:logical-top-dn(),units:infra-top-dn())"/>','','');</xsl:if>
							<xsl:if test="not($is-top)">top.menu.navigateMenuExt('<xsl:value-of select="$is-top"/>','<xsl:value-of select="$dn"/>','','');</xsl:if>
						</xsl:when>
					</xsl:choose>
										
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="nav-id">
						<xsl:choose>
							<xsl:when test="count($path) &gt; $menu-depth"><xsl:value-of select="$path[position() = $menu-depth]/@id"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="$path[position() = last()]/@id"/></xsl:otherwise>
						</xsl:choose>
					</xsl:variable>					
					top.menu.navigateMenu('<xsl:value-of select="$nav-id"/>');
				</xsl:otherwise>
			</xsl:choose>
			}
		}
	</script>
</xsl:template>

<xsl:template name="tooltip-area">
	<div id="toolTip" class="toolTipArea"></div>
	<div id="rightMenu"></div>
</xsl:template>

<xsl:template match="ui:screen" mode="vzcc">
	<xsl:param name="show-up-level"/>

		<table width="100%" cellspacing="0" cellpadding="0" border="0">    	
			<tr>
				<!-- Main window -->
				<td width="100%" valign="top" align="left">
					<table border="0" cellpadding="0" cellspacing="0" width="100%">
						<tr>
							<td class="titleBar">
								<xsl:call-template name="titlebar"/>
								<xsl:apply-templates select="ui:tab-bar-custom|ui:tab-bar"/>
								<xsl:if test="not(ui:tab-bar-custom/ui:tab) and not(ui:tab-bar)"><div id="noTabs"></div></xsl:if>
							</td>
						</tr>

						<xsl:call-template name="opresult"/>
						<!-- CONTENT -->
						<tr>
							<td class="Content">
								<xsl:apply-templates select="." mode="vzcp"/>
							</td>
						</tr>
					</table>
				</td>
			</tr>  
		</table> 
		<xsl:if test="ui:properties/ui:contains-date-control">
			<xsl:call-template name="ui:show-datetime-js"/>
		</xsl:if>   
</xsl:template>

<xsl:template match="ui:screen" mode="vzcc-plesk">
	<table width="100%" cellspacing="0" cellpadding="0" border="0">   
		<tr>
			<xsl:call-template name="default-form-open"/>
			<td>
				<xsl:call-template name="ui:show-toolbar"/>
				<xsl:call-template name="titlebar-plesk"/>
				<xsl:apply-templates select="ui:tab-bar-custom|ui:tab-bar"/>
				<xsl:if test="not(ui:tab-bar-custom/ui:tab) and not(ui:tab-bar)"><div id="noTabs"></div></xsl:if>
				<xsl:call-template name="plesk-opresult"/>
				<xsl:choose>
					<xsl:when test="ui:properties/ui:description">
						<xsl:apply-templates select="ui:properties/ui:description" mode="plesk"/>
					</xsl:when>
					<xsl:when test="$screen-info/info">
						<xsl:call-template name="ui:description">
							<xsl:with-param name="static-content">
								<xsl:value-of select="$screen-info/info"/>
							</xsl:with-param>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<!-- No description anywhere -->
					</xsl:otherwise>
				</xsl:choose>
				<div class="screenBody{sw:if(ui:content/ui:block[1]/*[position() = 1 and self::ui:browse],'Browse','')}">
					<xsl:choose>
						<xsl:when test="ui:properties/ui:width/@value = 'fixed'">
							<xsl:attribute name="style">width:688px</xsl:attribute>
						</xsl:when>
					</xsl:choose>
					<xsl:apply-templates select="ui:content/*" mode="plesk"/>
				</div>
			</td>
			<xsl:call-template name="default-form-close"/>
		</tr>
	</table>
</xsl:template>

<!-- login screen -->
<xsl:template match="ui:front-screen" mode="layout-vzcc">
	<html>
		<xsl:call-template name="head"/>
		<xsl:call-template name="body-tag-open"/>
			<script type="text/javascript">
			if (self != top)
				self.top.location = self.location;
				function callTip(){
				}
				function showSandclock(){
				}
				function beforeSubmit(){
				}
				function formCheckEmpty(){
				return true;
				}
			</script>
		<xsl:apply-templates select="." mode="vzcp"/>
		<xsl:call-template name="body-tag-close"/>
	</html>
</xsl:template>

<!-- login screen, plesk mode -->
<xsl:template match="ui:front-screen" mode="layout-vzcc-plesk">
	<!-- same as in layout-vzcc -->
	<xsl:apply-templates select="." mode="layout-vzcc"/>
</xsl:template>

<!-- call paren mode templates here -->
<xsl:template mode="vzcc" match="ui:*">
	<xsl:apply-templates select="." mode="vzcp"/>
	</xsl:template>

<!-- call paren mode templates here -->
<xsl:template mode="vzcc-plesk" match="ui:*">
	<xsl:apply-templates select="." mode="plesk"/>
</xsl:template>

<!-- display page head -->
	<func:function name="vzcc:head">
		<xsl:param name="custom" select="/.."/>
		
		<xsl:variable name="page-title">
			<sw:text>
				<xsl:with-param name="title" select="sw:text-subst($screen-info/@title)"/>
				Parallels Infrastructure Manager - %{title}
			</sw:text>
		</xsl:variable>
		  
		<func:result>
			<head>
				<script language="JavaScript">
					<!-- Top priority JS -->
					//wrapper
					function getTipText(string_id){
					  return top.getTipText(string_id)
					}
					
					function callTip(string_id, e){
					  <xsl:if test="sw:sesget('vzcc_tooltips') = 'false'">
					  	return false;
					  </xsl:if>
						if (string_id){
							fadingTips.tipOver(getTipText(string_id), e) 
						}else{
							fadingTips.tipOut();    
						}
					}

					function globalSearch(value){
						if (!value){
							return false
						}
						queryString = '<xsl:value-of select="$baseurl"/>/core/search?global_search='+value;
						window.location = queryString;
						return false;
					}
					
				</script>
				<title>
					<xsl:value-of select="$page-title"/>
				</title>
				<link rel="stylesheet" type="text/css" href="/{$theme}/common.css"/>
				<link rel="stylesheet" type="text/css" href="/{$theme}/css_expand.css"/>
				<link rel="stylesheet" type="text/css" href="/{$theme}/{sw:if(contains($layout,'plesk'),'plesk','vz')}.css"/>
				<xsl:for-each select="ui:screen/ui:properties/ui:include-css">
					<link rel="stylesheet" type="text/css" href="/{$theme}/{.}"/>
				</xsl:for-each>
				<link rel="shortcut icon" href="/favicon.ico"/>	
				<xsl:call-template name="javascript">
					<xsl:with-param name="javascript">
						<xsl:variable name="reload-dn" select="sw:sesget('frameset_reload_farmdir')"/>
						<xsl:if test="$reload-dn != ''">
							<xsl:value-of select="sw:sesput('frameset_reload_farmdir','')"/>          
							parent.menu.reloadGroup(
								'<xsl:value-of select="$reload-dn"/>',
								'<xsl:value-of select="sw:base64-encode($reload-dn)"/>',
								'<xsl:value-of select="units:tree-dn(units:dn2tree($reload-dn))"/>');
						</xsl:if>
						<xsl:variable name="reload-dn-logical" select="sw:sesget('frameset_reload_farmdir_logical')"/>
						<xsl:if test="$reload-dn-logical != ''">
							<xsl:value-of select="sw:sesput('frameset_reload_farmdir_logical','')"/>
							parent.menu.reloadGroup(
								'<xsl:value-of select="$reload-dn-logical"/>',
								'<xsl:value-of select="sw:base64-encode($reload-dn-logical)"/>',
								'<xsl:value-of select="units:tree-dn(units:dn2tree($reload-dn-logical))"/>');
						</xsl:if>
						<xsl:choose>
						<xsl:when test="not(ui:properties/ui:noframesetredirect)">
							if (window == window.top){
								var getargs = window.location.search;
								<![CDATA[
									if (getargs.match(/(\?|&)noframesetredirect=/)){
									setCookie("frameset_url","");
									]]>
									}else{
									setCookie("frameset_url", window.location.pathname);
									window.location.href='<xsl:value-of select="$baseurl"/>';
									}
								}else{
									setCookie("frameset_url","");
								}
							</xsl:when>
							<xsl:otherwise>
								setCookie("frameset_url","");
							</xsl:otherwise>
						</xsl:choose>
						function callRefreshTop(){
						//reserved for future use, no refreshable frames so far
						}
						function callUpdateTop(){
						//reserved for future use, no refreshable frames so far
						}
						<!-- Manadatory script for vz frameset -->
						function callPageTitle(){
						top.setPageTitle('<xsl:value-of select="sw:html-escape($page-title, 'escape-quote')"/>');
						} 
						
						//help in popup
						function callHelp(){
						open_help('<xsl:value-of select="$baseurl"/>/help?topic=<xsl:value-of select="current()/@id"/>')
						}

					</xsl:with-param>
				</xsl:call-template>
				<xsl:copy-of select="$custom"/>
			</head>
		</func:result>
	</func:function>

</xsl:stylesheet>
