<!--
  Copyright (c) Parallels, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func"
	exclude-result-prefixes="func ui vzcp ve env local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:vzcp="http://www.swsoft.com/xsl/cp/vzcp"
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
  >

<sw:include href="/lib/vt/env-core.xsl"/>
<sw:include href="vzcp/elements.xsl"/>
<sw:include href="vzcp/forms.xsl"/>
<sw:include href="vzcp/browse.xsl"/>
<sw:include href="vzcp/frameset.xsl"/>

<xsl:template match="ui:screen" mode="layout-vzcp-plesk">
	<html>
		<xsl:copy-of select="vzcp:head(ui:head/*)"/>
		<xsl:call-template name="body-tag-open"/>
		<xsl:apply-templates select="." mode="vzcc-plesk"/>
		<script language="JavaScript">
			function callNavigate(){
			<![CDATA[if (top.menu && top.menu.navigateMenu)]]>
				top.menu.navigateMenu('<xsl:value-of select="/*/@id"/>');
			}
		</script>
		<xsl:if test="ui:properties/ui:js-tail">
			<xsl:copy-of select="ui:properties/ui:js-tail/child::node()"/>
		</xsl:if>      
		<xsl:if test="ui:properties/ui:contains-date-control">
			<xsl:call-template name="ui:show-datetime-js"/>
		</xsl:if>
		<xsl:call-template name="ui:post-do-submit"/>
		<xsl:call-template name="sandclock"/>          
		<xsl:call-template name="body-tag-close"/>
	</html>
</xsl:template>

<!-- login screen -->
<xsl:template match="ui:front-screen" mode="layout-vzcp">
	<html>
		<xsl:call-template name="head"/>
		<xsl:call-template name="body-tag-open"/>
		<xsl:apply-templates select="." mode="vzcp"/>
		<xsl:call-template name="ui:post-do-submit"/>
		<xsl:call-template name="body-tag-close"/>
	</html>
</xsl:template>

<!-- login screen -->
<xsl:template match="ui:front-screen" mode="layout-vzcp-plesk">
	<!-- same as in layout-vzcc -->
	<xsl:apply-templates select="." mode="layout-vzcc"/>
</xsl:template>

<xsl:template match="ui:screen" mode="vzcp">
	<table cellpadding="0" cellspacing="0" border="0">
		<xsl:attribute name="width">
			<xsl:choose>
				<xsl:when test="ui:properties/ui:width/@value = 'fixed'">600</xsl:when>
				<xsl:otherwise>100%</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
		<xsl:if test="ui:properties/ui:description">
			<tr>
				<td>
					<xsl:apply-templates select="ui:properties/ui:description" mode="vzcp"/>
				</td>
			</tr>
		</xsl:if>
		<tr>
			<xsl:call-template name="default-form-open"/>
			<td>
				<xsl:apply-templates select="ui:content/*" mode="vzcp"/>
			</td>
			<xsl:call-template name="default-form-close"/>
		</tr>
	</table>
	<xsl:if test="//ui:*[@required='true']">
		<font color="#FF0000">*</font><img src="/{$theme}/images/1x1.gif" width="5" height="1"/> <sw:text>Required fields</sw:text>
	</xsl:if>
	<xsl:call-template name="vzcp:show-bottom-return">
		<xsl:with-param name="mode" select="'vzcp'"/>
	</xsl:call-template>  
	<xsl:if test="ui:properties/ui:contains-date-control">
		<xsl:call-template name="ui:show-datetime-js"/>
	</xsl:if>
</xsl:template>

<xsl:template mode="vzcp" match="ui:stop-sign">
	<xsl:call-template name="stopSign">
			<xsl:with-param name="width" select="sw:if(@width, @width, '100%')"/>
			<xsl:with-param name="head" select="@head"/>
			<xsl:with-param name="icon" select="@icon"/>
			<xsl:with-param name="body">
				<xsl:call-template name="ui:process-children"/>
			</xsl:with-param>
	</xsl:call-template>
	<br/>
</xsl:template>

<!-- Front-Screen templates (login, restore password etc.) -->
<xsl:template mode="vzcp" match="ui:front-screen">
	<script type="text/javascript">
		if (self != top)
			self.top.location = self.location;
	</script>
	<form method="post" action="{sw:if(@action,@action,'/vz/cp/login-wrapper')}" name="loginForm" id="loginForm">
	<br/> 
	<img src="/{$theme}/images/1x1.gif" width="1" height="50"/>
	<br/> 
	<!-- LOGIN FORM -->
		<table cellpadding="0" cellspacing="0" border="0" align="center" width="453">
		<tr>
			<td style="padding-bottom:20px;color:red" align="center">
				<noscript><sw:text>JavaScript is disabled in your browser. For the correct operation of Parallels Infrastructure Manager, please enable JavaScript.</sw:text></noscript>
			</td>
		</tr>
		<tr>
			<td background="/{$theme}/images/login-header.gif" height="59">
				<div class="loginHeader">
					<xsl:value-of select="sw:if(@title-long != '',@title-long,@title)"/>
				</div>
			</td>
		</tr>
		<tr>
			<td>
				<table cellpadding="3" cellspacing="0" WIDTH="100%" border="0" style="border: 1px solid #d0d0d0">
				<xsl:if test="ui:error">
					<tr>
						<td colspan="3" class="FormError">
						<xsl:value-of select="ui:error"/>
						</td>
					</tr>
				</xsl:if>
				<xsl:if test="ui:oldtext/@valign = 'top'">              
	                <tr>
	                  <td><img src="/{$theme}/images/1x1.gif" width="10" height="34"/></td>
	                  <td colspan="2" align="{ui:oldtext/@align}"><xsl:copy-of select="ui:oldtext/child::node()"/></td>
	                </tr>
				</xsl:if>
				<xsl:for-each select="ui:input">
					<tr>
						<td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>
						<td width="40%"><font style="color:#111111"><xsl:value-of select="@title"/></font></td>
						<td align="left" width="60%">
						<xsl:choose>
							<xsl:when test="(@type = 'text') or (@type='password')">
								<input type="{@type}" name="{@name}" class="FlatInput">
									<xsl:copy-of select="@*[name() != 'type' and name() != 'name']"/>
								</input>
							</xsl:when>
							<xsl:when test="@type = 'combo'">
								<select name="{@name}">
									<xsl:copy-of select="@*[name() != 'type' and name() != 'name']"/>
									<xsl:copy-of select="*"/>
								</select>                      
							</xsl:when>
						</xsl:choose>
						</td>
					</tr>                
				</xsl:for-each>
				<tr>
					<td><img src="/{$theme}/images/1x1.gif" width="10" height="1"/></td>
					<td colspan="2" style="padding:7px 18px 6px 3px;" align="left">
						<xsl:apply-templates mode="vzcp" select="ui:bottom/*[name() = 'ui:oldtext']"/>
						<div class="uiButtons">
							<xsl:apply-templates mode="vzcp" select="ui:bottom/*[name() != 'ui:oldtext']"/>
						</div>
					</td>
				</tr>
				</table>
				</td></tr>
				<tr>
		          <td><img src="/{$theme}/images/1x1.gif" width="1" height="10"/></td>
		        </tr>
		        <tr>
					<td>
						<table cellpadding="0" cellspacing="0" WIDTH="100%" border="0">
						<tr>
							<!-- td>
							<a href="http://www.swsoft.com" target="_blank">
							<img src="/{$theme}/images/powered_by_virtuozzo.gif" width="88" height="31" border="0"/>
							</a>
							</td -->
							<td align="right">
								<small style="color:#999999">
									<sw:text>Copyright &#169; 1999-2008 by Parallels<br/>All rights reserved</sw:text>
								</small>
							</td>
						</tr>
					</table>
					</td>
				</tr>
		</table>
		<xsl:call-template name="set-js-browser-pref-onlogin"/>
		<xsl:apply-templates select="ui:hidden"/>      
	</form>
	</xsl:template>

	<!-- show dashboard -->
	<xsl:template match="ui:dashboard">
		<xsl:call-template name="dashboard">
			<xsl:with-param name="screen-id" select="/ui:screen/@id"/>
		</xsl:call-template>
		<br/>
	</xsl:template>

	<!-- display page head -->
	<func:function name="vzcp:head">
		<xsl:param name="custom" select="/.."/>
		
		<xsl:variable name="page-title">
			<sw:text>
				<xsl:with-param name="title" select="sw:text-subst($screen-info/@title)"/>
				<xsl:with-param name="vename" select="env:eid2info(sw:ve-eid())/title"/>
				Parallels Power Panel - %{title} - %{vename}
			</sw:text>
		</xsl:variable> 		
		
		<func:result>
			<head>
				<script language="JavaScript">
					<!-- Top priority JS -->
					function callTip(string_id){
						if(!top.menu)//hints in the non-framed version not supported yet
						return false;
					
						if (string_id){
							top.showTip(string_id) 
						}else{
							top.showTip('<xsl:value-of select="current()/@id"/>');    
						}
					}
				</script>
				<title>
					<xsl:value-of select="$page-title"/>
				</title>
				<link rel="stylesheet" type="text/css" href="/{$theme}/common.css"/>
				<link rel="stylesheet" type="text/css" href="/{$theme}/plesk.css"/>      
				<link rel="stylesheet" type="text/css" href="/{$theme}/css_expand.css"/>
				<link rel="shortcut icon" href="/favicon.ico"/>
				<xsl:call-template name="javascript">
					<xsl:with-param name="javascript">
						<xsl:variable name="farmdir" select="sw:sesget('frameset_reload_farmdir')"/>
						<xsl:if test="$farmdir != ''">
							<xsl:value-of select="sw:sesput('frameset_reload_farmdir','')"/>
						</xsl:if>
						<xsl:variable name="farmdir_logical" select="sw:sesget('frameset_reload_farmdir_logical')"/>
						<xsl:if test="$farmdir_logical != ''">
							<xsl:value-of select="sw:sesput('frameset_reload_farmdir_logical','')"/>
						</xsl:if>
						<xsl:choose>
							<xsl:when test="not(ui:properties/ui:noframesetredirect)">
								if (window == window.top){
								var getargs = window.location.search;
								<![CDATA[
									if (getargs.match(/(\?|&)noframesetredirect=/)){
									setCookie("frameset_url","");
									]]>
									}else{
									setCookie("frameset_url", window.location.pathname);
									window.location.href='<xsl:value-of select="$baseurl"/>';
									}
								}else{
									setCookie("frameset_url","");
								}
							</xsl:when>
							<xsl:otherwise>
								setCookie("frameset_url","");
							</xsl:otherwise>
						</xsl:choose>
						<!-- Manadatory script for vz frameset -->
						function callPageTitle(){
							top.setPageTitle('<xsl:value-of select="sw:html-escape($page-title,'escape-quote')"/>');
						} 
						
						//help in popup
						function callHelp(){
							open_help('<xsl:value-of select="$baseurl"/>/help?topic=<xsl:value-of select="current()/@id"/>')
						}

						<xsl:variable name="curr-ve-state">
							<body>
								<xsl:call-template name="ui:current-ve-status"/>
							</body>
						</xsl:variable>
						
						function callUpdateTop(){
							var msg = '<sw:text lang="C" select="sw:html-escape(sw:text(exsl:node-set($curr-ve-state)/body/node()), 'escape-quotes,no-escape-amp,no-escape-ltgt')"/>';
							top.changeInnerHTML('topframe', 've_state',msg);
						}
						
						function callRefreshTop(){
							<xsl:choose>
								<!-- Trasition - always refreshin' -->
								<xsl:when test="ve:context-transition()">
									var reload_mode = 'transition';
									var period = <xsl:value-of select="$config/vzcpcon/timeout/status_bar_refresh/transition"/>;
								</xsl:when>
								<xsl:when test="$refresh_period &gt; 0">
									<!-- State, Refresh by timer -->
									var reload_mode = 'timer';
									var period = '<xsl:value-of select="$refresh_period"/>';
								</xsl:when>
								<xsl:otherwise>
									<!-- State, Smart resfresh (click+timer) -->
									var reload_mode = 'smart';
									var period = <xsl:value-of select="$config/vzcpcon/timeout/status_bar_refresh/smart"/>;
								</xsl:otherwise>
							</xsl:choose>      
							<![CDATA[  if(top && top.reloadManager) top.reloadManager(reload_mode,period);]]>   
						}
					</xsl:with-param>
				</xsl:call-template>
				<xsl:copy-of select="$custom"/>
			</head>
		</func:result>
	</func:function>

</xsl:stylesheet>
