<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
	-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:html="http://www.swsoft.com/xsl/cp/html"	 
	>

	<sw:include href="/layout/lib/html.xsl"/>
	
	<!-- show resources bars -->
	<xsl:template match="ui:resource-group" mode="vzcp">
		<xsl:if test="columns/@resource and columns/@usage">
			<tr>
				<!-- print column title only if resource and usage specifyed -->
				<th align="left" width="150">
					<xsl:value-of select="columns/@resource"/>
				</th>
				<th width="15">&#160;</th>
				<th colspan="2" width="150"><xsl:value-of select="columns/@usage"/></th>
				<!-- Additional columns -->	
				<xsl:for-each select="column">
					<th align="{@align}"><xsl:value-of select="."/></th>
				</xsl:for-each>
			</tr>
		</xsl:if>
		<xsl:for-each select="resource">
			<tr>
			<td class="name" width="150">
				<xsl:value-of select="name"/>
			</td>
			<td width="15">
				<xsl:choose>
					<xsl:when test="fraction and ../columns/@alert = 'yes'">
						<a>
							<xsl:copy-of select="a/@*"/>
							<img src="/{$theme}/icons/{mark/icon}.gif" border="0" width="15" height="13" alt="{mark/alt}" title="{mark/alt}"/>
						</a>
					</xsl:when>
					<xsl:otherwise>&#160;</xsl:otherwise>
				</xsl:choose>
			</td>
			<xsl:if test="fraction">
				<td width="100">
					<xsl:call-template name="showMeter">
					<xsl:with-param name="mcolor" select="mark/color"/>				
					<xsl:with-param name="f" select="fraction"/>
					<xsl:with-param name="a">
						<xsl:copy-of select="a"/>
					</xsl:with-param>
					</xsl:call-template>				
				</td>
				<xsl:choose>
					<xsl:when test="fraction/special-status">
						<td width="50" align="center" nowrap="1"><xsl:value-of select="fraction/special-status"/></td>
					</xsl:when>
					<xsl:otherwise>
						<td width="50" align="right" nowrap="1"><xsl:value-of select="format-number(fraction,'0.0#%')"/></td>
					</xsl:otherwise>	
				</xsl:choose>	
			</xsl:if>
			<!-- Additional columns -->
			<xsl:for-each select="col">
				<td align="{@align}" width="86">
					<xsl:copy-of select="./child::node()"/>
				</td>
			</xsl:for-each>
			</tr>
		</xsl:for-each>
	</xsl:template>

	<!-- From tag insertion -->
	<xsl:template match="ui:form" mode="vzcp">	
		<form>
			<xsl:copy-of select="@*"/>
			<xsl:if test="@name and not(@id)">
				<xsl:attribute name="id" select="@name" />
			</xsl:if>
			<xsl:if test="not(@method)">
				<xsl:attribute name="method">POST</xsl:attribute>
			</xsl:if>
			<xsl:if test="not(@action)">
				<xsl:attribute name="action"></xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="*" mode="vzcp"/>
		</form>
	</xsl:template>
	
	<!-- Display block contents -->
	<xsl:template match="ui:block" mode="vzcp">
		<xsl:param name="args" select="/.."/>
	
		<xsl:variable name="div-tag">
			<xsl:if test="@div-id">
    		<div id="{@div-id}"/>					
    	</xsl:if>
    </xsl:variable>
		
		<xsl:if test="@div-id">
			<xsl:copy-of select="html:tag-open($div-tag)"/>
		</xsl:if>
	
		<!-- process all not buttons -->
		<xsl:apply-templates select="ui:*" mode="vzcp">
			<xsl:with-param name="args" select="$args|error:get()"/>
		</xsl:apply-templates>
		
		<xsl:if test="@div-id">
			<xsl:copy-of select="html:tag-close($div-tag)"/>
		</xsl:if>
		
		<!-- postprocess -->
		<xsl:apply-templates select="ui:rows//ui:control-slave"/>
		<!-- /postprocess -->
		
	</xsl:template>	

	<xsl:template mode="vzcp" match="ui:rows-offset">    
		<table width="100%" border="0">
			<tr><td>
				<img src="/{$theme}/images/1x1.gif" width="{@size * 10}" height="1"/>
			</td>
			<td width="100%">
				<xsl:apply-templates mode="vzcp"/>
			</td>
			</tr>
		</table>
	</xsl:template>
	
	<xsl:template mode="vzcp" match="ui:rows-title">    
	</xsl:template>
  

	<!-- Iterate form	rows -->
	<xsl:template match="ui:rows" mode="vzcp">
		<xsl:param name="args" select="/.."/>
	
		<xsl:choose>
	
			<!-- have no rows defined -->
			<xsl:when test="not(ui:*)">
				<xsl:copy-of select="."/> <!-- XXX: xsl:apply-templates here ??? -->
			</xsl:when>
			
			<!-- have some ui:row elements -->		
			<xsl:otherwise>
      	<xsl:variable name="status" select="sw:get-row-state(.)"/>			
				<xsl:variable name="mode-edit" select="ancestor::ui:block/@mode='edit'"/>
				
				<xsl:call-template name="html:div-open"/>
				
				<table cellpadding="{sw:if($mode-edit,5,3)}" cellspacing="0" border="0">
					<xsl:choose>
						<xsl:when test="$mode-edit">
							<xsl:attribute name="class">EditFormTable</xsl:attribute>
						</xsl:when>
						<xsl:when test="@class">
							<xsl:attribute name="class"><xsl:value-of select="@class"/></xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
						<xsl:attribute name="class">ViewFormTable</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:call-template name="html:calc-width">
						<xsl:with-param name="control" select="."/>
					</xsl:call-template>					
					<!-- Show Title -->
					<xsl:if test="@title or ui:rows-title">
						<tr>
							<th align="left" class="subheader">
								<xsl:if test="@id">
									<xsl:attribute name="style">cursor:hand; cursor:pointer; vertical-align:middle;</xsl:attribute>
									<xsl:attribute name="onclick">flipBlock('<xsl:value-of select="@id"/>','/<xsl:value-of select="$theme"/>/icons/arr_');</xsl:attribute>
									<xsl:variable name="block-tip" select="sw:if(@tip,@tip,'sh_ctrl')"/>
									<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="$block-tip"/>',event)</xsl:attribute>
									<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
				
	          	  	<img src="/{$theme}/icons/arr_{sw:if($status = 1,'opened','gt')}.gif" width="12" height="11" border="0" alt="{sw:text('Click to show/hide the group.')}" id="{@id}_img" style="vertical-align:middle; margin-right:5px"/>								
								</xsl:if>								
								<xsl:value-of select="@title"/>
								<xsl:if test="ui:rows-title"><xsl:copy-of select="ui:rows-title/*"/></xsl:if>
								<xsl:if test="@alert-icon">
		          		<img src="/{$theme}/icons/{@alert-icon}.gif" width="16" height="16" border="0"/>      	
		          	</xsl:if>
		          	<xsl:if test="@alert-label">
		          		&#160;<xsl:value-of select="@alert-label"/>
		          	</xsl:if>
							</th>
						</tr>
					</xsl:if>			
					<tr>
						<td style="padding:0; border: none;padding-right:15px">
							<xsl:variable name="div-tag">
			        	<div id="show_{@id}" style="display:{sw:if($status = 1 or not(@id),'block','none')}"/>					
			        </xsl:variable>
			        <xsl:if test="@id">
			        	<xsl:copy-of select="html:tag-open($div-tag)"/>	        	
			        </xsl:if>							
							<!-- prepare some vars -->
							<xsl:variable name="separate-tables" select="@separate-tables='true'"/>
							<xsl:variable name="table-tag">
								<table border="0" class="{sw:if(@class,@class,'none')}">
									<xsl:if test="not(ui:row/@table-width='none')">
										<xsl:attribute name="width"><xsl:value-of select="sw:if(ui:row/@table-width,ui:row/@table-width,'100%')"/></xsl:attribute>
									</xsl:if>
								</table>
							</xsl:variable>
					    <!-- /prepare some vars -->    
					    <xsl:if test="not($separate-tables)">
								<xsl:copy-of select="html:tag-open($table-tag)"/>
							</xsl:if>
    					<!-- process childs -->
							<xsl:for-each select="ui:*">																
								<!--|-->
								<xsl:apply-templates select="." mode="vzcp">
									<xsl:with-param name="args" select="$args"/>
								</xsl:apply-templates>
								<!--|-->
							</xsl:for-each>					
							<!-- /process childs -->		
							<xsl:if test="not($separate-tables)">
								<xsl:copy-of select="html:tag-close($table-tag)"/>
							</xsl:if>
							<xsl:if test="@id">
			        	<xsl:copy-of select="html:tag-close($div-tag)"/>	        	
			        	<div id="hide_{@id}"></div>
			        </xsl:if>														
						</td>
					</tr>
					<xsl:if test="@id">
	        	<input type="hidden" name="{@id}" id="{@id}" value="{sw:if($status = 1,'1','0')}"/>
					</xsl:if>
				</table>
				
				<xsl:call-template name="html:div-close"/>	
	
			</xsl:otherwise>
			<!-- /have some ui:row elements -->		
		</xsl:choose>
	</xsl:template>	
	
</xsl:stylesheet>
