<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet extension-element-prefixes="exsl sw func" version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
    xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:sw="http://www.swsoft.com/xsl/cp"
    xmlns:func="http://exslt.org/functions" xmlns:sb="http://www.swsoft.com/xsl/cp/sb"
    xmlns:api="http://www.swsoft.com/xsl/cp/api">

    <func:function name="api:get_menu">
        <xsl:param name="mode"/>
        <xsl:param name="item-ids"/>
        <xsl:variable name="menu-data" select="sw:document($menu-file, $mode)"/>
        <xsl:variable name="validSections">
            <xsl:choose>
                <xsl:when test="not($item-ids/item-id != '')">
                    <xsl:copy-of
                        select="cred:filter-items($menu-data/menu/submenu | $menu-data/menu/submenu//item)"
                    />
                </xsl:when>
                <xsl:otherwise>
                    <xsl:copy-of
                        select="cred:filter-items($menu-data/menu/submenu[@item-id=$item-ids/item-id] | $menu-data/menu/submenu//item[@item-id=$item-ids/item-id])"
                    />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="result">
            <xsl:element name="menu">
                <xsl:for-each select="exsl:node-set($validSections)/*">
                    <xsl:copy-of select="api:get_items()"/>
                </xsl:for-each>
            </xsl:element>
        </xsl:variable>
        <func:result select="exsl:node-set($result)"/>
    </func:function>

    <func:function name="api:get_dashboard_items">
        <xsl:param name="mode"/>
        <xsl:param name="item-ids"/>
        <xsl:variable name="dashboard-data" select="sw:document('dashboard.xml', $mode)"/>
        <xsl:variable name="validSections">
            <xsl:choose>
                <xsl:when test="not($item-ids/item-id != '')">
                    <xsl:copy-of
                        select="cred:filter-items($dashboard-data/dashboards/dashboard/item)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:copy-of
                        select="cred:filter-items($dashboard-data/dashboards/dashboard/item[@item-id=$item-ids/item-id])"
                    />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="result">
            <xsl:element name="dashboard">
                <xsl:for-each select="exsl:node-set($validSections)/*">
                    <xsl:copy-of select="api:get_items()"/>
                </xsl:for-each>
            </xsl:element>
        </xsl:variable>
        <func:result select="exsl:node-set($result)"/>
    </func:function>

    <func:function name="api:get_dashboard">
        <xsl:param name="mode"/>
        <xsl:param name="dashboard-ids"/>
        <xsl:variable name="dashboard-data" select="sw:document('dashboard.xml', $mode)"/>
        <xsl:variable name="validSections">
            <xsl:choose>
                <xsl:when test="not($dashboard-ids/dashboard-id != '')">
                    <xsl:copy-of
                        select="cred:filter-items($dashboard-data/dashboards/dashboard)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:copy-of
                        select="cred:filter-items($dashboard-data/dashboards/dashboard[@dashboard-id=$dashboard-ids/dashboard-id])"
                    />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="result">
            <xsl:element name="dashboards">
                <xsl:for-each select="exsl:node-set($validSections)/*">
                    <xsl:copy-of select="api:get_items()"/>
                </xsl:for-each>
            </xsl:element>
        </xsl:variable>
        <func:result select="exsl:node-set($result)"/>
    </func:function>

    <func:function name="api:get_items">
        <xsl:variable name="subitems" select="item"/>
        <xsl:variable name="valid_subitems" select="cred:filter-items(item)"/>
        <xsl:variable name="result">
            <xsl:if test="count(subitems) = 0 or count($valid_subitems) &gt; 0">
                <xsl:element name="{name(.)}">
                    <!-- Convert attributes of item to elements -->
                    <xsl:for-each select="@*">
                        <xsl:choose>
                            <xsl:when test="local-name(.) = 'icon'">
                                <xsl:element name="icon_small">
                                    <xsl:value-of
                                        select="concat('/',$theme,'/icons/',string(.),'_16.gif')"/>
                                </xsl:element>
                                <xsl:element name="icon_big">
                                    <xsl:value-of
                                        select="concat('/',$theme,'/icons/',string(.),'_32.gif')"/>
                                </xsl:element>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:element name="{local-name(.)}" namespace="{namespace-uri(..)}">
                                    <xsl:choose>
                                        <xsl:when test="local-name(.) = 'href'">
                                            <xsl:choose>
                                                <xsl:when test="starts-with(string(.),'$baseurl')">
                                                  <xsl:value-of
                                                  select="concat($baseurl,substring-after(string(.),'$baseurl'))"
                                                  />
                                                </xsl:when>
                                                <xsl:otherwise>
                                                  <xsl:value-of select="."/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="."/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:element>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:for-each>
                    <!--  Process item elements as-is, optionally localize -->
                    <xsl:for-each select="*[not(self::item)]">
                        <xsl:choose>
                            <xsl:when test="local-name(.) = 'title' or local-name(.) = 'text'">
                                <xsl:copy>
                                    <sw:text select="string(.)"/>
                                </xsl:copy>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:copy-of select="."/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:for-each>
                    <!-- Process item sub-elements -->
                    <xsl:if test="count($valid_subitems)">
                        <xsl:for-each select="item">
                            <xsl:copy-of select="api:get_items()"/>
                        </xsl:for-each>
                    </xsl:if>
                </xsl:element>
            </xsl:if>
        </xsl:variable>
        <func:result select="exsl:node-set($result)"/>
    </func:function>

    <sw:include href="/lib/common.xsl"/>
    <sw:include href="/lib/globals.xsl"/>
    <sw:include href="/lib/cred-filter.xsl"/>
</xsl:stylesheet>
