<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:browse="http://www.swsoft.com/xsl/cp/browse" 
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"  
  >

	<!-- Look dtd/browse-paging.xsl make-paging() for details -->
	<xsl:template name="browse:make-paging">
		<xsl:param name="coords"/>
		<!--|-->
		<xsl:variable name="pages_onpage" select="7"/>
		<xsl:variable name="pc-switches">
			<pc-switch title="10" items="10"/>
			<pc-switch title="20" items="20"/>
			<pc-switch title="40" items="40"/>
			<pc-switch title="80" items="80"/>
		</xsl:variable>
		<!--|-->
		<xsl:variable name="current_index" select="number(sw:if($coords/@from > $coords/@total,$coords/@total,$coords/@from))"/>
		<xsl:variable name="total_items" select="number($coords/@total)"/>
		<xsl:variable name="pc" select="number($coords/@limit)"/>
		
		<xsl:variable name="last_page_" select="number(floor($total_items div $pc))"/>
		<xsl:variable name="last_page" select="sw:if($last_page_ * $pc &lt; $total_items,$last_page_ + 1,$last_page_)"/>
		
		<xsl:variable name="from_page5" select="floor($current_index div $pc)"/>
		<xsl:variable name="from_page4" select="sw:if($from_page5 &lt; 1,1,$from_page5)"/>
		<xsl:variable name="from_page3" select="$from_page4 - 4"/>
		<xsl:variable name="from_page2" select="sw:if($from_page3 &lt; 1,1,$from_page3)"/>
		
		<xsl:variable name="to_page2" select=" $from_page2 + $pages_onpage - 1"/>
		
		<xsl:variable name="fix2" select="($to_page2*$pc) > $total_items"/>
		<xsl:variable name="to_page1" select="sw:if($fix2,$last_page,$to_page2)"/>
		<xsl:variable name="from_page1" select="sw:if($fix2, $to_page1 - $pages_onpage + 1,$from_page2)"/>
		<xsl:variable name="from_page" select="sw:if($fix2,sw:if($from_page1 &lt; 1,1,$from_page1) ,$from_page1)"/>
		<xsl:variable name="to_page" select="$from_page + $pages_onpage - 1"/>
		
		<!--********************-->
		<xsl:variable name="onpage_last1" select="$current_index + $pc - 1"/>
		<xsl:variable name="onpage_last" select="sw:if($onpage_last1>$total_items,$total_items,$onpage_last1)"/>
		
		<xsl:variable name="item_index" select="($from_page - 1) * $pc + 1"/>
		
		<!--********************-->
		<xsl:variable name="pages1">
			<xsl:call-template name="browse:make-pages_">
				<xsl:with-param name="page" select="$from_page"/>
				<xsl:with-param name="item_index" select="$item_index"/>
				<xsl:with-param name="current_page" select="floor($current_index div $pc)+1"/>
				<xsl:with-param name="to_page" select="$to_page"/>
				<xsl:with-param name="pc" select="$pc"/>
				<xsl:with-param name="total_items" select="$total_items"/>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:if test="$current_index > 1">
			<first-page index="1" from-item="1" to-item="{$pc}"/>
			<prev-page index="{$from_page - 1}" from-item="{$current_index - $pc}" to-item="{$current_index - 1}"/>
		</xsl:if>
		<xsl:copy-of select="exsl:node-set($pages1)"/>
		<xsl:if test="$onpage_last &lt; $total_items">
			<next-page from-item="{$current_index+$pc}" to-item="{$current_index+$pc+$pc - 1}" index="{$from_page+1}"/>
			<last-page from-item="{($last_page - 1)*$pc+1}" to-item="{$total_items}" index="{$last_page}"/>
		</xsl:if>
		
		<!--********************-->
		
		<xsl:copy-of select="exsl:node-set($pc-switches)/*"/>
	
	</xsl:template>
	
	<xsl:template name="browse:make-pages_">
		<xsl:param name="page"/>
		<xsl:param name="item_index"/>
		<xsl:param name="current_page"/>
		<xsl:param name="to_page"/>
		<xsl:param name="pc"/>
		<xsl:param name="total_items"/>
		<!--|-->
		<xsl:variable name="page_end1" select="$item_index + $pc - 1"/>
		<xsl:variable name="page_end" select="sw:if($page_end1>$total_items,$total_items,$page_end1)"/>
		<!--|-->
		<xsl:variable name="other">
			<xsl:if test="($page &lt; $to_page) and  $page_end &lt; $total_items">
				<xsl:call-template name="browse:make-pages_">
					<xsl:with-param name="page" select="$page+1"/>
					<xsl:with-param name="item_index" select="$item_index+$pc"/>
					<xsl:with-param name="current_page" select="$current_page"/>
					<xsl:with-param name="to_page" select="$to_page"/>
					<xsl:with-param name="pc" select="$pc"/>
					<xsl:with-param name="total_items" select="$total_items"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:variable>
		<!--|-->
		<page from-item="{$item_index}" to-item="{$page_end}" index="{$page}">
			<xsl:if test="$current_page=$page">
				<xsl:attribute name="is-current">1</xsl:attribute>
			</xsl:if>
		</page>
		<xsl:copy-of select="$other"/>
		<!--|-->
	</xsl:template>

</xsl:stylesheet>
