<!--
     Copyright (c) SWsoft, 1999-2007
     All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date dyn browse html local format func" 
	exclude-result-prefixes="date dyn func env ui html browse local format"
	xmlns:xsl   ="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl  ="http://exslt.org/common" 
	xmlns:date  ="http://exslt.org/dates-and-times"
	xmlns:dyn   ="http://exslt.org/dynamic"
	xmlns:func  ="http://exslt.org/functions"	
	xmlns:sw    ="http://www.swsoft.com/xsl/cp" 
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"	
	xmlns:ui  		="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:html  	="http://www.swsoft.com/xsl/cp/html" 
	xmlns:global	="http://www.swsoft.com/xsl/cp/global" 	
	xmlns:browse	="http://www.swsoft.com/xsl/cp/browse" 
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:format	="http://www.swsoft.com/xsl/cp/format"
>
  <xsl:output method="html"/>
	
	<sw:include href="/lib/utils/format-datetime.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>
  
  <xsl:variable name="datetime" select="sw:document('datetime.xml')"/>
	
  <xsl:variable name="browse-default-search-opened">true</xsl:variable>

  <!-- date filter -->
	<xsl:template name="show-datefilter">
		<xsl:param name="filter"/>
		<xsl:param name="col"/>
		<table cellpadding="0" cellspacing="0" border="0">
			<tr>
				<xsl:call-template name="browse:show-datetime-element">
					<xsl:with-param name="prefix" select="'from'"/>
					<xsl:with-param name="value" select="string($col/@value-from-src)"/>
					<xsl:with-param name="col" select="$col"/>
				</xsl:call-template>
				<td>&#160;-&#160;</td>
				<xsl:call-template name="browse:show-datetime-element">
					<xsl:with-param name="prefix" select="'to'"/>
					<xsl:with-param name="value" select="string($col/@value-to-src)"/>
					<xsl:with-param name="col" select="$col"/>
				</xsl:call-template>			
			</tr>
		</table>
	</xsl:template>

  <xsl:template name="browse:show-datetime-element">
  	<xsl:param name="value"/>
  	<xsl:param name="prefix"/>
  	<xsl:param name="col"/>
  	<!--|-->
  	<xsl:variable name="name" select="concat('filter_',$col/@id,'_',$prefix)"/>
  	<!--|-->
  	<xsl:variable name="svalue">
	  	<xsl:choose>
				<xsl:when test="$value!=''">				
			    <xsl:value-of select="$value"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="''"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<td>
			<xsl:if test="sw:sesget('error_control')=$name">
				<xsl:attribute name="class">CellError</xsl:attribute>
				<xsl:if test="sw:reset-errors-control()"/>	
			</xsl:if>
			
			<xsl:call-template name="ui:post-date-control">
				<xsl:with-param name="name" select="$name"/>
				<xsl:with-param name="value" select="$svalue"/>
				<xsl:with-param name="tip">
					<!-- Post "Tip"  -->
					<xsl:if test="$prefix='from' and $col/@filter-from-tip!=''">
						<xsl:value-of select="$col/@filter-from-tip"/>
					</xsl:if>
					<xsl:if test="$prefix='to' and $col/@filter-to-tip!=''">
						<xsl:value-of select="$col/@filter-to-tip"/>
					</xsl:if>
					<!-- /Post "Tip"  -->
				</xsl:with-param>
			</xsl:call-template>	
		</td>		
		
		<!--
		<td>
			<nobr>
			<xsl:if test="sw:sesget('error_control')=$name">
				<xsl:attribute name="class">CellError</xsl:attribute>
				<xsl:if test="sw:reset-errors-control()"/>
			</xsl:if>
			<input style="vertical-align: middle;" id="{$name}" name="{$name}" size="8" value="{$svalue}"
				onKeyPress="filterOnKeyPress"
			>
				<xsl:if test="$prefix='from' and $col/@filter-from-tip!=''">
					<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="$col/@filter-from-tip"/>')</xsl:attribute>
					<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
				</xsl:if>
				<xsl:if test="$prefix='to' and $col/@filter-to-tip!=''">
					<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="$col/@filter-to-tip"/>')</xsl:attribute>
					<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
				</xsl:if>
			</input>
			<img src="/{$theme}/images/1x1.gif" width="1" height="1"/>
			<a href="#" onClick="showDate('{$name}')"><img src="/{$theme}/icons/dates.gif" width="16" height="18" style="vertical-align: middle;" alt="{sw:text('Click to select the date')}" border="0"/></a>
			</nobr>
			<div id="{$name}_div" 
				style="display:none;position:absolute;width:150px;border: solid 1px;border-color:#D0D0BF;background-color:#F9F8F8;"
			></div>
		</td>		
		-->
		
  </xsl:template>
  

<xsl:template name="browse:show-header-filter"> 		
	<xsl:param name="filter"/>
	<xsl:param name="filtered-cols"/>
	<!--|-->
	<xsl:variable name="filter-action-customize" select="boolean(sw:param('filter_action') = 'customize_filter_fields')"/>
	<xsl:variable name="filter-cols" select="$filter/ui:cols/ui:column[@filter!='' and @filter!='equal' and not(@filter-group)]"/>
	<xsl:variable name="custom-fields" select="$filter-cols[@filter!='' and (@title!='' or @filter-title != '')]"/>	
	
	<xsl:variable name="display" select="sw:if(
		not(($browse-default-search-opened='true') and not($filter/ui:browse-setup/@search-opened='false')) and
		not($filtered-cols) and 
		not($filter/ui:int/@show-all='1') and 
		not($filter/ui:browse-setup/@search-opened='true') and 
		not($filter-action-customize), 
		'display:none','')"/>

	<div class="filterBar" style="{$display}" id="filter_bar">
		<xsl:variable name="custom-id" select="concat('div_customfields_',$filter/ui:browse-setup/@id)"/>
		<table border="0" cellpadding="0" cellspacing="0" style="width:100%;">
			<tr>
				<td valign="middle">
					<table cellpadding="0" cellspacing="0" border="0">
						<tr>
							<td>
								<!-- Show Input Fields -->
								<div style="display: block; float: left;">
									<!-- secound check is a fix of #90107 -->
									<xsl:variable name="filter-cols-shown" select="$filter-cols[
										(not(@custom-filter-hidden = 'yes')) or
										(@filter='select' and @value!='')
									]"/>
									<xsl:variable name="filter-cols-selects" select="$filter-cols-shown[
										@filter='interval' or @filter='select' or (@filter='auto' and @data-type='bool')
									]"/>
									<xsl:variable name="filter-cols-inputs" select="$filter-cols-shown[not(@filter='interval' or @filter='select' or (@filter='auto' and @data-type='bool'))]"/>									
									<xsl:for-each select="$filter-cols-selects">
										<xsl:variable name="from-to" select="@filter='interval' and (@data-type='datetime' or @data-type='unixtime')"/>
										<xsl:variable name="group-cols" select="$filter/ui:cols/ui:column[@filter-group=current()/@id]"/>
										<div id="field_{@id}" style="display: block; float: left; padding-right: 3px">
											<xsl:call-template name="local:filter-label">
												<xsl:with-param name="filter" select="$filter"/>
												<xsl:with-param name="from-to" select="$from-to"/>
												<xsl:with-param name="group-cols" select="$group-cols"/>
											</xsl:call-template>
											<xsl:choose>
												<xsl:when test="@filter='interval'">
													<xsl:call-template name="show-datefilter">
														<xsl:with-param name="col" select="."/>
														<xsl:with-param name="filter" select="$filter"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:when test="@filter='select' and $group-cols">
													<select name="filter_{@id}">									
														<xsl:if test="not(ui:filter-option[@value=''])">
															<option value=""></option>
														</xsl:if>	
														<xsl:for-each select="$filter/ui:cols/ui:column[@id=current()/@id or @filter-group=current()/@id]">
															<xsl:if test="not(ui:filter-option[@value='']) and not(string(@title) = '')">
																<option style="color:#888888" value="">
																	---------&#160;&#160;<sw:text><xsl:with-param name="filter-title" select="@title"/>by %{filter-title}</sw:text>&#160;&#160;---------
																</option>
															</xsl:if>
															<xsl:call-template name="local:show-cols">
																<xsl:with-param name="prefix" select="concat(@id,'_')"/>
																<xsl:with-param name="col_value" select="string(@value-src)"/>
																<xsl:with-param name="options" select="ui:filter-option"/>
															</xsl:call-template>
														</xsl:for-each>
													</select>	
												</xsl:when>
												<xsl:when test="@filter='select'">
													<select name="filter_{@id}">
														<xsl:if test="not(ui:filter-option[@value=''])">
															<option value=""><sw:text>---</sw:text></option>
														</xsl:if>																																<xsl:call-template name="local:show-cols">
															<xsl:with-param name="prefix" select="''"/>
															<xsl:with-param name="col_value" select="@value-src"/>
															<xsl:with-param name="options" select="ui:filter-option"/>
														</xsl:call-template>
													</select>	
												</xsl:when>
												<xsl:when test="@filter='auto' and @data-type='bool'">
													<select name="filter_{@id}">
														<option value=""><sw:text>---</sw:text></option>
														<xsl:variable name="col_value" select="@value-src"/> 									
														<option value="1">
															<xsl:if test="$col_value=1 or $col_value='true' or $col_value='TRUE' or $col_value='yes'">
																<xsl:attribute name="selected">1</xsl:attribute>
															</xsl:if>
															<sw:text>Yes</sw:text>
														</option>
														<option value="0">
															<xsl:if test="$col_value=0  or $col_value='false'">
																<xsl:attribute name="selected">1</xsl:attribute>
															</xsl:if>
															<sw:text>No</sw:text>
														</option>
													</select>	
												</xsl:when>
											</xsl:choose>
										</div>
									</xsl:for-each>
									<xsl:for-each select="$filter-cols-inputs">
										<div id="field_{@id}" style="display: block; float: left; padding-right: 3px">
											<xsl:call-template name="local:filter-label">
												<xsl:with-param name="filter" select="$filter"/>
												<xsl:with-param name="from-to" select="''"/>
												<xsl:with-param name="group-cols" select="''"/>
											</xsl:call-template>										
											<xsl:if test="sw:sesget('error_control')=@if">
												<xsl:attribute name="class">CellError</xsl:attribute>
												<xsl:if test="sw:reset-errors-control()"/>
											</xsl:if>
											<input id="filter_{@id}" name="filter_{@id}" value="{@value-src}"
												onKeyPress="filterOnKeyPress"
											>
												<xsl:attribute name="size">
													<xsl:choose>
														<xsl:when test="@data-type='int'">6</xsl:when>
														<xsl:otherwise>16</xsl:otherwise>
													</xsl:choose>
												</xsl:attribute>
											</input>									
										</div>
									</xsl:for-each>									
								</div>
								<!-- /Show Input Fields -->
							</td>

							<td style="border-left: 1px solid #B9C7EF; padding-left: 5px">
								<table cellpadding="0" cellspacing="0" border="0">
									<tr>
										<td nowrap="nowrap" style="padding-right:7px">&#160;<br/>
											<xsl:if test="contains($toolbar-mode,'icon')">
												<a href="#" onclick="submitFilter('search')" class="listAction" onmouseover="callTip('search_list',event)" onmouseout="callTip	('')">
													<img src="/{$theme}/icons/search_16.gif" style="vertical-align:middle; padding:3px"/>
												</a>
											</xsl:if>
											<xsl:if test="contains($toolbar-mode,'text')">											
												<a style="color:#000000" href="#" onclick="submitFilter('search')" class="listAction" onmouseover="callTip('search_list',event)" onmouseout="callTip('')">
													<sw:text>Search</sw:text>
												</a>
											</xsl:if>
										 </td>
										<td nowrap="nowrap" style="padding-right:7px">&#160;<br/>
											<xsl:if test="contains($toolbar-mode,'icon')">
												<a href="#" onclick="submitFilter('show_all')" class="listAction" onmouseover="callTip('show_all_list',event)" 	onmouseout="callTip('')">
													<img src="/{$theme}/icons/show_all_16.gif" style="vertical-align:middle; padding:3px"/>
												</a>
											</xsl:if>
											<xsl:if test="contains($toolbar-mode,'text')">
												<a style="color:#000000" href="#" onclick="submitFilter('show_all');" class="listAction" onmouseover="callTip	('show_all_list',event)" onmouseout="callTip('')">
													<sw:text>Reset Results</sw:text>
												</a>
											</xsl:if>
										 </td>
										<td nowrap="nowrap" style="padding-right:7px">&#160;<br/>
											<xsl:if test="contains($toolbar-mode,'icon')">
												<a href="#" onclick="switchCustomFields('{$custom-id}', true); return false" class="listAction" onmouseover="callTip					('select_search_fields',event)" 		onmouseout="callTip('')">
													<img id="img_{$custom-id}" src="/{$theme}/icons/select_search_fields_16.gif" style="vertical-align:middle; padding:3px"/>
												</a>
											</xsl:if>
											<xsl:if test="contains($toolbar-mode,'text')">
												<a style="color:#000000" href="#" onclick="switchCustomFields('{$custom-id}', true); return false" class="listAction" 			onmouseover="callTip				('select_search_fields',event)" onmouseout="callTip('')">
													<sw:text>Customize</sw:text>
												</a>
											</xsl:if>
											<br/>
											<xsl:call-template name="local:customize-filter">
												<xsl:with-param name="custom-id" select="$custom-id"/>
												<xsl:with-param name="filter-cols" select="$filter-cols"/>
												<xsl:with-param name="custom-fields" select="$custom-fields"/>
											</xsl:call-template>
										</td>										 						 		
									</tr>
								</table>
							</td>
						</tr>
					</table>
				</td>					
		    	</tr>
		</table>
	</div>				
			
	<xsl:if test="$filter/ui:cols/ui:column[@filter='interval' and (@data-type='datetime' or @data-type='unixtime')]">
		<xsl:if test="not(/ui:screen/ui:properties/ui:contains-date-control)">
	     		<xsl:message terminate="yes">
					  Error in ui:cell/@type='date' - ui:screen/ui:properties/ui:contains-date-control is undefined			  		
			  		<xsl:if test="sw:sesput('parents',ancestor::*)"/>
					</xsl:message>
      	</xsl:if>
	</xsl:if>
	<script>
      	function submitCustomFields(div_id){
      		document.defaultForm.filter_action.value='customize_filter_fields';
	      	document.defaultForm.action = '<xsl:value-of select="concat($baseurl,$filter/ui:browse-setup/@url)"/>';
	    		doSubmit();
	    	}		
	    	
      	function switchCustomFields(div_id,show){
      		callTip('');
      		div = document.getElementById(div_id);
      		div.style.display=show?'':'none';
			align2right(div_id);      		
      	}
		
	        img_show = new Image();
	        img_hide = new Image();
	        img_show.src = '/<xsl:value-of select="$theme"/>/icons/show_search.gif';
	        img_hide.src = '/<xsl:value-of select="$theme"/>/icons/hide_search.gif';
	        
	       customFieldValues = new Array();
      	<xsl:for-each select="$custom-fields">
      		customFieldValues[
      			<xsl:value-of select="position()"/>
      		] = <xsl:value-of select="sw:if(not(@custom-filter-hidden='yes'),'true','false')"/>;
      	</xsl:for-each>
		<![CDATA[
	      	function restoreCustomFieldValues(){
	      		for (var i=1;i<=customFieldValues.length;i++){
		      		el = document.getElementById('_custom_filter_'+i);
	      			if (el)
	      				el.checked = customFieldValues[i];
	      		}
	      	}		
		]]>		
			function showFilter(){
				s = document.getElementById('filter_bar');
				o = document.getElementById('filter_on');
				i = document.getElementById('filter_on_icon');
				if(s.style.display=='none'){
					s.style.display='block';
					o.innerHTML="<sw:text>Hide Search</sw:text>";
					i.src = img_hide.src;
				}else{
					s.style.display='none';
					o.innerHTML="<sw:text>Show Search</sw:text>";
					i.src = img_show.src;					
				}				
				return false;
			}
			function  filterOnKeyPress(e)
			{
				var event = e ? e : window.event;
				var target = e ? event.target : event.srcElement;

				<![CDATA[      
				if (target.name && 13 == event.keyCode && target.name.indexOf('filter_')==0) {
					submitFilter('search');
					return false;
				}
				]]>

				return true;
			}			
    	function submitFilter(action){
    		if(action=='search'){
    		<xsl:for-each select="$filter/ui:cols/ui:column[@filter='auto' and @data-type='int']">
    			var v_obj = document.getElementById('filter_<xsl:value-of select="@id"/>');    			
    			if(v_obj &amp;&amp; v_obj.value!='' ){
    				var v = v_obj.value;
    				var pv = parseInt(v);
	    			if(isNaN(parseInt(v)) || v!=pv){
	    				<xsl:variable name="msg">
	    					<sw:text>
	    						<xsl:with-param name="id" select="@title"/>
	    						The "%{id}" search field should contain a numeric value!
	    					</sw:text>
	    				</xsl:variable>
	    				alert('<xsl:value-of select="sw:html-escape($msg,'escape-quote')"/>');
	    				return false;
	    			}
	    		}
    		</xsl:for-each>
    		<xsl:for-each select="$filter/ui:cols/ui:column[@filter='interval' and @data-type='datetime']">
    			if(!submitFilterCheckDate('filter_<xsl:value-of select="@id"/>_from','<xsl:value-of select="sw:html-escape(@title,'escape-all')"/>')){
    				return false;
    			}
    			if(!submitFilterCheckDate('filter_<xsl:value-of select="@id"/>_to','<xsl:value-of select="sw:html-escape(@title,'escape-all')"/>')){
    				return false;
    			}
    		</xsl:for-each>
    		}
    		document.defaultForm.filter_action.value=action;
    		document.defaultForm.action = '<xsl:value-of select="concat($baseurl,$filter/ui:browse-setup/@url)"/>';
    		doSubmit();
    	}		
    	function submitFilterCheckDate(id,title){
    			s = document.getElementById(id);    			    			
    			if(s &amp;&amp; s.value!='' &amp;&amp; !validateDate(s.value)){
    				<xsl:variable name="err">
    					<sw:text>
    						<xsl:with-param name="title" select="'ZZZ'"/>
    						<xsl:with-param name="format" select="$global-date-format"/>
    						Please correct the value in the "%{title}" field. The valid format is %{format}.
    					</sw:text>
    				</xsl:variable>
    				err = '<xsl:value-of select="sw:html-escape($err,'escape-quote')"/>';
    				rExp = /ZZZ/g;
    				error = err.replace(rExp,title);
    				alert(error);
    				s.focus();
    				return false;
    			}
    			return true;
    	}	
			//if (document.layers) document.captureEvents(Event.KEYPRESS);
			document.onkeypress =  filterOnKeyPress;
		</script>
  </xsl:template>

  	<xsl:template name="local:filter-label">
  		<xsl:param name="filter"/>
  
		<label for="{sw:if(@filter='interval',concat('filter_',@id,'_from'),concat('filter_',@id))}"> 
			<xsl:if test="@value-src!='' or @value-from-src!=''
				or (@filter='select' and $filter/ui:cols/ui:column[@filter-group=current()/@id]/@value-src!='')
			">
				<xsl:attribute name="class">searchFilled</xsl:attribute>
			</xsl:if>						
			<xsl:choose>
				<xsl:when test="$from-to">
					<xsl:value-of select="@filter-from-title"/>
				</xsl:when>		
				<xsl:when test="@filter-group-title">
					<xsl:value-of select="@filter-group-title"/>
				</xsl:when>
				<xsl:when test="@filter-title">
					<xsl:value-of select="@filter-title"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="@title"/>
				</xsl:otherwise>							
			</xsl:choose>																
		</label>				
		<br/>
	</xsl:template>
	
	<xsl:template name="local:show-cols">
		<xsl:param name="options"/>
		<xsl:param name="prefix"/>
		<xsl:param name="col_value"/>				
		
		<xsl:for-each select="$options">
			<xsl:choose>
				<xsl:when test="@type='other'">
					<xsl:variable name="value" select="'__other'"/>
					<option value="{$prefix}{$value}">
						<xsl:if test="$value=$col_value">
							<xsl:attribute name="selected">1</xsl:attribute>
						</xsl:if>
						<xsl:value-of select="@title"/>
					</option>
				</xsl:when>
				<xsl:otherwise>
					<option value="{$prefix}{@value}">
						<xsl:if test="@value=$col_value">
							<xsl:attribute name="selected">1</xsl:attribute>
						</xsl:if>
						<xsl:value-of select="@title"/>
					</option>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
  
  <xsl:template name="browse:show-header-cols">
    <xsl:param name="filter"/>
    <xsl:param name="check_cols"/>
    <xsl:param name="check_position" select="'left'"/>  	
    <xsl:param name="select-type"/>
    <xsl:param name="visible-cols"/>  	
    
    <xsl:variable name="check-id" select="string(sw:if($check_cols[1]/@select-id,$check_cols[1]/@select-id,$check_cols[1]/@id))"/>
    
    <tr>
      <xsl:if test="$check_cols and ($check_position = 'left')">
	      <th width="20" align="center" style="text-align: center;">
	      	<xsl:choose>
	      		<xsl:when test="$select-type='radio'">
	      			&#160;
	      		</xsl:when>
	      		<xsl:otherwise>
	       			<input type="checkbox" name="{$filter/ui:browse-setup/@id}_checkall" onclick="browseCheckAll(this,'{$check-id}')" />
	       		</xsl:otherwise>
	       	</xsl:choose>
		 		</th>    
			</xsl:if>
      <xsl:for-each select="$visible-cols">
          <th>
            <xsl:if test="@align">
              <xsl:attribute name="align"><xsl:value-of select="@align"/></xsl:attribute>
            </xsl:if>
            <xsl:choose>
              <xsl:when test="not(@sorting = 'no')">
								<xsl:if test="$filter/ui:sort/ui:col=@id">
									<!-- mark current sorting column with special td class -->
									<xsl:attribute name="class">sort</xsl:attribute>
								</xsl:if>
                <xsl:variable name="sort_token" select="concat('sort=',@id)"/>
                <xsl:variable name="sort_dir_token" 
                	select="sw:if( (@id=$filter/ui:sort/ui:col and $filter/ui:sort/ui:direction='desc') or @id!=$filter/ui:sort/ui:col,'asc','desc')"
                /> 
								<xsl:variable name="sort_url" select="concat($baseurl,$filter/ui:browse-setup/@url,sw:if(contains($filter/ui:browse-setup/@url,'?'),'&amp;','?'),$sort_token,'&amp;sort_dir=',$sort_dir_token)"/>
                <!--+-->
                <a href="#" onClick="sortBrowse('{$sort_url}')"><xsl:value-of select="@title"/></a>
                <!--+-->
                <xsl:if test="$filter/ui:sort/ui:col=@id">
	                <xsl:variable name="sort_img">
										<xsl:choose>
											<xsl:when test="$filter/ui:sort/ui:direction = 'asc'">
												<img src="/{$theme}/images/sort_up.gif" width="10" height="16" alt="{sw:text('Ascending')}" border="0"/>
											</xsl:when>
											<xsl:otherwise>
												<img src="/{$theme}/images/sort_down.gif" width="10" height="16" alt="{sw:text('Descending')}" border="0"/>
											</xsl:otherwise>
										</xsl:choose>
		              </xsl:variable>
		              <a href="#" onClick="sortBrowse('{$sort_url}')"><xsl:copy-of select="$sort_img"/></a>
		            </xsl:if>
                <!--+-->
              </xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="@title"/>
              </xsl:otherwise>
            </xsl:choose>
            <xsl:if test="not(string(@title))">&#160;</xsl:if>
          </th>
      </xsl:for-each>
      <xsl:if test="$check_cols and ($check_position = 'right')">
	      <th width="20" align="center" style="text-align: center;">
	        <xsl:choose>
	      		<xsl:when test="$select-type='radio'">
	      			&#160;
	      		</xsl:when>
	      		<xsl:otherwise>
	       			<input type="checkbox" name="{$filter/ui:browse-setup/@id}_checkall" onclick="browseCheckAll(this,'{$check-id}')" />
	       		</xsl:otherwise>
	       	</xsl:choose>
	      </th>
     </xsl:if>
    </tr>
     <script language="JavaScript">
      function sortBrowse(url){
      	document.defaultForm.action = url;
  			doSubmit();
      }
    </script>
  </xsl:template>


	<!-- javascript array definition -->
  <xsl:template match="ui:browse-js-array">
  	<xsl:variable name="root" select="."/>
  	<xsl:variable name="col" select="../ui:filter/ui:cols/ui:column[@for-select='yes']"/>
  	
    <script language="JavaScript">
     	var <xsl:value-of select="$root/@name"/>_array = new Array(<xsl:value-of select="count(ui:value)"/>);
     	<xsl:for-each select="ui:value">
				<xsl:value-of select="$root/@name"/>_array[<xsl:value-of select="position()-1"/>]='<xsl:value-of select="sw:html-escape(.,'escape-backslash')"/>';
     	</xsl:for-each>
     	
     	function check_<xsl:value-of select="$root/@name"/>_array(){
     		var errors = 0;
     		var elem;
     		//
				for (var i=0;i&lt;document.defaultForm.elements.length;i++){
					elem = document.defaultForm.elements[i];
					//
				  if(elem.name=='<xsl:value-of select="sw:if($col/@select-id,$col/@select-id,$col/@id)"/>' &amp;&amp; elem.checked) {				  	
				  	for(var ii=0;ii &lt; <xsl:value-of select="$root/@name"/>_array.length;ii++){
				  		if(elem.value==<xsl:value-of select="$root/@name"/>_array[ii]){
								errors++;;
							}
						}
				  }
				  //
				}
				//
				if(errors!=0){
					alert('<xsl:value-of select="$root/ui:warn"/>');
				}
				return errors==0;
     	}
    </script>
  </xsl:template>  

	<xsl:template match="ui:browse-js-one">
		<xsl:variable name="col" select="../ui:filter/ui:cols/ui:column[@for-select='yes']"/>
		<script>
			<![CDATA[	
			function onlyOne(){
				var num = 0;
				for (var i=0;i<document.defaultForm.elements.length;i++){
				  if(document.defaultForm.elements[i].name==]]>'<xsl:value-of select="sw:if($col/@select-id,$col/@select-id,$col/@id)"/>'<![CDATA[ && document.defaultForm.elements[i].checked) {
						num++;;
				  }
				}
				]]>
				
				if (num == 1) return true;
				alert('<xsl:value-of select="sw:html-escape(ui:warn,'escape-quote')"/>');
	      return false;
			}
		</script>
	</xsl:template>
	
	<xsl:template match="ui:browse-js-many">
		<xsl:variable name="col" select="../ui:filter/ui:cols/ui:column[@for-select='yes']"/>
		<script>
			<![CDATA[	
			function atLeastOne(){
				for (var i=0;i<document.defaultForm.elements.length;i++){
				  if(document.defaultForm.elements[i].name==]]>'<xsl:value-of select="sw:if($col/@select-id,$col/@select-id,$col/@id)"/>'<![CDATA[ && document.defaultForm.elements[i].checked) {
					 return true;
				  }
				}
				]]>
				alert('<xsl:value-of select="sw:html-escape(ui:warn,'escape-quote')"/>');
	      return false;
			}
		</script>
	</xsl:template>
	
  <xsl:template name="browse:show">
  	<xsl:param name="filter"/>
  	<xsl:param name="check_position"/>  	
	<xsl:param name="oncontext"/>
	<xsl:param name="oncontextplatform"/>

	  <xsl:variable name="check_cols" select="$filter/ui:cols/ui:column[@for-select='yes']"/> 
	  <xsl:variable name="onclick-cols" select="$filter/ui:cols/ui:column[@for-onclick='yes']"/>  
	  <xsl:variable name="col-nav-id" select="$filter/ui:cols/ui:column[@nav-type='id']"/>    
	  <xsl:variable name="col-nav-title" select="$filter/ui:cols/ui:column[@nav-type='title']"/>    
	  <xsl:variable name="col-check-alt" select="$filter/ui:cols/ui:column[@for-checkbox-alt='yes']"/>  
	  <xsl:variable name="check_cond" select="$filter/ui:cols/ui:column[@for-select='yes' and @for-select-condition]/@for-select-condition"/>    
	  <xsl:variable name="select-type" select="$filter/ui:browse-setup/@select-type"/>  
	  <xsl:variable name="select-id" select="$filter/ui:browse-setup/@select-id"/>    
	  <xsl:variable name="browse-id" select="$filter/ui:browse-setup/@id"/>    
	  <xsl:variable name="item-url-src" select="$filter/ui:browse-setup/@item-url"/>
	  <xsl:variable name="item-click" select="$filter/ui:browse-setup/ui:item-click"/>	  
	  <xsl:variable name="hide-header-cols" select="$filter/ui:browse-setup/@hide-header-cols"/>
	  <xsl:variable name="visible-cols" select="$filter/ui:cols/ui:column[not(@hidden = 'yes') or ui:filter-option[@value = ../@value and @type = 'custom']]"/>	  

     <xsl:if test="not($hide-header-cols = 'true')">
      <xsl:call-template name="browse:show-header-cols">
        <xsl:with-param name="filter" select="$filter"/>
        <xsl:with-param name="check_cols" select="$check_cols"/>
        <xsl:with-param name="check_position" select="$check_position"/> 
        <xsl:with-param name="select-type" select="$select-type"/>
        <xsl:with-param name="visible-cols" select="$visible-cols"/>
      </xsl:call-template>	  
    </xsl:if>
    
    <xsl:for-each select="$filter/ui:browse-rows/ui:row">

        <xsl:variable name="currentRow" select="."/>

<!--*** onrightclick, type ID in ui:browse-setup-->
	<xsl:variable name="cur_id" select="$currentRow//*[name() = 'id']"/>
	<xsl:variable name="tr_id">
		<xsl:choose>
			 <xsl:when test="$cur_id!='' and $oncontext!=''"><xsl:value-of select="$cur_id"/></xsl:when>
			 <xsl:otherwise><xsl:value-of select="$browse-id"/>_<xsl:value-of select="position()"/></xsl:otherwise>
		 </xsl:choose>
	</xsl:variable>
	<tr>
		<xsl:attribute name="id">vel_<xsl:value-of select="$tr_id"/></xsl:attribute>
		<xsl:attribute name="onclick">cTO(this,1,'<xsl:value-of select="$browse-id"/>');</xsl:attribute>
		<xsl:attribute name="style">cursor:pointer</xsl:attribute>

		<xsl:if test="$oncontext!='' or $filter/ui:browse-setup/@item-url-tip!=''">
			<xsl:attribute name="onmouseover">
				<xsl:if test="$oncontext!=''">mRM=1;</xsl:if>
				<xsl:if test="$filter/ui:browse-setup/@item-url-tip!=''">callTip('<xsl:value-of select="$filter/ui:browse-setup/@item-url-tip"/>',event)</xsl:if>
			</xsl:attribute>
			<xsl:attribute name="onmouseout">
				<xsl:if test="$oncontext!=''">mRM=0;</xsl:if>
				<xsl:if test="$filter/ui:browse-setup/@item-url-tip!=''">callTip()</xsl:if>
			</xsl:attribute>
		</xsl:if>
		
		<xsl:if test="$oncontext!=''">
			<xsl:attribute name="oncontextmenu">rML('<xsl:value-of select="$oncontext"/>',this,'','<xsl:value-of select="$currentRow//*[name() = $oncontextplatform]"/>');</xsl:attribute>
		</xsl:if>
<!--/*** onrightclick-->		

        <xsl:if test="not($filter/ui:browse-setup/@stripes = 'no')">
          <xsl:attribute name="class">
            <xsl:choose>
              <xsl:when test="position() mod 2">EvenRow</xsl:when>
              <xsl:otherwise>OddRow</xsl:otherwise>				
            </xsl:choose>
          </xsl:attribute>
        </xsl:if>
        
        <!-- Generate Item URL -->
        <xsl:variable name="item-url">
        	<xsl:choose>
        		<xsl:when test="$currentRow/@item-full-url">
        			<xsl:value-of select="$currentRow/@item-full-url"/>
        		</xsl:when>
        		<xsl:when test="contains($item-url-src,'%')">
        			<xsl:variable name="url-nodes" select="sw:split($item-url-src,'%')"/>
        			<xsl:value-of select="$baseurl"/>
        			<xsl:for-each select="$url-nodes">
        				<xsl:variable name="pos" select="position()"/>
        				<xsl:if test="position() mod 2">
        					<xsl:variable name="id" select="following::*[1]"/>
        					<xsl:value-of select="."/>
        					<xsl:if test="$id">
        						<xsl:value-of select="$currentRow//*[name() = $id]"/>
        					</xsl:if>
        				</xsl:if>
        			</xsl:for-each>
        		</xsl:when>
        		<xsl:when test="$item-url-src!='#' or $item-click">
        			<xsl:variable name="url">
								<xsl:choose>
									<xsl:when test="$item-click">
										<xsl:variable name="obj-type" select="string($currentRow/*[name()=$item-click/@obj-type-col])"/>
										<xsl:value-of select="$baseurl"/>
										<xsl:value-of select="$global:classes
											/class[ @vza-type=$obj-type]
											/actions
											/action[@id=$item-click/@action]
											/@href"
										/>
										<xsl:value-of select="$item-click/@ext-href"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="concat('/vz/cp',$item-url-src)"/>
									</xsl:otherwise>
								</xsl:choose>        		
							</xsl:variable>
							<xsl:value-of select="$url"/>
							<xsl:if test="not(contains($url,'?'))">?cmd=v</xsl:if>       								
		        	<xsl:for-each select="$filter/ui:cols/ui:column[@for-url='yes']">
								<xsl:variable name="id" select="@id"/>
		        		<xsl:value-of select="concat('&amp;',@for-url-name,'=')"/> 
		        		<xsl:variable name="value" select="string($currentRow//*[name() = $id])"/>  
		        		<xsl:choose>
		              <xsl:when test="@data-type!='int'">
		              	<xsl:choose>
		              		<xsl:when test="not(@encode='no')">
		                		<xsl:value-of select="sw:escape(sw:base64-encode($value))"/>
		                	</xsl:when>
		                	<xsl:otherwise>
		                		<xsl:value-of select="sw:escape($value)"/>
		                	</xsl:otherwise>
		                </xsl:choose>
		              </xsl:when>                
		              <xsl:otherwise>
		              	<xsl:value-of select="sw:escape($value)"/>
		              </xsl:otherwise>
		            </xsl:choose>                        		
		        	</xsl:for-each>        
		        </xsl:when>
		        <xsl:otherwise>
		        	<xsl:value-of select="$item-url-src"/>
		        </xsl:otherwise>
		      </xsl:choose>
        </xsl:variable>
        <!-- /Generate Item URL -->
        
        <xsl:if test="$check_cols and $check_position = 'left'">
        	<xsl:choose>
        		<xsl:when test="$select-type = 'radio'">
          		<xsl:copy-of select="browse:show-row-select($currentRow, $check_cols, $check_cond)"/>
          	</xsl:when>
          	<xsl:otherwise>
				<xsl:variable name="obj_alt">
					<xsl:choose>
						<xsl:when test="$col-check-alt and $col-check-alt/@apply-templates='yes'">
							<xsl:apply-templates select="$currentRow/*[name() = $col-check-alt/@id]"/>
						</xsl:when>
						<xsl:when test="$col-check-alt">
							<xsl:value-of select="$currentRow/*[name() = $col-check-alt/@id]"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
          		<xsl:copy-of select="browse:show-row-check($currentRow, $check_cols, $check_cond, $tr_id, $obj_alt )"/>
          	</xsl:otherwise>
          </xsl:choose>
        </xsl:if>                
        
        <xsl:for-each select="$visible-cols">
          <xsl:variable name="id" select="@id"/>
          <xsl:variable name="data-type" select="@data-type"/>
            <td align="{@align}">
              <xsl:if test="@width">
                <xsl:copy-of select="@width"/>
              </xsl:if>
              <xsl:variable name="value" select="string($currentRow//*[name() = $id])"/>  
              <!-- prepare content -->
              <xsl:variable name="cell-content-str">
	              <xsl:choose>
	            		<xsl:when test="@apply-templates='yes'">
	            			<xsl:apply-templates select="$currentRow//node()[name() = $id]">
	            				<xsl:with-param name="options" select="current()/ui:column-layout-options"/>
	            			</xsl:apply-templates>
	            		</xsl:when>
	            		<xsl:when test="$data-type='datetime'">	            			
	            			<xsl:choose>
	            				<xsl:when test="$value!=''">
	            					<nobr><xsl:value-of select="format:date-time(sw:vzatime2utime($value))"/></nobr>
	            				</xsl:when>
	            				<xsl:otherwise>
	            					<nobr><sw:text>n/a</sw:text></nobr>
	            				</xsl:otherwise>
	            			</xsl:choose>
	            		</xsl:when>
	            		<xsl:when test="@display-type='ui-data'">
	            			<xsl:apply-templates select="$currentRow//*[name() = $id]/*"/>
	            		</xsl:when>	   
	            		<xsl:when test="$value=''">
	            		</xsl:when>
	            		<xsl:when test="@display-type='size/byte' and @display-unit != ''">
	            			<nobr>
		            			<xsl:choose>
		            				<xsl:when test="string(number($value)) ='NaN'">
		            					<xsl:value-of select="$value"/>
		            				</xsl:when>
		            				<xsl:when test="@display-unit = 'kbyte' or @display-unit = 'mbyte' or @display-unit = 'gbyte'">
		            					<xsl:value-of select="format:int2bytes($value, @display-unit, sw:if(@show-unit='true','yes','no'), '#,##0.00')"/>
		            				</xsl:when>
		            				<xsl:otherwise>
		            					<xsl:value-of select="format:int2bytes($value, 'byte', sw:if(@show-unit='true','yes','no'), '#,##0')"/>
		            				</xsl:otherwise>
		            			</xsl:choose>
	            			</nobr>
	            		</xsl:when>
	            		<xsl:when test="@display-type='size/byte'">
	            			<xsl:value-of select="format:int2bytes($value)"/>
	            		</xsl:when>
	            		<xsl:when test="@display-type='procs' and string(number($value))!='NaN'">
	            			<nobr><xsl:value-of select="concat($value,' %')"/></nobr>
	            		</xsl:when>
	            		<xsl:when test="$data-type='bool'">
	            			<xsl:value-of select="sw:if($value='1' or $value='yes' or $value='true' or $value='TRUE',sw:text('Yes'),sw:text('No'))"/>
	            		</xsl:when>	            		
	            		<xsl:when test="@display-type='icon'">
	            			<img src="/{$theme}/icons/{$value}" border="0" width="16" height="16"/>
	            		</xsl:when>	   
	            		<xsl:when test="$data-type='unixtime'">	            			
	            			<nobr><xsl:value-of select="sw:strftime($value,sw:if($langObj/date-time,$langObj/date-time,'%c'))"/></nobr>
	            		</xsl:when>
	            		<xsl:when test="$data-type='percent'">	            			
	            			<ui:meter fraction="{$value div 100}" mcolor="#90F090" />
	            		</xsl:when>	            		
	            		<xsl:otherwise>                  		
	            			<xsl:value-of select="$value"/>
	              	</xsl:otherwise>                  
	              </xsl:choose>
	            </xsl:variable>
	            <!-- Add href -->
	            <xsl:variable name="cell-content-href">
		            <xsl:choose>
		            	<xsl:when test="$currentRow/@bottom='yes' or $currentRow/@disable-item-url='true'">
		            		<xsl:copy-of select="$cell-content-str"/>
		            	</xsl:when>
		             	<xsl:when test="@show-url='yes'">
		             		<a href="{$item-url}">
											<xsl:if test="$filter/ui:browse-setup/@item-url-tip!=''">
												<xsl:attribute name="onmouseover">callTip('<xsl:value-of select="$filter/ui:browse-setup/@item-url-tip"/>',event)</xsl:attribute>
												<xsl:attribute name="onmouseout">callTip()</xsl:attribute>
											</xsl:if>
											<xsl:if test="$filter/ui:browse-setup/@item-onclick-jsfunc">		             				             					             		
												<!-- Generate code for calling some JS-script with passing row ID and title -->		             			
												<xsl:variable name="row-title" select="$currentRow/*[name()=$col-nav-title/@id]"/>
												<xsl:attribute name="onclick"><xsl:value-of 
													select="$filter/ui:browse-setup/@item-onclick-jsfunc"/>(<xsl:for-each 
														select="$currentRow/*[name()=$onclick-cols/@id]"
													>'<xsl:value-of select="."/>',</xsl:for-each>'<xsl:value-of 
														select="$row-title"/>')</xsl:attribute>
		             		</xsl:if><xsl:copy-of select="$cell-content-str"/></a>
	            		</xsl:when>
	            		<xsl:otherwise>                  		
	            			<xsl:copy-of select="$cell-content-str"/>
	              	</xsl:otherwise>                  
		            </xsl:choose>
		          </xsl:variable>
	            <!-- /Add href -->
	            <!-- show content -->
	            <xsl:choose>
	             	<xsl:when test="@post-apply-templates='yes'">
	             		<xsl:variable name="d">
	            			<xsl:element name="{$id}">
	            				<xsl:copy-of select="$cell-content-href"/>
	            			</xsl:element>
	            			<xsl:copy-of select="$currentRow"/>
	            		</xsl:variable>
	            		<xsl:apply-templates select="exsl:node-set($d)/*[name()=$id]"/>
            		</xsl:when>
            		<xsl:otherwise>      
            			<xsl:copy-of select="$cell-content-href"/>
              	</xsl:otherwise>                  
	            </xsl:choose>
	            <!-- /show content -->
            </td>
        </xsl:for-each>
        
        <xsl:if test="$check_cols and $check_position = 'right'">
        	<xsl:choose>
        		<xsl:when test="$select-type = 'radio'">
          		<xsl:copy-of select="browse:show-row-select($currentRow, $check_cols, $check_cond)"/>
          	</xsl:when>
          	<xsl:otherwise>
          		<xsl:copy-of select="browse:show-row-check($currentRow, $check_cols, $check_cond)"/>
          	</xsl:otherwise>
          </xsl:choose>
        </xsl:if>           
      </tr>
    </xsl:for-each>
  </xsl:template>	
  
 <func:function name="browse:show-row-check">
    <xsl:param name="currentRow"/>
    <xsl:param name="check_cols"/>
    <xsl:param name="check_cond"/>
    <xsl:param name="check_tr_id"/>
    <xsl:param name="check_alt" select="''"/>
    
    <xsl:variable name="select-js" select="$currentRow/../../ui:browse-setup/@select-js"/>
	
		<func:result>
			<td align="center">	
				<xsl:choose>
					<xsl:when test="$currentRow/@bottom='yes' and not($currentRow/@disable-checkbox)">
						&#160;
					</xsl:when>
					<xsl:otherwise>
					
						<xsl:variable name="id">						
							<xsl:for-each select="$currentRow/*[name()=$check_cols/@id]">
								<xsl:if test="position()!=1">|</xsl:if><xsl:value-of select="."/>
							</xsl:for-each>						
						</xsl:variable> 
						
						<xsl:if test="not($currentRow/@no-checkbox)">
							<input name="{sw:if($check_cols/@select-id,$check_cols/@select-id,$check_cols/@id)}" type="checkbox" value="{$id}"
							>
								<xsl:if test="$check_tr_id!=''">
									<xsl:attribute name="alt"><xsl:value-of select="$check_alt"/></xsl:attribute>
									<xsl:attribute name="id">vec_<xsl:value-of select="$check_tr_id"/></xsl:attribute>
									<xsl:attribute name="onmouseover">cON=0</xsl:attribute>
									<xsl:attribute name="onmouseout">cON=1</xsl:attribute>
									<xsl:if test="not($select-js)">
										<xsl:attribute name="onclick">cTR(this,1)</xsl:attribute>
									</xsl:if>
								</xsl:if>
								<xsl:if test="$currentRow/@disable-checkbox or ($check_cond and not(dyn:evaluate($check_cond)))">
									<xsl:attribute name="disabled">1</xsl:attribute>
								</xsl:if>
								<xsl:if test="$currentRow/@selected-checkbox">
									<xsl:attribute name="checked">1</xsl:attribute>
								</xsl:if>
								<xsl:if test="$select-js">
									<xsl:attribute name="onclick">
										<xsl:if test="$check_tr_id!=''">cTR(this,1);</xsl:if>
										<xsl:value-of select="$select-js"/>
									</xsl:attribute>
								</xsl:if>
							</input>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</func:result>
	</func:function>
	
	<func:function name="browse:show-row-select">
    <xsl:param name="currentRow"/>
    <xsl:param name="check_cols"/>
    <xsl:param name="check_cond"/>
	
		<xsl:variable name="select-js" select="$currentRow/../../ui:browse-setup/@select-js"/>
		
		<func:result>
			<td align="center">	
				<xsl:choose>
					<xsl:when test="$currentRow/@final='yes'">
						&#160;
					</xsl:when>
					<xsl:otherwise>
												
						<xsl:variable name="id">						
							<xsl:for-each select="$currentRow/*[name()=$check_cols/@id]">
								<xsl:if test="position()!=1">|</xsl:if><xsl:value-of select="."/>
							</xsl:for-each>						
						</xsl:variable>
						
						<xsl:if test="not($currentRow/@show-selector='false')">
							<input name="{sw:if($check_cols/@select-id,$check_cols/@select-id,$check_cols/@id)}" type="radio" value="{$id}">
								<xsl:if test="$currentRow/@disable-checkbox or ($check_cond and not(dyn:evaluate($check_cond)))">
									<xsl:attribute name="disabled">1</xsl:attribute>
								</xsl:if>
								<xsl:if test="$currentRow/@selected-checkbox">
									<xsl:attribute name="checked">1</xsl:attribute>
								</xsl:if>
								<xsl:if test="$id=$currentRow/../../ui:browse-setup/@select-id">
									<xsl:attribute name="checked">1</xsl:attribute>
								</xsl:if>
								<xsl:if test="$select-js">
									<xsl:attribute name="onclick"><xsl:value-of select="$select-js"/></xsl:attribute>
								</xsl:if>
							</input>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</func:result>
	</func:function>

	<xsl:template name="local:customize-filter">
		<xsl:param name="filter-cols"/>	
		<xsl:param name="custom-id"/>
		<xsl:param name="custom-filelds"/>
		
		<xsl:variable name="custom-fields" select="$filter-cols[@filter!='' and (@title!='' or @filter-title != '')]"/>
	
		<div id="{$custom-id}" style="display:none; position: absolute; clear:both; width:150px; border: solid 1px #D0D0BF; background-color: #FFFFFF;z-index:100">
			<table cellpadding="0" cellspacing="0" border="0" width="100%">
				<tr style="background-color:#ABBEEF">
					<td><img src="/{$theme}/images/1x1.gif" width="14" height="14" border="0"/></td>
					<td width="100%" align="center"><b><sw:text>Select Fields</sw:text></b></td>
					<td><a href="#" onClick="switchCustomFields('{$custom-id}',false);restoreCustomFieldValues(); return false"><img src="/{$theme}/icons/close.gif" width="14" height="14" alt="{sw:text('Close the customization window')}" border="0"/></a></td>
				</tr>
			</table>
			<br/>
			<table cellpadding="0" cellspacing="0" border="0" width="100%">
				<xsl:for-each select="$custom-fields">
					<xsl:variable name="from-to" select="@filter='interval' and (@data-type='datetime' or @data-type='unixtime')"/>
					<tr style="background-color:#FFFFFF">
						<td>&#160;</td>
						<td align="left">
							<input type="checkbox" id="_custom_filter_{position()}" name="_custom_filter" value="{@id}">
								<xsl:if test="not(@custom-filter-hidden='yes')">
									<xsl:attribute name="checked"/>
								</xsl:if>
							</input>
							&#160;<label for="_custom_filter_{position()}">
								<xsl:choose>
									<xsl:when test="@filter-group-title"><xsl:value-of select="@filter-group-title"/></xsl:when>
									<xsl:when test="@filter-title"><xsl:value-of select="@filter-title"/></xsl:when>
									<xsl:otherwise><xsl:value-of select="@title"/></xsl:otherwise>
								</xsl:choose>
							</label>
						</td>
					</tr>
				</xsl:for-each>
			</table>
			<br/>
			<table cellpadding="0" cellspacing="0" border="0" width="100%">
				<tr style='background-color:#FFFFFF'>
					<td align="center">
						<a href='#' onclick="submitCustomFields('{$custom-id}');return false"><sw:text>Save</sw:text></a>
						&#160;
						<a href='#' onclick="switchCustomFields('{$custom-id}',false);restoreCustomFieldValues();return false"><sw:text>Cancel</sw:text></a>
					</td>
				</tr>
			</table>
			<br/>						
		</div>	
		<script language="Javascript">align2right('<xsl:value-of select="$custom-id"/>');</script>
	</xsl:template>

 <sw:include href="browse-paging.xsl"/>

</xsl:stylesheet>
