<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local action func"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"	  
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:local 	="http://www.swsoft.com/xsl/cp/local"
	xmlns:action	="http://www.swsoft.com/xsl/cp/action"
	xmlns:ve			="http://www.swsoft.com/xsl/cp/ve"
	xmlns:global			="http://www.swsoft.com/xsl/cp/global"	
>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>

  <func:function name="action:log-env-error">
  	<xsl:param name="message"/>
  	<xsl:param name="op-code"/>
  	<xsl:param name="eid" select="''"/>
  	<xsl:param name="op-result" select="4"/> <!-- error by default, use 3 for ok -->
  	<xsl:param name="ve-status"/>
  		
		<xsl:variable name="full-message">
			<xsl:copy-of select="$message"/>&#160;-&#160;
			<xsl:value-of select="ve:status2text($ve-status/state,$ve-status/transition)"/>
		</xsl:variable>
		<xsl:if test="sw:report-progress($full-message, 0, $op-result, $op-code, $eid)"/>
		<xsl:if test="$op-result='4'">
  		<xsl:if test="sw:sesput('error',$full-message)"/>
  	</xsl:if>
	</func:function>
  
  	<!-- 
  		Report current task progress:
  		action:report-progress($op-title, $op-name, $status, $eid, $info, $child-id)
	  -->
	<func:function name="action:report-progress">
		<xsl:param name="op-title"/>
		<xsl:param name="op-name"/>
		<xsl:param name="status"/>
		<xsl:param name="eid" select="/.."/>
		<xsl:param name="info" select="/.."/>
		<xsl:param name="child-id" select="''"/>
		
		<!-- Report about runned command -->
		<xsl:choose>
			
			<!-- "extended" reporting, no eid to env-info resolving -->
			<xsl:when test="$info">
				<xsl:variable name="mixed-info">
					<xsl:if test="$op-title">
						<message><xsl:value-of select="sw:base64-encode($op-title)"/></message>
						<name/>
					</xsl:if>
					
					<!-- provide reference to child operation -->
					<xsl:if test="$child-id">
						<parameter>
							<name>child_id</name>
							<message><xsl:value-of select="sw:base64-encode($child-id)"/></message>
						</parameter>
					</xsl:if>
					
					<xsl:copy-of select="$info"/>
				</xsl:variable>
				<xsl:if test="sw:report-progress-ex($mixed-info, 0, $status, $op-name, $eid)"/>
			</xsl:when>
			
			<!-- usual case - no additional data, eid to env-info automatic resolving -->
			<xsl:otherwise>
				<xsl:if test="sw:report-progress($op-title, 0, $status, $op-name, $eid, $child-id)"/>
			</xsl:otherwise>
			
		</xsl:choose>		
		
		<func:result select="/.."/>
	</func:function>
  
	<func:function name="action:start">
  	<xsl:param name="op-code"/>
  	<xsl:param name="eid" select="/.."/>
  	<xsl:variable name="start-text"><_>Starting the process</_></xsl:variable>
  	<xsl:if test="sw:report-progress($start-text, 0, 1, $op-code, $eid)"/>
  </func:function>
  
  <func:function name="action:log-error">
  	<xsl:param name="message"/>
  	<xsl:param name="op-code"/>
  	<xsl:param name="eid" select="/.."/>
  	<xsl:if test="sw:report-progress($message, 0, 4, $op-code, $eid)"/>
  	<xsl:if test="sw:sesput('error',$message)"/>
  </func:function>
  
  <func:function name="action:log-message">
  	<xsl:param name="message"/>
  	<xsl:param name="op-code"/>
  	<xsl:param name="eid" select="/.."/>
  	<xsl:if test="sw:report-progress($message, 0, 2, $op-code, $eid)"/>
  </func:function>

	<func:function name="action:complete">
  	<xsl:param name="op-code"/>
  	<xsl:param name="eid" select="/.."/>
	<xsl:param name="info" select="/.."/>
  	<xsl:param name="result-status" select="sw:if(sw:sesget('error'),$global:task-failed,$global:task-completed)"/>
  	
  	<xsl:variable name="completed-text"><_>Completing the process</_></xsl:variable>
  	<xsl:if test="action:report-progress($completed-text, $op-code, $result-status, $eid, $info)"/>
		
  	<func:result>
  		<xsl:choose>
  			<xsl:when test="$result-status=$global:task-failed">
  				<data>
						<error/>
					</data>
  			</xsl:when>
  			<xsl:otherwise>
					<data>
						<ok/>
						<xsl:if test="$eid and $eid!=''">
							<eid>
								<xsl:value-of select="$eid"/>
							</eid>
						</xsl:if>
					</data>
				</xsl:otherwise>
			</xsl:choose>
  	</func:result>
  	
  </func:function>


	<func:function name="action:run-child">
		<xsl:param name="packet-src"/>
		<xsl:param name="op-title"/>
		<xsl:param name="op-name"/>
		<xsl:param name="eid" select="/.."/>
		<xsl:param name="ext-info" select="/.."/>
	
		<!-- Send packet, take packet ID -->
		<xsl:variable name="packet-id" select="concat($request-id,'/',sw:generate-id())"/>
		<xsl:variable name="res" select="sw:send($packet-src,$packet-id)"/>
		
		<!-- Report about runned command -->
		<xsl:if test="action:report-progress($op-title, $op-name, 2, $eid, $ext-info, $packet-id)"/>
		
		<!-- Wait for command completion -->
		<xsl:variable name="packet-res" select="sw:recv($packet-id)"/>		
		
		<!-- Check for errors -->
		<xsl:choose>
			<xsl:when test="$packet-res/packet/data//error|$packet-res/packet/error">
				<xsl:if test="sw:sesput('error',$packet-res/packet/data//error|$packet-res/packet/error)"/>
				<func:result select="/.."/>
			</xsl:when>
			<!-- Check output from XSLT action -->
			<xsl:when test="$packet-res/packet/data/xslt">			
				<xsl:variable name="child-res" select="sw:node-set(sw:base64-decode($packet-res/packet/data/xslt/output))"/>
				<xsl:choose>
					<xsl:when test="$child-res/data/error">
						<func:result select="$child-res/data/error"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="$child-res"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- /Check output from XSLT action -->			
			<xsl:otherwise>
				<func:result select="$packet-res"/>
			</xsl:otherwise>
		</xsl:choose>

	</func:function>

</xsl:stylesheet>
