<!--
     Copyright (c) SWsoft, 1999-2007
     All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date browse func time local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:user-profile="http://www.swsoft.com/xsl/cp/user-profile"
	xmlns:time="http://www.swsoft.com/xsl/cp/time"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:func="http://exslt.org/functions"
>

	<sw:include href="/lib/core/user-profile.xsl"/>
	<sw:include href="/lib/date-time.xsl"/>

	<!-- Init Browse Filter -->
	<!--
		no-limit : set it to true() to show all existed items on all list ( do not limit list by 10,20,40 or 80 limit)
	-->
 	<xsl:template name="browse:init-filter">
  	<xsl:param name="browse"/>
  	<xsl:param name="no-limit" select="false()"/>

  	<xsl:variable name="data" select="exsl:node-set($browse)"/>

  	<xsl:variable name="screen_id" select="string($data/ui:browse-setup/@id)"/>
		<xsl:variable name="my-filter" select="sw:param('filter_action')='force_search' or sw:param('_lf')=$screen_id" />
		<!-- _lf is 'use Last Filter' -->

  	<xsl:variable name="cols" select="$data/ui:cols"/>

  	<xsl:variable name="core-pref" select="sw:sesgettree(concat('browse_',$screen_id))/settings"/>
  	<xsl:variable name="filter-pref" select="sw:sesgettree(concat('browse_filter_',$screen_id))/settings"/>

		<xsl:variable name="use-filter-pref" select="sw:param('_lf')" />
		<xsl:variable name="filter_action" select="sw:if($my-filter,string(sw:param('filter_action')),'')" />
  	<xsl:variable name="do_navigation" select="$my-filter and sw:param('from')!=''"/>			
  	<xsl:variable name="do_page_limit" select="$filter_action = 'pc'"/>		
  	<xsl:variable name="do_customize_filter" select="$filter_action = 'customize_filter_fields'"/>
   	<xsl:variable name="do_customize_list" select="$filter_action = 'customize_list_cols'"/>	
  	<xsl:variable name="do_show_all" select="$filter_action ='show_all'"/>
  	<xsl:variable name="do_search" select="$filter_action = 'search' or $filter_action = 'force_search' or $do_customize_filter or $do_page_limit or $do_navigation"/>

  	<xsl:variable name="do_resort" select="$my-filter and sw:param('sort')!=''"/>
  	<xsl:variable name="limit_post" select="sw:if($do_page_limit,sw:param('pc_switch'),'')"/>

  	<xsl:variable name="filter_">
  		<xsl:copy-of select="$data/ui:browse-setup"/>
			<ui:int>
				<xsl:if test="$do_show_all">
					<xsl:attribute name="show-all">1</xsl:attribute>
				</xsl:if>
			</ui:int>
  		<!-- Columns Definition -->
	  	<ui:cols>
	  		<xsl:for-each select="$cols/ui:column">
	  			<xsl:variable name="col_id" select="@id"/>
	  			<ui:column>
	  				<xsl:copy-of select="@*[not(self::hidden or self::custom-filter-hidden)]"/>
	  				<!-- Init @custom-hidden -->
	  				<xsl:variable name="pref-hidden" select="$core-pref/col[@id=$col_id and @hidden]"/>
	  				<xsl:variable name="customize-hidden" select="sw:if(sw:param('_custom_list')=@id,'no','yes')"/>
	  				<xsl:variable name="src-hidden" select="sw:if(@hidden='yes' or @custom-hidden='yes','yes','no')"/>	  				
 						<xsl:attribute name="src-hidden"><xsl:value-of select="$src-hidden"/></xsl:attribute>	  	
 						<xsl:attribute name="src-pref-hidden"><xsl:value-of select="$pref-hidden/@hidden"/></xsl:attribute>	 						
	  				<xsl:choose>
		  				<xsl:when test="$do_customize_list">
	  						<xsl:attribute name="hidden"><xsl:value-of select="$customize-hidden"/></xsl:attribute>
	  					</xsl:when>
							<xsl:when test="$pref-hidden">
								<xsl:attribute name="hidden"><xsl:value-of select="$pref-hidden/@hidden"/></xsl:attribute>
							</xsl:when>
							<xsl:when test="@custom-hidden">
								<xsl:attribute name="hidden"><xsl:value-of select="@custom-hidden"/></xsl:attribute>
							</xsl:when>
							<xsl:when test="@hidden='yes'">
								<xsl:attribute name="hidden">yes</xsl:attribute>
							</xsl:when>
						</xsl:choose>
						<!-- Init @custom-filter-hidden -->
	  				<xsl:variable name="pref-filter-hidden" select="$core-pref/col[@id=$col_id and @filter-hidden]"/>
	  				<xsl:variable name="customize-filter-hidden" select="sw:if(sw:param('_custom_filter')=@id,'no','yes')"/>
	  				<xsl:variable name="src-filter-hidden" select="sw:if(@custom-filter-hidden and @custom-filter-hidden='yes','yes','no')"/>	  					  				
 						<xsl:attribute name="src-filter-hidden"><xsl:value-of select="$src-filter-hidden"/></xsl:attribute>	  				
	  				<xsl:choose>
	  					<xsl:when test="$do_customize_filter">
	  						<xsl:attribute name="custom-filter-hidden"><xsl:value-of select="$customize-filter-hidden"/></xsl:attribute>
	  					</xsl:when>
							<xsl:when test="$pref-filter-hidden">
								<xsl:attribute name="custom-filter-hidden"><xsl:value-of select="$pref-filter-hidden/@filter-hidden"/></xsl:attribute>
							</xsl:when>
							<xsl:when test="@custom-filter-hidden and @custom-filter-hidden!=$src-filter-hidden">
								<xsl:attribute name="custom-filter-hidden"><xsl:value-of select="@custom-filter-hidden"/></xsl:attribute>
							</xsl:when>
							<xsl:when test="@custom-filter-hidden='yes'">
								<xsl:attribute name="custom-filter-hidden">yes</xsl:attribute>
							</xsl:when>
						</xsl:choose>
	  				<!-- Init @custom-filter-hidden -->
	  				<!--<xsl:variable name="pref-filter" select="$core-pref/custom-filter-hidden[@id=$col_id and @value!='']"/>
		  			<xsl:attribute name="custom-filter-hidden">
		  				<xsl:choose>
		  					<xsl:when test="$do_customize">
		  						<xsl:value-of select="sw:if(
		  							sw:param('_custom_filter')=@id,
		  							'no','yes'
		  						)"/>
		  					</xsl:when>
		  					<xsl:when test="$pref-filter">
		  						<xsl:value-of select="$pref-filter/@value"/>
		  					</xsl:when>
		  					<xsl:otherwise>
		  						<xsl:value-of select="@custom-filter-hidden"/>
		  					</xsl:otherwise>
		  				</xsl:choose>
		  			</xsl:attribute>
		  			-->
		  			<!-- /Init @custom-hidden -->
	  				<xsl:if test="not(@align)">
	  					<!-- Set align automatically -->
							<xsl:attribute name="align">
	  						<xsl:choose>
	  							<xsl:when test="@data-type='int'">right</xsl:when>
	  							<xsl:when test="@data-type='float'">right</xsl:when>
	  							<xsl:when test="@data-type='date' or @data-type='date'">right</xsl:when>
	  							<xsl:otherwise>left</xsl:otherwise>
	  						</xsl:choose>
	  					</xsl:attribute>
	  					<!-- /Set align automatically -->
	  				</xsl:if>
						<!-- Set vza-sort-ord automatically -->
	  				<xsl:if test="not(@vza-sort-ord)">
	  					<xsl:attribute name="vza-sort-ord">10</xsl:attribute>
	  				</xsl:if>
	  				<!-- Set for-url-name automatically -->
	  				<xsl:if test="not(@for-url-name)">
	  					<xsl:attribute name="for-url-name"><xsl:value-of select="$col_id"/></xsl:attribute>
	  				</xsl:if>
	  				<!-- Set data-type automatically -->
	  				<xsl:if test="not(@data-type)">
	  					<xsl:attribute name="data-type">str</xsl:attribute>
	  				</xsl:if>
	  				<!-- /Set data-type automatically -->
	  				<!-- Set for-url automatically -->
	  				<xsl:if test="not(@for-url) and (@nav-type='id')">
	  					<xsl:attribute name="for-url">yes</xsl:attribute>
	  				</xsl:if>
	  				<!-- /Set for-url automatically -->
	  				<!-- Set show-url automatically -->
	  				<xsl:if test="not(@show-url) and (@nav-type='id' or @nav-type='title')">
	  					<xsl:attribute name="show-url">yes</xsl:attribute>
	  				</xsl:if>
	  				<!-- Set select-idautomatically -->
	  				<xsl:if test="not(@select-id)">
	  					<xsl:attribute name="select-id"><xsl:value-of select="$col_id"/></xsl:attribute>
	  				</xsl:if>
	  				<!-- /Set for-url automatically -->
	  				<!-- Set value from filter/search box -->
	  				<xsl:choose>
	  					<!-- handle interval-like search controls -->
	  					<xsl:when test="@filter='interval'">
	  						<xsl:if test="not(@value-from) and not(@value-to)">

	  							<xsl:variable name="post_from_src" select="sw:if(not($do_show_all),sw:param( concat('filter_',$col_id,'_from') ), '')"/>
			  					<xsl:variable name="post_to_src" select="sw:if(not($do_show_all),sw:param( concat('filter_',$col_id,'_to') ), '')"/>

			  					<xsl:variable name="post_from" select="browse:conv-datetime($post_from_src,$col_id,'from')"/>
			  					<xsl:if test="$post_from_src!='' and $post_from=''">
			  						<xsl:if test="browse:post-datetime-error(.,'from')"/>
			  					</xsl:if>

			  					<xsl:variable name="post_to" select="browse:conv-datetime($post_to_src,$col_id,'to')"/>
			  					<xsl:if test="$post_to_src!=$post_to_src!='' and $post_to=''">
			  						<xsl:if test="browse:post-datetime-error(.,'to')"/>
			  					</xsl:if>

			  					<xsl:choose>
				  					<xsl:when test="$do_search">
				  						<xsl:if test="$post_from_src!=''">
				  							<xsl:attribute name="value-from-src"><xsl:value-of select="$post_from_src"/></xsl:attribute>
				  						</xsl:if>
				  						<xsl:if test="$post_to_src!=''">
				  							<xsl:attribute name="value-to-src"><xsl:value-of select="$post_to_src"/></xsl:attribute>
				  						</xsl:if>
				  						<xsl:if test="$post_from!=''">
				  							<xsl:attribute name="value-from"><xsl:value-of select="$post_from"/></xsl:attribute>
				  						</xsl:if>
				  						<xsl:if test="$post_to!=''">
				  							<xsl:attribute name="value-to"><xsl:value-of select="$post_to"/></xsl:attribute>
				  						</xsl:if>
				  					</xsl:when>
				  					<xsl:otherwise>
				  						<xsl:variable name="pref_from_src" select="string($filter-pref/ui:value[$use-filter-pref and @id=$col_id]/@value-from-src)"/>
				  						<xsl:variable name="pref_to_src" select="string($filter-pref/ui:value[$use-filter-pref and @id=$col_id]/@value-to-src)"/>

				  						<xsl:variable name="pref_from" select="browse:conv-datetime($pref_from_src,@id,'from')"/>
			  							<xsl:variable name="pref_to" select="browse:conv-datetime($pref_to_src,@id,'to')"/>

				  						<xsl:if test="$pref_from_src!='' and $pref_from=''">
					  						<xsl:if test="browse:post-datetime-error(.,'from')"/>
					  					</xsl:if>
					  					<xsl:if test="$pref_to_src!='' and $pref_to=''">
					  						<xsl:if test="browse:post-datetime-error(.,'to')"/>
					  					</xsl:if>

				  						<xsl:if test="not($do_show_all)">
					  						<xsl:if test="$pref_from_src!=''">
					  							<xsl:attribute name="value-from-src"><xsl:value-of select="$pref_from_src"/></xsl:attribute>
					  						</xsl:if>
					  						<xsl:if test="$pref_to_src!=''">
					  							<xsl:attribute name="value-to-src"><xsl:value-of select="$pref_to_src"/></xsl:attribute>
					  						</xsl:if>
					  						<xsl:if test="$pref_from!=''">
					  							<xsl:attribute name="value-from"><xsl:value-of select="$pref_from"/></xsl:attribute>
					  						</xsl:if>
					  						<xsl:if test="$pref_to!=''">
					  							<xsl:attribute name="value-to"><xsl:value-of select="$pref_to"/></xsl:attribute>
					  						</xsl:if>
					  					</xsl:if>
				  					</xsl:otherwise>
				  				</xsl:choose>
			  				</xsl:if>
	  					</xsl:when>
	  					<!-- handle single-value search controls -->
	  					<xsl:otherwise>
			  				<xsl:if test="not(@value) and @filter!=''">
			  					<xsl:variable name="post_src_raw" select="normalize-space(sw:param( concat('filter_',$col_id) ))"/>
			  					<xsl:variable name="post_src">
			  						<xsl:choose>
			  							<xsl:when test="@filter-group">
			  								<xsl:variable name="src" select="normalize-space(sw:param( concat('filter_',current()/@filter-group) ))"/>
			  					 			<xsl:variable name="code" select="substring-before($src,'_')"/>
			  								<xsl:if test="$code=$col_id">
			  									<xsl:value-of select="substring-after($src,'_')"/>
			  								</xsl:if>
			  							</xsl:when>
			  					 		<xsl:when test="$cols/ui:column[@filter-group=$col_id]">
			  					 			<xsl:variable name="code" select="substring-before($post_src_raw,'_')"/>
			  								<xsl:if test="$code=$col_id">
			  									<xsl:value-of select="substring-after($post_src_raw,'_')"/>
			  								</xsl:if>
			  					 		</xsl:when>
			  					 		<xsl:otherwise>
			  								<xsl:value-of select="$post_src_raw"/>
			  							</xsl:otherwise>
			  					 	</xsl:choose>
			  					</xsl:variable>
			  					<xsl:variable name="post" select="$post_src"/>
			  					<xsl:choose>
				  					<xsl:when test="$do_search">
				  						<xsl:if test="$post_src!=''">
				  							<xsl:attribute name="value-src"><xsl:value-of select="$post_src"/></xsl:attribute>
				  						</xsl:if>
				  						<xsl:if test="$post!=''">
				  							<xsl:attribute name="value"><xsl:value-of select="$post"/></xsl:attribute>
				  						</xsl:if>
				  					</xsl:when>
				  					<xsl:otherwise>
				  						<xsl:variable name="pref_src" select="$filter-pref/ui:value[$use-filter-pref and @id=$col_id]/@value-src"/>
				  						<xsl:variable name="pref_value" select="$pref_src"/>
				  						<xsl:if test="not($do_show_all)">
					  						<xsl:if test="$pref_src!=''">
					  							<xsl:attribute name="value-src"><xsl:value-of select="$pref_src"/></xsl:attribute>
					  						</xsl:if>
					  						<xsl:if test="$pref_value!=''">
					  							<xsl:attribute name="value"><xsl:value-of select="$pref_value"/></xsl:attribute>
					  						</xsl:if>
					  					</xsl:if>
				  					</xsl:otherwise>
				  				</xsl:choose>
			  				</xsl:if>
			  			</xsl:otherwise>
			  			<!-- /handle single-value search controls -->
				  	</xsl:choose>
	  				<!-- /Set value from filter/search box -->
	  				<xsl:if test="@display-type='icon' and not(@width)">
	  					<xsl:attribute name="width">20</xsl:attribute>
	  				</xsl:if>
	  				<xsl:copy-of select="node()"/>
	  			</ui:column>
	  		</xsl:for-each>
	  	</ui:cols>
	  	<!-- Sort Column/Direction Definition -->
	  	<ui:sort>
	  		<ui:direction>
	  			<xsl:choose>
	  				<xsl:when test="$my-filter and sw:param('sort_dir') !=''">
	  					<xsl:value-of select="sw:param('sort_dir')"/>
	  				</xsl:when>
	  				<xsl:when test="$my-filter and not(sw:param('sort')) and $core-pref/@sort-direction!=''">
	  					<xsl:value-of select="$core-pref/@sort-direction"/>
	  				</xsl:when>
	  				<xsl:when test="$cols/@sorting-direction">
	  					<xsl:value-of select="$cols/@sorting-direction"/>
	  				</xsl:when>
	  				<xsl:otherwise>
	  					<xsl:value-of select="'asc'"/>
	  				</xsl:otherwise>
	  			</xsl:choose>
	  		</ui:direction>
	  		<ui:col>
	  			<xsl:variable name="get-var" select="sw:param('sort')"/>
	  			<xsl:choose>
	  				<xsl:when test="$my-filter and $get-var and $cols/ui:column[@id=$get-var]">
	  					<xsl:value-of select="$get-var"/>
	  				</xsl:when>
	  				<xsl:when test="$core-pref/@sort-column!='' and $cols/ui:column[@id=$core-pref/@sort-column]">
	  					<xsl:value-of select="$core-pref/@sort-column"/>
	  				</xsl:when>
	  				<xsl:when test="$cols/@sorting-col">
	  					<xsl:if test="not($cols/ui:column[@id=$cols/@sorting-col])">
		  					<xsl:message terminate="yes">
									browse.xsl,init-filter(). Error: unknown @sorting-col='<xsl:value-of select="$cols/@sorting-col"/>'.
								</xsl:message>
							</xsl:if>
	  					<xsl:value-of select="$cols/@sorting-col"/>
	  				</xsl:when>
	  				<xsl:when test="$cols/ui:column[@nav-type='id'][1]">
	  					<xsl:value-of select="$cols/ui:column[@nav-type='id'][1]/@id"/>
	  				</xsl:when>
	  				<xsl:otherwise>
	  					<xsl:value-of select="$cols/ui:column[not(@sorting='no') and not(@hidden='yes')][1]/@id"/>
	  				</xsl:otherwise>
	  			</xsl:choose>
	  		</ui:col>
	  	</ui:sort>
	  	<!-- "Paging" Definition -->
	  	<ui:coords>
	  		<xsl:attribute name="limit">
	  			<xsl:choose>
		  			<xsl:when test="$limit_post!=''">
		  				<xsl:value-of select="$limit_post"/>
		  			</xsl:when>
		  			<xsl:when test="$no-limit=true()">
		  				<xsl:value-of select="268435456"/><!-- unlimited -->
		  			</xsl:when>
		  			<xsl:when test="$core-pref/@items-on-page!=''">
		  				<xsl:value-of select="$core-pref/@items-on-page"/>
		  			</xsl:when>
	  				<xsl:otherwise>20</xsl:otherwise>
	  			</xsl:choose>
	  		</xsl:attribute>
	  		<xsl:attribute name="from">
		  		<xsl:choose>
		  			<xsl:when test="$my-filter and sw:param('from') != ''">
	  					<xsl:value-of select="sw:param('from')"/>
	  				</xsl:when>
	  				<xsl:when test="$my-filter and sw:param('from') != ''">
	  					<xsl:value-of select="sw:param('from')"/>
	  				</xsl:when>
	  				<xsl:when test="not($do_search) and not($do_show_all) and not($limit_post) and not(sw:param('sort')) and ($use-filter-pref and $filter-pref/ui:coords/@from!='')">
	  					<xsl:value-of select="$filter-pref/ui:coords/@from"/>
	  				</xsl:when>
	  				<xsl:otherwise>1</xsl:otherwise>
		  		</xsl:choose>
		  	</xsl:attribute>
	  	</ui:coords>
	  	<!-- /"Paging" Definition -->
	  </xsl:variable>
	  <xsl:variable name="filter" select="exsl:node-set($filter_)"/>


		<xsl:choose>
			<xsl:when test="$do_search or $do_customize_filter or $do_show_all or $do_resort">
				<xsl:variable name="new_pref">
					<settings>
						<ui:type>session</ui:type>	
						<ui:coords from="{$filter/ui:coords/@from}"/>
						<xsl:for-each select="$filter/ui:cols/ui:column[@value-src!='' or @value-from-src!='' or @value-to-src!='']">
							<ui:value>
								<xsl:copy-of select="@id"/>
								<xsl:copy-of select="@value-src"/>
								<xsl:copy-of select="@value-from-src"/>
								<xsl:copy-of select="@value-to-src"/>
							</ui:value>
						</xsl:for-each>
					</settings>
				</xsl:variable>
	
				<xsl:if test="sw:sesput(concat('browse_filter_',$screen_id),$new_pref)"/>	  	
			</xsl:when>
			<!-- Drop old filter, we do not need it anymore  -->
			<xsl:when test="not($use-filter-pref) and $filter-pref">
				<xsl:if test="sw:sesput(concat('browse_filter_',$screen_id),'')"/>	  	
			</xsl:when>
	  </xsl:choose>
	  
		<!-- Put core settings to user profile -->
		<xsl:if test="$do_customize_list or $do_customize_filter or $do_page_limit or $do_resort">
			<xsl:variable name="new-core-pref-rtf">
	  		<settings 
	  			items-on-page="{$filter/ui:coords/@limit}"
	  			sort-column="{$filter/ui:sort/ui:col}"
	  			sort-direction="{$filter/ui:sort/ui:direction}"	
	  		>		
					<xsl:for-each select="$filter/ui:cols/ui:column[@hidden and 
						(@hidden!=@src-hidden)
					]">
						<col id="{@id}" hidden="{@hidden}"/>
					</xsl:for-each>
					<xsl:for-each select="$filter/ui:cols/ui:column[@filter and (
						(not(@src-filter-hidden) and @custom-filter-hidden)
						or
						(@custom-filter-hidden and @custom-filter-hidden!=@src-filter-hidden)
					)]">
						<col id="{@id}" filter-hidden="{@custom-filter-hidden}"/>
					</xsl:for-each>
				</settings>
	  	</xsl:variable>
		  <xsl:variable name="new-core-pref" select="exsl:node-set($new-core-pref-rtf)"/>	  	

	  	<xsl:if test="sw:sesputtree(concat('browse_',$screen_id),$new-core-pref)"/>	  	
	 
	 		<xsl:if test="local:save-settings2profile($data/ui:browse-setup,$new-core-pref/settings)"/>
		</xsl:if>
		<!-- /Put core settings to user profile -->		

  	<xsl:copy-of select="$filter"/>

 	</xsl:template>
 	<!-- /Init Browse Request -->

 

 	<func:function name="browse:read-datetime2"><!-- version for combo-filter -->
		<xsl:param name="id"/>
		<xsl:param name="control"/><!-- from or to -->
		<!--|-->
		<xsl:variable name="prefix" select="concat('filter_',$id,'_',$control,'_')"/>
		<!--|-->
		<xsl:variable name="year" select="sw:param(concat($prefix,'year'))"/>
		<xsl:variable name="month" select="sw:param(concat($prefix,'month'))"/>
		<xsl:variable name="day" select="sw:param(concat($prefix,'day'))"/>
		<xsl:variable name="time" select="sw:param(concat($prefix,'time'))"/>
		<!--|-->
		<xsl:variable name="t">
		  <xsl:variable name="t1" select="substring-before($time,':')"/>
		  <xsl:variable name="t2" select="substring-after($time, ':')"/>
		  <xsl:value-of select="format-number($t1, '00')"/>
		  <xsl:text>:</xsl:text>
		  <xsl:value-of select="format-number($t2, '00')"/>
		  <xsl:text>:00</xsl:text>
		</xsl:variable>
		<!--|-->
		<func:result>
			<xsl:choose>
				<xsl:when test="$year!='' and $month!='' and $day!='' and $time!=''">
					<xsl:value-of select="concat(format-number($year,'0000'),'-',format-number($month,'00'),'-',format-number($day,'00'),'T',$t)"/>
				</xsl:when>
				<xsl:otherwise></xsl:otherwise>
			</xsl:choose>
		</func:result>
 	</func:function>

 	<func:function name="browse:post-datetime-error">
 		<xsl:param name="col"/>
 		<xsl:param name="prefix"/>
		<xsl:variable name="error">
			<sw:text>
				<xsl:with-param name="title" select="$col/@title"/>
				The filter value for column "%{title}" is incorrect. Please change it.
			</sw:text>
		</xsl:variable>
		<xsl:if test="error:put($error,'',concat('filter_',$col/@id,'_',$prefix))"/>
		<func:result/>
	</func:function>

	<func:function name="browse:conv-datetime"><!-- version for input-filter -->
		<xsl:param name="value"/>
		<xsl:param name="id"/>
		<xsl:param name="control"/>

		<func:result select="time:web2time($value, $control)"/>

	</func:function>

	<func:function name="browse:prepare-datetime">
		<xsl:param name="value"/>
		<func:result select="sw:time2vzatime($value)"/>
	</func:function>

	<func:function name="browse:prepare-unixtime">
		<xsl:param name="value"/>
		<func:result select="sw:vzatime2utime(sw:time2vzatime($value))"/>
	</func:function>
	
	<!-- sort row-set manually -->
	<func:function name="browse:sort-rows">
		<xsl:param name="rows"/>                     <!-- filtered set of ui:rows -->
		<xsl:param name="filter"/>                   <!-- filter defenition -->
		<xsl:param name="rows-top" select="/.."/>    <!-- (opt) top rows no filtering -->
		<xsl:param name="rows-bottom" select="/.."/> <!-- (opt) bottom rows no filtering -->

		<xsl:variable name="sort-id" select="string($filter/ui:sort/ui:col)"/>
		<xsl:variable name="dir" select="sw:if($filter/ui:sort/ui:direction='asc','ascending','descending')"/>

		<!-- prepare mapping table -->
		<xsl:variable name="types">
			<type filter="int" xsl="number"/>
			<type filter="float" xsl="number"/>
			<type filter="bool" xsl="text"/>
			<type filter="datetime" xsl="text"/>
			<type filter="unixtime" xsl="number"/>
			<type filter="time" xsl="text"/><!-- todo:  correct sorting -->
			<type filter="str" xsl="text-nocase"/>
			<type filter="ip" xsl="ip"/>
			<type filter="file-name" xsl="file-name"/>
		</xsl:variable>

		<xsl:variable name="sorting-col" select="$filter/ui:cols/ui:column[@id=$sort-id]"/>
		<xsl:variable name="sort" select="string(sw:if($sorting-col/@xsl-sort-id,$sorting-col/@xsl-sort-id,$sorting-col/@id))"/>
		<xsl:variable name="datatype" select="exsl:node-set($types)/type[@filter=$filter/ui:cols/ui:column[@id=$sort-id]/@data-type]/@xsl"/>
		<xsl:if test="not($datatype) and $sort">
			<!-- info -->
			<xsl:if test="sw:sesput('sort',$sort)"/>
			<xsl:if test="sw:sesput('filter',$filter)"/>
			<xsl:if test="sw:sesput('column',$filter/ui:cols/ui:column[@id=$sort-id])"/>
			<xsl:message terminate="yes">
				browse.xsl,process-rows(). Error: Unknown data-type, view session log for details.
			</xsl:message>
		</xsl:if>

		<xsl:variable name="rows-sorted-rtf">
			<xsl:copy-of select="$rows-top[not(@allow-filter='true')]"/>
			<xsl:copy-of select="$rows[@position='top' and @allow-filter='true']"/>

			<xsl:choose>
				<xsl:when test="$sort=''">
					<xsl:copy-of select="$rows[not(@position)]"/>
				</xsl:when>
				<xsl:when test="$datatype='ip'">
					<xsl:for-each select="$rows[not(@position)]">
						<xsl:sort select="sw:ip2number(node()[name() = $sort])" order="{$dir}" data-type="number"/>
						<xsl:copy-of select="."/>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$datatype='file-name'">
					<xsl:for-each select="$rows[not(@position)]">
						<xsl:sort
							select="concat(sw:if(file-type='4','0','1'), file-name )"
							order="{$dir}"
							data-type="text"
						/>
						<xsl:copy-of select="."/>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$sorting-col/@id='file-size'">
					<xsl:for-each select="$rows[not(@position)]">
						<xsl:sort
							select="sw:if(file-type='4',0,1) + file-size"
							order="{$dir}"
							data-type="number"
						/>
						<xsl:copy-of select="."/>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$datatype='text-nocase'">
					<xsl:for-each select="$rows[not(@position)]">
						<xsl:sort select="sw:uc(node()[name() = $sort])" order="{$dir}" data-type="text"/>
						<xsl:copy-of select="."/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="$rows[not(@position)]">
						<xsl:sort select="node()[name() = $sort]" order="{$dir}" data-type="{$datatype}"/>
						<xsl:copy-of select="."/>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:copy-of select="$rows[@position='bottom' and @allow-filter='true']"/>
			<xsl:copy-of select="$rows-bottom[not(@allow-filter='true')]"/>
		</xsl:variable>
		<xsl:variable name="rows-sorted" select="exsl:node-set($rows-sorted-rtf)/*"/>

		<func:result select="$rows-sorted"/>
	</func:function>
	
	<!-- Store browse settings in LDAP -->
	<func:function name="local:save-settings2profile">
		<xsl:param name="browse-setup"/>	
		<xsl:param name="core-pref"/>	
		
		<xsl:variable name="user-profile-ref" select="user-profile:logged-ref()"/>
		<xsl:variable name="dn" select="concat('browseID=',$browse-setup/@id,',cn=BrowsersSettings,',$user-profile-ref/dn)"/>
		
		<!-- Try to find existed record -->
		<xsl:variable name="existed-obj" select="user-profile:load-obj($user-profile-ref,$dn)"/>		
		
		<!-- Prepare profile  -->
		<xsl:variable name="profile-rtf">
			<ref>
				<dn>
					<xsl:value-of select="$dn" />
				</dn>
				<objectClass>VZCPBrowseSettings</objectClass>
			</ref>
			<data>
				<browseID><xsl:value-of select="$browse-setup/@id"/></browseID>
				<itemsOnPage><xsl:value-of select="$core-pref/@items-on-page"/></itemsOnPage>
				<sortColumn><xsl:value-of select="$core-pref/@sort-column"/></sortColumn>	
				<sortDirection><xsl:value-of select="$core-pref/@sort-direction"/></sortDirection>		
				<filterVisibleColumns><xsl:for-each select="$core-pref/col[@filter-hidden and @filter-hidden='no']"
				><xsl:if test="position()!=1">,</xsl:if><xsl:value-of select="@id"/></xsl:for-each></filterVisibleColumns>
				<filterHiddenColumns><xsl:for-each select="$core-pref/col[@filter-hidden and @filter-hidden='yes']"
				><xsl:if test="position()!=1">,</xsl:if><xsl:value-of select="@id"/></xsl:for-each></filterHiddenColumns>
				<listVisibleColumns><xsl:for-each select="$core-pref/col[@hidden and @hidden='no']"
				><xsl:if test="position()!=1">,</xsl:if><xsl:value-of select="@id"/></xsl:for-each></listVisibleColumns>
				<listHiddenColumns><xsl:for-each select="$core-pref/col[@hidden and @hidden='yes']"
				><xsl:if test="position()!=1">,</xsl:if><xsl:value-of select="@id"/></xsl:for-each></listHiddenColumns>
			</data>
		</xsl:variable>
		<xsl:variable name="profile" select="exsl:node-set($profile-rtf)"/>
		
		<xsl:choose>
			<!-- Create new profile -->
			<xsl:when test="not($existed-obj)">			
				<xsl:variable name="result" select="user-profile:add-obj($user-profile-ref,$profile)"/>
				<func:result select="$result"/>
			</xsl:when>
			<!-- Update existing profile -->
			<xsl:otherwise>
				<xsl:variable name="result" select="user-profile:modify-obj($user-profile-ref,$profile)"/>			
				<func:result select="$result"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>

</xsl:stylesheet>
