<!--
     Copyright (c) SWsoft, 1999-2007
     All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date browse func dirm user time local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:user="http://www.swsoft.com/xsl/cp/user"
	xmlns:time="http://www.swsoft.com/xsl/cp/time"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:func="http://exslt.org/functions">

	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/date-time.xsl"/>
	<sw:include href="/lib/core/browse-filter-init.xsl"/>	

 	<!--============================================================== Receive data from LDAP(DIRM) ================================================-->
  <!--
  	look at browse.xsd / fill-from-ldap for details
 	-->
  <xsl:template name="browse:fill-from-ldap">
  	<xsl:param name="filter"/>
  	<xsl:param name="ldap-filter" select="''"/>
  	<xsl:param name="base-dn"/>
  	<xsl:param name="attrs-prefix"/>
  	<xsl:param name="cookies" select="''"/>
  	<xsl:param name="selected-ids" select="/"/>
  	<xsl:param name="rows" select="/.."/>

  	<xsl:variable name="rows_src" select="exsl:node-set($rows)"/>
  	<xsl:variable name="total_rows_list" select="$rows_src/ui:bottom-rows/ui:row"/>
		<xsl:variable name="sort" select="string($filter/ui:sort/ui:col)"/>

		<!-- Fieldset -->
		<xsl:variable name="fields">
			<xsl:for-each select="$filter/ui:cols/ui:column[@ldap-id]">
				<name><xsl:value-of select="concat($attrs-prefix,@ldap-id)"/></name>
			</xsl:for-each>
		</xsl:variable>
		<!-- Filter -->
		<xsl:variable name="where-cols">
			<xsl:for-each select="$filter/ui:cols/ui:column[@ldap-id!='' and @filter!='' and (@value!='' or @value-from!='' or @value-to!='')]">
				<xsl:variable name="ldap-id" select="@ldap-id"/>
				<xsl:choose>
					<xsl:when test="(@data-type='datetime' and @filter='interval')">
						<xsl:if test="@value-from!=''">
							<cond>(<xsl:value-of select="$ldap-id"/>&gt;=<xsl:value-of select="browse:prepare-datetime(@value-from)"/>)</cond>
						</xsl:if>
						<xsl:if test="@value-to!=''">
							<cond>(<xsl:value-of select="$ldap-id"/>&lt;=<xsl:value-of select="browse:prepare-datetime(@value-to)"/>)</cond>
						</xsl:if>
					</xsl:when>
					<xsl:when test="(@data-type='unixtime' and @filter='interval')">
						<xsl:if test="@value-from!=''">
							<cond>(<xsl:value-of select="$ldap-id"/>&gt;=<xsl:value-of select="browse:prepare-unixtime(@value-from)"/>)</cond>
						</xsl:if>
						<xsl:if test="@value-to!=''">
							<cond>(<xsl:value-of select="$ldap-id"/>&lt;=<xsl:value-of select="browse:prepare-unixtime(@value-to)"/>)</cond>
						</xsl:if>
					</xsl:when>
					<xsl:when test="@filter='select'">
						<xsl:variable name="option" select="ui:filter-option[@value= current()/@value]"/>
						<xsl:choose>
							<xsl:when test="$option/@type='other'">
								<xsl:variable name="c" select="ui:filter-option[not(@type='other')]"/>
								<xsl:for-each select="$c">
									<cond>(<xsl:value-of select="$ldap-id"/>!=<xsl:value-of select="@value"/>)</cond>
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="$option/@type='custom'">
								<cond>(<xsl:value-of select="$ldap-id"/><xsl:value-of select="$option/@value-custom"/>)</cond>
							</xsl:when>
							<xsl:otherwise>
								<cond>(<xsl:value-of select="$ldap-id"/>=<xsl:value-of select="@value"/>)</cond>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="(@data-type='bool' and @filter='auto') or @data-type='int' or @data-type='float'">
						<cond>(<xsl:value-of select="$ldap-id"/>=<xsl:value-of select="sw:if(@value='1' or @value='true','true','false')"/>)</cond>
					</xsl:when>
					<xsl:when test="@filter='equal'">
						<cond>(<xsl:value-of select="$ldap-id"/>=<xsl:value-of select="@value"/>)</cond>
					</xsl:when>
					<xsl:when test="@data-type='str' and @filter='auto'">
						<cond>(<xsl:value-of select="$ldap-id"/>=*<xsl:value-of select="@value"/>*)</cond>
					</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="where-conds">
			<xsl:copy-of select="$where-cols"/>
			<xsl:variable name="cond-cols" select="$filter/ui:cols/ui:column/ui:cond"/>
			<xsl:if test="$cond-cols">
				<xsl:for-each select="$cond-cols">
					<xsl:choose>
						<xsl:when test="@expr='&lt;'">
							<cond>(<xsl:value-of select="../@ldap-id"/>&lt;<xsl:value-of select="."/>)</cond>
						</xsl:when>
						<xsl:when test="@expr='&lt;='">
							<cond>(<xsl:value-of select="../@ldap-id"/>&lt;=<xsl:value-of select="."/>)</cond>
						</xsl:when>
						<xsl:when test="@expr='&gt;'">
							<cond>(<xsl:value-of select="../@ldap-id"/>&gt;<xsl:value-of select="."/>)</cond>
						</xsl:when>
						<xsl:when test="@expr='!='">
							<cond>(<xsl:value-of select="../@ldap-id"/>!=<xsl:value-of select="."/>)</cond>
						</xsl:when>
						<xsl:when test="@expr='='">
							<cond>(<xsl:value-of select="../@ldap-id"/>=<xsl:value-of select="."/>)</cond>
						</xsl:when>
					  <xsl:when test="@expr='like'">
					    <cond>(<xsl:value-of select="../@ldap-id"/>=*<xsl:value-of select="."/>*)</cond>
					  </xsl:when>
					  <xsl:when test="@expr='in'">
							<cond>
								<xsl:variable name="in-conds">
									<xsl:for-each select="ui:cond-value">
										<cond>(<xsl:value-of select="../@ldap-id"/>=<xsl:value-of select="."/>)</cond>
									</xsl:for-each>
								</xsl:variable>
								<xsl:value-of select="local:ldap-join-conditions('&amp;', exsl:node-set($in-conds)/conds)"/>
							</cond>
						</xsl:when>
					</xsl:choose>
				</xsl:for-each>
			</xsl:if>
			<xsl:if test="$ldap-filter">
				<cond><xsl:value-of select="$ldap-filter"/></cond>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="where">
			<xsl:value-of select="local:ldap-join-conditions('&amp;', exsl:node-set($where-conds)/cond)"/>
		</xsl:variable>
		<!-- Prepare data query-->
		<xsl:variable name="dirm-id" select="sw:internal-realm-id()"/>
		<xsl:variable name="ldap-count-request">
			<packet>
				<target>dirm</target>
				<data>
					<dirm>
						<search>
							<id><xsl:value-of select="$dirm-id"/></id>
							<base><xsl:value-of select="$base-dn"/></base>
							<scope>1</scope>
							<attrs>
								<name><xsl:value-of select="$filter/ui:cols/ui:column[@ldap-id]/@ldap-id[13]"/></name>
							</attrs>
							<!-- Filter -->
							<xsl:if test="string-length($where)">
								<filter>
									<xsl:value-of select="sw:base64-encode(normalize-space($where))"/>
								</filter>
							</xsl:if>
							<!-- /Filter -->
						</search>
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<xsl:variable name="ldap-count-response" select="sw:xchg($ldap-count-request)"/>
		<!-- Check VZA error -->
		<xsl:if test="$ldap-count-response/packet/data/error or $ldap-count-response/packet/data/dirm/error">
			<xsl:message terminate="yes">
				Error was occured in DIRM Operator.
				<xsl:copy-of select="$ldap-count-response//error"/>
			</xsl:message>
		</xsl:if>
		<xsl:variable name="total-count" select="count($ldap-count-response/packet/data/dirm/set/entry)"/>

		<!-- Prepare data query-->
		<xsl:variable name="ldap-request">
			<packet>
				<target>dirm</target>
				<data>
					<dirm>
						<search>
							<id><xsl:value-of select="$dirm-id"/></id>
							<base><xsl:value-of select="$base-dn"/></base>
							<scope>1</scope>
							<attrs>
								<xsl:copy-of select="$fields"/>
							</attrs>
							<!-- Filter -->
							<xsl:if test="string-length($where)">
								<filter>
									<xsl:value-of select="sw:base64-encode(normalize-space($where))"/>
								</filter>
							</xsl:if>
							<!-- /Filter -->
						</search>
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<xsl:variable name="ldap-response" select="sw:xchg($ldap-request)"/>

		<!-- Check DIRM error -->
		<xsl:if test="$ldap-response/packet/data[error|dirm/error]">
			<xsl:message terminate="yes">
				Error was occured in dirm pager operator.
				<xsl:copy-of select="$dirm-response//error"/>
			</xsl:message>
		</xsl:if>

		<xsl:variable name="cols-src">
			<xsl:for-each select="$filter/ui:cols/ui:column">
				<xsl:variable name="col" select="."/>
				<col id="{@id}" data-type="{@data-type}">
					<xsl:if test="@ldap-id">
						<xsl:attribute name="ldap-full-id"><xsl:value-of select="concat($attrs-prefix,@ldap-id)"/></xsl:attribute>
					</xsl:if>
					<xsl:copy-of select="$col/*"/>
				</col>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="cols" select="exsl:node-set($cols-src)"/>
		<xsl:variable name="rows-ldap" select="$ldap-response/packet/data/dirm/set/entry"/>

		<xsl:variable name="cols-for-select" select="$cols[@for-select='yes']"/>

  		<xsl:variable name="rows-list-rtf">
  			<xsl:for-each select="$rows-ldap">
  				<xsl:variable name="row" select="."/>
  				<ui:row>
  					<xsl:if test="$cols-for-select and $selected-ids">
  						<xsl:variable name="row-id">
  							<xsl:for-each select="$cols-for-select">
  								<xsl:variable name="col" select="."/>
  								<xsl:if test="position()!=1">|</xsl:if><xsl:value-of select="sw:base64-decode($row/attr[name=$col/@ldap-full-id]/value)"/>
  							</xsl:for-each>
  						</xsl:variable>
  						<xsl:if test="$row-id=$selected-ids/text()">
  							<xsl:attribute name="selected-checkbox">yes</xsl:attribute>
  						</xsl:if>
  					</xsl:if>
  					<!--- / -->
  					<xsl:for-each select="$cols/col">
  						<xsl:variable name="col" select="."/>
  						<xsl:variable name="col-def" select="."/>
  						<xsl:variable name="value" select="$row/attr[name=$col/@ldap-full-id]/value"/>
  						<xsl:element name="{$col/@id}">
  							<xsl:if test="$value">
  								<xsl:choose>
  									<xsl:when test="$col/@data-type = 'datetime'">
  										<xsl:value-of select="sw:utime2vzatime(sw:base64-decode($value))"/>
  									</xsl:when>
  									<xsl:otherwise>
  										<xsl:value-of select="sw:base64-decode($value)"/>
  									</xsl:otherwise>
  								</xsl:choose>
  								<xsl:for-each select="$col/ui:concat">
  									<xsl:variable name="conc-id" select="."/>
  									<xsl:value-of select="concat('|',  sw:base64-decode($row/attr[ name=concat($prefix,$conc-id) ]/value) )"/>
  								</xsl:for-each>
  							</xsl:if>
  						</xsl:element>
  					</xsl:for-each>
  				</ui:row>
  			</xsl:for-each>
  		</xsl:variable>

  		<xsl:variable name="rows-sorted" select="
  			browse:sort-rows(exsl:node-set($rows-list-rtf)/ui:row, $filter)"/>

		<!-- post rows  -->
		<ui:browse-rows>
			<xsl:copy-of select="$rows-sorted"/>
			<xsl:if test="$total-count!=0">
				<xsl:for-each select="$total_rows_list">
					<ui:row bottom="yes">
						<xsl:copy-of select="*"/>
					</ui:row>
				</xsl:for-each>
			</xsl:if>
		</ui:browse-rows>

		<xsl:if test="$cookies">
			<ui:cookies>
				<xsl:copy-of select="$cookies"/>
			</ui:cookies>
		</xsl:if>

		<xsl:copy-of select="$filter/*[name()!='ui:coords']"/>
		<ui:coords>
			<xsl:attribute name="total">
				<xsl:value-of select="$total-count"/>
			</xsl:attribute>
			<xsl:attribute name="count">
				<xsl:value-of select="count($rows-ldap)"/>
			</xsl:attribute>
			<xsl:copy-of select="$filter/ui:coords/@from"/>
			<xsl:copy-of select="$filter/ui:coords/@limit"/>
		</ui:coords>

 	</xsl:template>

	<func:function name="local:ldap-join-conditions">
		<xsl:param name="expr"/>
		<xsl:param name="conds" select="/.."/>

		<xsl:variable name="ret">
			<xsl:for-each select="$conds">
				<xsl:if test="position() != last()">
					<xsl:text>(</xsl:text>
					<xsl:value-of select="$expr"/>
				</xsl:if>
				<xsl:value-of select="."/>
			</xsl:for-each>
			<xsl:for-each select="$conds">
				<xsl:if test="position() != last()">
					<xsl:text>)</xsl:text>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>

		<func:result select="$ret"/>
	</func:function>

</xsl:stylesheet>
