<!--
     Copyright (c) SWsoft, 1999-2007
     All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date browse func time local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:time="http://www.swsoft.com/xsl/cp/time"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:func="http://exslt.org/functions"
>

	<sw:include href="/lib/core/browse-filter-init.xsl"/>	
	<sw:include href="/lib/date-time.xsl"/>

	
	<!--================================================= Filter Rowset ================================================================-->
	<!--
		look at browse.xsd / fill-filter for details
	-->
	<xsl:template name="browse:fill-filter">
  		<xsl:param name="filter"/>
  		<xsl:param name="rows"/>
  		<xsl:param name="cookies" select="''"/>
  		<!--|-->
  		<xsl:variable name="rows_src" select="exsl:node-set($rows)"/>
		<xsl:variable name="rows_list" select="$rows_src/ui:browse-rows/ui:row"/>
		<xsl:variable name="rows-top" select="$rows_src/ui:browse-rows/ui:row[@position='top']"/>
		<xsl:variable name="rows-bottom" select="$rows_src/ui:browse-rows/ui:row[@position='bottom']"/>
  		<xsl:variable name="total_rows_list" select="$rows_src/ui:bottom-rows/ui:row"/>

		<!-- filter rows by search criteria -->
		<xsl:variable name="rows_f_">
			<xsl:for-each select="$rows_list[not(@position) or @allow-filter='true']">
				<xsl:variable name="row" select="."/>
				<xsl:variable name="skip">
					<xsl:for-each select="$filter/ui:cols/ui:column[@filter!='' and (@value!='' or @value-from!='' or @value-to!='')]">
						<xsl:variable name="id" select="@id"/>
						<xsl:choose>
							<xsl:when test="(@data-type='datetime' or @filter='interval')">
								<xsl:variable name="value" select="sw:vzatime2utime($row/*[name()=$id])"/>
								<xsl:variable name="from">
									<xsl:if test="@value-from!=''"><xsl:value-of select="browse:prepare-unixtime(@value-from)"/></xsl:if>
								</xsl:variable>
								<xsl:variable name="to">
									<xsl:if test="@value-to!=''"><xsl:value-of select="browse:prepare-unixtime(@value-to)"/></xsl:if>
								</xsl:variable>
								<xsl:if test="@value-from!='' and $value &lt; $from">1</xsl:if>
								<xsl:if test="@value-to!='' and $value &gt; $to">1</xsl:if>
							</xsl:when>
							<xsl:when test="(@data-type='bool' and @filter='auto') and not($row/*[name()=$id]=@value)">1</xsl:when>
							<xsl:when test="(@data-type='int' or @data-type='float' or @data-type='ip' or @filter='select') and not($row/*[name()=$id]=@value)">1</xsl:when>
							<xsl:when test="@data-type='str' and @filter='auto' and not(contains(sw:lc(string($row/*[name()=$id])),sw:lc(@value)))">1</xsl:when>
						</xsl:choose>
					</xsl:for-each>
					<!-- Filter by cond-cols -->
					<xsl:for-each select="$filter/ui:cols/ui:column/ui:cond">
						<xsl:variable name="value" select="$row/*[name()=$id]"/>
						<xsl:choose>
							<xsl:when test="@expr='&lt;'">
								<xsl:if test="$value &lt; .">1</xsl:if>
							</xsl:when>
							<xsl:when test="@expr='&gt;'">
								<xsl:if test="$value &gt; .">1</xsl:if>
							</xsl:when>
							<xsl:when test="@expr='!='">
								<xsl:if test="$value != .">1</xsl:if>
							</xsl:when>
							<xsl:when test="@expr='='">
								<xsl:if test="$value = .">1</xsl:if>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="$skip=''">
					<xsl:copy-of select="$row"/>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="rows_s" select="
			browse:sort-rows(exsl:node-set($rows_f_)/ui:row, $filter, $rows-top, $rows-bottom)"/>

		<!-- calc coords -->
		<xsl:variable name="from" select="$filter/ui:coords/@from"/>
		<xsl:variable name="to_" select="number($filter/ui:coords/@from)+number($filter/ui:coords/@limit)-1"/>
		<xsl:variable name="to" select="sw:if($to_ > count($rows_s), count($rows_s), $to_)"/>

		<xsl:variable name="total" select="count($rows_s)"/>
		<xsl:copy-of select="$filter/*[name()!='ui:coords']"/>
		<ui:coords>
			<xsl:attribute name="total">
				<xsl:value-of select="$total"/>
			</xsl:attribute>
			<xsl:attribute name="count">
				<xsl:value-of select="$to - $from + 1"/>
			</xsl:attribute>
			<xsl:copy-of select="$filter/ui:coords/@from"/>
			<xsl:copy-of select="$filter/ui:coords/@limit"/>
		</ui:coords>

		<!-- limit rows  -->
		<ui:browse-rows>
			<xsl:choose>
				<xsl:when test="count($rows_s) &lt;= $filter/ui:coords/@limit">
					<xsl:copy-of select="$rows_s"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$rows_s[position() >= $from and position() &lt;= $to]"/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="$total!=0">
				<xsl:for-each select="$total_rows_list">
					<ui:row bottom="yes">
						<xsl:copy-of select="*"/>
					</ui:row>
				</xsl:for-each>
			</xsl:if>
		</ui:browse-rows>

		<xsl:if test="$cookies">
			<ui:cookies>
				<xsl:copy-of select="$cookies"/>
			</ui:cookies>
		</xsl:if>

 	</xsl:template>
 	<!-- /Filter Rowset -->

</xsl:stylesheet>
