<!--
     Copyright (c) SWsoft, 1999-2007
     All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date browse func time local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:time="http://www.swsoft.com/xsl/cp/time"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:func="http://exslt.org/functions"
>

	<sw:include href="/lib/core/browse-filter-init.xsl"/>
	<sw:include href="/lib/date-time.xsl"/>


 	<!--============================================================== Receive data from VZA ================================================-->
  <!--
  	look at browse.xsd / fill-from-vza for details
 	-->
  <xsl:template name="browse:fill-from-vza">
  	<xsl:param name="filter"/>
  	<xsl:param name="cookies" select="''"/>
  	<xsl:param name="sql-where" select="''"/>
  	<xsl:param name="selected-ids" select="/"/>
  	<xsl:param name="rows" select="/.."/>
  	<xsl:param name="die-on-error" select="true()"/>
  	<xsl:param name="forward-to-master" select="false()"/> <!-- use local pager by default -->

  	<xsl:variable name="rows_src" select="exsl:node-set($rows)"/>
  	<xsl:variable name="total_rows_list" select="$rows_src/ui:bottom-rows/ui:row"/>
		<xsl:variable name="sort" select="string($filter/ui:sort/ui:col)"/>

		<!-- Fieldset -->
		<xsl:variable name="fields">
			<xsl:for-each select="$filter/ui:cols/ui:column[@vza-id and (
					not(@select-only-filtered='true') or @value!=''	)]
				|
				$filter/ui:cols/ui:column/ui:cond[@vza-id and (
					not(../@select-only-filtered='true') or ../@value!='')]">
				<field>pager.<xsl:value-of select="@vza-id"/></field>
			</xsl:for-each>
		</xsl:variable>
		<!-- Filter -->
		<xsl:variable name="where-cols">
			<xsl:for-each select="$filter/ui:cols/ui:column[@vza-id!='' and @filter!='' and (@value!='' or @value-from!='' or @value-to!='')]">
				<xsl:variable name="vza-id" select="@vza-id"/>
				<xsl:if test="position() &gt; 1">
					<xsl:text> AND </xsl:text>
				</xsl:if>
				<xsl:choose>
					<!-- XXX: due to vzagent bug - assimetrical time processing for VZA DB -->
					<xsl:when test="contains($vza-id, '_log.time') and (@data-type='datetime' and @filter='interval')">
						<xsl:if test="@value-from!=''">
							pager.<xsl:value-of select="$vza-id"/> &gt;= '<xsl:value-of select="browse:prepare-datetime(@value-from)"/>'
						</xsl:if>
						<xsl:if test="@value-to!=''">
							<xsl:if test="@value-from!=''">
								AND
							</xsl:if>
							pager.<xsl:value-of select="$vza-id"/> &lt;= '<xsl:value-of select="browse:prepare-datetime(@value-to)"/>'
						</xsl:if>
					</xsl:when>

					<xsl:when test="(@data-type='datetime' and @filter='interval')">
						<xsl:if test="@value-from!=''">
							pager.<xsl:value-of select="$vza-id"/> &gt;= '<xsl:value-of select="browse:prepare-datetime(@value-from)"/>'
						</xsl:if>
						<xsl:if test="@value-to!=''">
							<xsl:if test="@value-from!=''">
								AND
							</xsl:if>
							pager.<xsl:value-of select="$vza-id"/> &lt;= '<xsl:value-of select="browse:prepare-datetime(@value-to)"/>'
						</xsl:if>
					</xsl:when>
					<xsl:when test="(@data-type='unixtime' and @filter='interval')">
						<xsl:if test="@value-from!=''">
							pager.<xsl:value-of select="$vza-id"/> &gt;= '<xsl:value-of select="browse:prepare-datetime(@value-from)"/>'
						</xsl:if>
						<xsl:if test="@value-to!=''">
							<xsl:if test="@value-from!=''">
								AND
							</xsl:if>
							pager.<xsl:value-of select="$vza-id"/> &lt;= '<xsl:value-of select="browse:prepare-unixtime(@value-to)"/>'
						</xsl:if>
					</xsl:when>
					<xsl:when test="@filter='select'">
						<xsl:variable name="option" select="ui:filter-option[@value= current()/@value]"/>
						<xsl:choose>
							<xsl:when test="$option/@type = 'other'">
								<xsl:for-each select="ui:filter-option[not(@type='other')]">
									<xsl:if test="position()!=1">
										AND
									</xsl:if>
									pager.<xsl:value-of select="$vza-id"/>!='<xsl:value-of select="sw:sql-escape(@value)"/>'
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="$option/@type = 'in'">
								<xsl:for-each select="$option/ui:filter-option-value">
									<xsl:if test="position()!=1"> OR </xsl:if>
									pager.<xsl:value-of select="$vza-id"/>='<xsl:value-of select="."/>'
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="$option/@type = 'custom'">
								pager.<xsl:value-of select="$vza-id"/><xsl:value-of select="$option/@value-custom"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="@filter-uncase='true'">
										UPPER(pager.<xsl:value-of select="$vza-id"/>)='<xsl:value-of select="sw:sql-escape(sw:uc(@value))"/>'
									</xsl:when>
									<xsl:otherwise>
										pager.<xsl:value-of select="$vza-id"/>='<xsl:value-of select="sw:sql-escape(@value)"/>'
									</xsl:otherwise>
								</xsl:choose>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="(@data-type='bool' and @filter='auto') or @data-type='int' or @data-type='float'">
						pager.<xsl:value-of select="$vza-id"/>='<xsl:value-of select="sw:sql-escape(@value)"/>'
					</xsl:when>
					<xsl:when test="@filter='equal'">
						<xsl:choose>
							<xsl:when test="@filter-uncase='true'">
								UPPER(pager.<xsl:value-of select="$vza-id"/>)='<xsl:value-of select="sw:sql-escape(sw:uc(@value))"/>'
							</xsl:when>
							<xsl:otherwise>
								pager.<xsl:value-of select="$vza-id"/>='<xsl:value-of select="sw:sql-escape(@value)"/>'
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="(@data-type='str' or  @data-type='ip') and @filter='auto'">
						UPPER(pager.<xsl:value-of select="$vza-id"/>) like UPPER('%<xsl:value-of select="sw:sql-escape(@value)"/>%')
					</xsl:when>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="where-conds">
			<xsl:copy-of select="$where-cols"/>
			<xsl:variable name="cond-cols" select="$filter/ui:cols/ui:column/ui:cond"/>
			<xsl:if test="$cond-cols">
				<xsl:variable name="conds">
					<xsl:for-each select="$cond-cols">
						<xsl:choose>
							<xsl:when test="../@select-only-filtered='true' and not(../@value)">
								<!-- skip column conditions with @select-only-filtered="true" -->
							</xsl:when>
							<xsl:when test="@expr='&lt;'">
								<cond>pager.<xsl:value-of select="sw:if(@vza-id, @vza-id, ../@vza-id)"/>&lt;<xsl:value-of select="sw:sql-escape(.)"/></cond>
							</xsl:when>
							<xsl:when test="@expr='&lt;='">
								<cond>pager.<xsl:value-of select="sw:if(@vza-id, @vza-id, ../@vza-id)"/>&lt;=<xsl:value-of select="sw:sql-escape(.)"/></cond>
							</xsl:when>
							<xsl:when test="@expr='&gt;'">
								<cond>pager.<xsl:value-of select="sw:if(@vza-id, @vza-id, ../@vza-id)"/>&gt;<xsl:value-of select="sw:sql-escape(.)"/></cond>
							</xsl:when>
							<xsl:when test="@expr='!='">
								<cond>pager.<xsl:value-of select="sw:if(@vza-id, @vza-id, ../@vza-id)"/>!='<xsl:value-of select="sw:sql-escape(.)"/>'</cond>
							</xsl:when>
							<xsl:when test="@expr='='">
								<cond>pager.<xsl:value-of select="sw:if(@vza-id, @vza-id, ../@vza-id)"/>='<xsl:value-of select="sw:sql-escape(.)"/>'</cond>
							</xsl:when>
						  <xsl:when test="@expr='like'">
						  	<cond>pager.<xsl:value-of select="sw:if(@vza-id, @vza-id, ../@vza-id)"/> like '<xsl:value-of select="sw:sql-escape(.)"/>'</cond>
						  </xsl:when>
						  <xsl:when test="@expr='in-unit-recursive'">
						  	<cond>pager.<xsl:value-of select="sw:if(@vza-id, @vza-id, ../@vza-id)"/> in ( unit '<xsl:value-of select="sw:sql-escape(.)"/>',recursive)</cond>
						  </xsl:when>
						  <xsl:when test="@expr='in'">
						  	<cond>
						  	(
						  		<xsl:for-each select="ui:cond-value">
						  			<xsl:if test="position()!=1"> OR </xsl:if>
						  			pager.<xsl:value-of select="sw:if(../@vza-id, ../@vza-id, ../../@vza-id)"/>='<xsl:value-of select="."/>'
						  		</xsl:for-each>
						  		<xsl:if test="not(ui:cond-value)">
						  			1=2
						  		</xsl:if>
						  	)
						  	</cond>
						  	<!--
								<cond>pager.<xsl:value-of select="../@vza-id"/> in (
								<xsl:for-each select="ui:cond-value">
									<xsl:if test="position()!=1">,</xsl:if>
									'<xsl:value-of select="."/>'
								</xsl:for-each>
								)</cond>
								-->
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="conditions" select="exsl:node-set($conds)/cond"/>
				<xsl:if test="string-length($where-cols)!=0 and $conditions">
					AND
				</xsl:if>
				<xsl:for-each select="$conditions">
					<xsl:if test="position()&gt;1	">
						AND
					</xsl:if>
					<xsl:value-of select="."/>
				</xsl:for-each>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="where">
			<xsl:value-of select="$where-conds"/>
			<xsl:if test="$sql-where!=''">
				<xsl:if test="$where-conds!=''"> AND </xsl:if>
				<xsl:value-of select="$sql-where"/>
			</xsl:if>
		</xsl:variable>




				<!-- Prepare data query-->
				<xsl:variable name="vza-request">
					<packet>
						<xsl:if test="$forward-to-master">
							<!-- Forward request to master optionally with token from current PP session -->
							<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>
							<xsl:if test="$auth-type='veuser' or $auth-type='pleskadmin'">
								<vzcpauth><token/></vzcpauth>
							</xsl:if>
						</xsl:if>
						<target>pager</target>
						<data>
							<pager>
								<select>
									<xsl:copy-of select="$fields"/>
									<!-- Prepare Sorting -->
									<xsl:variable name="sort-col" select="$filter/ui:cols/ui:column[@id=$sort]"/>
									<xsl:variable name="sort-fields">
										<xsl:if test="$sort-col">
											<sort>
												<field><xsl:value-of select="$sort-col/@vza-id"/></field>
												<ord><xsl:value-of select="$sort-col/@vza-sort-ord"/></ord>
											</sort>
										</xsl:if>
										<xsl:for-each select="$filter/ui:cols/ui:column[@vza-sort-with=$sort]/@vza-id">
											<sort>
												<field><xsl:value-of select="."/></field>
												<ord><xsl:value-of select="@vza-sort-ord"/></ord>
											</sort>
										</xsl:for-each>
									</xsl:variable>
									<!-- Sorting -->
									<xsl:for-each select="exsl:node-set($sort-fields)/sort">
										<xsl:sort select="ord" data-type="number"/>
										<sort>
											<field>pager.<xsl:value-of select="field"/></field>
											<xsl:if test="$filter/ui:sort/ui:direction!='asc'">
												<descending/>
											</xsl:if>
										</sort>
									</xsl:for-each>
									<!-- Sorting -->
									<!-- old
									<sort>
										<field>pager.<xsl:value-of select="$filter/ui:cols/ui:column[@id=$sort]/@vza-id"/></field>
										<xsl:if test="$filter/ui:sort/ui:direction!='asc'">
											<descending/>
										</xsl:if>
									</sort>
									<xsl:for-each select="$filter/ui:cols/ui:column[@vza-sort-with=$sort]/@vza-id">
										<sort>
											<field>pager.<xsl:value-of select="."/></field>
											<xsl:if test="$filter/ui:sort/ui:direction!='asc'">
												<descending/>
											</xsl:if>
										</sort>
									</xsl:for-each>
									-->
									<!-- Limits -->
									<limit>
										<size><xsl:value-of select="$filter/ui:coords/@limit"/></size>
										<offset><xsl:value-of select="$filter/ui:coords/@from - 1"/></offset>
									</limit>
									<count>1</count>
									<xsl:if test="string-length($where)">
										<where>
											<xsl:value-of select="sw:base64-encode($where)"/>
										</where>
									</xsl:if>
									<!-- /Filter -->
								</select>
							</pager>
						</data>
					</packet>
				</xsl:variable>

		<xsl:variable name="browse-result" select="browse:pager-get-rows($vza-request, $filter/ui:cols/ui:column)"/>
		<sw:die test="$browse-result/error and $die-on-error">
			Error was occured in VZA Pager Operator:
			<sw:text lang="C" disable-text-normalize="indent"  select="$browse-result"/>
		</sw:die>

		<xsl:copy-of select="$browse-result"/>

		<xsl:if test="$cookies">
			<ui:cookies>
				<xsl:copy-of select="$cookies"/>
			</ui:cookies>
		</xsl:if>

		<xsl:copy-of select="$filter/*[name()!='ui:coords']"/>
		<xsl:variable name="browse-rows" select="$browse-result/ui:browse-rows"/>
  	<ui:coords total="{sw:if($browse-rows/@total,$browse-rows/@total,0)}" count="{sw:if($browse-rows/@count,$browse-rows/@count,0)}">
			<xsl:copy-of select="$filter/ui:coords/@from"/>
			<xsl:copy-of select="$filter/ui:coords/@limit"/>
		</ui:coords>

 	</xsl:template>
 	<!-- /Filter Rowset -->

</xsl:stylesheet>
