<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func check"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"	  
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:check		="http://www.swsoft.com/xsl/cp/check"
	xmlns:local 	="http://www.swsoft.com/xsl/cp/local"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:time  ="http://www.swsoft.com/xsl/cp/time"
>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/date-time.xsl"/>	  

  <func:function name="check:res">
  	<xsl:param name="str"/>
  	<xsl:param name="measure"/>
  	<xsl:param name="allow-complex" select="false()"/>
		<xsl:choose>
			<xsl:when test="true()"><!-- todo: remove it in VZ 2.6.1 release -->
				<func:result select="$str='' or sw:re-test($str,'^[0-9]+$') or ($allow-complex and sw:re-test($str,'^[0-9]+:[0-9]+$'))"/>
			</xsl:when>
			<xsl:when test="$measure='1K-blocks'">				
				<func:result select="check:kb-str(sw:lc($str))"/>
			</xsl:when>
			<xsl:when test="$measure='bytes'">				
				<func:result select="check:kb-str(sw:lc($str))"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$str='' or sw:re-test($str,'^[0-9]+$')"/>
			</xsl:otherwise>
		</xsl:choose>
  </func:function>

  <!-- check input time -->
  <func:function name="check:time">
	<xsl:param name="str"/>
	<xsl:variable name="err" select="time:web-validate(concat('2000-01-01',' ',$str))"/>
	<func:result select="$err"/>
  </func:function>
 
  <func:function name="check:kb-str">
  	<xsl:param name="str"/>  	
  	<func:result select="sw:re-test($str,'^[0-9]+( )?(kb|mb|gb|tb){1}$')"/>
  </func:function>

  
  <!-- check file name-->
  <func:function name="check:fileName">
  	<xsl:param name="name"/>
  	<func:result select="sw:re-test($name,'^[^ ^\^/]{1}[^\^/]{0,253}$')"/>
  </func:function>
  
  <!-- check IP -->
  <func:function name="check:ip">
  	<xsl:param name="ip"/>
  	<xsl:variable name="oct" select="sw:split($ip,'.','o')"/>
  	<xsl:choose>
  		<xsl:when test="count($oct)!=4">	
  			<func:result select="false()"/>
  		</xsl:when>
  		<xsl:when test="count($oct[ number(.)&gt;=0 and number(.)&lt;256])!=4">	
  			<func:result select="false()"/>
  		</xsl:when>
  		<xsl:otherwise>
	  		<func:result select="true()"/>
	  	</xsl:otherwise>
  	</xsl:choose>  	
  </func:function>

  <!-- check PORT -->
  <func:function name="check:port">
  	<xsl:param name="port"/>
  	<xsl:choose>
  		<xsl:when test="check:num($port) and ($port &gt;= 1 and $port &lt;= 65535)">	
  			<func:result select="true()"/>
  		</xsl:when>
  		<xsl:otherwise>
	  		<func:result select="false()"/>
	  	</xsl:otherwise>
  	</xsl:choose>  	
  </func:function>
  
	<!-- 
		Check virtual network ID pattern
		Parameters:
			platform-ref - platform reference
			vn-id - string with network ID
		Returns: boolean
	-->
	<func:function name="check:network-id">
		<xsl:param name="platform-ref"/>
		<xsl:param name="vn-id"/>
		<func:result select="check:matches-voc-pattern($platform-ref,$vn-id,'pattern.network_id')"/>
	</func:function>
  
  <func:function name="check:matches-voc-pattern">
  	<xsl:param name="platform-ref"/>
  	<xsl:param name="value"/>
  	<xsl:param name="name"/>
  	
  	<func:result select="not(check:get-voc-pattern-match-error($platform-ref,$value, $name))" />
  </func:function>
  
  <func:function name="check:get-voc-pattern-match-error">
  	<xsl:param name="platform-ref" />
  	<xsl:param name="value" />
  	<xsl:param name="name" />

  	<xsl:variable name="str" select="string($value)" />

  	<xsl:variable name="pattern" select="voc:get-pattern($platform-ref,$name)" />
  	<sw:die test="not($pattern)">
  		Can't load regexp pattern '<xsl:value-of select="$name"/>'
  	</sw:die>

  	<xsl:variable name="result-rtf">
  		<xsl:choose>
  			<xsl:when test="string-length($str) &lt; $pattern/min">
  				<short/>
  				<xsl:copy-of select="$pattern"/> 
  			</xsl:when>
  			<xsl:when test="string-length($str) &gt; $pattern/max">
  				<long/>
  				<xsl:copy-of select="$pattern"/> 
  			</xsl:when>
  			<xsl:when test="not(sw:re-test($str, $pattern/regexp,'m'))">
  				<wrong/>
    			<xsl:copy-of select="$pattern"/> 
  			</xsl:when>
  		</xsl:choose>
  	</xsl:variable>
  	
  	<func:result select="exsl:node-set($result-rtf)/*" />
  </func:function>
  
  <!-- check hostname -->
  <func:function name="check:hostname">
	  <xsl:param name="platform-ref"/>
  	<xsl:param name="hostname"/>
    	
  	<func:result select="check:matches-voc-pattern($platform-ref,$hostname, 'pattern.hostname')" />
  </func:function>
  
   <!-- check hostname -->
  <func:function name="check:search-domain">
	  <xsl:param name="platform-ref"/>
  	<xsl:param name="value"/>
    	
  	<func:result select="check:matches-voc-pattern($platform-ref,$value, 'pattern.search_domain')" />
  </func:function> 
  
    
  <!-- check hostname and receive error full details -->
  <func:function name="check:hostname-ext">
	  <xsl:param name="platform-ref"/>
  	<xsl:param name="hostname"/>
    	
  	<xsl:variable name="error" select="check:get-voc-pattern-match-error($platform-ref,$hostname, 'pattern.hostname')" />
  	<func:result select="$error"/>
  	
  </func:function>
  
  <!-- check hostname -->
  <func:function name="check:env-name">
	  <xsl:param name="platform-ref"/>
  	<xsl:param name="name"/>
  	
  	<func:result select="check:matches-voc-pattern($platform-ref,$name, 'pattern.env_name')"/>
  </func:function>

  <!-- check domain name -->
  <func:function name="check:domain">
  	<xsl:param name="domain"/>
  	<xsl:choose>
  		<xsl:when test="string-length($domain)>255">	
  			<func:result select="false()"/>
  		</xsl:when>
  		<xsl:when test="check:ip($domain)">	<!-- domain can not be IP ! -->
  			<func:result select="false()"/>
  		</xsl:when>
  		<xsl:when test="$domain='localhost.rev'">	<!-- thanks to PSA for it! -->
  			<func:result select="true()"/>
  		</xsl:when>  		
  		<xsl:otherwise>
  			<func:result select="sw:re-test($domain,'^[A-Za-z0-9]([A-Za-z0-9-]{0,61}[A-Za-z0-9]){0,1}(\.[A-Za-z0-9]([A-Za-z0-9-]{0,61}[A-Za-z0-9]){0,1}){1,}$')"/>
  		</xsl:otherwise>
  	</xsl:choose>
  </func:function>
  
  <!-- check email name -->
  <func:function name="check:email-name">  	
  	<xsl:param name="name"/>
  	<func:result select="sw:re-test($name,'^[_+A-Za-z0-9-]+((\.)[+A-Za-z0-9-]+)*$')"/>
  </func:function>
  
  <!-- check email address-->
  <func:function name="check:email">
  	<xsl:param name="name"/>
  	<xsl:variable name="words" select="sw:split($name,'@','w')"/>
  	<xsl:choose>
  		<xsl:when test="count($words)!=2">	
  			<func:result select="false()"/>
  		</xsl:when>
  		<xsl:otherwise>
  			<func:result select="check:email-name($words[1]) and check:domain($words[2])"/>
  		</xsl:otherwise>
  	</xsl:choose>
  </func:function>

  
</xsl:stylesheet>
