<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred jobs xsi check"
  xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl				="http://exslt.org/common"
  xmlns:sw					="http://www.swsoft.com/xsl/cp"
  xmlns:error				="http://www.swsoft.com/xsl/cp/error"
  xmlns:func				="http://exslt.org/functions"
	xmlns:cred 				="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"
  xmlns:browse			="http://www.swsoft.com/xsl/cp/browse" 	
	xmlns:jobs				="http://www.swsoft.com/xsl/cp/jobs"
	xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"	
	xmlns:date				="http://exslt.org/dates-and-times"	
	xmlns:xsi					="http://www.w3.org/2001/XMLSchema-instance"	
	xmlns:vza-scheduler		="http://www.swsoft.com/webservices/vzl/4.0.0/scheduler"
	xmlns:time				="http://www.swsoft.com/xsl/cp/time"		
	xmlns:check		="http://www.swsoft.com/xsl/cp/check"
>
  <sw:include href="/lib/common.xsl"/>
  <sw:include href="/lib/cred.xsl"/>
  <sw:include href="/lib/date-time.xsl"/>	  
  <sw:include href="/lib/core/check-funcs.xsl"/>	  
  <sw:include href="/lib/swa/scheduler.xsl"/>

  <xsl:output method="xml"/>

	<!--*********************************** PUBLIC FUNCTIONS ****************************-->

	<!-- Restore timer date and time -->	
	<xsl:template name="jobs:restore-timer-time">
		<time>
			<xsl:value-of select="sw:param('time')"/>
		</time>
		<start-date>
			<xsl:value-of select="sw:param('start_date')"/>
		</start-date>			
	</xsl:template>	
	
	<!-- Check job timer time and date
		Arguments
			timer
				time
				date
	-->
	<xsl:template name="jobs:check-timer-time">
		<xsl:param name="timer"/>
		
		<!-- Check time -->
		<xsl:choose>
			<!-- check presence -->
			<xsl:when test="string($timer/time)=''">
				<xsl:if test="error:put(sw:text('Please specify the task time.'),'','time')"/>
			</xsl:when>
			<!-- Check validity-->
			<xsl:when test="check:time($timer/time)!=''">
				<xsl:if test="error:put(sw:text('The time value is invalid. Please correct the task time. The valid format is HH:MM.'),'','time')"/>
			</xsl:when>
		</xsl:choose>
		<!-- /Check time -->
		
		<!-- Check start date-->
		<xsl:choose>
			<!-- check presence -->
			<xsl:when test="string($timer/start-date)=''">
				<xsl:if test="error:put(sw:text('Please specify the task date.'),'','start_date')"/>
			</xsl:when>
			<!-- Check validity-->
			<xsl:when test="time:web-validate($timer/start-date)!=''">
				<xsl:variable name="err">
					<sw:text>
						<xsl:with-param name="format" select="$global-date-format"/>
						The date value is invalid. Please correct the task date. The valid format is %{format}.
					</sw:text>
				</xsl:variable>
				<xsl:if test="error:put($err,'','start_date')"/>
			</xsl:when>
		</xsl:choose>
		<!-- /Check start date-->	
	</xsl:template>			
	
	<!-- Show job timer time and date
		Arguments
			timer
				time
				date
	-->
	<xsl:template name="jobs:edit-timer-time">
		<xsl:param name="timer"/>
		<xsl:param name="offset" select="''"/>	
				
		<ui:row table-width="none">
			<ui:cell-label show-aster="true">
				<xsl:if test="$offset!=''">
					<xsl:attribute name="offset"><xsl:value-of select="$offset"/></xsl:attribute>
				</xsl:if>			
				<sw:text>Time</sw:text>
			</ui:cell-label>
			<ui:cell-input id="time" maxlength="8" width="10"
				value="{$timer/time}"
			>
				&#160;<sw:text>format HH:MM</sw:text>
			</ui:cell-input>
		</ui:row>				
		<!-- /Start -->
		<ui:row table-width="none">
			<ui:cell-label show-aster="true">
				<xsl:if test="$offset!=''">
					<xsl:attribute name="offset"><xsl:value-of select="$offset"/></xsl:attribute>
				</xsl:if>			
				<sw:text>Date</sw:text>
			</ui:cell-label>
			<ui:cell type="date" id="start_date" 
				value="{$timer/start-date}"
			>					
				&#160;<sw:text><xsl:with-param name="format" select="$global-date-format"/>format %{format}</sw:text>
			</ui:cell>
		</ui:row>				
	</xsl:template>

	<func:function name="jobs:categories">			
		<xsl:variable name="res-rtf">
			<ui:filter-option value="vz.backup.ves" icon="backup_restore_16.gif">
				<xsl:attribute name="title">
					<sw:text>Back Up Container(s)</sw:text>
				</xsl:attribute>
			</ui:filter-option>		
			<ui:filter-option value="vz.restart.ves" icon="restart_16.gif">
				<xsl:attribute name="title">
					<sw:text>Restart Container(s)</sw:text>
				</xsl:attribute>
			</ui:filter-option>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)/ui:filter-option"/>		
	</func:function>
	
	<!--
		Arguments
			none
		Result
		 <job> or <error>, look local:list-jobs() for <job> details
	-->
	<func:function name="jobs:list">		
		<func:result select="local:list-jobs()"/>
	</func:function>
	
	<!--
		Arguments
			Job ID - string ID
		Result
		 <job> or <error>, look local:list-jobs() for <job> details
	-->
	<func:function name="jobs:find-by-id">		
		<xsl:param name="job-id"/>
		
		<xsl:choose>
			<xsl:when test="$job-id!=''">
				<func:result select="local:list-jobs($job-id)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>

	<!--
		Arguments
			Job
		Result
			packet in RTF format
	-->
	<xsl:template name="jobs:construct-update-packet">		
		<xsl:param name="job"/>
		
		<packet 
			xmlns:xsi ="http://www.w3.org/2001/XMLSchema-instance"	
			xmlns:vza-scheduler ="http://www.swsoft.com/webservices/vzl/4.0.0/scheduler"	
		>
			<target>scheduler</target>
			<xsl:choose>
				<!-- Add Task -->
				<xsl:when test="not($job/id)">					
					<cookie>
						<msg>
							<ok><sw:text>The task has been added successfully.</sw:text></ok>
							<error><sw:text>Failed to add the task.</sw:text></error>
						</msg>
						<redirect-prev/>       
					</cookie>		
					<data>
						<scheduler>
							<add>
								<xsl:call-template name="jobs:construct-task-from-job">
									<xsl:with-param name="job" select="$job"/>
								</xsl:call-template>
							</add>
						</scheduler>
					</data>
				</xsl:when>
				<!-- /Add Task -->
				<!-- Update Task -->
				<xsl:otherwise>					
					<cookie>					
						<msg>
							<ok><sw:text>The task has been updated successfully.</sw:text></ok>
							<error><sw:text>Failed to update the task.</sw:text></error>
						</msg>
						<redirect-prev/>       
					</cookie>		
					<data>
						<scheduler>
							<update>
								<xsl:call-template name="jobs:construct-task-from-job">
									<xsl:with-param name="job" select="$job"/>
								</xsl:call-template>
							</update>
						</scheduler>
					</data>
				</xsl:otherwise>
				<!-- /Update Task -->
			</xsl:choose>
		</packet>		
	</xsl:template>
	
	<!--
		Find the next job for selected  VE
		Arguments:
			ve-eid - VE Eid, required
			category - filter by category, optional
		Result:
			ref to job nodeset
	-->
	<func:function name="jobs:find-next-for-ve">
		<xsl:param name="ve-eid"/>
		<xsl:param name="filter-category" select="false()"/>
	
		<xsl:variable name="ve-jobs" select="jobs:list()[
			(not($filter-category) or category=$filter-category)
			and ves/eid=$ve-eid and enabled='true' and next-start
		]"/>
		
		<xsl:variable name="first-id">
			<xsl:for-each select="$ve-jobs">
				<xsl:sort select="next-start"/>
				<xsl:if test="position()=1"><xsl:value-of select="id"/></xsl:if>
			</xsl:for-each>
		</xsl:variable>
		
		<xsl:choose>
			<xsl:when test="$first-id!=''">
				<func:result select="$ve-jobs[id=$first-id]"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	
	
	<!--
		Arguments
			Job
		Result
			task nodeset in RTF format
	-->
	<xsl:template name="jobs:construct-task-from-job">		
		<xsl:param name="job"/>
		
		<task>
			<xsl:if test="$job/id!=''">
				<id><xsl:value-of select="$job/id"/></id>
			</xsl:if>
			<category><xsl:value-of select="$job/category"/></category>
			<title><xsl:value-of select="sw:base64-encode($job/title)"/></title>
			<description><xsl:value-of select="sw:base64-encode($job/description)"/></description>	
			<disabled><xsl:value-of select="sw:if($job/enabled='true','false','true')"/></disabled>
			<packet>
				<xsl:value-of select="sw:base64-encode(sw:text(local:job2task-internal-packet($job)))"/>
			</packet>
			<triggers>
				<xsl:call-template name="local:job2task-trigger">
					<xsl:with-param name="job" select="$job"/>
				</xsl:call-template>
			</triggers>
		</task>
		
	</xsl:template>
	
	
	<!--*********************************** LOCAL FUNCTIONS ****************************-->

	<!--
		Arguments
			Job IDS - string ID (OPTIONAL)
		Result
			<job> or <error>
		
		Details
			<job>
				// BASE R/W DATA
				<id>
				<source>
				<category>
				<title>
				<description>
				<enabled/>				
				// RECURRENCE R/W DATA
				<timer>
					<time>23:59</time>
					<start-date>31/12/2007</start-date>
					<end-mode> none/date
					<end-date> 31/12/2007				
					<recurrence-type>  none|daily|weekly|yearly
					<daily-type> every|weekday|sunday
					<daily-every-days>1</daily-every-days>
					<weekly-weeks>1</weekly-weeks>
					<weekly-day>[] 1,2,3....7
					<monthly-mode>day</monthly-mode>
					<monthly-day-day><xsl:value-of select="$now-day"/></monthly-day-day>
					<monthly-day-month><xsl:value-of select="$now-month"/></monthly-day-month>
					<monthly-ext-month>1</monthly-ext-month>
					<yearly-mode>every</yearly-mode>
					<yearly-every-month><xsl:value-of select="$now-month"/></yearly-every-month>
					<yearly-every-day><xsl:value-of select="$now-day"/></yearly-every-day>
				</timer>
				// VES R/W DATA 
				<ves>
					<eid>
				</ves>
				// READ-ONLY CALCULATED DATA
				<next-start>  format - xs:dateTime or no node
				// READ-ONLY DECODED DATA
				<decoded-packet/>
				// ACTION SPECIFIC OPTIONS
				<specific>
					// BACKUP OPTIONS
					<backup-options> -nodeset with backup core options. Look vt/backups-core.xsl/core-options/defaults for details.
						...
					</backup-options>
					<backup-exclude>
						<hidden>true</hidden>
						<system>true</system>				
						<path[]>
					</backup-exclude>
					<backup-include>
						<path[]>
					</backup-include>					
				</specific>
			</job>		
	-->
	<func:function name="local:list-jobs">		
		<xsl:param name="filter-by-id" select="/.."/>
		
		<sw:die test="$filter-by-id and $filter-by-id=''">
			job-id argument should be empty nodeset or some string
		</sw:die>
		
		<xsl:variable name="vza-tasks" select="local:scheduler-list($filter-by-id)"/>
		<xsl:choose>
			<xsl:when test="not($vza-tasks)">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:when test="name($vza-tasks)='error'">
				<func:result select="$vza-tasks"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="jobs-rtf">
					<xsl:for-each select="$vza-tasks">
						<xsl:variable name="decoded-packet" select="sw:base64-decode(packet)"/>
						<xsl:variable name="denoded-packet" select="sw:node-set($decoded-packet, true())"/>
						<!-- Transform VZA ugly data to VZCC shinning format -->
						<job>
							<xsl:copy-of select="id"/>
							<category><xsl:value-of select="category"/></category>
							<enabled><xsl:value-of select="sw:if(disabled='true' or disabled='1','false','true')"/></enabled>
							<title>
								<xsl:copy-of select="sw:base64-decode(title)"/>							
							</title>
							<description>
								<xsl:copy-of select="sw:base64-decode(description)"/>							
							</description>
							<decoded-packet>
								<xsl:copy-of select="$denoded-packet"/>
							</decoded-packet>
							<!-- Process triggers -->
							<timer>
								<xsl:copy-of select="local:task2recurrence(.)"/>
							</timer>
							<!-- Process task_info internal data -->
							<xsl:if test="next_start">
								<next-start><xsl:copy-of select="sw:vzatime2time(next_start)"/></next-start>		
							</xsl:if>
							<!-- Reconstruct operation-specific options -->
							<specific>
								<xsl:copy-of select="local:packet2specific-options(category,$denoded-packet/packet)"/>
							</specific>
							<!-- Reconstruct "ves" nodeset -->
							<ves>
								<xsl:copy-of select="local:packet2eids(category,$denoded-packet/packet)"/>
							</ves>
						</job>
						<!-- /Transform VZA ugly data to VZCC shinning format -->
					</xsl:for-each>
				</xsl:variable>
				<func:result select="exsl:node-set($jobs-rtf)/job"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>

	<!--
		Get EIDs from job internal packet.
	-->
	<func:function name="local:packet2eids">			
		<xsl:param name="category"/>	
		<xsl:param name="packet"/>
		
		<xsl:choose>
			<xsl:when test="$category='vz.backup.ves'">
				<func:result select="$packet/data/backupm/backup_env/env_list/eid"/>		
			</xsl:when>
			<xsl:when test="$category='vz.restart.ves'">
				<func:result select="$packet/data/vzaenvm/restart/eid"/>		
			</xsl:when>
			<xsl:otherwise>
				<func:result select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	<!--
		Get operation-specific options from job internal packet.
	-->
	<func:function name="local:packet2specific-options">			
		<xsl:param name="category"/>	
		<xsl:param name="packet"/>
		
		<xsl:choose>
			<xsl:when test="$category='vz.backup.ves'">
				<func:result>
					<xsl:variable name="data" select="$packet/data/backupm/backup_env"/>		
					<backup-options>
						<storage-server-eid>
							<xsl:if test="$data/backup_server/protocol='agent'">
								<xsl:value-of select="$data/backup_server/address"/>
							</xsl:if>
						</storage-server-eid>
						<backup-type>
							<xsl:if test="$data/backup_options/type!=''">
								<xsl:value-of select="$data/backup_options/type"/>
							</xsl:if>
						</backup-type>
						<compression-level>
							<xsl:if test="$data/backup_options/compression!=''">
								<xsl:value-of select="$data/backup_options/compression"/>
							</xsl:if>
						</compression-level>
					</backup-options>
					<backup-exclude>
						<xsl:for-each select="$data/backup_options/exclude_list/path">
							<path><xsl:value-of select="sw:base64-decode(.)"/></path>
						</xsl:for-each>
						<xsl:if test="$data/backup_options/exclude_list/system">
							<system>true</system>
						</xsl:if>
						<xsl:if test="$data/backup_options/exclude_list/hidden">
							<hidden>true</hidden>
						</xsl:if>						
					</backup-exclude>
					<backup-include>
						<xsl:for-each select="$data/backup_options/include_list/path">
							<path><xsl:value-of select="sw:base64-decode(.)"/></path>
						</xsl:for-each>
					</backup-include>					
				</func:result>
			</xsl:when>
			<xsl:when test="$category='vz.restart.ves'">
				<func:result/>		
			</xsl:when>
			<xsl:otherwise>
				<func:result/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
		
	
	<!--
		Transform "VZA task triggers" to "VZCP job recurrence"
	-->
	<func:function name="local:task2recurrence">			
		<xsl:param name="task"/>
		
		<!-- Preselect some variables -->
		<xsl:variable name="trg" select="$task/triggers/trigger"/>
		<xsl:variable name="trigger-type" select="substring-before(substring-after($trg/@xsi:type,':'),'_')"/>
		<!--<sw:die test="not($trigger-type='' or $recurrence-type='daily' or $recurrence-type='weekly' or $recurrence-type='once')">
			Unsupported trigger type '<xsl:value-of select="$recurrence-type"/>'
		</sw:die>-->
		<xsl:variable name="recurrence-type" select="sw:if($trigger-type='once','none',$trigger-type)"/>
		<!-- /Preselect some variables -->
		
		<func:result>
			<!-- Transform start_time -->
			<xsl:if test="true()">
				<xsl:variable name="time" select="sw:vzatime2time($trg/start_time)"/>
				<time>
					<xsl:value-of select="substring(date:time($time),1,5)"/>
				</time>
				<start-date>
					<xsl:value-of select="time:time2web($time)"/>
				</start-date>
			</xsl:if>
			<!-- /Transform start_time -->
			<!-- Transform end_time -->
			<xsl:if test="true()">
				<xsl:choose>
					<xsl:when test="$trg/end_time">
						<xsl:variable name="time" select="sw:vzatime2time($trg/end_time)"/>
						<end-date>
							<xsl:value-of select="time:time2web($time)"/>
						</end-date>
						<end-mode>date</end-mode>
					</xsl:when>
					<xsl:otherwise>
						<end-mode>none</end-mode>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<!-- /Transform end_time -->
			<!-- Copy  recurrence-type -->
			<recurrence-type><xsl:value-of select="$recurrence-type"/></recurrence-type>
			<!-- Transform TRIGGER -->
			<xsl:choose>
				<!-- Daily -->
				<xsl:when test="$recurrence-type='daily'">
					<xsl:choose>
						<xsl:when test="$trg/days_interval">
							<daily-every-days><xsl:value-of select="$trg/days_interval"/></daily-every-days>
							<daily-type>every</daily-type>
						</xsl:when>
						<xsl:when test="$trg/workdays">
							<daily-type>weekday</daily-type>
						</xsl:when>
						<xsl:when test="$trg/weekends">
							<daily-type>sunday</daily-type>
						</xsl:when>
						<xsl:otherwise>
							<sw:die>
								Uknown triggery daily format.
							</sw:die>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<!-- /Daily -->
				<!-- Weekly -->
				<xsl:when test="$recurrence-type='weekly'">
					<weekly-weeks><xsl:value-of select="$trg/weeks_interval"/></weekly-weeks>
					<xsl:for-each select="$trg/day_of_week">
						<weekly-day><xsl:value-of select="sw:if(.=0,7,.)"/></weekly-day><!-- Sunday should be 7, not 0 -->
					</xsl:for-each>
				</xsl:when>
				<!-- /Weekly -->
			</xsl:choose>
			<!-- /Transform TRIGGER -->
		</func:result>
	</func:function>
	
	<func:function name="local:scheduler-list">		
		<xsl:param name="filter-id" select="/.."/>

		<xsl:variable name="req">
			<packet>
				<target>scheduler</target>
				<data>
					<scheduler>
						<list>
							<xsl:if test="$filter-id">
								<id><xsl:value-of select="$filter-id"/></id>
							</xsl:if>
						</list>
					</scheduler>
				</data>
			</packet>
		</xsl:variable>	
		
		<xsl:variable name="data" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="error" select="$data/error|$data/scheduler/error"/>
		<xsl:choose>
			<xsl:when test="$error">
				<func:result select="$error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$data/scheduler/task"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>	

	
	<!-- Transform VZCP Job to VZA Task trigger -->
	<xsl:template name="local:job2task-trigger">
		<xsl:param name="job"/>
		
		<xsl:variable name="timer" select="$job/timer"/>
				
		<!-- post timer recurrency -->
		<trigger>
		
			<!-- Specify trigger type -->
			<xsl:variable name="trigger-type" select="sw:if($timer/recurrence-type='none','once',$timer/recurrence-type)"/>
			<xsl:attribute name="xsi:type">vza-scheduler:<xsl:value-of select="$trigger-type"/>_triggerType</xsl:attribute>
			
			<!-- Copy start and end times -->
			<xsl:copy-of select="local:job-timer2task-start-end-time($timer)"/>

			<xsl:choose>
				<!-- Daily -->
				<xsl:when test="$timer/recurrence-type='daily'">
					<xsl:copy-of select="local:job-timer2task-daily-trigger($timer)"/>
				</xsl:when>
				<!-- /Daily -->
				<!-- Weekly -->
				<xsl:when test="$timer/recurrence-type='weekly'">
					<xsl:copy-of select="local:job-timer2task-weekly-trigger($timer)"/>
				</xsl:when>
				<!-- /Weekly -->
			</xsl:choose>
			
		</trigger>
		<!-- /post timer recurrency -->
		
	</xsl:template>
	
	<!-- Convert JobTimer time & start-date to VZA Task start time -->
	<func:function name="local:job-timer2task-start-end-time">
		<xsl:param name="timer"/>
				
		<func:result>
			<start_time>
				<xsl:value-of select="time:web2vzatime($timer/start-date, $timer/time)"/>		
			</start_time>
			<xsl:if test="$timer/end-mode='date'">
				<end_time>
					<xsl:variable name="time-src" select="date:add(time:web2time($timer/end-date),'PT23H59M59S')"/>		
					<xsl:value-of select="sw:time2vzatime($time-src)"/>
				</end_time>
			</xsl:if>
		</func:result>
	
	</func:function>
	
	<!-- Convert JobTimer daily recurence & VZA Task triger -->
	<func:function name="local:job-timer2task-daily-trigger">
		<xsl:param name="timer"/>
		
		<func:result>
			<xsl:choose>
				<xsl:when test="$timer/daily-type='every'">	
					<days_interval>			
						<xsl:value-of select="$timer/daily-every-days"/>
					</days_interval>
				</xsl:when>
				<xsl:when test="$timer/daily-type='weekday'">	
					<workdays/>
				</xsl:when>
				<xsl:when test="$timer/daily-type='sunday'">	
					<weekends/>
				</xsl:when>
			</xsl:choose>
		</func:result>
	
	</func:function>
	
	
	<!-- Convert JobTimer weekly recurence & VZA Task triger -->
	<func:function name="local:job-timer2task-weekly-trigger">
		<xsl:param name="timer"/>
		
		<func:result>
			<weeks_interval>			
				<xsl:value-of select="$timer/weekly-weeks"/>
			</weeks_interval>
			<xsl:for-each select="$timer/weekly-day">
				<day_of_week>			
					<xsl:value-of select="."/>
				</day_of_week>
			</xsl:for-each>
		</func:result>
	
	</func:function>
	
	<!-- Generate task internal packet from Job -->
	<func:function name="local:job2task-internal-packet">
		<xsl:param name="job"/>
		<xsl:choose>
			<xsl:when test="$job/category='vz.backup.ves'">				
				<func:result>
					<!--
					<xsl:variable name="backup-set-rtf">
						<xsl:for-each select="$data/backup-envs/eid">
							<backup>
								<ve-eid><xsl:value-of select="."/></ve-eid>
							</backup>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="backup-options-rtf">
					</xsl:variable>
					<xsl:copy-of select="backups:new-action(
						exsl:node-set($backup-set-rtf),
						exsl:node-set($backup-options-rtf),
						local:make-internal-packet-task($data)
					)"/>
					-->
					<packet log="on" progress="on"
						xmlns:ns2="http://www.swsoft.com/webservices/vzl/4.0.0/backupm" 
						xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"					
					>
						<target>backupm</target>
						<cookie>							
							<operation>backup_ve</operation>
							<msg>
								<ok>
									<sw:text>Containers were successfully backed up.</sw:text>
								</ok>
								<error>Failed to backup VEs.</error>
							</msg>
						</cookie>
						<data>
							<backupm>
								<backup_env>
									<env_list>
										<xsl:copy-of select="$job/ves/eid"/>
									</env_list>
									<!-- Setup backup options -->
									<xsl:variable name="backup-options" select="$job/specific/backup-options"/>
									<xsl:variable name="backup-exclude" select="$job/specific/backup-exclude"/>									
									<xsl:variable name="backup-include" select="$job/specific/backup-include"/>									
									<xsl:choose>
										<xsl:when test="$backup-options/storage-server-eid!=''">
											<backup_server>
												<protocol>agent</protocol>
												<address><xsl:value-of select="$backup-options/storage-server-eid"/></address>
											</backup_server>
										</xsl:when>
										<xsl:otherwise>
											<global/>
										</xsl:otherwise>
									</xsl:choose>									
									<backup_options xsi:type="ns2:backup_optionsType">
										<policy>
											<ignore_error/>
											<ignore_unexistent/>
										</policy>
										<!-- Exclude -->
										<xsl:if test="$backup-exclude[path or system='true' or hidden='true']">
											<exclude_list>
												<xsl:for-each select="$backup-exclude/path">
													<path>
														<xsl:value-of select="sw:base64-encode(.)"/>
													</path>
												</xsl:for-each>
												<xsl:if test="$backup-exclude/hidden='true'">
													<hidden/>
												</xsl:if>
												<xsl:if test="$backup-exclude/system='true'">
													<system/>
												</xsl:if>
											</exclude_list>
										</xsl:if>
										<!-- Include -->
										<xsl:if test="$backup-include[path]">
											<include_list>
												<xsl:for-each select="$backup-include/path">
													<path>
														<xsl:value-of select="sw:base64-encode(.)"/>
													</path>
												</xsl:for-each>
											</include_list>
										</xsl:if>										
										<!--- Core Options -->
										<xsl:if test="$backup-options/backup-type!=''">
											<type>
												<xsl:value-of select="$backup-options/backup-type"/>
											</type>
										</xsl:if>
										<xsl:if test="$backup-options/compression-level!=''">
											<compression>
												<xsl:value-of select="$backup-options/compression-level"/>
											</compression>
										</xsl:if>
									</backup_options>
									<!-- /Setup backup options -->
								</backup_env>
							</backupm>
						</data>
						<vzcpauth/>
					</packet>
				</func:result>
			</xsl:when>
			<xsl:when test="$job/category='vz.restart.ves'">				
				<func:result>
					<packet log="on" progress="on">
						<target>vzaenvm</target>
						<xsl:copy-of select="sw:hn-dst($job/ves/eid)"/>
						<cookie>							
							<operation>restart_ve</operation>
							<msg>
								<ok>VEs were successfully restarted.</ok>
								<error>Failed to restart VEs.</error>
							</msg>
						</cookie>
						<data>
							<xsl:for-each select="$job/ves/eid">
								<vzaenvm>
									<restart>
										<xsl:copy-of select="."/>
									</restart>
								</vzaenvm>
							</xsl:for-each>
						</data>
					</packet>
				</func:result>
			</xsl:when>
		</xsl:choose>
	</func:function>

</xsl:stylesheet>
