 <!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl func licenses"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"	
	xmlns:licenses="http://www.swsoft.com/xsl/cp/licenses"	
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
	xmlns:date	="http://exslt.org/dates-and-times"
	xmlns:show	="http://www.swsoft.com/xsl/cp/show"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"	
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"	
>
	<sw:include href="/lib/swa/licensem.xsl"/>	
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/hn-select.xsl"/>			
	<sw:include href="/lib/vocabulary.xsl"/>	

	<xsl:variable name="licenses:def-envelop-file" select="0"/>
	<xsl:variable name="licenses:def-envelop-key" select="1"/>

	<xsl:template name="licenses:view-license">
		<xsl:param name="lic"/>
		<xsl:param name="show-status" select="true()"/>
		<xsl:param name="show-hw" select="true()"/>
		<xsl:param name="hn-eid" select="''"/>
				
		<xsl:variable name="classes" select="licensem:classes()"/>
		<xsl:variable name="statuses" select="licensem:statuses()"/>
		<xsl:variable name="voc" select="voc:get('license',env:make-platform-ref(sw:master-eid()))"/>
		
		<!-- Show well-known parameters -->
		<ui:rows title="{sw:text('License General Information')}">
			<ui:row>
				<ui:cell-label>
					<sw:text>Key Number</sw:text>
				</ui:cell-label>
				<ui:cell-text><xsl:value-of select="$lic/param[id='key_number']/value"/></ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-label>
					<sw:text>Class</sw:text>
				</ui:cell-label>
				<ui:cell-text><xsl:value-of select="licensem:class2text($lic/param[id='CLASS']/value,$classes)"/></ui:cell-text>
			</ui:row>
			<xsl:if test="$hn-eid!=''">	
				<ui:row>
					<ui:cell-label>
						<sw:text>Hardware Node</sw:text>
					</ui:cell-label>
					<ui:cell-text>
						<ui:env-eid-link>
							<xsl:value-of select="$hn-eid"/>
						</ui:env-eid-link>
					</ui:cell-text>
				</ui:row>
			</xsl:if>
			<xsl:if test="$show-hw">
				<ui:row>
					<ui:cell-label>
						<sw:text>Target</sw:text>
					</ui:cell-label>
					<ui:cell-text><xsl:value-of select="licenses:license2hw($lic)"/></ui:cell-text>
				</ui:row>
			</xsl:if>			
			<xsl:if test="$show-status">
				<ui:row>
					<ui:cell-label>
						<sw:text>Status</sw:text>
					</ui:cell-label>
					<ui:cell-text>
						<xsl:variable name="status" select="licensem:status2info($lic/param[id='status']/value,$statuses)"/>
						<ui:license-status icon="{$status/@icon}">
							<xsl:value-of select="$status/@title"/>
						</ui:license-status>
					</ui:cell-text>
				</ui:row>
			</xsl:if>
			<ui:row>
				<ui:cell-label>
					<sw:text>Expiration</sw:text>
				</ui:cell-label>
				<ui:cell-text>
					<ui:license-expiration>
						<xsl:value-of select="$lic/param[id='expiration']/value"/>
					</ui:license-expiration>
				</ui:cell-text>
			</ui:row>
		</ui:rows>
		<ui:rows title="{sw:text('Extended Information')}">
			<!-- Scan vacabulary-known parameters -->
			<xsl:for-each select="$voc[not(
				id='CLASS' or id='status' or id='expiration' or id='key_number' or id='hwid'
			)]">
				<xsl:sort select="sw:uc(short)"/>
				<xsl:variable name="lic-params" select="$lic/param[id=current()/id]"/>
				<xsl:if test="$lic-params">
					<!-- Show params existing in license -->
					<xsl:call-template name="local:show-voc-param">
						<xsl:with-param name="voc-param" select="."/>
						<xsl:with-param name="lic-params" select="$lic/param[id=current()/id]"/>					
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
			<!-- Show all other unknown parameters -->
			<xsl:for-each select="$lic/param[not(id=$voc/id)]">
				<xsl:sort select="sw:uc(id)"/>
				<xsl:call-template name="local:show-uknown-param">
					<xsl:with-param name="lic-param" select="."/>					
				</xsl:call-template>
			</xsl:for-each>
		</ui:rows>
		
	</xsl:template>
	
	<xsl:template name="local:show-voc-param">
		<xsl:param name="voc-param"/>
		<xsl:param name="lic-params"/>
		
		<ui:row>
			<ui:cell-label><xsl:value-of select="sw:text(string($voc-param/short), 'vzagent-vocabulary')"/></ui:cell-label>
			<ui:cell-text>
				<xsl:for-each select="$lic-params">
					<xsl:if test="position()!=1">,&#160;</xsl:if>
					<xsl:choose>
						<xsl:when test="$voc-param/type='boolean'">
							<xsl:value-of select="sw:if(value='1',sw:text('Yes'),sw:text('No'))"/>
						</xsl:when>
						<xsl:when test="$voc-param/type='date'">
							<ui:license-date>
								<xsl:value-of select="value"/>
							</ui:license-date>
						</xsl:when>
						<xsl:when test="$voc-param/type='int'">
							<xsl:value-of select="value"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="value"/>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="$voc-param/measure!=''">
						<xsl:value-of select="'&#160;'"/><sw:text domain="vzagent-vocabulary" select="$voc-param/measure/text()"/>
					</xsl:if>
				</xsl:for-each>
			</ui:cell-text>
		</ui:row>
		
	</xsl:template>
	
	<xsl:template name="local:show-uknown-param">
		<xsl:param name="lic-param"/>
		
		<ui:row>
			<ui:cell-label><xsl:value-of select="sw:text(string($lic-param/id),'vzagent-vocabulary')"/></ui:cell-label>
			<ui:cell-text>
				<xsl:value-of select="value"/>
			</ui:cell-text>
		</ui:row>
		
	</xsl:template>
	
	<!-- Transform license to title of targeted HN -->
	<func:function name="licenses:license2hw">
		<xsl:param name="lic"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$lic/param[id='CLASS']/value='VZGROUP'">
					<sw:text>Any Virtuozzo Hardware Node</sw:text>
				</xsl:when>
				<xsl:when test="$lic/param[id='CLASS']/value='VZSRV'">
					<xsl:variable name="hwid" select="$lic/param[id='hwid']/value"/>
					<xsl:choose>
						<xsl:when test="not($hwid) or $hwid=$licensem:zero-hwid">
							<sw:text>Any Virtuozzo Hardware Node</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="hn-eid" select="hn:hwid2eid($hwid)"/>
							<sw:text>
								<xsl:with-param name="hn" select="env:env2title(env:get-env($hn-eid)/env)"/>
								%hn only
							</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>n/a</sw:text>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

</xsl:stylesheet>
