<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl permissions local func"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:form	="http://www.swsoft.com/xsl/cp/form"	
	xmlns:permissions	="http://www.swsoft.com/xsl/cp/permissions"	
	xmlns:authm	="http://www.swsoft.com/xsl/cp/authm"			
	xmlns:securitym	="http://www.swsoft.com/xsl/cp/securitym"		
 >
	<sw:include href="/layout/forms-list.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>	
	<sw:include href="/lib/swa/vzcpsecuritym.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
 	
	<!-- Restore permissions block -->
	<xsl:template name="permissions:restore">
		<xsl:call-template name="form:restore-list">
			<xsl:with-param name="code" select="'permissions'"/>
			<xsl:with-param name="row-node-name" select="'permission'"/>
		</xsl:call-template>
	</xsl:template>
  
	<!-- Show permissions edit block -->
	<func:function name="permissions:check">
		<xsl:param name="data"/>
		
		<xsl:for-each select="$data/permission">
			<xsl:if test="user!='' and not(role!='')">
				<xsl:if test="error:put( sw:text('Please select a role.'),'', concat('role_permissions_',position()) )"/>
			</xsl:if>
			<xsl:if test="role!='' and not(user!='')">
				<xsl:if test="error:put( sw:text('Please select a user or group.'),'', concat('user_permissions_',position()) )"/>
			</xsl:if>
		</xsl:for-each>
		
	</func:function>		
	
	<!-- Show permissions edit block -->
	<xsl:template name="permissions:edit">
		<xsl:param name="data"/>
		
		<xsl:variable name="roles" select="securitym:list-assignable-roles()"/>
		<xsl:call-template name="form:show-list">
			<xsl:with-param name="config">
				<code>permissions</code>
				<add_label><sw:text>Add a new permission.</sw:text></add_label>
				<remove_label><sw:text>Remove the permission.</sw:text></remove_label>
				<xsl:for-each select="$data/permission">
					<ui:row>
						<xsl:call-template name="local:edit-permission">
							<xsl:with-param name="data" select="."/>
							<xsl:with-param name="roles" select="$roles"/>
						</xsl:call-template>
					</ui:row>
				</xsl:for-each>
				<ui:new-row>
					<xsl:call-template name="local:edit-permission">
						<xsl:with-param name="data" select="/.."/>
						<xsl:with-param name="roles" select="$roles"/>
					</xsl:call-template>
				</ui:new-row>
			</xsl:with-param>
		</xsl:call-template>		
	</xsl:template>
  
  <xsl:template name="local:edit-permission">
  	<xsl:param name="data"/>
   	<xsl:param name="roles"/>
		<!-- We should allow to select User OR GROUP, but can not due to #89891 -->	
  	<ui:cell-text>
			<sw:text>User</sw:text>
		</ui:cell-text>
		<ui:cell-selector id="user" align="left" value="" colspan="2"
			code-value="{$data/user}" width="20"
			link-tip="select_user"
			link-onclick="open_details('{$baseurl}/sysdir/securman/users/select-popup?id=$id&amp;mode=single','user_list',620,850); return false;"											
			link-caption="{sw:text('Select...')}"
		>
			<xsl:if test="$data">
				<xsl:variable name="user-key" select="authm:sid2user-key($data/user)"/>
				<xsl:attribute name="value"><xsl:value-of select="sw:base64-decode($user-key/name)"/></xsl:attribute>
			</xsl:if>
		</ui:cell-selector>
		<ui:cell-text>
			<sw:text>Role</sw:text>
		</ui:cell-text>
		<ui:cell-list id="role" value="{$data/role}">
			<ui:list-item title="" id=""/>
			<xsl:for-each select="$roles">
				<xsl:sort select="name"/>
				<xsl:variable name="name" select="name"/>
				<ui:list-item title="{$name}" id="{$name}"/>
			</xsl:for-each>
		</ui:cell-list>
		<ui:cell-text>
			&#160;&#160;
		</ui:cell-text>
  </xsl:template>
	
</xsl:stylesheet>
