<!-- Copyright (c) SWsoft, 1999-2007 All rights reserved. -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func browse search"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:func	="http://exslt.org/functions"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:search="http://www.swsoft.com/xsl/cp/search"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"	
	xmlns:set		="http://exslt.org/sets"
>

	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/core/search/screen-finder.xsl"/>	

	<xsl:template name="search:in-ves">
		<xsl:param name="search-pattern"/>
		<xsl:variable name="request-for-search-rtf">
			<search-pattern>
				<xsl:value-of select="$search-pattern"/>
			</search-pattern>
			<fields>
				<field>
					<not-for-search/>
					<not-for-show/>
					<id>pager.env.eid</id>
					<for-link/>
				</field>
				<field>
					<not-for-search/>
					<id>pager.env.vconfig.veid</id>
					<label><xsl:value-of select="sw:text('Container ID')"/></label>
					<link/>
				</field>
				<field>
					<id>pager.env.vconfig.name</id>
					<label><xsl:value-of select="sw:text('Name')"/></label>
					<link/>					
				</field>
				<field>
					<id>pager.env.vconfig.hostname</id>
					<label><xsl:value-of select="sw:text('Hostname')"/></label>
					<link/>
				</field>
				<field>
					<id>pager.env.vconfig.description</id>
					<label><xsl:value-of select="sw:text('Description')"/></label>					
				</field>
			</fields>
			<title>
				<sw:text>Containers</sw:text>
			</title>
			<object-type>
				<xsl:value-of select="'ve'"/>
			</object-type>
			<url-link>
				<base>/vzdir/infrman/envs/env</base>
				<item>id</item>
			</url-link>
		</xsl:variable>
		<xsl:variable name="request-for-search" select="exsl:node-set($request-for-search-rtf)"/>
		<xsl:call-template name="local:make-search">
			<xsl:with-param name="request"	select="$request-for-search"/>
		</xsl:call-template>
	</xsl:template>


	<xsl:template name="search:in-hns">
		<xsl:param name="search-pattern"/>
		<xsl:variable name="request-for-search-rtf">
			<search-pattern>
				<xsl:value-of select="$search-pattern"/>
			</search-pattern>
			<fields>
				<field>
					<not-for-search/>
					<not-for-show/>  
					<id>pager.env.eid</id>
					<for-link/>					
				</field>
				<field>
					<id>pager.env.config.name</id>
					<label><xsl:value-of select="sw:text('Name')"/></label>
					<link/>
				</field>
				<field>
					<id>pager.env.config.description</id>
					<label><xsl:value-of select="sw:text('Description')"/></label>
					<link/>					
				</field>
			</fields>
			<title>
				<sw:text>Hardware Nodes</sw:text>
			</title>
			<object-type>
				<xsl:value-of select="'hn'"/>
			</object-type>
			<url-link>
				<base>/vt/hns/hn</base>
				<item>id</item>
			</url-link>
		</xsl:variable>
		<xsl:variable name="request-for-search" select="exsl:node-set($request-for-search-rtf)"/>
		<xsl:call-template name="local:make-search">
			<xsl:with-param name="request"	select="$request-for-search"/>
		</xsl:call-template>
	</xsl:template>


	<xsl:template name="search:in-templates">
		<xsl:param name="search-pattern"/>
		<xsl:variable name="request-for-search-rtf">
			<search-pattern>
				<xsl:value-of select="$search-pattern"/>
			</search-pattern>
			<fields>
				<field>
					<id>pager.packages.name</id>
					<label><xsl:value-of select="sw:text('Name')"/></label>
					<link-as-template/>
				</field>
				<field>
					<not-for-search/>
					<id>pager.packages.version</id>
					<label><xsl:value-of select="sw:text('Version')"/></label>
				</field>
				<field>
					<id>pager.packages.summary</id>
					<label><xsl:value-of select="sw:text('Summary')"/></label>
					<link-as-template/>	
				</field>
				<field>
					<not-for-search/>
					<not-for-show/>
					<id>pager.packages.arch</id>
				</field>
				<field>
					<not-for-search/>
					<not-for-show/>
					<id>pager.packages.os.platform</id>
				</field>
				<field>
					<not-for-show/>
					<id>pager.packages.os.name</id>
				</field>
				<field>
					<not-for-search/>
					<not-for-show/>
					<id>pager.packages.os_template</id>
				</field>
				<field>
					<not-for-search/>
					<not-for-show/>
					<id>pager.packages.technology</id>
				</field>
				<field>
					<not-for-show/>
					<not-for-search/>
					<id>pager.env.config.name</id>
					<label><xsl:value-of select="sw:text('Hardware Node')"/></label>
				</field>
				<field>
					<not-for-search/>
					<not-for-show/>
					<id>pager.env.eid</id>
					<for-link/>
				</field>
				<field>
					<id>pager.packages.description</id>
					<label><xsl:value-of select="sw:text('Description')"/></label>
				</field>		
			</fields>
			<title>
				<sw:text>Templates</sw:text>
			</title>
			<object-type>
				<xsl:value-of select="'template'"/>
			</object-type>
			<url-link>
				<base>/vzdir/infrman/templates/ez/group-app</base>
				<item>hn-eid</item>
			</url-link>
			<unique>
				<id>pager.packages.name</id>
				<id>pager.packages.version</id>
				<id>pager.packages.arch</id>
				<id>pager.packages.os.platform</id>
				<id>pager.packages.os.name</id>
				<id>pager.packages.os_template</id>
			</unique>
		</xsl:variable>
		<xsl:variable name="request-for-search" select="exsl:node-set($request-for-search-rtf)"/>
		<xsl:call-template name="local:make-search">
			<xsl:with-param name="request"	select="$request-for-search"/>
		</xsl:call-template>
 	</xsl:template>


	<xsl:template name="search:in-backups">
		<xsl:param name="search-pattern"/>
		<xsl:variable name="request-for-search-rtf">
			<search-pattern>
				<xsl:value-of select="$search-pattern"/>
			</search-pattern>
			<fields>
				<field>
					<not-for-search/>
					<not-for-show/>  
					<id>pager.backup.id</id>
					<for-link/>					
				</field>
				<field>
					<id>pager.backup.description</id>
					<label><xsl:value-of select="sw:text('Description')"/></label>
					<link/>
				</field>
			</fields>
			<title>
				<sw:text>Backups</sw:text>
			</title>
			<object-type>
				<xsl:value-of select="'backup'"/>
			</object-type>
			<url-link>
				<base>/vt/backups/backup?load-eid=true&amp;</base>
				<item>id</item>
			</url-link>
		</xsl:variable>
		<xsl:variable name="request-for-search" select="exsl:node-set($request-for-search-rtf)"/>
		<xsl:call-template name="local:make-search">
			<xsl:with-param name="request"	select="$request-for-search"/>
		</xsl:call-template>
	</xsl:template>


	<xsl:template name="search:in-screens">
		<xsl:param name="search-pattern"/>
		<xsl:variable name="screens" select="sw:document('screens.xml')"/>
		<xsl:variable name="screen-id-rc" select="$screens//screen[@id=$search-pattern]"/>
		<xsl:variable name="screen-title-rc" select="$screens//screen[contains(sw:uc(@title),sw:uc($search-pattern)) or contains(sw:uc(@full-title),sw:uc($search-pattern))]"/>
		<xsl:variable name="screen-description-rc" select="$screens//screen[contains(sw:uc(info),sw:uc($search-pattern))]"/>
		<xsl:variable name="screen-count" select="count($screen-id-rc) + count($screen-title-rc) + count($screen-description-rc)"/>
		<common-result>
			<count>
				<xsl:value-of select="$screen-count"/>
			</count>
			<id>screen</id>
			<raw>
				<ui:block mode="edit" width="max">					
					<!-- Search by Screen ID -->
						<xsl:variable name="result-show-rtf">
						<xsl:if test="$screen-id-rc">
							<xsl:for-each select="$screen-id-rc">
								<xsl:call-template name="search:show-screen">
									<xsl:with-param name="screen"	select="."/>
									<xsl:with-param name="screens"	select="$screens"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:if>
						<!-- /Search by Screen ID -->
					
						<!-- Search by Screen Title -->
						<xsl:if test="$screen-title-rc">
							<xsl:for-each select="$screen-title-rc">
								<xsl:call-template name="search:show-screen">
									<xsl:with-param name="screen"	select="."/>
									<xsl:with-param name="screens"	select="$screens"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:if>
						<!-- /Search by Screen ID -->
					
						<!-- Search by Screen Description -->
						<xsl:if test="$screen-description-rc">
							<xsl:for-each select="$screen-description-rc">
								<xsl:call-template name="search:show-screen">
									<xsl:with-param name="screen"	select="."/>
									<xsl:with-param name="screens"	select="$screens"/>
								</xsl:call-template>
							</xsl:for-each>
						</xsl:if>
						<!-- /Search by Screen ID -->
					</xsl:variable>
					<xsl:variable name="result-show" select="exsl:node-set($result-show-rtf)"/>
								
					<xsl:choose>
						<xsl:when test="$screen-count &gt; 0">
							<!-- founded at least in one section -->
							<xsl:copy-of select="$result-show"/>
						</xsl:when>
						<xsl:otherwise>
							<!-- nothing found -->
							<ui:rows title="{sw:text('Screens')}">
								<ui:row>
									<ui:cell-text>
										<sw:text>
											<xsl:with-param name="search-pattern" select="$search-pattern"/>
											Your search - %{search-pattern} - did not match any objects.
										</sw:text>
									</ui:cell-text>
								</ui:row>
							</ui:rows>					
						</xsl:otherwise>
					</xsl:choose>
				</ui:block>
			</raw>
		</common-result>
	</xsl:template>


	<xsl:template name="local:make-search">
		<xsl:param name="request"/>
    <xsl:variable name="req">
			<packet>
				<target>pager</target>
				<data>
					<pager>
						<select>
							<xsl:for-each select="$request/fields/field/id">
								<field><xsl:value-of select="."/></field>
							</xsl:for-each>
							<xsl:variable name="where">
								<xsl:choose>
									<xsl:when test="$request/object-type = 've'">
										((pager.env.vconfig.type!='')		and	(pager.env.vconfig.type!='generic'))	and
										((pager.env.vconfig.veid = '')	or	(pager.env.vconfig.veid!=1))			and
									</xsl:when>
									<xsl:when test="$request/object-type = 'hn'">
										not(pager.env.vconfig.type!='' and pager.env.vconfig.type!='generic') and
									</xsl:when>									
								</xsl:choose>
								(
								<xsl:for-each select="$request/fields/field[not(not-for-search)]/id">
									<xsl:if test="position() != 1"> or </xsl:if>
									UPPER(<xsl:value-of select="."/>) like UPPER('%<xsl:value-of select="$request/search-pattern"/>%')
								</xsl:for-each>
								)
							</xsl:variable>
							<where><xsl:value-of select="sw:base64-encode($where)"/></where>
						</select>
					</pager>
				</data>
			</packet>
    </xsl:variable>
    <xsl:variable name="search-result" select="sw:xchg($req)/packet/data/pager"/>
		<xsl:variable name="common-result-rtf">
			<xsl:copy-of select="$request/*[name() != 'fields']"/>
			<xsl:variable name="fields-rtf">
				<fields>
					<xsl:for-each select="$request/fields/field">
						<xsl:variable name="pos" select="position()"/>
						<field>
							<xsl:copy-of select="./*"/>
							<pos><xsl:value-of select="$pos"/></pos>
						</field>
					</xsl:for-each>
				</fields>
			</xsl:variable>
			<xsl:variable name="fields" select="exsl:node-set($fields-rtf)/fields"/>
			<xsl:copy-of select="$fields"/>
			
			<xsl:choose>
				<xsl:when test="$request/unique">
					<xsl:variable name="rows-rtf">
						<xsl:for-each select="$search-result/row_set/row">
							<xsl:variable name="row" select="."/>
							<record>
								<id>
									<xsl:for-each select="$request/unique/id">
										<xsl:value-of select="local:get-field(., $fields, $row)"/>|
									</xsl:for-each>
								</id>
								<xsl:copy-of select="$row"/>
							</record>
						</xsl:for-each>
					</xsl:variable>
					<xsl:variable name="rows" select="exsl:node-set($rows-rtf)/record"/>
					<row_set>
						<xsl:for-each select="set:distinct($rows/id)">
							<xsl:variable name="id" select="."/>
							<xsl:copy-of select="$rows[id=$id][1]/row"/>
						</xsl:for-each>
					</row_set>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$search-result/row_set"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="common-result" select="exsl:node-set($common-result-rtf)"/>
		<common-result>
			<count>
				<xsl:value-of select="count($common-result/row_set/row)"/>
			</count>
			<id><xsl:value-of select="$common-result/object-type"/></id>
			<raw>
				<xsl:copy-of select="$common-result"/>
			</raw>
		</common-result>
	</xsl:template>
	
	<func:function name="local:get-field">
		<xsl:param name="name"/>
		<xsl:param name="fields"/>
		<xsl:param name="data"/>
		
		<func:result select="sw:base64-decode($data[position()=number($fields/field[id=$name]/pos)])"/>
	</func:function>
		
	<func:function name="local:create-package-id">
		<xsl:param name="type"/>
		<xsl:param name="name"/>
		<xsl:param name="version"/>
		<xsl:param name="platform"/>
		<xsl:param name="arch"/>
		<xsl:param name="os-name" select="''"/>
		
		<func:result select="concat(
	  			$type, '/',
	  			$platform, '/',
	  			$arch, '/',
		  		sw:if($type='os', '', $os-name), '/',
		  		sw:if($version='', $name, concat($name, '/', $version))
		  	)"/>
	</func:function>


	<xsl:template name="search:show-result">
		<xsl:param name="common-result"/>
		
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="global-search"
						hide-filter-controls="true" post-only-rows="true"
						url="/core/search?global_search={sw:sesgetstr('search-string')}"/>
					<ui:cols>		
						<xsl:for-each select="$common-result/fields/field[not(not-for-show)]">
							<ui:column id="col-{position()}" title="{label}" apply-templates="yes"/>
						</xsl:for-each>						
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		
		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$common-result/row_set/row">
							<xsl:variable name="one-data-row" select="param/value"/>
							<xsl:variable name="pos-of-field-with-link-id" select="$common-result/fields/field[for-link]/pos"/>
							<xsl:variable name="link-id-value" select="$one-data-row[position() = $pos-of-field-with-link-id]"/>
							<ui:row>
								
								<xsl:for-each select="$common-result/fields/field[not(not-for-show)]">
									<xsl:variable name="field-pos" select="pos"/>
									<!-- get value from "one-data-row" only for current field-->
									<xsl:variable name="cur-value-raw" select="sw:base64-decode($one-data-row[position() = $field-pos])"/>
									<xsl:variable name="cur-value" 
										select="sw:if(contains(id, 'packages.name') 
														or contains(id, 'packages.os.name'),
														sw:app-id2title($cur-value-raw), $cur-value-raw)"/>
									<xsl:element name="col-{position()}">
										<xsl:choose>
											<xsl:when test="link">
												<xsl:variable name="link" select="concat($baseurl,$common-result/url-link/base,sw:if(contains($common-result/url-link/base,'?'),'','?'),$common-result/url-link/item,'=',$link-id-value)"/>
												<ui:link href="{$link}"><xsl:value-of select="$cur-value"/></ui:link>
											</xsl:when>
											<xsl:when test="link-as-template">
												<xsl:variable name="app-id" 
													select="local:create-package-id(
														sw:if(local:get-field('pager.packages.os_template', 
																$common-result/fields, $one-data-row) = 1, 'os', 'app'),
															local:get-field('pager.packages.name', $common-result/fields, $one-data-row),
															local:get-field('pager.packages.version', $common-result/fields, $one-data-row),
															local:get-field('pager.packages.os.platform', $common-result/fields, $one-data-row),
															local:get-field('pager.packages.arch', $common-result/fields, $one-data-row),
															local:get-field('pager.packages.os.name', $common-result/fields, $one-data-row)
													)"/> 
												<xsl:variable name="link" select="concat($baseurl,$common-result/url-link/base,'?',$common-result/url-link/item,'=',$link-id-value,
																					'&amp;app-id=',sw:base64-encode($app-id))"/>
												<ui:link href="{$link}"><xsl:value-of select="$cur-value"/></ui:link>
											</xsl:when>
											<xsl:when test="id='pager.packages.version' and $cur-value=''">
												<sw:text>n/a</sw:text>												
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="$cur-value"/>
											</xsl:otherwise>
										</xsl:choose>									
									</xsl:element>
								</xsl:for-each>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		
		<ui:block width="100%">	
			<xsl:choose>
				<xsl:when test="count($common-result/row_set/row) != 0">
					<ui:browse>
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
					</ui:browse>
				</xsl:when>
				<xsl:otherwise>
					<ui:rows title="{$common-result/title}">
						<ui:row>
							<ui:cell-text>
								<sw:text>
									<xsl:with-param name="search-pattern" select="$common-result/search-pattern"/>
									Your search - %{search-pattern} - did not match any objects.
								</sw:text>
							</ui:cell-text>
						</ui:row>
					</ui:rows>
				</xsl:otherwise>
			</xsl:choose>
		</ui:block>
	</xsl:template>
	
	
</xsl:stylesheet>

