<!-- Copyright (c) SWsoft, 1999-2007 All rights reserved. -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl search"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:search="http://www.swsoft.com/xsl/cp/search"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:html	="http://www.swsoft.com/xsl/cp/html"
>

	<sw:include href="/layout/lib/html.xsl"/>

  <xsl:template name="search:show-screen">
  	<xsl:param name="screen"/>
  	<xsl:param name="screens"/>
  	<xsl:variable name="screen-icon" select="sw:if($screen/@icon, $screen/@icon, 'no_icon')"/>
  	<xsl:variable name="screen-title" select="sw:if($screen/@full-title,$screen/@full-title,$screen/@title)"/>  	  	
  	<ui:rows separate-tables="true">
  		<ui:rows-title>
  			<img src="/{$theme}/icons/{$screen-icon}_32.gif" width="32" height="32" border="0" style="margin:0px;padding-left:0px;padding-right:7px;" />
  			<ui:text>
  				<xsl:value-of select="sw:text($screen-title)"/>
  			</ui:text>
			</ui:rows-title>
			<ui:row>			
				<ui:cell-label><sw:text>Title</sw:text></ui:cell-label>		
				<ui:cell-text>
					<xsl:choose>
						<xsl:when test="$screen/link[not(@panel) or @panel='vzcc']">
							<a>
								<xsl:attribute name="href">
									<xsl:choose>
										<xsl:when test="$screen/link/@href">
											<xsl:value-of select="$screen/link/@href"/>
										</xsl:when>
										<xsl:when test="$screen/@href">
											<xsl:value-of select="$screen/@href"/>
										</xsl:when>
									</xsl:choose>
								</xsl:attribute>
							 <xsl:value-of select="sw:text($screen-title)"/>
							</a>
						</xsl:when>
						<xsl:otherwise>
							 <xsl:value-of select="sw:text($screen-title)"/>
						</xsl:otherwise>
					</xsl:choose>
				</ui:cell-text>
			</ui:row>	
			<ui:row>			
				<ui:cell-label><sw:text>ID</sw:text></ui:cell-label>		
				<ui:cell-text>
					<xsl:value-of select="$screen/@id"/>
				</ui:cell-text>
			</ui:row>	
			<ui:row>			
				<ui:cell-label><sw:text>Description</sw:text></ui:cell-label>		
				<ui:cell-text>
					<xsl:choose>
						<xsl:when test="$screen/info">
							<xsl:value-of select="sw:text(string($screen/info))"/>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>n/a</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:cell-text>
			</ui:row>	
			<ui:row>
				<ui:cell-text colspan="2" cell-style="border-bottom: 1px dashed #CCCCCC;" cell-width="100%"></ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-text/>
			</ui:row>
			<ui:row>
				<ui:cell-label><sw:text>Screen Location</sw:text></ui:cell-label>
			</ui:row>
			<ui:row>
				<ui:cell-text colspan="2">
					<xsl:variable name="paths-rtf">
						<xsl:call-template name="local:make-screen-path">
							<xsl:with-param name="screen" select="$screen"/>
					  	<xsl:with-param name="screens"	select="$screens"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="paths" select="exsl:node-set($paths-rtf)"/>	 
					<xsl:for-each select="$paths//screen[not(screen)]">
						<xsl:call-template name="local:show-screen-path">
							<xsl:with-param name="screen" select="."/>	 					
						</xsl:call-template>	 				
					</xsl:for-each>
				</ui:cell-text>
			</ui:row>			
		</ui:rows>		
  </xsl:template>
  

  <xsl:template name="local:show-screen-path">
  	<xsl:param name="screen"/>  	  	
  	<xsl:param name="shift" select="'&#160;'"/>  	
		<table border="0">						
			<xsl:for-each select="$screen/locate">
				<tr>
					<xsl:choose>
						<xsl:when test="position()=1">
							<td>
								<xsl:value-of select="$shift"/>
							</td>
							<td style="vertical-align:top">
								<img src="/{$theme}/icons/{$screen/icon}_16.gif" width="16" height="16" border="0" hspace="2"/>
								<img src="/{$theme}/images/1x1.gif" width="5" height="1"/>
							</td>
						</xsl:when>
						<xsl:otherwise>
							<td/><td/>
						</xsl:otherwise>
					</xsl:choose>
					<td>
						<nobr>
							<sw:text select="substring-after(html:plain2html(.),'&lt;br/&gt;')"/>
						</nobr>
					</td>
					<td width="100%"/>
				</tr>
				<tr>
					<td/><td/>
					<td>
						<span class="inactive">
							<nobr>							
								<sw:text>
									<xsl:with-param name="title" select="sw:text(string($screen/title))"/>
									You have reached the "%title" screen.
								</sw:text>
							</nobr>
						</span>
					</td>
				</tr>
			</xsl:for-each>
		</table>
  	<xsl:if test="$screen/ancestor::*">  		
	  	<xsl:call-template name="local:show-screen-path">
				<xsl:with-param name="screen" select="$screen/ancestor::*[1]"/>	 					
				<xsl:with-param name="shift" select="concat($shift,'&#160;&#160;&#160;')"/>	 					
			</xsl:call-template>	 				
		</xsl:if>  	
  </xsl:template>
  

  <xsl:template name="local:make-screen-path">
  	<xsl:param name="screen"/>
  	<xsl:param name="screens"/>
  	<xsl:variable name="parent-ids-rtf">
	  	<xsl:choose>
	  		<xsl:when test="$screen/@parent-id">
	  			<id><xsl:value-of select="$screen/@parent-id"/></id>
	  		</xsl:when>
	  		<xsl:otherwise>
	  			<xsl:for-each select="$screen/parent">
	  				<id><xsl:value-of select="@id"/></id>
	  			</xsl:for-each>
	  		</xsl:otherwise>
	  	</xsl:choose>
	  </xsl:variable>
	  <xsl:variable name="parent-ids" select="exsl:node-set($parent-ids-rtf)"/>	  
	  <screen>
			<title>
				<xsl:value-of select="sw:if($screen/@full-title!='',$screen/@full-title,$screen/@title)"/><br/>
			</title>
			<icon>
				<xsl:value-of select="$screen/@icon"/>
			</icon>
			<xsl:copy-of select="$screen/locate"/>
			<xsl:if test="not($screen/locate/@on-top='yes')">
				<xsl:for-each select="$parent-ids/id">
					<xsl:variable name="parent" select="$screens//screen[@id=current()]"/>
					<xsl:call-template name="local:make-screen-path">
						<xsl:with-param name="screen"		select="$parent"/>
						<xsl:with-param name="screens"	select="$screens"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:if>
		</screen>	   	
  </xsl:template>
	
</xsl:stylesheet>

