<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred security check"
  xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl				="http://exslt.org/common"
  xmlns:sw					="http://www.swsoft.com/xsl/cp"
  xmlns:func				="http://exslt.org/functions"
	xmlns:cred 				="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"
	xmlns:security		="http://www.swsoft.com/xsl/cp/security"
	xmlns:authm				="http://www.swsoft.com/xsl/cp/authm"	
	xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"
	xmlns:global			="http://www.swsoft.com/xsl/cp/global"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
>

  <sw:include href="/lib/common.xsl"/>
  <sw:include href="/lib/cred.xsl"/>
 	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/core/check-funcs.xsl"/>

  <xsl:output method="xml"/>

	<!--*********************************** PUBLIC FUNCTIONS ****************************-->
	
	<!-- 
		Return information about existed realms. Determines current realm, gets it from GET param or calc some default. 
		Arguments
			session-key-id : Curren realm key ID in session. (Optional)
		Result
			<info>
				<current-eid>...</current-eid>
				<realm eid="" title=""/>
				<realm/>
				...
			</info>
			or <error/>
	-->
	<func:function name="security:realms-info">
		<xsl:param name="session-key-id" select="'core-security-realm'"/>
		
		<xsl:variable name="value-from-get" select="sw:param('realm')"/>
		<xsl:variable name="value-from-session" select="sw:sesgetstr($session-key-id)"/>	
		<xsl:variable name="all-realms" select="authm:list-realms()"/>

		<xsl:choose>
			<xsl:when test="$all-realms[self::error]">
				<func:result select="$all-realms"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="current-realm-eid">
					<xsl:choose>
						<xsl:when test="$value-from-get!=''">
							<xsl:value-of select="$value-from-get"/>
						</xsl:when>
						<xsl:when test="$value-from-session!='' 
							and $all-realms/realm[id=$value-from-session]">
							<xsl:value-of select="$value-from-session"/>
						</xsl:when>
						<xsl:otherwise>
							<!-- TODO: ask VZAgent about default realm -->
							<xsl:value-of select="$all-realms/realm[1]/id"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				
				<sw:die test="$current-realm-eid=''">
					Can not determine the current authentication database.
				</sw:die>
				
				<xsl:if test="$current-realm-eid!=$value-from-session">
					<xsl:if test="sw:sesputstr($session-key-id,$current-realm-eid)"/>
				</xsl:if>
				
				<xsl:if test="sw:sesputstr(concat($session-key-id,'-name'),sw:text(string($all-realms/realm[id=$current-realm-eid]/name)))"/>
				
				<xsl:variable name="vz-realm-id" select="sw:internal-realm-id()"/>
				
				<!-- Prepare result -->
				<xsl:variable name="result-rtf">
					<info>
						<current-eid><xsl:value-of select="$current-realm-eid"/></current-eid>
						<xsl:for-each select="$all-realms/realm[
							not(builtin) or id=$global:system-realm-id or id=$vz-realm-id
						]">
							<!-- Very bad hardcoded condition, thanks to our partners for such beatifull code -->										
							<realm eid="{id}" title="{sw:text(string(name))}" 
								allow-creation="{boolean(id=$vz-realm-id)}"
								allow-deletion="{boolean(id=$vz-realm-id)}"/>
						</xsl:for-each>
					</info>
				</xsl:variable>
				
				<func:result select="exsl:node-set($result-rtf)/info"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!--
		Post ui:tab-bar with subtab-per-realm.
		Arguments
			current-tab : string with name of one of VZCC/Security tabs. Usually "users" or "groups".
			realms-info : ref to nodeset from security:realms-info()
			subtab-base-url : base URL for every custom subtab.
		Result
			<ui:tab-bar...> 
	-->
	<xsl:template name="security:realms-tab-bar">
		<xsl:param name="current-tab"/>
		<xsl:param name="realms-info"/>		
		<xsl:param name="subtab-base-url"/>				
		
		<ui:tab-bar id="security" current-tab="{$current-tab}" current-subtab="{$realms-info/current-eid}" merge-mode="custom-subtabs">
			<xsl:for-each select="$realms-info/realm">
				<xsl:variable name="subtab-tip">
					<sw:text>
						<xsl:with-param name="users-or-groups" select="$current-tab"/>
						<xsl:with-param name="title" select="@title"/>
						Manage the %{users-or-groups} in the %{title} authentication database.
					</sw:text>
				</xsl:variable>
				<ui:tab href="{$subtab-base-url}realm={@eid}" title="{@title}" 
					id="security.realm.{@eid}" tab="{@eid}" tip="{$subtab-tip}"
				/>
			</xsl:for-each>
		</ui:tab-bar>
		
	</xsl:template>
	
<!--
		Post ui:tab-bar-custom with tab-per-realm.
		Arguments
			realms-info : ref to nodeset from security:realms-info()
			tab-base-url : base URL for every custom subtab.
		Result
			<ui:tab-bar-custom...> 
	-->
	<xsl:template name="security:realms-tab-bar-popup">
		<xsl:param name="realms-info"/>		
		<xsl:param name="tab-base-url"/>				
		
		<ui:tab-bar-custom current-tab="{$realms-info/current-eid}" >
			<xsl:for-each select="$realms-info/realm">
				<ui:tab href="{$tab-base-url}realm={@eid}" tab="{@eid}" selected="{sw:if(@eid=$realms-info/current-eid,'true','false')}">
					<xsl:value-of select="@title"/>
				</ui:tab>
			</xsl:for-each>
		</ui:tab-bar-custom>
		
	</xsl:template>	


	<xsl:template name="security:realm-edit-form">
		<xsl:param name="realm"/>
		<xsl:param name="password"/>

		<ui:rows title="{sw:text('General Settings')}">
			<ui:row>
				<ui:cell-label><sw:text>Database Name</sw:text></ui:cell-label>
				<ui:cell-input id="name" required="true" value="{$realm/name}"/>
			</ui:row>						
		</ui:rows>
		
		<ui:rows title="{sw:text('Connection Settings')}">
			<ui:row>
				<ui:cell-label><sw:text>Server Address</sw:text></ui:cell-label>
				<ui:cell-input id="address" required="true" value="{$realm/address}"/>
			</ui:row>
			<ui:row>
				<ui:cell/>
				<ui:cell-text>
					<ui:text-disabled>
						<sw:text>The domain name or IP address of the database server.</sw:text>
					</ui:text-disabled>
				</ui:cell-text>
			</ui:row>

			<ui:row>
				<ui:cell-label><sw:text>Port</sw:text></ui:cell-label>
				<ui:cell-input id="port" required="true" value="{$realm/port}"/>
			</ui:row>
		</ui:rows>

		<ui:rows title="{sw:text('Login Settings')}">
			<ui:row>
				<ui:cell-label><sw:text>Login</sw:text></ui:cell-label>
				<ui:cell-input id="login" required="true"
					value="{sw:base64-decode($realm/login/name)}"/>
			</ui:row>

			<ui:row>
				<ui:cell-label><sw:text>Password</sw:text></ui:cell-label>
				<ui:cell-input mode-password="true" id="password" maxlength="64"
					value="{sw:base64-decode($password)}"/>
			</ui:row>
					  
            <ui:row>
            	<ui:cell-label><sw:text>Domain</sw:text></ui:cell-label>
            	<ui:cell-input id="domain" maxlength="64"
					value="{sw:base64-decode($realm/login/domain)}"/>
			</ui:row>
			<ui:row>
				<ui:cell/>
				<ui:cell-text>
					<ui:text-disabled>
						<sw:text>Leave this field empty to log in from the server domain.</sw:text>
					</ui:text-disabled>
				</ui:cell-text>
			</ui:row>
		</ui:rows>
					
		<ui:rows title="{sw:text('Directory Settings')}">
			<ui:row>
				<ui:cell-label><sw:text>Base DN</sw:text></ui:cell-label>
				<ui:cell-input id="base_dn" maxlength="1024" value="{$realm/base_dn}"
					width="60" required="true"/>
			</ui:row>
			<ui:row>
				<ui:cell/>
				<ui:cell-text>
					<ui:text-disabled>
						<sw:text>
							The distinguished name of the root directory.
							<br/>Example: DC=yourdomain
						</sw:text>
					</ui:text-disabled>
				</ui:cell-text>
			</ui:row>		
			<ui:row>
				<ui:cell-label><sw:text>Default DN</sw:text></ui:cell-label>
				<ui:cell-input id="default_dn" maxlength="1024" value="{$realm/default_dn}"
					width="60"/>								
			</ui:row>
			<ui:row>
				<ui:cell/>
				<ui:cell-text>
					<ui:text-disabled>
						<sw:text>
							The distinguished name of the users' storage directory
							<br/>(the complete navigation path to this directory).
							<br/>Leave this field empty if it coincides with the Base DN.
							<br/>Example: OU=Sales,OU=Personnel,DC=yourdomain
						</sw:text>
					</ui:text-disabled>
				</ui:cell-text>
			</ui:row>						
		</ui:rows>
	</xsl:template>


	<xsl:template name="security:restore-realm">
		<xsl:param name="orig-realm" select="/.."/>
		
		<xsl:variable name="base_dn" select="normalize-space(sw:param('base_dn'))"/>
		<xsl:variable name="default_dn" select="normalize-space(sw:param('default_dn'))"/>
		<xsl:variable name="login_domain" select="normalize-space(sw:param('domain'))"/>
		
		<realm>
			<xsl:if test="$orig-realm/id">
				<id><xsl:value-of select="$orig-realm/id"/></id>
			</xsl:if>
			<name>
				<xsl:value-of select="sw:param('name')"/>
			</name>
			<address><xsl:value-of select="sw:param('address')"/></address>
			<port>
				<xsl:value-of select="sw:param('port')"/>
			</port>
			<login>
				<name>
					<xsl:value-of select="sw:base64-encode(sw:param('login'))"/>
				</name>
				<xsl:if test="string-length($login_domain) &gt; 0">
					<domain>
						<xsl:value-of select="sw:base64-encode($login_domain)"/>
					</domain>
				</xsl:if>
			</login>
			<type>1</type>
			<base_dn><xsl:value-of select="$base_dn"/></base_dn>
			<default_dn><xsl:value-of select="sw:if(not($default_dn!=''),$base_dn,$default_dn)"/></default_dn>
		</realm>
	</xsl:template>
	
	<xsl:template name="security:validate-realm">
		<xsl:param name="realm"/>
		
		<xsl:choose>
			<xsl:when test="not($realm/name != '')">
				<xsl:if test="error:put(sw:text('The authentication database name has not been specified.'))"/>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="not($realm/address != '')">
				<xsl:if test="error:put(sw:text('The server address has not been specified.'),'','address')"/>
			</xsl:when>
			<xsl:when test="not(check:domain($realm/address)) 
				and not(check:ip($realm/address))">
				<xsl:if test="error:put(sw:text('The server address format is invalid. It should be either a fully qualified domain name or an IP address.'),'','address')"/>
			</xsl:when>
		</xsl:choose>
		
		<xsl:choose>
			<xsl:when test="not($realm/port != '')">
				<xsl:if test="error:put(sw:text('The port has not been specified.'))"/>
			</xsl:when>
			<xsl:when test="not(check:port($realm/port))">
				<xsl:if test="error:put(sw:text('The port number is invalid. It should be a numeric value in the 1-65535 range.'))"/>
			</xsl:when>
		</xsl:choose>
		
		<xsl:choose>					
			<xsl:when test="not($realm/login/name != '')">
				<xsl:if test="error:put(sw:text('The login has not been specified.'))"/>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="not($realm/base_dn != '')">
				<xsl:if test="error:put(sw:text('The base DN has not been specified.'))"/>
			</xsl:when>						
		</xsl:choose>		
	</xsl:template>
	
	<!--*********************************** LOCAL FUNCTIONS ****************************-->


</xsl:stylesheet>
