<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func authm dirm sys"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:func="http://exslt.org/functions"
	xmlns:exsl="http://exslt.org/common" 
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:global  ="http://www.swsoft.com/xsl/cp/global"	
	xmlns:local="http://www.swsoft.com/xsl/cp/local/lib/core/sys-attrs"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:sys="http://www.swsoft.com/xsl/cp/sys"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm">
	
	<!--
		This file provides functions for system settings storage.		
	-->

	<!-- Includes -->
	<sw:include href="../globals.xsl" />
	<sw:include href="../swa/dirm.xsl" />
	<!-- /Includes -->
	
	
	<func:function name="sys:get-attrs">
		<xsl:param name="prefix" />
		<xsl:param name="sys-id" select="'vzcp'" />
		<xsl:param name="default" select="/.." />
		
		<xsl:variable name="sys-data" select="local:load-from-dirm($prefix,$sys-id)" />

		<xsl:choose>
			<xsl:when test="$sys-data!=''">
				<func:result select="$sys-data" />
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$default" />
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>

	<!-- Get a attr directly from agent using attributes storage attribute name (prefix) and attribute name-->
	<func:function name="sys:get-attr">
		<xsl:param name="prefix" />
		<xsl:param name="name" />
		<xsl:param name="sys-id" select="'vzcp'"/>
		<xsl:param name="default" select="/.." />
		
		<xsl:variable name="sys-data" select="sys:get-attrs($prefix,$sys-id)/*[name()=$name]" />
		<func:result select="sw:if($sys-data, $sys-data, $default)" />
	</func:function>
	
	<!-- Get a attr from previously loaded attributes object -->
	<func:function name="sys:get-cached-attr">
		<xsl:param name="attrs" />
		<xsl:param name="name" />
		<xsl:param name="default" select="/.." />
		
		<func:result select="sw:if($attrs/*[name()=$name], $attrs/*[name()=$name], $default)" />
	</func:function>
	
	<func:function name="sys:set-attrs">
		<xsl:param name="prefix" />
		<xsl:param name="data" />
		<xsl:param name="sys-id" select="'vzcp'"/>

		<xsl:variable name="data-rtf">
			<data>
				<xsl:copy-of select="$data" />
			</data>
		</xsl:variable>
		<xsl:if test="local:save-in-dirm($prefix, $data-rtf, $sys-id)" />		
		<func:result select="''"/>
	</func:function>
		
	<func:function name="sys:set-attr">
		<xsl:param name="prefix" />
		<xsl:param name="name" />
		<xsl:param name="value" />
		<xsl:param name="sys-id" select="'vzcp'"/>
		
		<xsl:variable name="old" select="sys:get-attrs($prefix,$sys-id)" />
		<xsl:variable name="new">
			<xsl:copy-of select="$old/*[name()!=$name]" />
			<xsl:element name="{$name}">
				<xsl:copy-of select="$value"/>
			</xsl:element>
		</xsl:variable>
		<xsl:if test="sys:set-attrs($prefix, $new,$sys-id)" />
		<func:result select="$old/*[name()=$name]"/>
	</func:function>
		

	<func:function name="local:load-from-dirm">		
		<xsl:param name="name"/>
		<xsl:param name="sys-id"/>
		
		<xsl:variable name="dn" select="concat('cn=',$sys-id,',cn=SysProfiles,cn=vzcp,',$global:vzl-dn)" />
		<xsl:variable name="existed" select="dirm:search($dn,'',0)/obj[1]" />

		<xsl:choose>
			<!-- Profile not found -->
			<xsl:when test="not($existed)">
				<func:result select="/.." />
			</xsl:when>
			<!-- /Profile not found -->
			<!-- Profile existed -->
			<xsl:otherwise>
				<func:result select="sw:node-set(sw:base64-decode(
					$existed/*[name()=$name]
				))/data" />
			</xsl:otherwise>
			<!-- /Profile existed -->
		</xsl:choose>
	</func:function>

	<func:function name="local:save-in-dirm">		
		<xsl:param name="name" />
		<xsl:param name="data" />
		<xsl:param name="sys-id" />
		
		<xsl:variable name="dn" select="concat('cn=',$sys-id,',cn=SysProfiles,cn=vzcp,',$global:vzl-dn)" />

		<!-- Try to find existed ENV profile -->
		<xsl:variable name="existed" select="dirm:search($dn,'',0)/obj[1]" />
		
		<xsl:choose>
			<!-- Create new profile -->
			<xsl:when test="not($existed)">
				<!-- Prepare profile  -->
				<xsl:variable name="profile-rtf">
					<ref>
						<dn>
							<xsl:value-of select="$dn" />
						</dn>
						<objectClass>VZCPSysProfile</objectClass>
					</ref>
					<data>
						<cn>
							<xsl:value-of select="$sys-id" />
						</cn>
						<xsl:element name="{$name}">
							<xsl:value-of select="sw:base64-encode(sw:text($data))" />
						</xsl:element>
					</data>
				</xsl:variable>
				<xsl:variable name="profile" select="exsl:node-set($profile-rtf)" />
				<!-- /Prepare profile  -->
				<!-- Store Profile -->
				<xsl:variable name="dirm-resp" select="dirm:add-obj($profile)" />
				<!-- /Store Profile -->
			</xsl:when>
			<!-- /Create new profile -->
			<!-- Update existing profile  -->
			<xsl:otherwise>
				<xsl:if
					test="dirm:set-attr($dn, $name, sw:base64-encode(sw:text($data)),$existed/*[name()=$name])" />
			</xsl:otherwise>
			<!-- /Update existing profile  -->
		</xsl:choose>

	</func:function>

</xsl:stylesheet>
