<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date cred units func local"
exclude-result-prefixes="func date cred global local units ui"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"
	xmlns:date		="http://exslt.org/dates-and-times"	
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:global  ="http://www.swsoft.com/xsl/cp/global"	
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:units		="http://www.swsoft.com/xsl/cp/units"	
	xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"
>	
		
	<xsl:variable name="units:top-level" select="3"/>
													
	<func:function name="units:encode-dn">
		<xsl:param name="dn"/>	
		<xsl:variable name="result">
			<xsl:for-each select="sw:explode-dn($dn)/attribute">
				<xsl:value-of select="concat(type,'=')"/>
				<xsl:value-of select="sw:base64-encode(sw:escape-dn-attribute(value))"/>
				<xsl:if test="position()!=last()">,</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="$result"/>
	</func:function>
	
	<func:function name="units:decode-dn">
		<xsl:param name="dn"/>
		<xsl:variable name="result">
			<xsl:if test="$dn!=''">
				<xsl:for-each select="sw:split($dn,',')">
					<xsl:value-of select="concat(substring-before(.,'='),'=')"/>
					<xsl:value-of select="sw:base64-decode(substring-after(.,'='))"/>
					<xsl:if test="position()!=last()">,</xsl:if>				
				</xsl:for-each>
			</xsl:if>
		</xsl:variable>
		<func:result select="$result"/>
	</func:function>												
							
	<func:function name="units:set-current-dn">
		<xsl:param name="dn"/>
		<func:result select="sw:sesputstr('farmdir-parent-dn',$dn)"/>
	</func:function>
	
	
	<func:function name="units:is-dn-top">
		<xsl:param name="dn"/>
		<func:result select="units:are-dns-equal($dn,units:logical-top-dn()) or units:are-dns-equal($dn,units:infra-top-dn())"/>
	</func:function>
	
	<func:function name="units:are-dns-equal">
		<xsl:param name="dn1"/>
		<xsl:param name="dn2"/>
		<func:result select="sw:uc(units:decode-dn($dn1))=sw:uc(units:decode-dn($dn2))"/>
	</func:function>
	
	<!-- 
		Get GUID for logical unit
		Parameters:
			Unit DN
		Returns: GUID string
	-->
	<func:function name="units:get-guid">
		<xsl:param name="dn"/>
		<func:result select="units:list($dn,$def-scope-base)/unit/id"/>
	</func:function>
	
	<func:function name="units:is-tree-logical">
		<xsl:param name="dn"/>
		<func:result select="units:dn2tree($dn)='logical'"/>
	</func:function>
	
	<func:function name="units:dn2tree">
		<xsl:param name="dn"/>
		<xsl:variable name="dn-decoded" select="sw:uc(units:decode-dn($dn))"/>		
		<xsl:choose>
			<xsl:when test="contains($dn-decoded,sw:uc(units:decode-dn(units:logical-top-dn())))">
				<func:result select="'logical'"/>
			</xsl:when>
			<xsl:when test="contains($dn-decoded,sw:uc(units:decode-dn(units:infra-top-dn())))">
				<func:result select="'infrastructure'"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>Unknown tree. Decoded dn is '<xsl:value-of select="$dn-decoded"/>'. Original dn is '<xsl:value-of select="$dn"/>."/></sw:die>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
				
	<func:function name="units:dn2level">
		<xsl:param name="dn"/>
		<func:result select="count(sw:split($dn,','))"/>
	</func:function>
	
	<!-- Calc parent's dn
		Input: encoded dn
	-->
	<func:function name="units:dn2parent">
		<xsl:param name="dn"/>
		<func:result select="substring-after($dn,',')"/>
	</func:function>
	
	<!-- Calc unit's name 
		Input: encoded escaped dn
	-->
	<func:function name="units:dn2name">
		<xsl:param name="dn"/>
		<func:result select="substring-before($dn,',')"/>
	</func:function>	
	
	<!-- Return title of unit by his DN -->
	<func:function name="units:dn2title">
		<xsl:param name="dn"/>
		<xsl:choose>
			<xsl:when test="units:are-dns-equal($dn,units:infra-top-dn())">
				<func:result select="sw:text('Infrastructure')"/>
			</xsl:when>
			<xsl:when test="units:are-dns-equal($dn,units:logical-top-dn())">
				<func:result select="sw:text('Logical View')"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:explode-dn(units:decode-dn($dn))[1]/attribute/value"/>				
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	
	<!-- Transform DN to nodeset -->
	<func:function name="units:dn2nodes">	
		<xsl:param name="dn"/>
		
		<xsl:variable name="res-rtf">
			<xsl:for-each select="sw:explode-dn(units:decode-dn($dn))">
				<xsl:variable name="full-dn">
					<xsl:value-of select="concat(attribute/type,'=',sw:base64-encode(sw:escape-dn-attribute(attribute/value)))"/>
					<xsl:for-each select="following-sibling::*">
						<xsl:value-of select="concat(',',attribute/type,'=',sw:base64-encode(sw:escape-dn-attribute(attribute/value)))"/>
					</xsl:for-each>		
				</xsl:variable>				
				<dn full-dn="{$full-dn}" 
					name="{attribute/type}" 
					value="{attribute/value}" 
					title="{units:dn2title($full-dn)}"
					index="{position()}"
					/>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>
	
	<!-- Return the LDAP base DN for trees -->
	<func:function name="units:tree-dn">					
		<xsl:param name="tree-id"/>
		
		<xsl:choose>
			<xsl:when test="$tree-id='logical'">
				<func:result select="units:logical-top-dn()"/>
			</xsl:when>
			<xsl:when test="$tree-id='infrastructure'">				
				<func:result select="units:infra-top-dn()"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					Unknown tree with name '<xsl:value-of select="$tree-id"/>'
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Return the LDAP base DN for Logical tree -->
	<func:function name="units:logical-top-dn">			
		<func:result select="units:encode-dn(concat('ou=VZLOrganization,',$global:vzl-dn))"/>
	</func:function>
	
	<!-- Return the LDAP base DN for Infrastructure list -->
	<func:function name="units:infra-top-dn">			
		<func:result select="units:encode-dn(concat('ou=VZLInfrastructure,',$global:vzl-dn))"/>
	</func:function>
				
	<!-- Find unit by dn  -->
	<func:function name="units:find-unit">
		<xsl:param name="dn"/>		
		
		<xsl:variable name="childs" select="units:list($dn,$def-scope-base)"/>
			
		<func:result select="$childs/unit[1]"/>
	</func:function>
	
  <!-- returns units list
  	Returns ref to error or nodeset with units and eids
  -->
	<func:function name="units:list">
  	<xsl:param name="dn"/>
  	<xsl:param name="scope" select="$def-scope-list"/>
  	
    <xsl:variable name="req">
      <packet>
      	<target>infrastructurem</target>
        <data>
          <infrastructurem>
            <list>
            	<name><xsl:value-of select="units:decode-dn($dn)"/></name>
            	<scope><xsl:value-of select="$scope"/></scope>
            	<attrs/>
            </list>
         </infrastructurem>
       </data>
     </packet>
   	</xsl:variable>
   
		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="resp-error" select="$resp/error|$resp/infrastructurem/error"/>
		
		<xsl:choose>
    	<xsl:when test="$resp-error">
    		<func:result select="$resp-error"/>			
    	</xsl:when>
    	<xsl:otherwise>
    		<xsl:variable name="result-rtf">
    			<infrastructurem>
    				<xsl:call-template name="units:list-convert-items">
    					<xsl:with-param name="units" select="$resp/infrastructurem/unit"/>
    				</xsl:call-template>
    			</infrastructurem>
    		</xsl:variable>
    		<func:result select="exsl:node-set($result-rtf)/infrastructurem"/>				
			</xsl:otherwise>
		</xsl:choose>
   
	</func:function>
	
	<xsl:template name="units:list-convert-items">
		<xsl:param name="units"/>
		
		<xsl:for-each select="$units">
			<unit>
				<xsl:copy-of select="@*"/>
				<xsl:copy-of select="*[not(self::name or self::unit)]"/> 
				<name>
					<xsl:copy-of select="name/@*"/>
					<xsl:value-of select="units:encode-dn(name)"/>
				</name>
				<xsl:if test="unit">
					<xsl:call-template name="units:list-convert-items">
						<xsl:with-param name="units" select="unit"/>
					</xsl:call-template>
				</xsl:if>
			</unit>
		</xsl:for-each>
		
	</xsl:template>
	
	<func:function name="units:folder-types">
		<xsl:variable name="folders-rtf">
			<folder type="1" title="{sw:text('Folder')}" icon="folder"/>
			<folder type="2" title="{sw:text('Datacenter')}" tree="infrastructure" icon="datacenter"/>
			<folder type="3" title="{sw:text('Rack')}" tree="infrastructure" icon="rack"/>
			<folder type="4" title="{sw:text('Department')}" tree="logical" icon="infrastructure"/>
		</xsl:variable>
		<func:result select="exsl:node-set($folders-rtf)/folder"/>
	</func:function>


	<!--  tab-now - tab where to go, but some external conditions need be checked:
        		tab-force = 'default' - means that stays on current tab
	          tab-force - tab setted by force
            tab-current - current tab. Diff screens has same tabs. 
            								For example infrastructure view, logical view, hn and ve has tab "Backup".
								            If tab-current defined and no force - then redirect to tab-current insteed tab-now
	-->
	<func:function name="units:tab-redirect">
		<xsl:param name="object-type"/>
		<xsl:param name="tab-now"/>
		
		<xsl:variable name="object-type-current" select="sw:sesgetstr('units-obj-type')"/>
		<xsl:if test="sw:sesputstr('units-obj-type',$object-type)"/>
		
		<xsl:choose>
			<!-- Do redirect only in VZCC -->
			<xsl:when test="$activeMode='vzcc'">		
				<xsl:variable name="tab-current" select="sw:sesgetstr('units-tab')"/>
				<xsl:variable name="tab-force" select="string(sw:param('tab-force'))"/>
				<xsl:choose>
					<!-- tab-force default, redirect to requested tab (tab-now)-->
					<xsl:when test="$tab-force='default' or ($object-type-current!='' and $object-type-current!=$object-type)">
						<xsl:if test="sw:sesputstr('units-tab',$tab-now)"/>
						<func:result select="''"/>												
					</xsl:when>
					<!-- not empty tab-force  setted, redirect to it  -->
					<xsl:when test="($tab-force != $tab-now) and ($tab-force !='')">
						<xsl:if test="sw:sesputstr('units-tab',$tab-force)"/>
						<func:result select="units:object2url($tab-force,$object-type)"/>						
					</xsl:when>					
					<!-- Already on right tab -->
					<xsl:when test="$tab-now = $tab-current">
						<func:result select="''"/>
					</xsl:when>
					<!--Redirect to current tab -->
					<xsl:when test="$tab-current != ''">
						<xsl:if test="sw:sesputstr('units-tab',$tab-current)"/>
						<func:result select="units:object2url($tab-current,$object-type)"/>
					</xsl:when>
					<!-- nothing change -->
					<xsl:otherwise>
						<func:result select="''"/>
					</xsl:otherwise>
				</xsl:choose>
				
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>

		
	</func:function>
	
	<func:function name="units:object2url">
		<xsl:param name="tab-current"/>
		<xsl:param name="object-type"/>
	
		<xsl:variable name="new-href" select="$global:classes/class[@vzcp-type=$object-type]/actions/action[@id = concat('redirect.',$tab-current)]/@href"/>
		<xsl:choose>
			<xsl:when test="$new-href!=''">
				<func:result>
					<packet>
						<cookie>
							<redirect><xsl:value-of select="concat($baseurl,$new-href)"/></redirect>
						</cookie>
					</packet>
				</func:result>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>

	<!-- Post Unit screen toolbars  -->	
	<xsl:template name="units:define-unit-toolbars">
		<xsl:variable name="parent-dn" select="units:current-dn()"/>
		
		<xsl:variable name="parent-title" select="units:dn2title($parent-dn)"/>
		<xsl:if test="sw:sesput('farmdir-parent-title',$parent-title)"/>	

		<xsl:choose>
			<xsl:when test="units:is-tree-logical($parent-dn)">
				<ui:toolbar id="logical.unit"/>
			</xsl:when>
			<xsl:otherwise>
				<ui:toolbar id="infrastructure.unit"/>
			</xsl:otherwise>
		</xsl:choose>
	
		<xsl:if test="not(units:is-dn-top($parent-dn))">
			<ui:toolbar id="unit.child"/>	
		</xsl:if>
			
	</xsl:template>
	<!-- /Post Unit screen toolbars  -->
		
</xsl:stylesheet>
