<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date cred units func local vzaconfig vzenv env"
exclude-result-prefixes="func date cred global local units env ve hn vzenv vzaconfig ui"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"
	xmlns:date		="http://exslt.org/dates-and-times"	
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:units		="http://www.swsoft.com/xsl/cp/units"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:ve			="http://www.swsoft.com/xsl/cp/ve"	
	xmlns:hn			="http://www.swsoft.com/xsl/cp/hn"
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:vzaconfig	="http://www.swsoft.com/xsl/cp/vzaconfig"
	xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"	
	xmlns:global    ="http://www.swsoft.com/xsl/cp/global"
>		
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vzaconfig.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>	
	
	<xsl:variable name="folder-types" select="units:folder-types()"/>
	<xsl:variable name="is-show-hn" select="boolean(sw:sesgetstr('menu-depth') != 'folders')"/>
	<xsl:variable name="is-show-ve" select="boolean(sw:sesgetstr('menu-depth') = 'ves')"/>
	
	<!-- Load units,envs and build new tree -->
	<func:function name="units:build-tree"> 
		<xsl:param name="dn"/>
		<xsl:param name="compact-mode" select="false()"/>		
		<xsl:param name="scope" select="$def-scope-tree"/>
		
		<!-- Load data -->
		<xsl:variable name="units" select="units:list($dn,$scope)"/>		
		<xsl:variable name="all-envs" select="local:tmp-load-envs($dn,$units)"/>
		<!-- /Load data -->
		
		<xsl:variable name="local-level" select="1"/>
		<xsl:variable name="start-units" select="sw:if($scope=$def-scope-tree,sw:if(
			units:are-dns-equal($units/unit[1]/name,$dn), 
			$units/unit[1]/*, $units/*),$units/*
		)"/>
		

		
		<xsl:variable name="res-rtf">	
			<xsl:copy-of select="local:tree-childs(				
				$start-units[self::unit],
				$all-envs,				
				$local-level,
				$compact-mode
			)"/>
			<!-- 
				Security issue. For 'Infrastructure' folder list all available
				HNs and VEs not included in any (sub)folder.
			-->
			<xsl:if test="units:are-dns-equal($dn,units:infra-top-dn())">
				<xsl:copy-of select="local:tree-envs($dn,$all-envs/env[not(eid=$units//eid)],$local-level,$compact-mode)"/>					
			</xsl:if>
				
			<xsl:copy-of select="local:tree-envs($dn,$all-envs/env[eid=$start-units[self::eid]],$local-level,$compact-mode)"/>
		</xsl:variable>				
		
		<func:result select="exsl:node-set($res-rtf)"/>
		
	</func:function>
	<!-- /Load units,envs and build new tree -->
	
	<!--
		Temporary local function to list environments from units.
		Caused by security issue - if there are no Hardware Nodes in 'Infrastructure' folder,
		get plain list of all available Nodes or Virtual Environments. Otherwise - list environments
		from units list.		
		Parameters:
			dn - current unit DN
			units - list of units
	-->
	<func:function name="local:tmp-load-envs">
		<xsl:param name="dn"/>
		<xsl:param name="units"/>
		<xsl:choose>
			<xsl:when test="units:are-dns-equal($dn,units:infra-top-dn())">
				<xsl:variable name="hns" select="local:load-envs(/..,'hn')"/>
				<xsl:variable name="ves-rtf">
					<xsl:if test="$is-show-ve">
						<xsl:copy-of select="local:load-envs(/..,'ve',$hns/env/eid)"/>
					</xsl:if>
				</xsl:variable>
				<xsl:variable name="ves" select="exsl:node-set($ves-rtf)"/>
				<func:result select="$hns | $ves/*"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="unit-eids" select="$units//eid"/>
				<xsl:choose>
					<xsl:when test="$unit-eids">
						<func:result select="local:load-envs($unit-eids)"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="/.."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>				
					
	<func:function name="local:tree-childs">
		<xsl:param name="units"/>
		<xsl:param name="all-envs"/>
		<xsl:param name="local-level"/>
		<xsl:param name="compact-mode" select="true()"/>
		<xsl:param name="open" select="false()"/>
				
		<!-- cycle -->
		<func:result>			
			<!-- Post units -->
			<xsl:for-each select="$units">
				<xsl:sort select="name"/>
				<xsl:variable name="unit" select="."/>
				<xsl:variable name="unit-level" select="units:dn2level(name)"/>
				<xsl:variable name="unit-title" select="units:dn2title(name)"/>
				<xsl:variable name="unit-type" select="sw:base64-decode(attr[name='vzlUnitType']/value)"/>
				<xsl:variable name="is-root" select="$unit-level=$units:top-level"/>
				<!--
				-->				
				<ui:cluster-unit id="{name}" level="{$local-level}" title="{$unit-title}"
					title4sort="00{$unit-title}"
					type="{sw:if(not($is-root),'unit','rootunit')}"
					type-text="{sw:text('Group Unit')}"
					icon="{sw:if($unit-type!='',concat($folder-types[@type=$unit-type]/@icon,'_16.gif'),'file_dir.gif')}"
				>
					<xsl:if test="$open">
						<xsl:attribute name="open">true</xsl:attribute>
					</xsl:if>
					<ui:description>
						<xsl:value-of select="$unit-title"/>
						<xsl:if test="attr[name='description']/value!=''">
							<br/>
							<xsl:value-of select="attr[name='description']/value"/>
						</xsl:if>
					</ui:description>
				</ui:cluster-unit>				
				<!-- Post childs -->
				<xsl:copy-of select="local:tree-childs(unit,$all-envs,$local-level+1,$compact-mode,$open)"/>
				<!-- /Post childs -->
				<!-- Post ENVs -->
				<xsl:copy-of select="local:tree-envs(name,$all-envs/env[eid=$unit/eid],$local-level+1,$compact-mode)"/>
				<!-- /Post ENVs -->
			</xsl:for-each>
			<!-- /Post units -->		
		</func:result>
		
	</func:function>
		
	<func:function name="local:tree-envs">
		<xsl:param name="parent-dn"/>
		<xsl:param name="envs"/>
		<xsl:param name="local-level"/>
		<xsl:param name="compact-mode" select="true()"/>
		
		<func:result>
			<!-- Post  HNs -->
			<xsl:if test="$is-show-hn">
				<xsl:for-each select="$envs[type='hn.core.vt']">
					<xsl:sort select="title"/>
					<xsl:variable name="hn" select="."/>			
					<xsl:variable name="left-icon" select="$hn:state[vza-value=$hn/state]/left-icon"/>
					<ui:cluster-unit id="eid={sw:base64-encode(eid)},{$parent-dn}" level="{$local-level}" 					
						title4sort="10{$hn/title}"
						env-eid="{eid}"
						icon="{$left-icon}"
						env-ip-address="{$hn/ip-text}"
						type="{type}"
						type-text="{sw:text('Virtuozzo HN')}"
						env-state="{$env-state/running}"
					>	
						
						<xsl:choose>
							<xsl:when test="not($hn)">
								<xsl:attribute name="env-state"><xsl:value-of select="$env-state/unexist"/></xsl:attribute>
								<xsl:attribute name="title">&lt;<sw:text>Deleted HN</sw:text>&gt;</xsl:attribute>
								<ui:description>
									HN was deleted or migrated.
								</ui:description>
							</xsl:when>
							<xsl:otherwise>
								<xsl:choose>
									<xsl:when test="$compact-mode or not($all-tree)">
										<xsl:attribute name="title"><xsl:value-of select="$hn/title"/></xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="title"><xsl:value-of 
											select="concat($hn/title,' ',$hn/ip-text)"
										/></xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
								<ui:description>
									<sw:text>Virtuozzo Hardware Node</sw:text>
									<br/>
									<xsl:value-of select="$hn/title"/>
									<br/>	
									<xsl:value-of select="$hn/ip-text"/>
								</ui:description>
							</xsl:otherwise>
						</xsl:choose>
					</ui:cluster-unit>	
				</xsl:for-each>
			</xsl:if>				
			<!-- /Post HNs -->
		
			<!-- Post ENVs -->
			<xsl:for-each select="$envs[type='env.core.vt']">
				<xsl:variable name="env" select="."/>				
				<xsl:variable name="left-icon" select="$ve:state[vza-value=$env/state]/left-icon"/>
				<ui:cluster-unit id="eid={sw:base64-encode(eid)},{$parent-dn}" level="{$local-level}" 				
					env-eid="{eid}"
					icon="{$left-icon}"
					type="{type}"
					type-text="{sw:text('Virtuozzo Container')}"
					env-ip-address="{$env/ip-text}"
					env-state="{$env/state}"
					env-transition="{$env/transition}"
					env-hn-title="{$env/hn-title}"
					env-sample-title="{$env/sample-title}"
					title4sort="11{$env/title}"
				>
					<xsl:choose>
						<xsl:when test="not($env)">
							<xsl:attribute name="env-state"><xsl:value-of select="$env-state/unexist"/></xsl:attribute>
							<xsl:attribute name="title">&lt;<sw:text>Deleted Container</sw:text>&gt;</xsl:attribute>
							<ui:description>
								VE was deleted or migrated.
							</ui:description>
						</xsl:when>
						<xsl:otherwise>		
							<xsl:attribute name="title">
								<xsl:value-of select="$env/title"/>
							</xsl:attribute>
										
							<ui:description>
								<sw:text>Virtuozzo Container</sw:text>&#160;#<xsl:value-of select="$env/veid"/>															
								<br/>
								<xsl:choose>
									<xsl:when test="$env/title!=''">
										<xsl:value-of select="$env/title"/>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>No title assigned</sw:text>
									</xsl:otherwise>
								</xsl:choose>
								<br/>								
								<xsl:choose>
									<xsl:when test="$env/ip-text!=''">
										<xsl:value-of select="$env/ip-text"/>
									</xsl:when>
									<xsl:otherwise>
										<sw:text>No IP address assigned</sw:text>
									</xsl:otherwise>
								</xsl:choose>
								<br/>
							</ui:description>
						</xsl:otherwise>
					</xsl:choose>
				</ui:cluster-unit>										
			</xsl:for-each>
			<!-- /Post ENVs -->
		</func:result>
	</func:function>

	<!--
		Local function to load environments via pager
		Parameters:
			eids - list of EDIs to load. If empty - load all environments
			env-type - optional, 've' - list VEs only, 'hn' - list HNs only, 
				'' - list all Environments, default
			hn-filter - node-set with list of EIDs, HNs with this EIDs and VEs
				with parent EIDs equal to given EIDs will be skipped 
	-->
	<func:function name="local:load-envs">
		<xsl:param name="eids"/>
		<xsl:param name="env-type" select="''"/>
		<xsl:param name="hn-filter" select="/.."/>
				<xsl:variable name="query">				
					<fields>
						<env.eid/>						
						<env.title/>
						<env.vconfig.ip_text/>
						<env.state/>
						<env.transition/>
						<env.parent_hostname/>
						<env.config.type/>
						<env.config.hostname/>								
						<env.config.ip_text/>
						<env.vconfig.veid/>
						<xsl:choose>
							<xsl:when test="$env-type='ve'">
								<env.vconfig.type/>
								<env.vconfig.os.platform/>
								<env.vconfig.architecture/>
							</xsl:when>
							<xsl:otherwise>
								<env.config.os.platform/>
								<env.config.architecture/>
							</xsl:otherwise>
						</xsl:choose>
					</fields>
					<sort>
						<fields>
							<env.title/>
							<env.config.hostname/>							
						</fields>
					</sort>
					<where>
						<xsl:variable name="conditions-rtf">
							<xsl:if test="not(vzaconfig:show-sve())">
								<condition>
									<xsl:copy-of select="ve:get-veid-range-filter()" />
								</condition>
							</xsl:if>
							<xsl:if test="$eids">			 
								<condition>
									(
										<xsl:for-each select="$eids">
												<xsl:if test="position()!=1"> or </xsl:if>						
												pager.env.eid='<xsl:value-of select="."/>'						
											</xsl:for-each>
									)
								</condition>
							</xsl:if>
							<xsl:choose>
								<xsl:when test="$env-type = 've'">
									<condition>
										pager.env.config.type!='generic'
									</condition>
								</xsl:when>
								<xsl:when test="$env-type = 'hn'">
									<condition>
										pager.env.config.type='generic'
									</condition>
								</xsl:when>
								<xsl:otherwise/>
							</xsl:choose>
							<xsl:if test="$hn-filter">
								<xsl:choose>
									<xsl:when test="$env-type = 've'">
										<condition>
											(
											<xsl:for-each select="$hn-filter">
												pager.env.parent_eid!='<xsl:value-of select="."/>'
												<xsl:if test="position()!=last()"> AND </xsl:if>
											</xsl:for-each>
											)
										</condition>										
									</xsl:when>
									<xsl:when test="$env-type = 'hn'">
										<condition>
											(
											<xsl:for-each select="$hn-filter">
												pager.env.eid!='<xsl:value-of select="."/>'
												<xsl:if test="position()!=last()"> AND </xsl:if>
											</xsl:for-each>
											)
										</condition>
									</xsl:when>
								</xsl:choose>
							</xsl:if>
						</xsl:variable>
						<xsl:for-each select="exsl:node-set($conditions-rtf)/condition">
							<xsl:if test="position()!=1"> AND </xsl:if>
							<xsl:value-of select="."/>
						</xsl:for-each>
					</where>
				</xsl:variable>								
				<xsl:variable name="result-rtf">				
					<envs>
						<xsl:for-each select="sw:xchg-sql($query)/pager/row_set/row/env">							
							<env>
								<eid><xsl:value-of select="eid"/></eid>
								<xsl:choose>
									<xsl:when test="config/type='generic'"><!-- HN -->
										<title><xsl:value-of select="config/hostname"/></title>
										<ip-text><xsl:value-of select="config/ip_text"/></ip-text>
										<type>hn.core.vt</type>
										<platform><xsl:value-of select="hn:hn2platform(.)"/></platform>
									</xsl:when>									
									<xsl:otherwise>
										<title><xsl:value-of select="title"/></title>
										<sample-title><xsl:value-of select="sw:if(vconfig/veid&lt;1000,'Gold','Silver')"/></sample-title>
										<hn-title><xsl:value-of select="parent_hostname"/></hn-title>
										<ip-text><xsl:value-of select="vconfig/ip_text"/></ip-text>
										<xsl:copy-of select="vconfig/veid"/>
										<type>env.core.vt</type>
										<platform><xsl:value-of select="ve:vza2platform(vconfig/os/platform, vconfig/architecture)"/></platform>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:copy-of select="state"/>
								<xsl:copy-of select="transition"/>
							</env>
						</xsl:for-each>
					</envs>
				</xsl:variable>
				<func:result select="exsl:node-set($result-rtf)/envs"/>
	</func:function>		
		
</xsl:stylesheet>
