<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func authm dirm user"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:func="http://exslt.org/functions"
	xmlns:exsl="http://exslt.org/common" 
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local/lib/core/user-attrs"
	xmlns:global  ="http://www.swsoft.com/xsl/cp/global"	
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:user="http://www.swsoft.com/xsl/cp/user"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm">
	
	<!--
		This file provides functions for user personal data storage.
		Cluster user uses user profile and VE user - env profile.
	-->

	<!-- Includes -->
	<sw:include href="../globals.xsl" />
	<sw:include href="../swa/authm.xsl" />
	<sw:include href="../swa/dirm.xsl" />

	<sw:include href="../vt/env-private.xsl" />
	<!-- /Includes -->
	
	<!-- Get stored user [interface] attrs/preferences -->
	 
	<!-- Get a attr set by prefix, ie authm user attribute name - 'desktopSettings', etc.-->
	<func:function name="user:supports-attrs">
		<xsl:param name="auth-type"/>
		<func:result select="$auth-type='veuser' or $auth-type='pleskadmin' or $auth-type='clusteruser'"/>
	</func:function>
	
	<func:function name="user:get-attrs">
		<xsl:param name="prefix" />
		<xsl:param name="default" select="/.." />
		
		<func:result select="user:get-attrs-ex($auth-type, local:get-context-selector($auth-type), $prefix, $default)" />
	</func:function>

	<func:function name="user:get-attrs-ex">
		<xsl:param name="auth-type" />
		<!-- eid, login etc. -->
		<xsl:param name="selector" />
		<xsl:param name="prefix" />
		<xsl:param name="default" select="/.." />

		<xsl:choose>
			<!-- Load for vzpp -->
			<xsl:when test="$auth-type = 'veuser' or $auth-type = 'env' or $auth-type = 'pleskadmin'">
				<xsl:variable name="user-data" select="local:load-from-dirm($prefix, $selector, 'UserEnvProfiles')" />
				<xsl:choose>
					<xsl:when test="$user-data!=''">
						<func:result select="$user-data" />
					</xsl:when>
					<xsl:otherwise>
						<func:result select="$default" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- /Load for vzpp -->
			<!-- Load for cluster user -->
			<xsl:when test="$auth-type = 'clusteruser'">
				<xsl:variable name="user-data" select="local:load-from-dirm($prefix, $selector, 'UserAuthProfiles')" />
				<xsl:choose>
					<xsl:when test="$user-data!=''">
						<func:result select="$user-data" />
					</xsl:when>
					<xsl:otherwise>
						<func:result select="$default" />
					</xsl:otherwise>
				</xsl:choose>			
			</xsl:when>
			<!--<xsl:when test="$auth-type = 'clusteruser'">
				<xsl:variable name="user-data"
					select="
					sw:node-set(
						sw:base64-decode(
							authm:get-user-attr($selector, $prefix)
						)
					)/data
				" />
				<xsl:choose>
					<xsl:when test="$user-data!=''">
						<func:result select="$user-data" />
					</xsl:when>
					<xsl:otherwise>
						<func:result select="$default" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>-->
			<!-- /Load for cluster user -->
			<xsl:when test="$auth-type = 'restoreauthmpassword'">
				<func:result select="$default" />
			</xsl:when>
			<xsl:when test="$auth-type = 'registration'">
				<func:result select="$default" />
			</xsl:when>
			<xsl:when test="not($auth-type != '')">
				<!-- no action here , it's login page -->
				<func:result select="$default"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					User preference library does not support auth-type <xsl:value-of select="$auth-type" />
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- Get a attr directly from agent using attributes storage attribute name (prefix) and attribute name-->
	<func:function name="user:get-attr">
		<xsl:param name="prefix" />
		<xsl:param name="name" />
		<xsl:param name="default" select="/.." />
		
		<xsl:variable name="user-data" select="user:get-attrs($prefix)/*[name()=$name]" />
		<func:result select="sw:if($user-data, $user-data, $default)" />
	</func:function>
	
	<!-- Get a attr directly from agent using attributes storage attribute name (prefix) and attribute name-->
	<func:function name="user:get-attr-ex">
		<xsl:param name="auth-type" />
		<!-- eid, login etc. -->
		<xsl:param name="selector" />
		<xsl:param name="prefix" />
		<xsl:param name="name" />
		<xsl:param name="default" select="/.." />
		
		<xsl:variable name="user-data"
			select="user:get-attrs-ex($auth-type, local:get-context-selector($auth-type), $prefix)/*[name()=$name]" />
		<func:result select="sw:if($user-data, $user-data, $default)" />
	</func:function>
	
	<!-- Get a attr from previously loaded attributes object -->
	<func:function name="user:get-cached-attr">
		<xsl:param name="attrs" />
		<xsl:param name="name" />
		<xsl:param name="default" select="/.." />
		
		<func:result select="sw:if($attrs/*[name()=$name], $attrs/*[name()=$name], $default)" />
	</func:function>
	
	<!-- Saves attributes set to authm/dirm or whatever backend we choose. -->
	<func:function name="user:set-attrs">
		<xsl:param name="prefix" />
		<xsl:param name="data" />
		<func:result select="user:set-attrs-ex($auth-type, local:get-context-selector($auth-type), $prefix, $data)" />
	</func:function>
	
	<func:function name="user:set-attrs-ex">
		<xsl:param name="auth-type" />
		<!-- eid, login etc. -->
		<xsl:param name="selector" />
		<xsl:param name="prefix" />
		<xsl:param name="data" />

		<xsl:if test="false()">
			<xsl:variable name="data-rtf">
				<data>
					<xsl:copy-of select="$data" />
				</data>
			</xsl:variable>
			<xsl:choose>
				<!-- Save for vzpp -->
				<xsl:when test="$auth-type = 'veuser' or $auth-type='env' or $auth-type='pleskadmin'">
					<func:result select="local:save-in-dirm($prefix, $data-rtf, $selector,'UserEnvProfiles')" />
				</xsl:when>
				<!-- /Save for vzpp -->
				<!-- Save for cluster user -->
				<xsl:when test="$auth-type = 'clusteruser'">
					<func:result select="local:save-in-dirm($prefix, $data-rtf, $selector,'UserAuthProfiles')" />
				</xsl:when>
				<!-- /Save for cluster user -->
				<!-- /Save for cluster user -->
				<xsl:when test="not($auth-type != '')">
					<!-- no action here , it's login page -->
					<func:result select="/.."/>
				</xsl:when>
				<xsl:otherwise>
					<sw:die>
						User preference library does not support auth-type <xsl:value-of select="$auth-type" />
					</sw:die>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		
		<func:result select="/.."/>
		
	</func:function>

	<!-- Set a single attribute. All other nodes in user attrs set are copied unchanged.
		Return old attr value. -->
	<func:function name="user:set-attr">
		<xsl:param name="prefix" />
		<xsl:param name="name" />
		<xsl:param name="value" />

		<xsl:if test="false()">
			<func:result select="user:set-attr-ex($auth-type, local:get-context-selector($auth-type), $prefix, $name, $value)" />
		</xsl:if>
		<func:result select="/.."/>		
	</func:function>
		
	<func:function name="user:set-attr-ex">
		<xsl:param name="auth-type" />
		<!-- eid, login etc. -->
		<xsl:param name="selector" />
		<xsl:param name="prefix" />
		<xsl:param name="name" />
		<xsl:param name="value" />
		
		<xsl:if test="false()">
			<xsl:variable name="old" select="user:get-attrs-ex($auth-type, $selector, $prefix)" />
			<xsl:variable name="new">
				<xsl:copy-of select="$old/*[name()!=$name]" />
				<xsl:element name="{$name}">
					<xsl:copy-of select="$value"/>
				</xsl:element>
			</xsl:variable>
			<xsl:if test="user:set-attrs-ex($auth-type, $selector, $prefix, $new)" />
			<func:result select="$old/*[name()=$name]"/>
		</xsl:if>
		<func:result select="/.."/>				
	</func:function>
	
	
	<!-- local utitlity functions -->
	
	<func:function name="local:get-context-selector">
		<xsl:param name="auth-type" />
		<xsl:choose>
			<xsl:when test="$auth-type='veuser' or $auth-type='pleskadmin'">
				<func:result select="sw:ve-eid()" />				
			</xsl:when>
			<xsl:when test="$auth-type='clusteruser'">
				<func:result select="$login" />
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:ve-eid()" />				
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="local:load-from-dirm">
		<xsl:param name="name" />
		<xsl:param name="eid" select="sw:ve-eid()" />
		<xsl:param name="cn"/>	
		
		<xsl:variable name="dn" select="concat('cn=',$eid,',cn=',$cn,',cn=vzcp,',$global:vzl-dn)" />
		<xsl:variable name="existed" select="dirm:search($dn,'',0)/obj[1]" />

		<xsl:choose>
			<!-- Profile not found -->
			<xsl:when test="not($existed)">
				<func:result select="/.." />
			</xsl:when>
			<!-- /Profile not found -->
			<!-- Profile existed -->
			<xsl:otherwise>
				<func:result select="sw:node-set(sw:base64-decode(
					$existed/*[name()=$name]
				))/data" />
			</xsl:otherwise>
			<!-- /Profile existed -->
		</xsl:choose>
	</func:function>

	<func:function name="local:save-in-dirm">
		<xsl:param name="name" />
		<xsl:param name="data" />
		<xsl:param name="eid" select="sw:ve-eid()" />
		<xsl:param name="cn"/>
		
		<xsl:variable name="dn" select="concat('cn=',$eid,',cn=',$cn,',cn=vzcp,',$global:vzl-dn)" />

		<!-- Try to find existed ENV profile -->
		<xsl:variable name="existed" select="dirm:search($dn,'',0)/obj[1]" />
		<xsl:choose>
			<!-- Create new profile -->
			<xsl:when test="not($existed)">
				<!-- Prepare profile  -->
				<xsl:variable name="profile-rtf">
					<ref>
						<dn>
							<xsl:value-of select="$dn" />
						</dn>
						<objectClass>VZCPUserProfile</objectClass>
					</ref>
					<data>
						<cn>
							<xsl:value-of select="$eid"/>
						</cn>						
						<xsl:element name="{$name}">
							<xsl:value-of select="sw:base64-encode(sw:text($data))" />
						</xsl:element>
					</data>
				</xsl:variable>
				<xsl:variable name="profile" select="exsl:node-set($profile-rtf)"/>
				<!-- /Prepare profile  -->
				<!-- Store Profile -->
				<func:result select="dirm:add-obj($profile)"/>
				<!-- /Store Profile -->
			</xsl:when>
			<!-- /Create new profile -->
			<!-- Update existing profile  -->
			<xsl:otherwise>
				<func:result select="dirm:set-attr($dn, $name, sw:base64-encode(sw:text($data)),$existed/*[name()=$name])" />
			</xsl:otherwise>
			<!-- /Update existing profile  -->
		</xsl:choose>

	</func:function>

</xsl:stylesheet>
