<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.

	== Functions Specifications ==
	
	User Profile Reference Handling
		user-profile:logged-ref()
		user-profile:construct-ref()
		
	User Profile Handling
		user-profile:get()
		
	User Profile Attrubutes Handling
		user-profile:get-attr()
		user-profile:set-attr()
		user-profile:set-attrs()
		
	User Profile Child Objects Handling
		user-profile:load-objects()
		user-profile:load-obj()
		user-profile:add-obj()
		user-profile:modify-obj()	

-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func authm dirm user-profile"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:func="http://exslt.org/functions"
	xmlns:exsl="http://exslt.org/common" 
	xmlns:global  ="http://www.swsoft.com/xsl/cp/global"	
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local/lib/core/user-profile"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:user-profile="http://www.swsoft.com/xsl/cp/user-profile"
	xmlns:user-profile-dirm="http://www.swsoft.com/xsl/cp/user-profile-dirm"	
	xmlns:user-profile-vearea="http://www.swsoft.com/xsl/cp/user-profile-vearea"		
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
>

	<xsl:variable name="user-profile:storage-dirm" select="'dirm'"/>
	<xsl:variable name="user-profile:storage-vearea" select="'vearea'"/>

	<!-- Includes -->
	<sw:include href="/lib/globals.xsl" />
	<sw:include href="/lib/swa/authm.xsl" />	
	<sw:include href="/lib/core/user-profile/storage-dirm.xsl" />		
	<sw:include href="/lib/core/user-profile/storage-vearea.xsl" />			
	
	<func:function name="user-profile:logged-ref">
		<xsl:choose>
			<xsl:when test="$auth-type='veuser' or $auth-type='pleskadmin'">
				<func:result select="user-profile:construct-ref($auth-type,$login,'',sw:ve-eid())"/>				
			</xsl:when>
			<xsl:when test="$auth-type='clusteruser'">
				<xsl:variable name="login-info" select="sw:login()/login"/>	
				<func:result select="user-profile:construct-ref($auth-type,sw:base64-decode($login-info/name),$login-info/realm,'')"/>					
			</xsl:when>
			<xsl:otherwise>
				<func:result select="user-profile:construct-ref($auth-type,$login,'',sw:ve-eid())"/>				
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="user-profile:construct-ref">
		<xsl:param name="auth-type"/>
		<xsl:param name="login"/>
		<xsl:param name="realm"/>
		<xsl:param name="ve-eid"/>
		
		<xsl:variable name="ref-id" select="concat($login,$realm,$ve-eid)"/>
		<xsl:variable name="storage-type" select="sw:if($auth-type = 'clusteruser',$user-profile:storage-dirm,$user-profile:storage-vearea)"/>		
		
		<xsl:variable name="data-rtf">
			<user-profile-ref>
				<storage><xsl:value-of select="$storage-type"/></storage>
				<ref-id><xsl:value-of select="$ref-id"/></ref-id>
				<auth-type><xsl:value-of select="$auth-type"/></auth-type>
				<login><xsl:value-of select="$login"/></login>				
				<xsl:choose>
					<xsl:when test="$storage-type=$user-profile:storage-vearea">
						<xsl:copy-of select="user-profile-vearea:extend-ref($ref-id,$auth-type,$login,$realm,$ve-eid)"/>
					</xsl:when>
					<xsl:when test="$storage-type=$user-profile:storage-dirm">
						<xsl:copy-of select="user-profile-dirm:extend-ref($ref-id,$auth-type,$login,$realm,$ve-eid)"/>
					</xsl:when>
				</xsl:choose>
			</user-profile-ref>	
		</xsl:variable>
		
		<func:result select="exsl:node-set($data-rtf)/user-profile-ref"/>
	</func:function>
	
	<func:function name="user-profile:get">
		<xsl:param name="ref"/>		
	
		<xsl:choose>
			<xsl:when test="$ref/storage=$user-profile:storage-vearea">
				<func:result select="user-profile-vearea:get($ref)"/>
			</xsl:when>
			<xsl:when test="$ref/storage=$user-profile:storage-dirm">
				<func:result select="user-profile-dirm:get($ref)"/>
			</xsl:when>
		</xsl:choose>
	
	</func:function>
	
	<func:function name="user-profile:get-attr">
		<xsl:param name="ref"/>		
		<xsl:param name="attr-name"/>
	
		<xsl:choose>
			<xsl:when test="$ref/storage=$user-profile:storage-vearea">
				<func:result select="user-profile-vearea:get-attr($ref,$attr-name)"/>
			</xsl:when>
			<xsl:when test="$ref/storage=$user-profile:storage-dirm">
				<func:result select="user-profile-dirm:get-attr($ref,$attr-name)"/>
			</xsl:when>
		</xsl:choose>
	
	</func:function>

	<func:function name="user-profile:set-attr">
		<xsl:param name="ref"/>		
		<xsl:param name="attr-name"/>
		<xsl:param name="attr-value"/>
			
		<xsl:choose>
			<xsl:when test="$ref/storage=$user-profile:storage-vearea">
				<func:result select="user-profile-vearea:set-attr($ref,$attr-name,$attr-value)"/>
			</xsl:when>
			<xsl:when test="$ref/storage=$user-profile:storage-dirm">
				<func:result select="user-profile-dirm:set-attr($ref,$attr-name,$attr-value)"/>
			</xsl:when>
		</xsl:choose>

	</func:function>
	

	<func:function name="user-profile:set-attrs">
		<xsl:param name="ref"/>		
		<xsl:param name="data"/>
			
		<xsl:choose>
			<xsl:when test="$ref/storage=$user-profile:storage-vearea">
				<func:result select="user-profile-vearea:set-attrs($ref,$data)"/>
			</xsl:when>
			<xsl:when test="$ref/storage=$user-profile:storage-dirm">
				<func:result select="user-profile-dirm:set-attrs($ref,$data)"/>
			</xsl:when>
		</xsl:choose>

	</func:function>	
	
	<func:function name="user-profile:load-objects">
		<xsl:param name="ref"/>
		<xsl:param name="folder"/>	
		<xsl:param name="recreate" select="false()"/>				
		<xsl:param name="folder-class" select="''"/>			
			
		<xsl:choose>
			<xsl:when test="$ref/storage=$user-profile:storage-vearea">
				<func:result select="user-profile-vearea:load-objects($ref,$folder,$recreate,$folder-class)"/>
			</xsl:when>
			<xsl:when test="$ref/storage=$user-profile:storage-dirm">
				<func:result select="user-profile-dirm:load-objects($ref,$folder,$recreate,$folder-class)"/>
			</xsl:when>
		</xsl:choose>

	</func:function>

	<func:function name="user-profile:load-obj">
		<xsl:param name="ref"/>
		<xsl:param name="dn"/>
		
		<xsl:choose>
			<xsl:when test="$ref/storage=$user-profile:storage-vearea">
				<func:result select="user-profile-vearea:load-obj($ref,$dn)"/>
			</xsl:when>
			<xsl:when test="$ref/storage=$user-profile:storage-dirm">
				<func:result select="user-profile-dirm:load-obj($ref,$dn)"/>
			</xsl:when>
		</xsl:choose>
	</func:function>
	
	<func:function name="user-profile:add-obj">
		<xsl:param name="ref"/>
		<xsl:param name="obj"/>
		
		<xsl:choose>
			<xsl:when test="$ref/storage=$user-profile:storage-vearea">
				<func:result select="user-profile-vearea:add-obj($ref,$obj)"/>
			</xsl:when>
			<xsl:when test="$ref/storage=$user-profile:storage-dirm">
				<func:result select="user-profile-dirm:add-obj($ref,$obj)"/>
			</xsl:when>
		</xsl:choose>
	</func:function>
	
		
	<func:function name="user-profile:modify-obj">
		<xsl:param name="ref"/>
		<xsl:param name="obj"/>
		
		<xsl:choose>
			<xsl:when test="$ref/storage=$user-profile:storage-vearea">
				<func:result select="user-profile-vearea:modify-obj($ref,$obj)"/>
			</xsl:when>
			<xsl:when test="$ref/storage=$user-profile:storage-dirm">
				<func:result select="user-profile-dirm:modify-obj($ref,$obj)"/>
			</xsl:when>
		</xsl:choose>
	</func:function>
	
</xsl:stylesheet>
