<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
	
	== Functions Specifications ==
	
	User Profile Reference Handling
		user-profile-dirm:extend-ref()
		
	User Profile Handling
		user-profile-dirm:get()		
		
	User Profile Single Attrubutes Handling
		user-profile-dirm:get-attr()
		user-profile-dirm:set-attr()
		user-profile-dirm:set-attrs()
		
	User Profile Child Objects Handling
		user-profile-dirm:load-objects()
		user-profile-dirm:load-obj()
		user-profile-dirm:add-obj()
		user-profile-dirm:modify-obj()	
		
	Data specification
		Data is storing in LDAP, profile root is cn=<login><realm>,cn=UserAuthProfiles,cn=vzcp,ou=MASTER_EID,dc=VZL
		
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func authm dirm user-profile-dirm"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform" 
	xmlns:func			="http://exslt.org/functions"
	xmlns:exsl			="http://exslt.org/common" 
	xmlns:sw				="http://www.swsoft.com/xsl/cp" 
	xmlns:global		="http://www.swsoft.com/xsl/cp/global"	
	xmlns:local			="http://www.swsoft.com/xsl/cp/local/lib/core/user-profile/storage-dirm"
	xmlns:authm			="http://www.swsoft.com/xsl/cp/authm"
	xmlns:user-profile-dirm="http://www.swsoft.com/xsl/cp/user-profile-dirm"
	xmlns:dirm			="http://www.swsoft.com/xsl/cp/dirm"
>
	<!-- Includes -->
	<sw:include href="/lib/globals.xsl" />
	<sw:include href="/lib/swa/authm.xsl" />
	<sw:include href="/lib/swa/dirm.xsl" />
	
	<func:function name="user-profile-dirm:extend-ref">
		<xsl:param name="ref-id"/>
		<xsl:param name="auth-type"/>
		<xsl:param name="login"/>
		<xsl:param name="realm"/>
		<xsl:param name="ve-eid"/>
		
		<xsl:variable name="data-rtf">				
			<realm><xsl:value-of select="$realm"/></realm>	
			<dn><xsl:value-of select="concat('cn=',sw:escape-dn-attribute($ref-id),',cn=UserAuthProfiles,cn=vzcp,',$global:vzl-dn)"/></dn>				
		</xsl:variable>
		
		<func:result select="$data-rtf"/>
	</func:function>	

	<func:function name="user-profile-dirm:get">
		<xsl:param name="ref"/>		
		
		<xsl:variable name="obj" select="dirm:search($ref/dn,'',0)/obj[1]" />				
		<func:result select="$obj"/>	
	
	</func:function>

	<func:function name="user-profile-dirm:get-attr">
		<xsl:param name="ref"/>		
		<xsl:param name="attr-name"/>
		
		<xsl:variable name="obj" select="dirm:search($ref/dn,'',0)/obj[1]" />		
		
		<xsl:choose>
			<xsl:when test="not($obj) or $obj[self::error]">
				<func:result select="$obj"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$obj/*[name()=$attr-name]"/>
			</xsl:otherwise>
		</xsl:choose>
	
	</func:function>
	
	<func:function name="user-profile-dirm:set-attrs">
		<xsl:param name="ref" />		
		<xsl:param name="data" />
			
		<xsl:variable name="dirm-resp" select="dirm:set-attrs($ref/dn, $data)/packet/data"/>
		<func:result select="$dirm-resp/error|$dirm-resp/dirm/error"/>

	</func:function>	

	<func:function name="user-profile-dirm:set-attr">
		<xsl:param name="ref" />		
		<xsl:param name="attr-name" />
		<xsl:param name="attr-value" />
			
		<!-- Try to find existed profile -->
		<xsl:variable name="existed-obj" select="dirm:search($ref/dn,'',0)/obj[1]"/>		
		
		<xsl:choose>
			<!-- Create new profile -->
			<xsl:when test="not($existed-obj)">
				<!-- Create only for non-empty attribute value -->
				<xsl:if test="$attr-value!=''">
					<sw:die>
						Profile should be created in postlogin code.
					</sw:die>
				</xsl:if>
			</xsl:when>
			<!-- /Create new profile -->
			<!-- Update existing profile -->
			<xsl:otherwise>
				<xsl:variable name="existed-attr" select="$existed-obj/*[name()=$attr-name]"/>					
				<xsl:choose>
					<!-- Remove empty attribute -->
					<xsl:when test="$attr-value='' and $existed-attr">
						<xsl:variable name="dirm-resp" select="dirm:remove-attr($ref/dn, $attr-name)/packet/data"/>
						<func:result select="$dirm-resp/error|$dirm-resp/dirm/error"/>
					</xsl:when>
					<!-- Update or add attribute -->
					<xsl:when test="$attr-value!=''">					
						<xsl:variable name="dirm-resp" select="dirm:set-attr(
							$ref/dn, $attr-name, $attr-value, boolean($existed-attr), true() 
						)/packet/data"/>
						<func:result select="$dirm-resp/error|$dirm-resp/dirm/error"/>
					</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
			<!-- /Update existing profile  -->
		</xsl:choose>

	</func:function>
	
	<func:function name="user-profile-dirm:load-objects">
		<xsl:param name="ref"/>			
		<xsl:param name="folder-name"/>
		<xsl:param name="recreate" select="false()"/>				
		<xsl:param name="folder-class" select="''"/>		
		
		<xsl:variable name="full-dn" select="concat('cn=',$folder-name,',',$ref/dn)"/>
	
		<!-- Seek settings in LDAP under user profile -->
		<xsl:variable name="records" select="dirm:search($full-dn,'',2)/obj"/>
		
		<xsl:choose>
			<!-- Error was occured -->
			<xsl:when test="$records[self::error]">
				<func:result select="$records"/>
			</xsl:when>
			<!-- Folder is existing -->
			<xsl:when test="$records">
				<func:result select="$records[position()!=1]"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- Prepare -->
				<xsl:variable name="obj-rtf">
					<ref>
						<dn>
							<xsl:value-of select="$full-dn" />
						</dn>
						<objectClass><xsl:value-of select="$folder-class"/></objectClass>
					</ref>
					<data>
						<cn><xsl:value-of select="$folder-name"/></cn>
					</data>
				</xsl:variable>
				<xsl:variable name="obj" select="exsl:node-set($obj-rtf)"/>
				<!-- /Prepare -->
				<!-- Create -->
				<xsl:variable name="dirm-resp" select="dirm:add-obj($obj)/packet/data"/>
				<xsl:variable name="error" select="$dirm-resp/error|$dirm-resp/dirm/error"/>	
				<func:result select="$error"/>
				
			</xsl:otherwise>
		</xsl:choose>
	
	</func:function>
	
	<func:function name="user-profile-dirm:load-obj">
		<xsl:param name="ref"/>
		<xsl:param name="dn"/>
	
		<func:result select="dirm:search($dn,'',0)/obj[1]"/>		
		
	</func:function>
	
	<func:function name="user-profile-dirm:add-obj">
		<xsl:param name="ref"/>
		<xsl:param name="obj"/>
		<func:result select="dirm:add-obj($obj)"/>
	</func:function>

	<func:function name="user-profile-dirm:modify-obj">
		<xsl:param name="ref"/>
		<xsl:param name="obj"/>
		<func:result select="dirm:modify-obj($obj)"/>
	</func:function>
	
</xsl:stylesheet>
