<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
	
	== Functions Specifications ==
	
	User Profile Reference Handling
		user-profile-vearea:extend-ref()
		
	User Profile Handling
		user-profile-vearea:get()
		
	User Profile Attrubutes Handling
		user-profile-vearea:get-attr()
		user-profile-vearea:set-attr()
		user-profile-vearea:set-attrs()
		
	User Profile Child Objects Handling
		user-profile-vearea:load-objects()
		user-profile-vearea:load-obj()
		user-profile-vearea:add-obj()
		user-profile-vearea:modify-obj()	
		
	Data specification
		Data is storing in VE private area, in XML file.
		Example of /vz/private/102/vzagent/vzcp-profile 

		<profiles>
			<profile login="root">
				<mail>test@test.com</mail>
				<directory>
					<BrowsersSettings>
						<obj dn="browseID=services,cn=BrowsersSettings,cn=root627b205c-ad1b-ec42-8a76-b6c00c8415a9,cn=UserEnvProfiles,cn=vzcp,dc=VZL">
							<browseID>services</browseID>
							<itemsOnPage>80</itemsOnPage>
							<sortColumn>id</sortColumn>
							<sortDirection>asc</sortDirection>
							<filterVisibleColumns></filterVisibleColumns>
							<filterHiddenColumns></filterHiddenColumns>
							<listVisibleColumns></listVisibleColumns>
							<listHiddenColumns></listHiddenColumns>
						</obj>
					</BrowsersSettings>
				</directory>
			</profile>
		</profiles>
	
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func user-profile-vearea"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:func="http://exslt.org/functions"
	xmlns:exsl="http://exslt.org/common" 
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:local="http://www.swsoft.com/xsl/cp/local/lib/core/user-profile/storage-vearea"
	xmlns:user-profile-vearea="http://www.swsoft.com/xsl/cp/user-profile-vearea"
>
	<!-- Includes -->
	<sw:include href="/lib/globals.xsl" />
	<sw:include href="/lib/vt/env-private.xsl" />	
	
	<func:function name="user-profile-vearea:extend-ref">
		<xsl:param name="ref-id"/>
		<xsl:param name="auth-type"/>
		<xsl:param name="login"/>
		<xsl:param name="realm"/>
		<xsl:param name="ve-eid"/>
		
		<xsl:variable name="data-rtf">				
			<ve-eid><xsl:value-of select="$ve-eid"/></ve-eid>
			<vearea-key><xsl:value-of select="'vzcp-profile'"/></vearea-key>
			<dn><xsl:value-of select="concat('cn=',$ref-id,',cn=UserEnvProfiles,cn=vzcp,dc=VZL')"/></dn>				
		</xsl:variable>
		
		<func:result select="$data-rtf"/>
	</func:function>
	
	<func:function name="user-profile-vearea:get">
		<xsl:param name="ref"/>		
		
		<xsl:variable name="data" select="sw:get-private($ref/ve-eid,$ref/vearea-key)"/>	
		<xsl:choose>
			<xsl:when test="not($data)">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$data/profiles/profile[@login=$ref/login]"/>			
			</xsl:otherwise>
		</xsl:choose>

	</func:function>	
	
	<func:function name="user-profile-vearea:get-attr">
		<xsl:param name="ref"/>		
		<xsl:param name="attr-name"/>
		
		<xsl:variable name="data" select="sw:get-private($ref/ve-eid,$ref/vearea-key)"/>	
		<xsl:choose>
			<xsl:when test="not($data)">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$data/profiles/profile[@login=$ref/login]/*[name()=$attr-name]"/>			
			</xsl:otherwise>
		</xsl:choose>

	</func:function>

	<func:function name="user-profile-vearea:set-attr">
		<xsl:param name="ref"/>		
		<xsl:param name="attr-name"/>
		<xsl:param name="attr-value"/>
		
		<xsl:variable name="old-data" select="sw:get-private($ref/ve-eid,$ref/vearea-key)"/>	
		<xsl:variable name="old-profile" select="$old-data/profiles/profile[@login=$ref/login]"/>	

		<xsl:variable name="res" select="local:update-profile-element($ref,$old-data,$old-profile,$attr-name,string($attr-value))"/>	

		<func:result select="/.."/>
	</func:function>
	
	<func:function name="user-profile-vearea:set-attrs">
		<xsl:param name="ref"/>		
		<xsl:param name="data"/>
		
		<xsl:variable name="old-data" select="sw:get-private($ref/ve-eid,$ref/vearea-key)"/>	
		<xsl:variable name="old-profile" select="$old-data/profiles/profile[@login=$ref/login]"/>	

		<xsl:variable name="res" select="local:update-profile-elements($ref,$old-data,$old-profile,$data)"/>	

		<func:result select="/.."/>
	</func:function>	

	
	<func:function name="user-profile-vearea:load-obj">
		<xsl:param name="ref"/>
		<xsl:param name="dn"/>
		<!--  dn format: objId=objIDValue,cn=folderName,.....  -->
		<xsl:variable name="dns" select="sw:split($dn,',')"/>
		<xsl:variable name="folder-name" select="substring-after($dns[2],'=')"/>	
	
		<xsl:variable name="folder" select="user-profile-vearea:load-objects($ref,$folder-name)"/>	
		<func:result select="$folder/obj[@dn=$dn]"/>
		
	</func:function>
	
	<func:function name="user-profile-vearea:add-obj">
		<xsl:param name="ref"/>
		<xsl:param name="obj"/>
		
		<func:result select="user-profile-vearea:modify-obj($ref,$obj)"/>	

	</func:function>

	<func:function name="user-profile-vearea:modify-obj">
		<xsl:param name="ref"/>
		<xsl:param name="obj"/>
		
		<xsl:variable name="dns" select="sw:split($obj/ref/dn,',')"/>
		<xsl:variable name="folder-name" select="substring-after($dns[2],'=')"/>	
	
		<xsl:variable name="old-data" select="sw:get-private($ref/ve-eid,$ref/vearea-key)"/>	
		<xsl:variable name="old-profile" select="$old-data/profiles/profile[@login=$ref/login]"/>	
		<xsl:variable name="old-directory" select="$old-profile/directory"/>
		<xsl:variable name="old-folder" select="$old-directory/*[name()=$folder-name]"/>

		<xsl:variable name="new-directory-rtf">
			<xsl:copy-of select="$old-directory/*[not(name()=$folder-name)]"/>
			<xsl:element name="{$folder-name}">
				<xsl:copy-of select="$old-folder/obj[not(@dn=$obj/ref/dn)]"/>
				<obj dn="{$obj/ref/dn}">
					<xsl:for-each select="$obj/data/*">
						<xsl:element name="{name()}">
							<xsl:value-of select="."/>
						</xsl:element>
					</xsl:for-each>
				</obj>
			</xsl:element>
		</xsl:variable>
		<xsl:variable name="res" select="local:update-profile-element($ref,$old-data,$old-profile,'directory',$new-directory-rtf)"/>	
		
		<func:result select="/.."/>
	</func:function>
	

	<func:function name="user-profile-vearea:load-objects">
		<xsl:param name="ref"/>			
		<xsl:param name="folder-name"/>
		<xsl:param name="recreate" select="false()"/>				
		<xsl:param name="folder-class" select="''"/>		
		
		<xsl:variable name="old-data" select="sw:get-private($ref/ve-eid,$ref/vearea-key)"/>	
		<xsl:variable name="old-profile" select="$old-data/profiles/profile[@login=$ref/login]"/>	
		<xsl:variable name="old-directory" select="$old-profile/directory"/>	
		<xsl:variable name="old-folder" select="$old-directory/*[name()=$folder-name]"/>
				
		<xsl:choose>
			<!-- folder exists -->
			<xsl:when test="$old-folder">
				<func:result select="$old-folder/obj"/>
			</xsl:when>
			<!-- create folder -->
			<xsl:otherwise>
				
				<xsl:if test="$recreate">
					<xsl:variable name="new-directory-rtf">
						<xsl:copy-of select="$old-directory/*[not(name()=$folder-name)]"/>
						<xsl:element name="{$folder-name}"/>
					</xsl:variable>
					<xsl:variable name="res" select="local:update-profile-element($ref,$old-data,$old-profile,'directory',$new-directory-rtf)"/>	
				</xsl:if>
				
				<func:result select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<func:function name="local:update-profile-element">
		<xsl:param name="ref"/>			
		<xsl:param name="old-data"/>
		<xsl:param name="old-profile"/>
		<xsl:param name="element-name"/>
		<xsl:param name="element-content"/>
				
		<xsl:variable name="new-data-rtf">
			<profiles>
				<xsl:copy-of select="$old-data/profiles/profile[not(@login=$ref/login)]"/>
				<profile login="{$ref/login}">
					<xsl:copy-of select="$old-profile/*[not(name()=$element-name)]"/>
					<xsl:element name="{$element-name}">
						<xsl:copy-of select="$element-content"/>
					</xsl:element>
				</profile>
			</profiles>
		</xsl:variable>
		<xsl:variable name="res" select="sw:put-private($new-data-rtf,$ref/ve-eid,$ref/vearea-key)"/>
		<func:result select="$res"/>
		
	</func:function>
	
	<func:function name="local:update-profile-elements">
		<xsl:param name="ref"/>			
		<xsl:param name="old-data"/>
		<xsl:param name="old-profile"/>
		<xsl:param name="data"/>
				
		<xsl:variable name="new-data-rtf">
			<profiles>
				<xsl:copy-of select="$old-data/profiles/profile[not(@login=$ref/login)]"/>
				<profile login="{$ref/login}">
					<xsl:copy-of select="$data/*"/>				
					<xsl:for-each select="$old-profile/*">
						<xsl:variable name="name" select="name()"/>
						<xsl:if test="not($data/*[name()=$name])">
							<xsl:copy-of select="."/>
						</xsl:if>
					</xsl:for-each>
				</profile>
			</profiles>
		</xsl:variable>
		<xsl:variable name="res" select="sw:put-private($new-data-rtf,$ref/ve-eid,$ref/vearea-key)"/>
		<func:result select="$res"/>
		
	</func:function>	
	
</xsl:stylesheet>
