<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func dyn vt hn env securitym local error ui"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:dyn="http://exslt.org/dynamic"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<sw:include href="/lib/swa/securitym.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<!-- filter items by credentials and addon conditions 
		Arguments 
			items list
		return-type   'nodeset'(default)/'RTF'
		Result
			nodeset or RTF
	-->
	<func:function name="cred:filter-items">
		<xsl:param name="items"/>
		<xsl:param name="return-type" select="'nodeset'"/>

		<xsl:variable name="cred-set-rtf">
			<xsl:call-template name="local:filter-cred-set">
				<xsl:with-param name="items" select="$items"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="cred-set" select="exsl:node-set($cred-set-rtf)"/>
		<!-- Access map - list of credentials per object type and ID with allow/deny element -->
		<xsl:variable name="access-map" select="securitym:access-map($cred-set/cred)"/>
		
		<xsl:variable name="ve-platform" select="env:env2platform( env:get-env(sw:ve-eid())/env )"/>
		<xsl:variable name="hn-platform" select="hn:hn2platform( env:get-env(sw:hn-eid())/env )"/>
		
		<xsl:variable name="result-rtf">
			<xsl:call-template name="local:filter-list">
				<xsl:with-param name="items" select="$items"/>
				<xsl:with-param name="ve-platform" select="$ve-platform"/>
				<xsl:with-param name="hn-platform" select="$hn-platform"/>				
				<xsl:with-param name="access-map" select="$access-map"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$return-type='nodeset'">
				<func:result select="exsl:node-set($result-rtf)/*"/>
			</xsl:when>
			<xsl:when test="$return-type='RTF'">
				<func:result select="$result-rtf"/>							
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					Wrong return-type value '<xsl:value-of select="$return-type"/>'
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!--
		Local function. Return entries from access map which intersects
		with list of credentials by means of security attributes
		Parameters:
			node-set with access map
			node-set with creds
	-->
	<func:function name="local:match-cred-access">
		<xsl:param name="access-map"/>
		<xsl:param name="creds"/>

		<xsl:variable name="access-matched-rtf">
			<xsl:for-each select="$access-map">
				<xsl:if test="$creds[@cred=string(current()/@id) 
					and sw:if(@security-obj-type,@security-obj-type,'vzcp')=string(current()/@security-obj-type)
					and sw:if(@security-obj-id,@security-obj-id,'default')=string(current()/@security-obj-id)]">
					<xsl:copy-of select="."/>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($access-matched-rtf)/*"/>
	</func:function>

	<xsl:template name="local:filter-list">
		<xsl:param name="items"/>
		<xsl:param name="ve-platform"/>
		<xsl:param name="hn-platform"/>		
		<xsl:param name="access-map"/>
				
		<xsl:for-each
			select="
			$items[ 
				name()!=''
				and (not(@cond) or dyn:evaluate(@cond)) 
				and (not((@sve = 'deny') and (sw:sesget('env-veid') = 1)))
				and (not(@platform) or vt:compare-platforms($ve-platform,@platform))
				and (not(@hn-platform) or vt:compare-platforms($hn-platform,@hn-platform))]
		">
			<xsl:variable name="sobj-type"
				select="sw:if(not(@security-obj-type!=''),'vzcp',string(@security-obj-type))"/>
			<xsl:variable name="sobj-id"
				select="sw:if(not(@security-obj-id!=''),'default',string(@security-obj-id))"/>
			<!--
				Valid item:
				1. No creds
				2. Element credential matches access map
				3. Any of included list credentials match access map 
			-->
			<xsl:if test="( 
				$config/vzcpcon/security/enabled='false'
				or ( not(@cred) and count(security)=0 and not(@security-op-id) ) )
				or ( @security-op-id and securitym:check-operation(
					@security-op-id,
					sw:if($sobj-id='default',securitym:context-scope($sobj-type),securitym:scope($sobj-id,$sobj-type))) ) 
				or $access-map/cred[@id=current()/@cred and @security-obj-type=$sobj-type and @security-obj-id=$sobj-id]/allow
				or local:match-cred-access($access-map/cred,security)/allow">
				<xsl:element name="{name()}">
					<xsl:copy-of select="@*"/>
					<xsl:if test="*[name(.)!='']">
						<xsl:call-template name="local:filter-list">
							<xsl:with-param name="items" select="*[name(.)!='']"/>
							<xsl:with-param name="ve-platform" select="$ve-platform"/>
							<xsl:with-param name="hn-platform" select="$hn-platform"/>
							<xsl:with-param name="access-map" select="$access-map"/>						
						</xsl:call-template>
					</xsl:if>
					<xsl:copy-of select="text()"/>
				</xsl:element>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<!-- 
		Local template. For given tree, converts security attributes
		to fully specified 'cred' child elements
		Parameters:
			Any node list
	-->
	<xsl:template name="local:filter-cred-set">
		<xsl:param name="items"/>
		<xsl:for-each select="$items">
			<xsl:if test="@cred != ''">
				<cred security-obj-type="{sw:if(not(@security-obj-type!=''),'vzcp',@security-obj-type)}"
					security-obj-id="{sw:if(not(@security-obj-id!=''),'default',@security-obj-id)}"
					id="{@cred}"/>
			</xsl:if>
			<xsl:for-each select="security">
				<cred security-obj-type="{sw:if(not(@security-obj-type!=''),'vzcp',@security-obj-type)}"
					security-obj-id="{sw:if(not(@security-obj-id!=''),'default',@security-obj-id)}"
					id="{@cred}"/>				
			</xsl:for-each>
			<xsl:call-template name="local:filter-cred-set">
				<xsl:with-param name="items" select="*[name(.)!='']"/>
			</xsl:call-template>			
		</xsl:for-each>
	</xsl:template>

	<func:function name="cred:filter-valid-env">
		<xsl:param name="perm"/>
		<xsl:param name="env-ids"/>
		<xsl:param name="set-error" select="true()"/>
		<xsl:variable name="cred-rtf">
			<xsl:for-each select="$env-ids">
				<cred id="{$perm}" security-obj-type="ve.vz.vt"
					security-obj-id="{.}"/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="access-map" 
			select="securitym:access-map(exsl:node-set($cred-rtf)/cred)/cred"/>
		
		<xsl:variable name="filtered-eid-rtf">
			<xsl:for-each select="$env-ids">
				<xsl:choose>
					<xsl:when 
						test="$access-map[string(@security-obj-type)='ve.vz.vt'][string(@security-obj-id)=current()][string(@id)=$perm]/allow">
						<xsl:copy-of select="."/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="$set-error">
							<xsl:variable name="error-msg">
								<sw:text>
									<xsl:with-param name="env-title" select="env:eid2info(.)/title"/>
									Access denied to the %{env-title} Container
								</sw:text>
							</xsl:variable>
							<xsl:if test="error:put($error-msg)"/>
						</xsl:if>						
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($filtered-eid-rtf)/*"/>
	</func:function>

	<func:function name="cred:filter-valid-hw">
		<xsl:param name="perm"/>
		<xsl:param name="hw-ids"/>
		<xsl:param name="set-error" select="true()"/>
		
		<xsl:variable name="cred-rtf">
			<xsl:for-each select="$hw-ids">
				<cred id="{$perm}" security-obj-type="hn.vz.vt"
					security-obj-id="{.}"/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="access-map" 
			select="securitym:access-map(exsl:node-set($cred-rtf)/cred)/cred"/>		
		
		<xsl:variable name="filtered-eid-rtf">
			<xsl:for-each select="$hw-ids">
				<xsl:choose>
					<xsl:when 
						test="$access-map[string(@security-obj-type)='hn.vz.vt'][string(@security-obj-id)=current()][string(@id)=$perm]/allow">
						<xsl:copy-of select="."/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="$set-error">
							<xsl:variable name="error-msg">
								<sw:text>
									<xsl:with-param name="hw-title" select="env:eid2info(.)/title"/>
									Access denied to the %{hw-title} Hardware Node
								</sw:text>
							</xsl:variable>
							<xsl:if test="error:put($error-msg)"/>							
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($filtered-eid-rtf)/*"/>
	</func:function>

</xsl:stylesheet>
