<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func cred securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>
	
	<sw:include href="/lib/swa/securitym.xsl"/>
	
	<!--
		Check credentails of 'cred' elements having
		security attribute group - @id,@security-obj-type and @security-obj-id.
		Parameters:
			creds-rtf - node-set or RTF with plain list of 'cred' elements
		Returns:
			node-set with copy of 'cred' elements with 'allow' or 'deny' inside each of them
	-->
	<xsl:template name="cred:access-map">
		<xsl:param name="creds-rtf"/>
		<xsl:variable name="request-rtf">
			<xsl:for-each select="exsl:node-set($creds-rtf)/cred">
				<cred id="{@id}" security-obj-type="{@security-obj-type}" 
					security-obj-id="{sw:if(@security-obj-id,@security-obj-id,'default')}"/>
			</xsl:for-each>
		</xsl:variable>
		<xsl:copy-of select="securitym:access-map(exsl:node-set($request-rtf)/cred)"/>
	</xsl:template>
	
	<!--
		Check access for given credential and security object using given access map
		(see cred:access-map)
		Parameters:
			access-map - result from cred:access-map function
			cred - credential ID
			obj-type - security object type
			obj-id - optional security object ID, current context object ID with type obj-type
		Returns: true/false 
	-->
	<func:function name="cred:match-access">
		<xsl:param name="access-map"/>
		<xsl:param name="cred"/>
		<xsl:param name="obj-type"/>
		<xsl:param name="obj-id" select="'default'"/>
		<func:result 
			select="sw:if($access-map[string(@security-obj-type)=$obj-type][string(@security-obj-id)=$obj-id][string(@id)=$cred]/allow,true(),false())"/>
	</func:function>

	<func:function name="cred:check">
		<xsl:param name="perm"/>
		<xsl:choose>
			<xsl:when test="$config/vzcpcon/security/enabled='false'">
				<func:result select="true()"/>
			</xsl:when>
			<xsl:when test="not($activeMode='vzcc')">
				<func:result select="false()"/>	
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="check-result" select="securitym:check-access($perm)"/>
				<xsl:if test="not($check-result) and $config/vzcpcon/logging/level > 3">
					<xsl:message>CRED CHECK FAILED: <xsl:value-of select="sw:if($perm,$perm,'empty credential')"
					/></xsl:message>
				</xsl:if>
				<func:result select="$check-result"/>	
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="cred:check-context">
		<xsl:param name="perm"/>
		<!-- Credential name -->
		<xsl:param name="obj-type"/>
		<!-- Security object type -->

		<xsl:choose>
			<xsl:when
				test="not($obj-type != '') or $obj-type = 'vzcc.vzcp' or $obj-type = 'vzpp.vzcp' or $obj-type = 'vzcp'">
				<func:result select="cred:check($perm)"/>
			</xsl:when>
			<xsl:when
				test="$obj-type = 'env.core.vt' or $obj-type = 've.vz.vt' or $obj-type = 'vm.vmware.vt'">
				<func:result select="cred:check-env($perm,sw:context-object-id($obj-type))"/>
			</xsl:when>
			<xsl:when
				test="$obj-type = 'hn.core.vt' or $obj-type = 'hn.vz.vt' or $obj-type = 'hn.vmware.vt'">
				<func:result select="cred:check-hw($perm,sw:context-object-id($obj-type))"/>
			</xsl:when>
			<xsl:when test="$obj-type = 'unit.farm'">
				<func:result select="cred:check-unit($perm,sw:context-object-id($obj-type))"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="true()"/>
				<!-- TODO -->
				<!-- <func:result select="false()"/> -->
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="cred:check-env">
		<xsl:param name="perm"/>
		<xsl:param name="eid"/>
		<xsl:choose>
			<xsl:when test="not($config/vzcpcon/security/enabled='false')">
				<xsl:variable name="check-result"
					select="securitym:check-access($perm,securitym:env-scope($eid))"/>
				<xsl:if test="not($check-result) and $config/vzcpcon/logging/level > 3">
					<xsl:message>ENV #<xsl:value-of select="$eid"/> CRED CHECK FAILED: <xsl:value-of
						select="sw:if($perm,$perm,'empty credential')"/></xsl:message>
				</xsl:if>
				<func:result select="$check-result"/>				
			</xsl:when>
			<xsl:otherwise>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="cred:check-hw">
		<xsl:param name="perm"/>
		<xsl:param name="hwid"/>
		<xsl:choose>
			<xsl:when test="not($config/vzcpcon/security/enabled='false')">
				<xsl:variable name="check-result"
					select="securitym:check-access($perm,securitym:env-scope($hwid))"/>
				<xsl:if test="not($check-result) and $config/vzcpcon/logging/level > 3">
					<xsl:message>HW #<xsl:value-of select="$hwid"/> CRED CHECK FAILED: <xsl:value-of
						select="sw:if($perm,$perm,'empty credential')"/></xsl:message>
				</xsl:if>
				<func:result select="$check-result"/>				
			</xsl:when>
			<xsl:otherwise>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="cred:check-unit">
		<xsl:param name="perm"/>
		<xsl:param name="dn"/>
		<xsl:choose>
			<xsl:when test="not($config/vzcpcon/security/enabled='false')">
				<xsl:variable name="check-result"
					select="securitym:check-access($perm,securitym:unit-scope($dn))"/>
				<xsl:if test="not($check-result) and $config/vzcpcon/logging/level > 3">
					<xsl:message>UNIT <xsl:value-of select="$dn"/> CRED CHECK FAILED: <xsl:value-of
						select="sw:if($perm,$perm,'empty credential')"/></xsl:message>
				</xsl:if>
				<func:result select="$check-result"/>						
			</xsl:when>
			<xsl:otherwise>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="cred:detail-check">
		<xsl:param name="perm"/>
		<xsl:param name="set-error" select="'yes'"/>

		<xsl:variable name="res" select="cred:check($perm)"/>

		<xsl:if test="$set-error = 'yes' and not($res)">
			<xsl:if test="error:put(sw:text('Access is denied.'),'')"/>
		</xsl:if>

		<func:result select="$res"/>
	</func:function>

	<func:function name="cred:detail-check-hw">
		<xsl:param name="perm"/>
		<xsl:param name="hn-eid"/>
		<xsl:param name="set-error" select="'yes'"/>

		<xsl:variable name="res" select="cred:check-hw($perm,$hn-eid)"/>

		<xsl:if test="$set-error = 'yes' and not($res)">
			<xsl:if test="error:put(sw:text('Access is denied.'),'')"/>
		</xsl:if>

		<func:result select="$res"/>
	</func:function>

	<func:function name="cred:detail-check-env">
		<xsl:param name="perm"/>
		<xsl:param name="eid"/>
		<xsl:param name="set-error" select="'yes'"/>

		<sw:die test="not($eid)">
			You should specify the VE.
		</sw:die>

		<xsl:variable name="res" select="cred:check-env($perm,$eid)"/>

		<xsl:if test="$set-error = 'yes' and not($res)">
			<xsl:if test="error:put(sw:text('Access is denied.'),'')"/>
		</xsl:if>

		<func:result select="$res"/>
	</func:function>

	<func:function name="cred:is-demo-mode">
		<!-- TODO actual check for DEMO mode -->
		<func:result select="false()"/>
	</func:function>

</xsl:stylesheet>
