<!--
    Copyright (c) SWsoft, 1999-2007
    All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date func time"
    xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
    xmlns:exsl		="http://exslt.org/common"
    xmlns:date		="http://exslt.org/dates-and-times"
    xmlns:func		="http://exslt.org/functions"	  
    xmlns:sw		="http://www.swsoft.com/xsl/cp"
    xmlns:time		="http://www.swsoft.com/xsl/cp/time"	
    >

    <!-- 
        Web time format support (to JS operations
        Format: (ANSI)
            2007-07-30
            2007-07-30 23:11
            
         Use only for JS or manual input.
      -->

    <!-- Conver web-form data to xs:date -->
    <func:function name="time:web2time">
        <xsl:param name="value"/>    <!-- data value in web-format -->
        <xsl:param name="def-time"/> <!-- how to prefill time 'from', 'to' or 'HH:MM' -->
        <!--|-->
        <xsl:variable name="empty" select="$value=''"/>
        <!--|-->
        <xsl:if test="$empty">
            <func:result/>
        </xsl:if>
        <xsl:if test="not($empty)">
            <xsl:variable name="year" select="substring-before($value,'-')"/>
            <xsl:variable name="o1" select="substring-after($value,'-')"/>
            <xsl:variable name="month" select="substring-before($o1,'-')"/>
            <xsl:variable name="o2" select="substring-after($o1,'-')"/>
            <xsl:variable name="o3" select="substring-after($o2,' ')"/>
            <xsl:variable name="day" select="sw:if($o3!='',substring-before($o2,' '),$o2)"/>
            <xsl:variable name="time">
                <xsl:choose>
                    <xsl:when test="$o3!=''">
                        <xsl:value-of select="$o3"/>
                    </xsl:when>	
                    <xsl:when test="$def-time = 'from'">
                        <xsl:value-of select="'00:00:00'"/>
                    </xsl:when>
                    <xsl:when test="$def-time = 'to'">
                        <xsl:value-of select="'23:59:59'"/>
                    </xsl:when>
                    <xsl:when test="sw:re-match($def-time, '[0-9]?[0-9]:[0-9][0-9]')">
                        <xsl:value-of select="concat($def-time, ':00')"/>
                    </xsl:when>
                    <xsl:otherwise>00:00:00</xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <!--|-->		
            <xsl:variable name="t">
                <xsl:variable name="h" select="substring-before($time,':')"/>
                <xsl:variable name="t1" select="substring-after($time,':')"/>
                <xsl:variable name="m_2" select="substring-before($t1,':')"/>
                <xsl:variable name="m" select="sw:if($m_2!='',$m_2,$t1)"/>
                <xsl:variable name="t2" select="substring-after($m,':')"/>
                <xsl:variable name="s" select="sw:if($t2!='',$t2,'0')"/>
                
                <xsl:value-of select="format-number($h, '00')"/>
                <xsl:text>:</xsl:text>
                <xsl:value-of select="format-number($m, '00')"/>
                <xsl:text>:</xsl:text>
                <xsl:value-of select="format-number($s, '00')"/>
            </xsl:variable>	
            <!--|-->		
            <func:result>
                <xsl:choose>
                    <xsl:when test="$year!='' and $month!='' and $day!='' and $time!=''">
                        <xsl:value-of select="concat(format-number($year,'0000'),'-',format-number($month,'00'),'-',format-number($day,'00'),'T',$t)"/>	
                    </xsl:when>
                    <xsl:otherwise></xsl:otherwise>
                </xsl:choose>
            </func:result>
        </xsl:if>
    </func:function>
    
    <!-- Conver web-form data to vzatime -->
    <func:function name="time:web2vzatime">
        <xsl:param name="web-time"/>
        <xsl:param name="control"/>
        <func:result select="sw:time2vzatime(time:web2time($web-time, $control))"/>
    </func:function>
    
    <!-- WebTime date format composer YMD -->
    <func:function name="time:web-compose">
        <xsl:param name="y"/>
        <xsl:param name="m"/>
        <xsl:param name="d"/>
        <func:result select="concat(format-number($y,'0000'),'-',format-number($m,'00'),'-',format-number($d,'00'))"/>
    </func:function>
    
    <!-- Convert xs:date to web-time format -->
    <func:function name="time:time2web">		
        <xsl:param name="time"/>
        <func:result select="time:web-compose( date:year($time), date:month-in-year($time), date:day-in-month($time) )"/>
    </func:function>
    
    <!-- validate webtime, return empty result on success or error message on error 
    	second param: diag-format.
    		if = 'short-format' - showed short format message
    		if = 'long-format'  - show long format messaage (default)
    -->
    <func:function name="time:web-validate">
        <xsl:param name="web-time"/>
        <xsl:param name="diag-format" select="'long-format'"/>
        <xsl:variable name="xtime" select="time:web2time($web-time)"/>
        <xsl:choose>
            <xsl:when test="date:date($xtime)">
                <func:result/>
            </xsl:when>
            <xsl:otherwise>
                <func:result>
                	<xsl:choose>
                		<xsl:when test="$diag-format = 'short-format'">
	                    <sw:text>Invalid date format, please use "YYYY-MM-DD"</sw:text>
	                  </xsl:when>
                		<xsl:when test="$diag-format = 'long-format'">
	                    <sw:text>Invalid date format, please use "YYYY-MM-DD" or "YYYY-MM-DD HH:MM"</sw:text>
	                  </xsl:when>	                  
                		<xsl:otherwise>
                			<!-- default is long format-->
	                    <sw:text>Invalid date format, please use "YYYY-MM-DD" or "YYYY-MM-DD HH:MM"</sw:text>
	                  </xsl:otherwise>
	                </xsl:choose>
                </func:result>
            </xsl:otherwise>
        </xsl:choose>
    </func:function>

    <!-- Conver vzatime to web-form data -->
    <func:function name="time:vzatime2web">
        <xsl:param name="vza-time"/>
        <func:result select="time:time2web(sw:vzatime2time($vza-time))"/>
    </func:function>
    
 </xsl:stylesheet>
 