<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->


<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl dyn filem func vzenv local format"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:dyn="http://exslt.org/dynamic"
  xmlns:filem	="http://www.swsoft.com/xsl/cp/filem"
  xmlns:vzenv		="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:local ="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"
  xmlns:format="http://www.swsoft.com/xsl/cp/format"
>
  
  <sw:include href="vz/vzenv-core.xsl"/>
  
	<sw:include href="vza/filem.xsl"/>
	<sw:include href="common.xsl" />
	<sw:include href="/lib/utils/format-resusage.xsl"/>


	<!-- show download package -->
	<xsl:template match="package">
		<xsl:if test="not(@cond) or dyn:evaluate(@cond)">
			<tr>
				<td colspan="3" nowrap="nowrap">
					<nobr>
						<xsl:value-of select="sw:text(string(description))"/>
						(
							<xsl:for-each select="version">
								<xsl:choose>
									<!-- we have link section -->
									<xsl:when test="link">
										<a href="{link}" target="_blank">
											<img src="/{$theme}/icons/{sw:if(link/@icon, link/@icon,'file_pdf')}.gif" title="{name}" alt="{name}" style="margin-right:5px;" />
										</a>							
										<a href="{link}" target="_blank">
											<sw:text>Open</sw:text>
										</a>		
									</xsl:when>
									
									<!-- no link, just point on file in download area -->
									<xsl:when test="file">
										<xsl:variable name="href" select="concat('/vz/download/',string(file))"/>
										<a href="{$href}" target="_blank">
											<img src="/{$theme}/icons/{sw:if(file/@icon, file/@icon,'download_16')}.gif" title="{name}" alt="{name}" style="margin-right:5px;" />
										</a>
										<a href="{$href}" target="_blank">
											<xsl:variable name="size" select="local:get-size(.)"/>
											<xsl:value-of select="sw:if($size != '', $size, sw:text('Open'))"/>
										</a>
									</xsl:when>
									
								</xsl:choose>
								<xsl:if test="position() != last()">, </xsl:if>
							</xsl:for-each>						
						)
					</nobr>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<!-- 
		include packages list 
		attributes: 
		href
		dir
	-->
	<xsl:template match="packages-include">
		<xsl:if test="not(@cond) or dyn:evaluate(@cond)">
			<xsl:variable name="dlist" select="sw:document(@href, @dir, 'noerror')/packages" />
			<xsl:apply-templates select="$dlist/package" />
			<xsl:apply-templates select="$dlist/packages-include" />
		</xsl:if>
	</xsl:template>

	<!-- show download box -->
	<xsl:template name="download-box">
		<xsl:variable name="load-first">
			<packages-include href="{sw:if($activeMode = 'vzcc','cc','pp')}/downloads.xml" dir="etc" />
		</xsl:variable>
		<xsl:variable name="downloads-content">
			<xsl:apply-templates select="exsl:node-set($load-first)/packages-include" />
		</xsl:variable>
		<xsl:if test="string-length($downloads-content)">
			<table border="0" cellpadding="2" cellspacing="0">
				<xsl:copy-of select="exsl:node-set($downloads-content)/child::node()" />
			</table>
		</xsl:if>
	</xsl:template>
	
	<func:function name="local:get-size">
		<xsl:param name="node" />
		<xsl:variable name="size-rtf">
			<files>
				<xsl:for-each select="$node/file">
					<xsl:variable name="sve-id" select="vzenv:veid-to-eid(1,sw:local-hn-eid())"/>
					<xsl:variable name="fields">
						<info>
							<size/>
						</info>
					</xsl:variable>
					<xsl:variable name="stat" select="filem:stat($config/vzcpcon/paths/download,string(.),$sve-id,$fields,true())" />
					<xsl:if test="$stat">
						<xsl:variable name="size" select="$stat/size"/>
						<xsl:if test="string(number($size)) != 'NaN'">
							<file>
								<xsl:value-of select="$size" />
							</file>
						</xsl:if>
					</xsl:if>

				</xsl:for-each>
			</files>
		</xsl:variable>
		<xsl:variable name="size" select="sum(exsl:node-set($size-rtf)/files/file)" />
		<func:result>
			<xsl:if test="$size and string(number($size)) != 'NaN'">
				<xsl:value-of select="format:int2bytes($size, 'mbytes', 'yes', '#,##0')" />
			</xsl:if>
		</func:result>
	</func:function>
	
</xsl:stylesheet>
