<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func local show dynamic dyn html"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:dyn="http://exslt.org/dynamic"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:func="http://exslt.org/functions"
	xmlns:show="http://www.swsoft.com/xsl/cp/show" xmlns:dynamic="http://www.swsoft.com/xsl/cp/dynamic"
	xmlns:html="http://www.swsoft.com/xsl/cp/html"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
>
	
	<sw:include href="/layout/lib/html.xsl"/>
	
	<!-- 
		Creates ajax powered component like "Click here to get information".
		Result are shown in-place or optionaly in external div specified by 'target-id',
		and also on successful load of data Javascript function with name 'trigger-id' 
		taking array [status, content] as parameter is invoked.  		 
	-->
	<xsl:template name="dynamic:create-ajax-div">
		<!-- Required params -->
		<!-- initial message -->
		<xsl:param name="init-msg" />
		<!-- progress message -->
		<xsl:param name="progress-msg" />
		<!-- dynamic request url -->
		<xsl:param name="request-url" />

		<!-- Aux params -->
		<!-- id of target HTML element -->
		<xsl:param name="target-id" select="false()"/>
		<!-- name of JS function to call when response is recieved, 
			function must take one argument - array of strings -->
		<xsl:param name="trigger-id" select="false()"/>
		
		<xsl:variable name="id" select="sw:generate-id()" />
		<xsl:variable name="fsend-name" select="concat('init', $id)" />
		<xsl:variable name="frecv-name" select="concat('recv', $id)" />
		<xsl:variable name="send-ui-name" select="concat('sendui', $id)" />
		<xsl:variable name="recv-ui-name" select="concat('recvui', $id)" />
		<xsl:variable name="div-name" select="concat('div', $id)" />
		<xsl:variable name="img-name" select="concat('img', $id)" />
		
		<xsl:variable name="link">
			<a href="#" onclick="{$fsend-name}()"><xsl:value-of select="sw:html-escape($init-msg)" /></a>
		</xsl:variable>

		<a href="#" onclick="{$fsend-name}()"><img id="{$img-name}" width="16" border="0" height="16" src="/{$theme}/icons/refresh_16.gif"/></a>&#160;
		<span id="{$div-name}">
			<xsl:copy-of select="$link" />
		</span>
		
		<script>
			function <xsl:value-of select="$send-ui-name"/>() {
				document.getElementById('<xsl:value-of select="$img-name"/>').src='/<xsl:value-of select="$theme"/>/icons/indicator.gif';
				document.getElementById('<xsl:value-of select="$div-name"/>').innerHTML = '<xsl:value-of select="sw:html-escape($progress-msg)"/>';
				<xsl:if test="$target-id">
					document.getElementById('<xsl:value-of select="$target-id"/>').innerHTML = '';
				</xsl:if>
			}
			
			function <xsl:value-of select="$recv-ui-name"/>(content) {
				<!-- replace progress with initial message -->
				<xsl:if test="$target-id">
					document.getElementById('<xsl:value-of select="$div-name"/>').innerHTML = '<xsl:copy-of select="$link" />';
				</xsl:if>
				document.getElementById('<xsl:value-of select="$img-name"/>').src="/<xsl:value-of select="$theme"/>/icons/refresh_16.gif";
				var div_obj = document.getElementById('<xsl:value-of select="sw:if($target-id, $target-id, $div-name)"/>');
				
				if (content.length &gt; 1) {
					div_obj.innerHTML = content[1];
				}
				<xsl:if test="$trigger-id">
					<xsl:value-of select="$trigger-id" />(content);
				</xsl:if>			
			}
		</script>
		
		<xsl:call-template name="dynamic:ajax-sender-func">
			<xsl:with-param name="sender-func" select="$fsend-name"/>
			<xsl:with-param name="reciever-func" select="$frecv-name" />
			<xsl:with-param name="request-url" select="$request-url"/>
			<xsl:with-param name="ui-func" select="$send-ui-name" />
		</xsl:call-template>

		<xsl:call-template name="dynamic:ajax-reciever-func">
			<xsl:with-param name="reciever-func" select="$frecv-name"/>
			<xsl:with-param name="ui-func" select="$recv-ui-name" />
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="dynamic:ajax-sender-func">
		<xsl:param name="sender-func" />
		<xsl:param name="reciever-func" />
		<xsl:param name="request-url" />
		
		<xsl:param name="ui-func" select="false()"/>
				
		<script>
			function <xsl:value-of select="$sender-func"/>(){
				<xsl:if test="$ui-func">
					<xsl:value-of select="normalize-space($ui-func)"/>();
				</xsl:if>
				requestContent('<xsl:value-of select="$request-url"/>'
					,<xsl:value-of select="$reciever-func"/>
					,'<xsl:value-of select="$ticket"/>'
					,'<xsl:value-of select="$ticketid"/>');
			}
		</script>	
	</xsl:template>
	
	<xsl:template name="dynamic:ajax-reciever-func">
		<xsl:param name="reciever-func" />
		<xsl:param name="ui-func" select="false()"/>
				
		<script>
			function <xsl:value-of select="$reciever-func"/>(req){
				var content = req.readyState==4?req.responseText:'';
				if(content!=''){
					var content_nodes = new Array();
					var index = content.indexOf('|');
					
					if (index==-1) {
						content_nodes[0] = 'NA';
						content_nodes[1] = content;
					} else {
						index1 = content.indexOf('|', index+1);
						
						content_nodes[0] = content.substring(index+1, index1);
						content_nodes[1] = content.substring(index1+1, content.lastIndexOf('|'));
					}
					<xsl:if test="$ui-func">
						<xsl:value-of select="normalize-space($ui-func)" />(content_nodes);
					</xsl:if>
				}
			}
		</script>	
	</xsl:template>
	
	<!--
		Creates skeleton for *-dynamic screens. Function with name specified by $request-handler is invoked to 
		provide screen content. Request handler must return nodeset '<result>...</result><status>...</status>. 
	 -->
	<xsl:template name="dynamic:create-ajax-handler">
		<xsl:param name="request-handler" />
			
		<xsl:variable name="fcall" select="concat($request-handler, '()')" />
		<xsl:variable name="result" select="exsl:node-set(dyn:evaluate($fcall))" />
		
		<ui:body-screen>
			<ui:content>
				<xsl:if test="$result">
					<ui:raw>|<xsl:value-of select="sw:text($result/status/node(), 'C')" disable-output-escaping="yes"/>|<xsl:value-of select="sw:text($result/result/node(), 'C')" disable-output-escaping="yes"/>|</ui:raw>
				</xsl:if>
			</ui:content>
		</ui:body-screen>
	</xsl:template>
	
	<!-- Creates simple error reporting component with 'show/hide error details' link. -->
	<xsl:template name="dynamic:error-reporter">
		<!-- set of errors (VZAgent-like) -->
		<xsl:param name="errors"/>
		<!-- show link message -->
		<xsl:param name="open" select="sw:text('Show Error Details')"/>
		<!-- hide link message -->
		<xsl:param name="hide" select="sw:text('Hide Error Details')"/>
		<!-- general message about errors -->
		<xsl:param name="message" select="sw:text('An error occurred.')"/>
		
		<xsl:call-template name="dynamic:error-reporter-script">
			<xsl:with-param name="open" select="$open"/>
			<xsl:with-param name="hide" select="$hide"/>
		</xsl:call-template>
		
		<xsl:call-template name="dynamic:error-reporter-body">
			<xsl:with-param name="errors" select="$errors"/>
			<xsl:with-param name="open" select="$open"/>
			<xsl:with-param name="message" select="$message"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Creates script for simple error reporting component with 'show/hide error details' link. -->
	<xsl:template name="dynamic:error-reporter-script">
		<xsl:param name="hide" select="sw:text('Hide Error Details')"/>
		<xsl:param name="open" select="sw:text('Show Error Details')"/>
		
		<xsl:call-template name="dynamic:opener-link-script">
			<xsl:with-param name="open" select="$open"/>
			<xsl:with-param name="hide" select="$hide"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Creates body content for simple error reporting component with 'show/hide error details' link. -->
	<xsl:template name="dynamic:error-reporter-body">
		<xsl:param name="errors"/>
		<xsl:param name="open" select="sw:text('Show Error Details')"/>
		<xsl:param name="message" select="sw:text('An error occurred.')"/>
		
		<xsl:variable name="guid" select="sw:generate-id()"/>
		
		<span><xsl:if test="$message"><xsl:value-of select="$message" disable-output-escaping="yes"/>&#160;</xsl:if><xsl:call-template name="dynamic:opener-link">
			<xsl:with-param name="open" select="$open"/>
			<xsl:with-param name="tip" select="'error_details'"/>
			<xsl:with-param name="block-id" select="concat('report', $guid)"/>
			<xsl:with-param name="link-id" select="concat('reportLink',$guid)"/>
		</xsl:call-template>
			<div id="report{$guid}" style="display:none;">
				<br/>
				<xsl:for-each select="$errors">
					<sw:text>
						<xsl:with-param name="code" select="code"/>
						VZAgent returned error #%{code}</sw:text>
						<br/>
						<xsl:value-of select="html:plain2html(sw:if(message, message, .))" disable-output-escaping="yes"/>
				</xsl:for-each>
			</div>
		</span>
	</xsl:template>
	
	<!--
		Creates script to implement show/hide block element script. Used for example for clickable div's. 
	 -->
	<xsl:template name="dynamic:switcher-script">
		<script language="JavaScript">
			function switchBlockLocal(blockId, imgId){		
				s = document.getElementById(blockId);
				o = document.getElementById(imgId);
			  if(s&amp;&amp;o){
				if(s.style.display=='none'){
					s.style.display='block';
					o.src="<xsl:value-of select="concat('/',$theme,'/icons/arr_opened.gif')"/>";
				}else{
					s.style.display='none';
					o.src="<xsl:value-of select="concat('/',$theme,'/icons/arr_gt.gif')"/>";
				}				
			  }
				return false;
			}				
		</script>
	</xsl:template>
	
	<!--
		General purpose show/hide component controlled by link.  
	 -->
	<xsl:template name="dynamic:opener">
		<!-- open link message -->
		<xsl:param name="open" />
		<!-- hide link message -->
		<xsl:param name="hide" />
		<!-- tip message -->
		<xsl:param name="tip" />
		<!-- block elemet id to be shown/hidden -->
		<xsl:param name="block-id" />
		
		<xsl:call-template name="dynamic:opener-link-script">
			<xsl:with-param name="open" select="$open"/>
			<xsl:with-param name="hide" select="$hide"/>
		</xsl:call-template>
		
		<xsl:call-template name="dynamic:opener-link">
			<xsl:with-param name="open" select="$open"/>
			<xsl:with-param name="hide" select="$hide"/>
			<xsl:with-param name="tip" select="$tip"/>
			<xsl:with-param name="block-id" select="$block-id"/>
		</xsl:call-template>
	</xsl:template>
	
	
	<!--
		Link control for general purpose show/hide component.  
	 -->
	<xsl:template name="dynamic:opener-link">
		<!-- open link message -->
		<xsl:param name="open" />
		<!-- link tip -->
		<xsl:param name="tip" />
		<!-- block id -->
		<xsl:param name="block-id" />
		<!-- optional link id to be used elsewhere -->
		<xsl:param name="link-id" select="false()" />
		
		<xsl:variable name="lid" select="sw:if($link-id, $link-id, concat('link', sw:generate-id()))" />
		
		<a href="#" onclick="showHidden('{$block-id}', '{$lid}')" onmouseover="callTip('{$tip}',event)" onmouseout="callTip()"><span id="{$lid}"><xsl:value-of select="$open" disable-output-escaping="yes" /></span></a>
	</xsl:template>
	
	<!--
		Script for link control for general purpose show/hide component.  
	 -->
	<xsl:template name="dynamic:opener-link-script">
		<!-- open link message -->
		<xsl:param name="open" />
		<!-- hide link message -->
		<xsl:param name="hide" />
				
		<script>
			function showHidden(blockId, linkId){
				s = document.getElementById(blockId);
				link = document.getElementById(linkId);
				if(s.style.display=='none'){
					s.style.display='block';
					link.innerHTML='<xsl:value-of select="$hide" disable-output-escaping="yes" />';
				}else{
					s.style.display='none';
					link.innerHTML='<xsl:value-of select="$open" disable-output-escaping="yes" />';
				}
				return false;
			}
		</script>
	</xsl:template>
	
	<xsl:template name="dynamic:describe-task">
		<xsl:param name="task" />
		<xsl:param name="last" select="false()" />

		<xsl:variable name="message" select="task:message($task)" />
		<xsl:variable name="status" select="local:status($task, $last)"/>
		<xsl:variable name="percent" select="task:percent($task)" />
		
		<xsl:if test="not($status=$global:task-completed and $percent=100)">
			<xsl:apply-templates select="$task/time" />
			&#160;&#160;
			<xsl:value-of select="$message" />
			&#160;&#160;
			<xsl:call-template name="local:show-status">
				<xsl:with-param name="status" select="$status" />
			</xsl:call-template>
			<br />
		</xsl:if>
	</xsl:template>

	<func:function name="local:status">
		<xsl:param name="task" />
		<xsl:param name="last" select="false()" />

		<xsl:variable name="percent" select="task:percent($task)" />

		<func:result>
			<xsl:variable name="children" select="task:children($task)" />
			<xsl:choose>
				<xsl:when test="$children">
					<xsl:choose>
						<!-- completed OK -->
						<xsl:when test="not($last) and not($children[last()][status=$global:task-failed])"><xsl:value-of 
							select="$global:task-completed"/></xsl:when>
						<!-- completed with errors -->
						<xsl:when test="not($last) and $children[last()][status=$global:task-failed]"><xsl:value-of 
							select="$global:task-failed"/></xsl:when>
						<!-- in progress -->
						<xsl:otherwise><xsl:value-of select="$global:task-processing"/></xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<!-- completed with errors -->
						<xsl:when test="$task/status=$global:task-failed"><xsl:value-of select="$global:task-failed"/></xsl:when>
						<!-- completed OK or not last in PROGRESS-->
						<xsl:when
							test="$task/status=$global:task-completed or ($task/status=$global:task-started
								 and not($last)) or ($task/status=$global:task-processing and not ($last)) 
								 or number($percent)=100">
							<xsl:value-of select="$global:task-completed"/>
						</xsl:when>
						<!-- in progress -->
						<xsl:when test="$last and number($percent) &gt; 0">
							<xsl:value-of select="$percent" />%
						</xsl:when>
						<xsl:otherwise><xsl:value-of select="$global:task-processing"/></xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<xsl:template name="local:show-status">
		<xsl:param name="status" />
		<b>
			<xsl:choose>
				<xsl:when test="$status=$global:task-failed">
					<span class="red">
						[<sw:text>Failed</sw:text>]
					</span>
				</xsl:when>
				<xsl:when test="contains($status, '%') and string(number(substring-before($status, '%'))) != 'NaN'">
					[
					<xsl:value-of select="$status" />
					]
				</xsl:when>

				<xsl:otherwise>&#160;</xsl:otherwise>
			</xsl:choose>
		</b>
	</xsl:template>
	
</xsl:stylesheet>
