<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="exsl sw func global"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"  
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:func	="http://exslt.org/functions"
	xmlns:user	="http://www.swsoft.com/xsl/cp/user"
	xmlns:global	="http://www.swsoft.com/xsl/cp/global"
  >

	<xsl:variable name="global:classes" select="sw:document('classes.xml')/classes"/>	

  <!--  hints for login page only -->
  <xsl:param name="psa-skin-on-login-page"/>
  <xsl:param name="psa-lang-on-login-page"/>
  <xsl:param name="psa-locale-mode-on-login-page"/>  
	<!-- special hack for implement plesk logic -->
	<xsl:variable name="psa-lang-combined-on-login-page">
		<xsl:choose>
			<xsl:when test="$request/http_request/cookies/parameter[name = 'locale']/value">
				<xsl:value-of select="$request/http_request/cookies/parameter[name = 'locale']/value"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$psa-lang-on-login-page"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- select active mode vzcp, plesk, vzcc -->
	<xsl:variable name="activeMode">
		<xsl:choose>
			<xsl:when test = "false()">vzcp</xsl:when> <!-- TODO: remove this DIRTY HACK -->
			<xsl:when test = "$auth-type = 'sveuser'">vzcc</xsl:when>
			<xsl:when test = "$auth-type = 'clusteruser'">vzcc</xsl:when>
			<xsl:when test = "$request/http_request/env/parameter[name = 'VZCP_MODE_PLESK']/value">plesk</xsl:when>
			<xsl:when test = "$auth-type = 'registration'">vzcc</xsl:when>
			<xsl:otherwise>vzcp</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
  <xsl:variable name="sessionModeParam" select="concat('mode-', $activeMode)"/>
  <xsl:variable name="http-user-agent" select="$request/http_request/env/parameter[name = 'HTTP_USER_AGENT']/value"/>

  <!-- definition of knobs to setup skin/lang/etc in vzarions vzcp modes -->
  <xsl:variable name="global-data-RTF">
    <mode id="vzcp">
      <skin>
        <http tag="cookies">vzcpSkin</http>
      </skin>
      <lang>
        <http tag="post">active_lang</http>
        <http tag="get">active_lang</http>
        <http tag="cookies">vzcpLang</http>
      </lang>
    </mode>

    <mode id="vzcc">
      <skin>
        <http tag="cookies">vzcpSkin</http>
      </skin>
      <lang>
        <http tag="post">active_lang</http>
        <http tag="cookies">vzcpLang</http>
      </lang>
    </mode>

    <mode id="plesk">
      <skin>
        <http tag="get"		id="plesk-skin-id">psa_active_skin</http>
				<http tag="post"	id="plesk-skin-id">psa_active_skin</http>
      </skin>
      <lang psa-locale-mode="old">
        <http tag="get"		id="plesk-lang-id">psa_active_lang</http>
        <http tag="post"	id="plesk-lang-id">psa_active_lang</http>
        <http tag="post">active_lang</http>
      </lang>
      <lang psa-locale-mode="new">
        <http tag="get"		id="plesk-locale-id">psa_active_lang</http>
        <http tag="post"	id="plesk-locale-id">psa_active_lang</http>
        <http tag="post">active_lang</http>
      </lang>
    </mode>
  </xsl:variable>
  <xsl:variable name="global-data" select="exsl:node-set($global-data-RTF)"/>

  <!-- load skins/languages library -->
  <xsl:variable name="all-skins" select="sw:document('skins.xml')/skins/mode"/>
  <xsl:variable name="all-langs" select="sw:document('languages.xml')/languages/language"/>
  
  <xsl:variable name="_js_on">
  	<xsl:choose>
  		<xsl:when test="sw:sesgetstr('js_mode') &gt; 1.1">1</xsl:when>
  		<xsl:otherwise>
  			<xsl:if test="$request/http_request/post/parameter[name = 'js_mode']/value  &gt; 1.1">1</xsl:if>
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:variable>
  <xsl:variable name="js_on" select="string($_js_on)"/>

  <!-- get data from globals, parameter: nodeset of description for specific parametr -->
  <func:function name="sw:getGlobals">
    <xsl:param name="data"/>
    <xsl:variable name="ret">
      <values>
        <xsl:for-each select="$data/*">
          <!-- info type (cookie/get/post) -->
          <xsl:variable name="prms" select="$request/http_request/*[name() = current()/@tag]/parameter[name = current()]/value"/>
          <xsl:if test="count($prms) and string($prms[1])">
            <value id="{sw:if(@id, @id, 'id')}"><xsl:value-of select="$prms[1]"/></value>
          </xsl:if>
        </xsl:for-each>
      </values>
    </xsl:variable>
    <func:result select="exsl:node-set($ret)/values/*[1]"/>
  </func:function>

  <!-- active tool parameters (skin, lang) -->
  <func:function name="sw:getActiveMode">
  	<xsl:param name="reset" select="0"/>
    <xsl:variable name="sessionModeObj" select="sw:sesget($sessionModeParam)"/>
    <xsl:choose>
      <!-- we have found predefined value, check it and set -->
      <xsl:when test="($reset != 1) and
      								exsl:object-type($sessionModeObj) = 'node-set' and
                      $sessionModeObj/skin and $all-skins[@id = $activeMode]/skin[id = $sessionModeObj/skin] and
                      $sessionModeObj/lang ">
        <!-- all ok use this config obj -->
        <func:result select="$sessionModeObj"/>
      </xsl:when>
      <xsl:otherwise>
        <!-- there is no valid predefined values, calculate it -->
				<xsl:variable name="psa-locale-mode" select="sw:getPsaLocaleMode()"/>
        <xsl:variable name="modeRTF">
          <id><xsl:value-of select="$activeMode"/></id>
          <skin><xsl:value-of select="sw:getActiveSkin()"/></skin>
          <lang><xsl:value-of select="sw:getActiveLang($psa-locale-mode)"/></lang>
          <psa-locale-mode><xsl:value-of select="$psa-locale-mode"/></psa-locale-mode>
        </xsl:variable>
        <!-- store mode in session -->
        <xsl:if test="sw:sesput($sessionModeParam, $modeRTF)"/>
        <!-- return mode obj -->
        <func:result select="exsl:node-set($modeRTF)"/>
      </xsl:otherwise>
    </xsl:choose>
  </func:function>

	<!-- determine , support plesk new locale or not -->
  <func:function name="sw:getPsaLocaleMode">
		<xsl:variable name="mode">    
	    <xsl:choose>
  	  	<xsl:when test="$request/http_request/env/parameter[name = 'VZCP_MODE_PLESK']/value !=''">
  	  		<xsl:choose>
  	  			<xsl:when test="$psa-locale-mode-on-login-page != ''">
  	  				<!-- login page, speedup here -->
  	  				<xsl:value-of select="$psa-locale-mode-on-login-page"/>
  	  			</xsl:when>
  	  			<xsl:when test="$request/http_request/post/parameter[name = 'psa-locale-mode']/value != ''">
  	  				<!-- after login page, hav mode from post -->
  	  				<xsl:value-of select="$request/http_request/post/parameter[name = 'psa-locale-mode']/value"/>
  	  			</xsl:when>
  	  			<xsl:otherwise>
		    			<!-- not found psa-locale-mode, try use  prev from session -->
		    			<!-- it's because mode never change after login in plesk -->
					    <xsl:variable name="sessionModeObj" select="sw:sesget($sessionModeParam)"/>
							<xsl:value-of select="$sessionModeObj/psa-locale-mode"/>
						</xsl:otherwise>
					</xsl:choose>
	    	</xsl:when>
  	  	<xsl:otherwise>
  	  		<!-- it's not plesk mode, use empty string -->
    			<xsl:value-of select="''"/>
    		</xsl:otherwise>
	    </xsl:choose>
		</xsl:variable>
		
		<func:result select="$mode"/>
	</func:function>

  <!-- determine active skin -->
  <func:function name="sw:getActiveSkin">
    
    <!-- try to get globals from request -->
    <xsl:variable name="found" select="sw:getGlobals($global-data/mode[@id = $activeMode]/skin)"/>
    <xsl:choose>
    	<!-- first check that it's login page for plesk mode -->
			<xsl:when test="$activeMode = 'plesk' and $psa-skin-on-login-page and $all-skins[@id = $activeMode]/skin[plesk-skin-id = $psa-skin-on-login-page]/id">
				<func:result select="string($all-skins[@id = $activeMode]/skin[plesk-skin-id = $psa-skin-on-login-page]/id)"/>
			</xsl:when>

      <!-- found value corresponds configuration without javascript-->
      <xsl:when test="not($js_on) and $found and $all-skins[@id = $activeMode]/skin[not(java-script-required)][*[name() = $found/@id] = string($found)]">
        <func:result select="string($all-skins[@id = $activeMode]/skin[not(java-script-required)][*[name() = $found/@id] = string($found)]/id)"/>
      </xsl:when>    

      <!-- found value corresponds configuration -->
      <xsl:when test="$js_on and $found and $all-skins[@id = $activeMode]/skin[*[name() = $found/@id] = string($found)]">
        <func:result select="string($all-skins[@id = $activeMode]/skin[*[name() = $found/@id] = string($found)]/id)"/>
      </xsl:when>

      <!-- default skin of desired mode -->
      <xsl:when test="$js_on and $all-skins[@id = $activeMode]/skin[default]/id">
      	<func:result select="$all-skins[@id = $activeMode]/skin[default]/id"/>
      </xsl:when>
       
      <!-- fallback: first skin for mode -->
      <xsl:when test="$js_on">
      	<func:result select="$all-skins[@id = $activeMode]/skin[default]/id"/>
      </xsl:when>       

			<!-- fallback: first skin without js for mode -->
      <xsl:otherwise>
      	<func:result select="$all-skins[@id = $activeMode]/skin[1]/id"/>
    	</xsl:otherwise>
		</xsl:choose>		      
	</func:function>

   <!-- try detect active lang -->    
   <func:function name="sw:getActiveLang">     
		<xsl:param name="psa-locale-mode"/>
    <!-- try to get globals from request -->
    <xsl:variable name="found" select="sw:getGlobals($global-data/mode[@id = $activeMode]/lang[(@psa-locale-mode = $psa-locale-mode) or (not($psa-locale-mode != ''))])"/>

    <xsl:choose>
			<!-- special case - login with language selector  "User Default" -->
			<xsl:when test="$found = 'default'">
				<xsl:variable name="lang-def-from-post" select="$request/http_request/post/parameter[name = 'admin_default_lang']/value"/>
				<!-- normalize default to "id" -->
				<xsl:choose>
					<!-- it's plesk , but plesk is down and report because empty admin_default_lang -->
					<!-- fallback to default in vzcp term -->
					<xsl:when test="$lang-def-from-post = ''">
						<func:result select="$all-langs[default]/id"/>
					</xsl:when>
				
					<xsl:when test="$psa-locale-mode = 'new'">
						<!-- it's new plesk locale -->
						<func:result select="$all-langs[plesk-locale-id = $lang-def-from-post]/id"/>
					</xsl:when>
					<xsl:otherwise>
						<!-- its' old plesk locale -->
						<func:result select="$all-langs[plesk-lang-id = $lang-def-from-post]/id"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
      <!-- found value corresponds configuration -->
      <xsl:when test="$found and $all-langs[*[name() = $found/@id] = string($found)]">
        <func:result select="string($all-langs[*[name() = $found/@id] = string($found)]/id)"/>
      </xsl:when>

			<!-- plesk lang for admin login, only for plesk mode -->
			<xsl:when test="$activeMode = 'plesk' and $psa-lang-combined-on-login-page">
				<xsl:choose>
					<xsl:when test="$psa-locale-mode = 'new'">
						<!-- it's new plesk locale -->
						<xsl:choose>
							<xsl:when test="$all-langs[plesk-locale-id = $psa-lang-combined-on-login-page]/id">
								<func:result select="$all-langs[plesk-locale-id = $psa-lang-combined-on-login-page]/id"/>
							</xsl:when>
							<xsl:otherwise>
								<!-- plesk mode, new locale, locale not found,  return  english -->
								<func:result select="'en-US'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<!-- its' old plesk locale -->
						<xsl:choose>
							<xsl:when test="$all-langs[plesk-lang-id = $psa-lang-combined-on-login-page]/id">
								<func:result select="$all-langs[plesk-lang-id = $psa-lang-combined-on-login-page]/id"/>
							</xsl:when>
							<xsl:otherwise>
								<!-- plesk mode, old locale, locale not found,  return  english -->
								<func:result select="'en'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

      <!-- no hints for detect lang, try default -->
      <xsl:when test="$all-langs[default]/id">
        <func:result select="$all-langs[default]/id"/>
      </xsl:when>
       
      <!-- total fallback: English, for all modes -->
      <xsl:otherwise>
        <func:result select="sw:if($psa-locale-mode = 'new','en-US','en')"/>
      </xsl:otherwise>

    </xsl:choose>		         
  </func:function>

   <xsl:variable name="modeObj" select="sw:getActiveMode(0)"/>
   <xsl:variable name="skinObj" select="$all-skins[@id = $activeMode]/skin[id = $modeObj/skin]"/>
   <xsl:variable name="langObj" select="$all-langs[id = $modeObj/lang]"/> 

   <!-- renderer variables -->
   <xsl:variable name="menuType" select="$skinObj/menu"/>
   <xsl:variable name="buttonType" select="$skinObj/buttons"/>
   <xsl:variable name="layout" select="$skinObj/layout"/>
   <xsl:variable name="theme" select="concat('vz/skins/', sw:if($skinObj/theme, $skinObj/theme, $skinObj/id))"/>
   <xsl:variable name="plesk-skin-id" select="string($skinObj/plesk-skin-id)"/>

   <xsl:variable name="psa-locale-mode"	select="string($modeObj/psa-locale-mode)"/>

   <xsl:variable name="tab-limit" select="8"/>

   <!-- translation variables -->
		<xsl:variable name="active_lang_id"			select="string($langObj/id)"/>
		<xsl:variable name="active_lang_locale"	select="string($langObj/locale)"/>

		<xsl:variable name="plesk-lang-id">
			<xsl:choose>
				<xsl:when test="$psa-locale-mode = 'new'">
					<xsl:value-of select="$langObj/plesk-locale-id"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$langObj/plesk-lang-id"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

   <!-- real locale set only with normalize active lang variables -->
   <xsl:variable name="_setLocale">
		 <xsl:if test="sw:sesgetstr('active_locale') != $active_lang_locale">
			 <xsl:if test="sw:setlocale($active_lang_locale)"/>
			 <xsl:if test="sw:sesputstr('active_locale', $active_lang_locale)"/>
		 </xsl:if>
   </xsl:variable>

   <xsl:variable name="refresh_period" select="sw:sesget('refresh_period')"/>

   <!-- default target frame for menu opens -->
   <xsl:variable name="def_target">
     <xsl:choose>
       <xsl:when test="starts-with($layout, 'vzcc')">main</xsl:when>
       <xsl:when test="$layout = 'framed'">main</xsl:when>
       <xsl:when test="$layout = 'vzcp-plesk'">main</xsl:when>       
       <xsl:when test="$layout = 'plesk-integrated'">workFrame</xsl:when>      
       <xsl:otherwise>_self</xsl:otherwise>
     </xsl:choose>  
   </xsl:variable>         

	<xsl:param name="menu-source" select="sw:if($activeMode = 'vzcc', 'vzcc', 'vzpp')"/>
	<xsl:param name="menu-file" select="'menu.xml'"/>

	<!-- Env Constansts -->
	<xsl:variable name="env-state" select="$global:classes/class[@id='env.core.vt']/state"/>
	<xsl:variable name="env-trans" select="$global:classes/class[@id='env.core.vt']/trans"/>
	<!-- /Env Constansts -->

	<xsl:variable name="global:vzl-dn" select="concat('ou=',sw:master-eid(),',dc=VZL')"/>
	<xsl:variable name="def-users-dn" select="concat('cn=Users,',$global:vzl-dn)"/>
	<xsl:variable name="def-roles-dn" select="concat('cn=Roles,cn=Security,cn=vzcp,',$global:vzl-dn)"/>
	<xsl:variable name="def-permissions-dn" select="concat('cn=Permissions,cn=Security,cn=vzcp,',$global:vzl-dn)"/>
	<xsl:variable name="def-defenvsamples-dn" select="concat('cn=EnvDefaultSamples,cn=vzcp,',$global:vzl-dn)"/>

	<xsl:variable name="toolbar-mode" select="sw:sesgetstr('toolbar-mode')"/>
	
	<xsl:variable name="def-scope-base" select="'0'"/>
	<xsl:variable name="def-scope-list" select="'1'"/>
	<xsl:variable name="def-scope-tree" select="'2'"/>
	
	<xsl:variable name="def-vzl-ns" select="'http://www.swsoft.com/webservices/vzl/4.0.0/'"/>

	<xsl:variable name="def-ip-auto-vzcp" select="'&lt;auto&gt;'"/>
	<xsl:variable name="def-ip-auto-vza" select="'0.0.0.0'"/>
  <xsl:variable name="global:ip-default-netmask" select="'255.255.255.255'"/>

	
	<xsl:variable name="global:move-newobj-btn-2toolbar" select="false()"/>

	<!-- Known realms -->
	<xsl:variable name="global:system-realm-id" select="'00000000-0000-0000-0000-000000000000'"/>

	<xsl:variable name="global:auth-name-type-user" select="'1'"/>
	<xsl:variable name="global:auth-name-type-group" select="'2'"/>
	<!-- Internal and wellknown groups -->
	<xsl:variable name="global:auth-name-type-alias" select="'4'"/>
	<xsl:variable name="global:auth-name-type-wellknown-group" select="'5'"/>

	<!-- Authentication types -->
	<xsl:variable name="global:auth-type-registration" select="'registration'"/>
	
	<!-- Task statuses -->
	<xsl:variable name="global:task-started" select="'1'"/>	
	<xsl:variable name="global:task-processing" select="'2'"/>		
	<xsl:variable name="global:task-completed" select="'3'"/>			
	<xsl:variable name="global:task-failed" select="'4'"/>
	<xsl:variable name="global-date-format" select="'YYYY-MM-DD'"/>
	<xsl:variable name="global-date-regexp-check" select="'^[0-9]{4}-[0-9]{1,2}-[0-9]{1,2}$'"/>
	
	<!-- Backup Types -->
	<xsl:variable name="global:backup-full" select="0"/>	
	<xsl:variable name="global:backup-inc" select="1"/>	
	<xsl:variable name="global:backup-diff" select="2"/>	
			
</xsl:stylesheet>
