<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  >

  <xsl:variable name="meter-scale">
		<mark level="NA">
		  <color>grey</color>
		  <icon>small_gray</icon>
		  <alt><sw:text>The resource meter is not available.</sw:text></alt>
		</mark>
		<mark level="3">
		  <color>red</color>
		  <icon>small_black</icon>
		  <alt><sw:text>The resource is in the black zone.</sw:text></alt>
		  <help id="cpu">824&amp;a=o838</help>
		  <help id="system">825&amp;a=o843</help>
		  <help id="bandwidth">853</help>
		  <help id="diskspace">826&amp;a=o839</help>
		  <help id="diskinodes">827&amp;a=o835</help>
		</mark>
		<mark level="2">
		  <color>red</color>
		  <icon>small_red</icon>
		  <alt><sw:text>The resource is in the red zone.</sw:text></alt>
		  <help id="cpu">824&amp;a=o838</help>
		  <help id="system">825&amp;a=o831</help>
		  <help id="bandwidth">853</help>
		  <help id="diskspace">826&amp;a=o834</help>
		  <help id="diskinodes">827&amp;a=o842</help>
		</mark>
	
	
		<mark level="1">
		  <color>yellow</color>
		  <icon>small_yellow</icon>
		  <alt><sw:text>The resource is in the yellow zone.</sw:text></alt>
		  <help id="cpu">824&amp;a=o830</help>
		  <help id="system">825&amp;a=o841</help>
		  <help id="bandwidth">853</help>
		  <help id="diskspace">826&amp;a=o833</help>
		  <help id="diskinodes">827&amp;a=o837</help>
		</mark>
	
		<mark level="0">
		  <color>green</color>
		  <icon>small_green</icon>
		  <alt><sw:text>The resource is in the green zone.</sw:text></alt>
		  <help id="cpu">824&amp;a=o840</help>
		  <help id="system">825&amp;a=o836</help>
		  <help id="bandwidth">853</help>
		  <help id="diskspace">826&amp;a=o832</help>
		  <help id="diskinodes">827&amp;a=o829</help>
		</mark>
  </xsl:variable>
  <xsl:variable name="scale" select="exsl:node-set($meter-scale)"/>

  <!-- TODO: move it to the layouts -->
  <xsl:template name="showMeter">
		<xsl:param name="a"/>
		<xsl:param name="width" select="''"/>
		<xsl:param name="alert" select="'0'"/>
		
		<!-- 
			if fraction less then 0.00005 (0.005%), then round() get 0.0% 
			and this value would print in right side from meter.
			But meter still paint in green. To prevent this, 
			all fraction less then such value round to 0.
		-->
		<xsl:variable name="f-round" select="sw:if($f &lt; 0.00005,0,$f)"/>

		<xsl:choose>
			<xsl:when test="$a">
				<a>
					<xsl:copy-of select="exsl:node-set($a)/a/@*"/>
					<xsl:choose>
						<xsl:when test="$width != ''">
							<xsl:call-template name="meter-vzcp-wide">
								<xsl:with-param name="fraction" select="$f-round"/>
								<xsl:with-param name="color" select="$scale/mark[@level = $alert]/color"/>
								<xsl:with-param name="width" select="$width"/>
							</xsl:call-template>				
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="meter-vzcp">
								<xsl:with-param name="fraction" select="$f-round"/>
								<xsl:with-param name="color" select="$scale/mark[@level = $alert]/color"/>
							</xsl:call-template>				
						</xsl:otherwise>
					</xsl:choose>
				</a>
			</xsl:when>
			
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$width != ''">
						<xsl:call-template name="meter-vzcp-wide">
							<xsl:with-param name="fraction" select="$f-round"/>
							<xsl:with-param name="color" select="$scale/mark[@level = $alert]/color"/>
							<xsl:with-param name="width" select="$width"/>
						</xsl:call-template>				
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="meter-vzcp">
							<xsl:with-param name="fraction" select="$f-round"/>
							<xsl:with-param name="color" select="$scale/mark[@level = $alert]/color"/>
						</xsl:call-template>				
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>

		</xsl:choose>

  </xsl:template>
    
  <xsl:template name="meter-plesk">
		<xsl:param name="fraction"/>
		<xsl:param name="mcolor"/>  
		<xsl:param name="width" select="''"/>  
		
		<xsl:variable name="width-ext" select="sw:if($width!='',$width,150)"/>		
		<xsl:variable name="f" select="sw:if(number($fraction),$fraction,0)"/>
		<xsl:variable name="value" select="round($f*100)"/>
		
		<div class="gaugeArea">    
			<!--<xsl:value-of select="$value"/>%&#160;-->
		  <table class="gaugeLayout" border="0" width="{$width-ext}" cellspacing="0" cellpadding="0">
			<tr>
			  <xsl:choose>
				<xsl:when test="$f &lt;= 0">
				  <td><img src="/{$theme}/images/gauge/begin-empty.gif" alt="Bar Begin" /></td>
				  <td width="100%" class="barEmpty"><img src="/{$theme}/images/gauge/empty.gif" alt="Not available"/></td>
				  <td><img src="/{$theme}/images/gauge/end-empty.gif" alt="Bar End" /></td>            
				</xsl:when>          
				<xsl:when test="$f &gt;= 1">
				  <td><img src="/{$theme}/images/gauge/begin-filled.gif" alt="Bar Begin" /></td>
				  <td width="100%" class="barFilled"><img src="/{$theme}/images/gauge/fill.gif" alt="100%"/></td>
				  <td><img src="/{$theme}/images/gauge/end-filled.gif" alt="Bar End" /></td>            
				</xsl:when>
				<xsl:otherwise>
				  <td><img src="/{$theme}/images/gauge/begin-filled.gif" alt="Bar Begin" /></td>
				  <td width="{round($f*100)}%" class="barFilled"><img src="/{$theme}/images/gauge/fill.gif" alt="{round($f*100)}% used" /></td>
				  <td width="{100 - round($f*100)}%" class="barEmpty"><img src="/{$theme}/images/gauge/empty.gif" alt="{round($f*100)}% available"/></td>
				  <td><img src="/{$theme}/images/gauge/end-empty.gif" alt="Bar End" /></td>                        
				</xsl:otherwise>
			  </xsl:choose>
			</tr>
		  </table>
		</div>
  </xsl:template>  
	  
	<xsl:template name="meter-vzcp">
		<xsl:param name="fraction"/>
		<xsl:param name="color" select="'green'"/>
		
		<xsl:variable name="f" select="sw:if(number($fraction),round($fraction*10),0)"/>
		<xsl:variable name="c">
			<xsl:choose>
				<xsl:when test="$color='red'">r</xsl:when>
				<xsl:when test="$color='yellow'">y</xsl:when>
				<xsl:otherwise></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$f &gt;= 0 and $f &lt;= 10">
			<img src="/{$theme}/images/m{$c}{$f}.gif"/>
		</xsl:if>

	</xsl:template>  

	<xsl:template name="meter-vzcp-wide">
		<xsl:param name="fraction"/>
		<xsl:param name="color" select="'green'"/>
		<xsl:param name="width" select="''"/>  
		<xsl:variable name="width-ext" select="sw:if($width!='',$width,41)"/>		
		<xsl:variable name="f" select="sw:if(number($fraction),$fraction,0)"/>
		<div class="{$color}Meter">
			<table class="meter" border="0" style="width:{$width-ext}px" cellspacing="0" cellpadding="0">
				<tr class="meterRow">
					<xsl:call-template name="showCell">
						<xsl:with-param name="i" select="'0'"/>
						<xsl:with-param name="f" select="$f"/>
						<xsl:with-param name="mcolor" select="$color"/>
					</xsl:call-template>
				</tr>
			</table>			
		</div>
	</xsl:template>  
  
	<xsl:template name="showCell">
		<xsl:variable name="cell-class" select="sw:if($i &lt; ($f*10),'fc','ec')"/>
		<td class="{$cell-class}">
			<xsl:if test="((($f*10) - $i) &gt; 0) and ((($f*10) - $i) &lt; 1) ">
				<xsl:call-template name="showBorderCell">
					<xsl:with-param name="f" select="($f*10)-$i"/>
					<xsl:with-param name="mcolor" select="$mcolor"/>			
				</xsl:call-template>
			</xsl:if>
		</td>
		<xsl:if test="$i &lt; 9">
			<xsl:call-template name="showCell">
				<xsl:with-param name="i" select="$i+1"/>
				<xsl:with-param name="f" select="$f"/>
				<xsl:with-param name="mcolor" select="$mcolor"/>				
			</xsl:call-template>
 		</xsl:if>
	</xsl:template>
  
<xsl:template name="showBorderCell">
	<table width="100%" cellpadding="0" cellspacing="0">
		<tr>
			<td class="borderCellLeft" width="{format-number($f*100,'#')}%">
			</td>
			 <td class="borderCellRight" width="{format-number(100 - $f*100, '#')}%">
			</td>
		</tr>
	</table>
</xsl:template> 

	<!-- TODO: move it to the layouts -->
	<xsl:template name="showBar">
		<xsl:param name="a" />

		<a>
			<xsl:if test="$a">
				<xsl:copy-of select="exsl:node-set($a)/a/@*" />
			</xsl:if>
			<!-- 
				if fraction less then 0.00005 (0.005%), then round() get 0.0% 
				and this value would print in right side from meter.
				But meter still paint in green. To prevent this, 
				all fraction less then such value round to 0.
			-->
			<xsl:variable name="f-round" select="sw:if($f &lt; 0.00005,0,$f)" />
			<xsl:choose>
				<xsl:when test="contains($layout , 'plesk')">
					<xsl:call-template name="bar-plesk">
						<xsl:with-param name="fraction" select="$f-round" />
						<xsl:with-param name="mcolor" select="$mcolor" />
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="bar-vzcp">
						<xsl:with-param name="fraction" select="$f-round" />
						<xsl:with-param name="mcolor" select="$mcolor" />
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</a>
	</xsl:template>

	<xsl:template name="bar-plesk">
		<xsl:param name="fraction" />
		<xsl:param name="mcolor" />
		
		<xsl:variable name="f" select="sw:if(number($fraction),$fraction,0)" />
		
		<xsl:variable name="w">
			<xsl:choose>
				<xsl:when test="$f &lt;= 0">0</xsl:when>
				<xsl:when test="$f &lt; 0.01">1</xsl:when>
				<xsl:when test="$f &gt;= 1">
					<xsl:value-of select="100" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="round($f*100)" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<div class="gaugeArea" width="150">
			<table class="gaugeLayout" border="0" width="{$w}%" cellspacing="0" cellpadding="0">
				<tr>
					<td>
						<img src="/{$theme}/images/gauge/begin-{sw:if($w &gt; 0, 'filled', 'empty')}.gif" />
					</td>
					<xsl:if test="$w &gt; 0">
						<td width="100%" class="barFilled">
							<img src="/{$theme}/images/gauge/fill.gif" />
						</td>
					</xsl:if>
					<td>
						<img src="/{$theme}/images/gauge/end-{sw:if($w &gt; 0, 'filled', 'empty')}.gif" />
					</td>
				</tr>
			</table>
		</div>
	</xsl:template>

	<xsl:template name="bar-vzcp">
		<xsl:param name="fraction" />
		<xsl:param name="mcolor" />

		<xsl:variable name="f" select="sw:if(number($fraction),$fraction,0)" />

		<xsl:variable name="w">
			<xsl:choose>
				<xsl:when test="$f &lt;= 0">0</xsl:when>
				<xsl:when test="$f &lt; 0.01">1</xsl:when>
				<xsl:when test="$f &gt;= 1">
					<xsl:value-of select="100" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="round($f*100)" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="curr_color" select="sw:if($f &gt; 0, $mcolor,'#F0F0F0')" />
		<table class="bar" border="0" width="{$w}%" cellspacing="0" cellpadding="0">
			<tr>
				<td width="100%" bgcolor="{$curr_color}" style="background-color:{$curr_color}">
					<img src="/{$theme}/images/1x1.gif" width="1" height="8" style="vertical-align:auto" />
				</td>
			</tr>
		</table>
	</xsl:template>

</xsl:stylesheet>
