<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local units request"
exclude-result-prefixes="cred local units request"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
  xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:units	="http://www.swsoft.com/xsl/cp/units"  
  xmlns:request	="http://www.swsoft.com/xsl/cp/request"
>
  	
	<sw:include href="/lib/cred-filter.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/core/units-tree.xsl"/>
	<sw:include href="../layout/lib/tree.xsl" />  
  
  <xsl:template name="href">
  	<xsl:param name="href" select="@href"/>
  	
  	<xsl:variable name="real-href">
  		<xsl:choose>
  			<xsl:when test="string($href)!=''">
  				<xsl:value-of select="string($href)"/>
  			</xsl:when>
  			<xsl:when test="href">
  				<xsl:value-of select="string(href[1]/@href)"/>
  			</xsl:when>
  		</xsl:choose>
  	</xsl:variable>
  	
  	<xsl:param name="reset-paths" select="false()"/>
  	<xsl:variable name="based">  	
	    <xsl:choose>
	      <xsl:when test="contains($real-href, '$baseurl')">
	        <xsl:value-of select="concat($baseurl, substring-after($real-href, '$baseurl'))"/>
	      </xsl:when>
	      <xsl:otherwise>
	        <xsl:value-of select="$real-href"/>
	      </xsl:otherwise>
	    </xsl:choose>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="not($reset-paths)">
				<xsl:value-of select="$based"/>
			</xsl:when>
	    <xsl:when test="contains($based, '?')">
	      <xsl:value-of select="concat($based,'&amp;path=reset')"/>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:value-of select="concat($based,'?path=reset')"/>
	    </xsl:otherwise>
	  </xsl:choose>
  </xsl:template>

<xsl:template name="vzcc_menu">
	<xsl:param name="validItems"/>
	<xsl:param name="mode"/>	

	<xsl:variable name="items">
		<xsl:choose>
			<xsl:when test="$mode = 'all'">
				<xsl:copy-of select="$validItems"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="$validItems[@id = $mode]"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:apply-templates select="exsl:node-set($items)" mode="menu-tree">
		<xsl:with-param name="section_id" select="'1'"/>
		<xsl:with-param name="parent" select="'menu'"/>
		<xsl:with-param name="mode" select="$mode"/>
		<xsl:with-param name="id-supplied" select="true()"/>
	</xsl:apply-templates>

	<xsl:call-template name="menu-js"/>

	<script type="text/javascript">
        var Nodes = new Array ();
          <xsl:apply-templates select="$validItems" mode="cc-menu-tree-js">
            <xsl:with-param name="parent" select="'Nodes'"/>
          </xsl:apply-templates>
 <![CDATA[         
	function navigateMenu(screen_id){
		var id = getItemId(Nodes, screen_id);
		showSelectedItem(id);

	}

	function navigateMenuExt(is_top,units_path,obj_id,ve_parent_hn_eid){
		if (ve_parent_hn_eid){
			//VE in HN
			showSelectedItem('item_eid='+ve_parent_hn_eid+','+units_path+'_'+obj_id);
			return;
		}else
		if (obj_id){
			//VE or HN in unit
			var id = obj_id+','+units_path;
			showSelectedItem('item-eid='+id);
			return;
		}else
		if (units_path){
			//UNIT
			if(is_top == 'true'){
				showSelectedItem('item_'+units_path);
				
			}else{
				showSelectedItem('item-'+units_path);
			}
			return;
		}
	}

	function  getItemId(node, screen_id){
		//look for screen ID
		if(node[0] && node[0].length){
			for(var i=1;i<node[0].length;i++){
				//alert(node[0][i]+'  '+screen_id);
				if (node[0][i] == screen_id){
					return 'item_'+node[0][0];
				}
			}
		}
		//look for children
		if (node[1]){
			for(var i=1;i<node.length;i++){
				if(node[i].length) 
				var ret = getItemId(node[i], screen_id);
				if (ret) 
					return ret
			}
		}
		return ''
	}
		
        function _callTip(string_id, e){
          if (string_id){
            fadingTips.tipOver(string_id, e) 
          }else{
            fadingTips.tipOut(window);    
          }
        }

	function customRefresh( URL ) {
		var str = '';
		var open = parent.LeftRefresh.open;
		var close = parent.LeftRefresh.close;
		for ( var i=0;i<document.images.length;i++ ) {
			str=new String(document.images[i].onclick);
			if (str.indexOf('treeClick')!=-1) {
				open = open.replace(document.images[i].id+'|','');
				close = close.replace(document.images[i].id+'|','');
				if (document.images[i].src.indexOf('open_tree')!=-1) {close+=document.images[i].id+'|';}
				if (document.images[i].src.indexOf('close_tree')!=-1) {open+=document.images[i].id+'|';}
			}
		}
		parent.LeftRefresh.open = open.replace('/||/g','|');
		parent.LeftRefresh.close = close.replace('/||/g','|');
		parent.LeftRefresh.x = document.getElementById('navArea').scrollLeft;
		parent.LeftRefresh.y = document.getElementById('navArea').scrollTop;

		location.href=URL;
	}
]]>
	function initFirst(){
		<!-- We need to generalize it for any menu item -->
		<xsl:variable name="first-href">
			<xsl:call-template name="href">
				<xsl:with-param name="href" select="exsl:node-set($items)/item[1]/@href"/>
			</xsl:call-template>
		</xsl:variable>
		var url = '<xsl:value-of select="$first-href"/>';
		top.main.location.href = url;
		//showSelectedItem('item_menu_1');
	}        
        setCookie("vzcc-menu-mode",'<xsl:value-of select="$mode"/>', 2E12);	
        
<![CDATA[         
	//---parse init data;
	var open = '';
	var close = '';
	var navX = 0;
	var navY = 0;
	if (typeof parent.LeftRefresh != 'undefined') {
		open = parent.LeftRefresh.open;
		close = parent.LeftRefresh.close;
		navX = parent.LeftRefresh.x;
		navY = parent.LeftRefresh.y;
	}
	var el='';

	function simulateClick(elId) {
		var evt;
		var el = document.getElementById(elId);
		if (document.createEvent){
			evt = document.createEvent("MouseEvents");
				evt.initMouseEvent("click", true, true, window,
				0, 0, 0, 0, 0, false, false, false, false, 0, null);
		}
		(evt)? el.dispatchEvent(evt):(el.click && el.click());
	}

	//---dynamic open;
	if (open!='') {
		var tmp=open.split('|');
		for(var i=0;i<tmp.length;i++) {
			if (tmp[i]!='') {
				el=document.getElementById(tmp[i]);
				if (el) { if (el.src.indexOf('open_tree')!=-1) {simulateClick(tmp[i]);}	}
			}
		}
	}
	//---dynamic close;
	if (close!='') {
		var tmp=close.split('|');
		for(var i=0;i<tmp.length;i++) {
			if (tmp[i]!='') {
				el=document.getElementById(tmp[i]);
				if (el) { if (el.src.indexOf('close_tree')!=-1) {simulateClick(tmp[i]);}	}
			}
		}
	}
	function retardSet() {
		document.getElementById('navArea').scrollLeft = navX;
		document.getElementById('navArea').scrollTop = navY;
	}
	
	//---set XY;
	if ( document.getElementById('navArea') && (navY>0||navX>0) ) { setTimeout('retardSet()',10); }

]]>

	</script>
</xsl:template>

  <xsl:template name="vzpp_menu">
   <xsl:variable name="menu-data" select="sw:document($menu-file, $menu-source)"/>   
   <xsl:variable name="validSections" select="cred:filter-items($menu-data/menu/submenu)"/>

          <xsl:for-each select="$validSections">
            <xsl:variable name="validItems" select="item"/>
            <xsl:if test="count($validItems) &gt; 0">
            <xsl:variable name="section_number" select="position()"/>
            <xsl:variable name="section_target">
              <xsl:choose>
                <xsl:when test="string-length(@target) &gt; 0"><xsl:value-of select="@target"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="$def_target"/></xsl:otherwise>
              </xsl:choose>
            </xsl:variable>      
            <xsl:variable name="hrefsm"><xsl:call-template name="href"/></xsl:variable>
            <!-- group head -->
            <table  border="0" cellspacing="0" cellpadding="0" width="100%" id="section_{$section_number}" class="menuSectionOpen">
              <tr>
                <td width="100%" align="left" valign="middle" class="MenuTitle">
                  <table border="0" cellspacing="0" cellpadding="0" width="100%">
                    <tr>
                      <td class="MenuTitleLeft" valign="top"><img src="/{$theme}/images/topleft.gif" border="0" style="vertical-align:top" /></td>
                      <td class="MenuTitleText" width="100%">
                        <xsl:choose>
                          <xsl:when test="string(@href)">
                            <a href="{$hrefsm}" target="{$section_target}" onclick="selectMenuItem('')" onmouseover="_callTip('{@tip}',event)" onmouseout="_callTip()"><sw:text select="@name"/></a>
                          </xsl:when>
                          <xsl:otherwise>
                            <sw:text select="@name"/>
                          </xsl:otherwise>
                        </xsl:choose>
                      </td>
                      <td class="MenuTitleKnob"  onclick="openSection('section_{$section_number}')"><img src="/{$theme}/images/1x1.gif" id="knob_section_{$section_number}" border="0" width="20" height="22"  alt="{sw:text('Close Group')}" title="{sw:text('Close Group')}"/></td>
                      <td class="MenuTitleRight" valign="top"><img src="/{$theme}/images/topright.gif" border="0" style="vertical-align:top"/></td>
                    </tr>
                  </table>
                </td>
              </tr>
              <tr>
                <td>
                  <div>
                    <xsl:choose>
                      <xsl:when test="$validItems/item">
                        <xsl:attribute name="class">menuSectionTree</xsl:attribute>
                        <!-- menu - tree -->
                        <xsl:apply-templates select="$validItems" mode="menu-tree">
                          <xsl:with-param name="section_id"><xsl:value-of select="$section_number"/></xsl:with-param>
                          <xsl:with-param name="parent"><xsl:value-of select="$section_number"/></xsl:with-param>
                        </xsl:apply-templates>
                      </xsl:when>
                      <xsl:otherwise>
                        <xsl:attribute name="class">menuSectionFlat</xsl:attribute>
                        <!-- menu - flat -->
                        <xsl:apply-templates select="$validItems" mode="menu-tree">
                          <xsl:with-param name="section_id"><xsl:value-of select="$section_number"/></xsl:with-param>
                        </xsl:apply-templates>                      
                      </xsl:otherwise>
                    </xsl:choose>
                  </div>
                </td>
              </tr>
            </table>
	     			 </xsl:if>
            </xsl:for-each>

     	<xsl:call-template name="menu-js"/>
      <script type="text/javascript">

        var Nodes = new Array ();
        <xsl:for-each select="$validSections">
          <xsl:variable name="i" select="position()"/>
          <xsl:variable name="validItems" select="item"/>
          Nodes[<xsl:value-of select="$i"/>] = new Array();
          <xsl:apply-templates select="$validItems" mode="pp-menu-tree-js">
            <xsl:with-param name="parent">Nodes[<xsl:value-of select="$i"/>]</xsl:with-param>
          </xsl:apply-templates>
        </xsl:for-each>      
        
	function openSection(section){
	  if (document.getElementById) {
	    var el = document.getElementById (section);
	     var knob = document.getElementById ('knob_'+section);
<![CDATA[		  if (el && el.className) {]]>
		    if (el.className == 'menuSectionOpen'){
		      el.className = 'menuSectionClosed';
		      knob.alt =  '<sw:text>Open Group</sw:text>';
		      knob.title =  '<sw:text>Open Group</sw:text>';
		    }else{
			el.className = 'menuSectionOpen';
		      knob.alt =  '<sw:text>Close Group</sw:text>';
		      knob.title =  '<sw:text>Close Group</sw:text>';
		    }

		  }
	    }
	  }
	
<![CDATA[

	function navigateMenu(screen_id){
		id = getItemId(Nodes, 'item', screen_id);
		selectMenuItem(id);
	}
	
	function  getItemId(node, parentStr, screen_id){
		//look for screen ID
		if(node[0] && node[0].length){
			for(var i=0;i<node[0].length;i++){
				//alert(node[0][i] +' == '+screen_id);
				if (node[0][i] == screen_id){
					return parentStr;
				}
			}
		}
		//look for children
		if (node[1]){
			for(var i=1;i<node.length;i++){
				if(node[i].length) 
					var ret = getItemId(node[i], parentStr+'_'+i, screen_id);
					if (ret) return ret
			}
		}
		return ''
	}
	
function hide_children(id){
	img = document.getElementById('img_'+id);
	if (img.src == img_open.src){
		img.src = img_close.src;
		document.getElementById(id).className = 'TreeBranchOpen';
	}else{
		img.src = img_open.src;
		document.getElementById(id).className = 'TreeBranchClosed';
	}
}
]]>
	
    </script>	
  </xsl:template>
  
  <xsl:template name="menu-js">
    <script type="text/javascript">  
	var activeElementId = '';
	var delimeter = /_/;
	var itemStr = 'item_';

	img_open = new Image();
	img_close = new Image();
	img_open.src = '/<xsl:value-of select="$theme"/>/images/open_tree.gif';
	img_close.src = '/<xsl:value-of select="$theme"/>/images/close_tree.gif';
	
	function showSelectedItem(elementId){
		//alert(elementId);
		if (activeElementId.length > 0 ) {
			var cur = document.getElementById(activeElementId);
			if (cur) cur.className = 'MenuItem';
		}
		activeElementId = elementId;
		if (!document.getElementById(elementId)) return false;
		if (activeElementId != ""){
			var el = document.getElementById(activeElementId);
			el.className='MenuItemActive';
		}
	}
<![CDATA[
	function getSectionID(elementId){
	 var mySubstr = elementId.substr(itemStr.length);
	 return 'section_'+mySubstr.substr(0,mySubstr.indexOf('_'));
	}

	function selectMenuItem(elementId){
	 //open section
	 var section = getSectionID(elementId);
	 var el = document.getElementById(section);
	  if(el && el.className == 'menuSectionClosed'){
		openSection(section);
	  }
	  //open tree branch
	   initTree(elementId);
	   showSelectedItem(elementId);
	 }

    function openPageHelp(){
      if(top.main){
        top.main.callHelp()
      }
      return false;
    }
    
    // (Temporary) Plug for VZ compatibility
    function setActiveNode(){
   } 
  
    function _callTip(text_id, e){
      if (top.main && top.main.document && top.main.callTip){
         top.main.callTip(text_id, e);
      }
    }   
]]>  	
    </script>
  </xsl:template>
</xsl:stylesheet>
