<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:cookies="http://www.swsoft.com/xsl/cp/cookies"
>

	<xsl:output method="xml" encoding="utf-8"/>  
	<xsl:variable name="skip-redir"
			select="$request/http_request/*[self::post or self::get]/parameter[name = 'skip-redir']/value"/>

  <xsl:template match="/">

<xsl:choose>
	<xsl:when test="$skip-redir='true'">
		<details>
			[details]<xsl:value-of select="string(/packet/@id)"/>[/details]
		</details>
		<xsl:value-of select="sw:sesput('msg','')"/>
	</xsl:when>
	<xsl:otherwise>
<!--no skip-redirect BEGIN-->

		<ui:redirect>
			<xsl:choose>

				<!-- path navigation -->
				<xsl:when test="/packet/cookie/redirect-prev">
					<xsl:attribute name="path">prev</xsl:attribute>
				</xsl:when>

				<xsl:when test="/packet/cookie/redirect-last">
					<xsl:attribute name="path">last</xsl:attribute>
				</xsl:when>

				<!-- direct navigation -->
				<xsl:when test="/packet/cookie/redirect">
					<xsl:attribute name="location"><xsl:value-of select="/packet/cookie/redirect"/></xsl:attribute>
				</xsl:when>

				<!-- same screen - default -->
				<xsl:otherwise>
					<xsl:attribute name="location"><xsl:value-of select="$requesturl"/></xsl:attribute>					
				</xsl:otherwise>												

			</xsl:choose>
			
			<!-- set system cookies -->
			<xsl:if test="/packet/cookie/set-system-cookies">
				
				<xsl:for-each select="exsl:node-set(cookies:get-cookies())/cookie">
					<ui:cookie>
						<xsl:copy-of select="@*"/>
						<xsl:value-of select="."/>
					</ui:cookie>
				</xsl:for-each>
			</xsl:if>
			
			<!-- set custom cookies -->
			<xsl:for-each select="/packet/cookie/set-custom-cookies/cookie">
				<ui:cookie>
					<xsl:copy-of select="@*"/>
					<xsl:value-of select="."/>
				</ui:cookie>
			</xsl:for-each>
			
		</ui:redirect>

    <!-- operation fail -->
    <xsl:choose>      
      <xsl:when test="/packet/data//error">
        <xsl:variable name="det">
          <xsl:value-of select="/packet/cookie/msg/error"/><xsl:text>&#10;</xsl:text>
          <xsl:value-of select="/packet/data//error/message"/>
        </xsl:variable>
        <xsl:if test="error:put(string(/packet/cookie/msg/error),string($det))"/>       
      </xsl:when>

      <xsl:when test="/packet/data/progm/exec/status != 0">
        <xsl:variable name="det">
          <xsl:value-of select="/packet/cookie/msg/error"/><xsl:text>&#10;</xsl:text>
          <xsl:value-of select="sw:base64-decode(/packet/data/progm/exec/output)"/>
        </xsl:variable>
        <xsl:if test="error:put(string(/packet/cookie/msg/error),string($det))"/>          
      </xsl:when>
				
      <!-- operation progm ok -->
      <xsl:when test="/packet/data/progm/exec/status = 0">
        <xsl:value-of select="sw:sesput('msg', string(/packet/cookie/msg/ok))"/>
      </xsl:when>

      <!-- operation scheduled -->
      <xsl:when test="/packet/data/progress">
        <xsl:value-of select="sw:sesput('operation_id', string(/packet/@id))"/>
        <xsl:choose>
        	<xsl:when test="/packet/cookie/msg/sched/message='UXVldWVpbmc='"> <!-- # 56501 workaround -->
        		<xsl:value-of select="sw:sesput('msg', sw:text('The requested operation has been placed in the queue because of a high number of current requests. While the operation awaits execution, neither the Task Details nor Active Tasks screen will display it.'))"/>
        	</xsl:when>
          <xsl:when test="/packet/cookie/msg/sched">
            <xsl:value-of select="sw:sesput('sched', string(/packet/cookie/msg/sched))"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="sw:sesput('sched', sw:text('Operation scheduled'))"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>

			<!-- get ok/sched/error from packet without <data> node -->
	    <xsl:when test="/packet/cookie/msg/set-error">
        <xsl:variable name="det">
        	<xsl:if test="/packet/cookie/msg/set-error/detail">
	          <xsl:value-of select="/packet/cookie/msg/set-error/short-desc"/><xsl:text>&#10;</xsl:text>
	          <xsl:value-of select="/packet/cookie/msg/set-error/detail"/>
	         </xsl:if>
        </xsl:variable>
        <xsl:if test="error:put(string(/packet/cookie/msg/set-error/short-desc),string($det))"/>       
    	</xsl:when>

	    <xsl:when test="/packet/cookie/msg/set-ok">
  	    <xsl:value-of select="sw:sesput('msg',string(/packet/cookie/msg/set-ok))"/>
    	</xsl:when>

	    <xsl:when test="/packet/cookie/msg/set-sched">
        <xsl:value-of select="sw:sesput('operation_id', string(/packet/cookie/msg/set-sched/operation-id))"/>
  	    <xsl:value-of select="sw:sesput('sched',string(/packet/cookie/msg/set-sched/short-desc))"/>
    	</xsl:when>
    	
    	<!-- operation ok -->
      <xsl:when test="/packet/data">
        <xsl:value-of select="sw:sesput('msg', string(/packet/cookie/msg/ok))"/>
      </xsl:when>
			
    </xsl:choose>

    <xsl:if test="/packet/cookie/operation">
      <xsl:value-of select="sw:sesput('operation', string(/packet/cookie/operation))"/>
    </xsl:if>

	</xsl:otherwise>
<!--no skip-rediret END-->

</xsl:choose>

  </xsl:template>
  
  <sw:include href="../http/cookies.xsl"/> 
  <sw:include href="globals.xsl"/>
	<sw:include href="common.xsl"/>

</xsl:stylesheet>
