<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw func exsl proc"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:proc		="http://www.swsoft.com/xsl/cp/proc"
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"
	xmlns:perfmon	="http://www.swsoft.com/xsl/cp/perfmon"
  >

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/swa/perfmon.xsl"/>	
	<sw:include href="/lib/utils/format-resusage.xsl"/>

  <!-- request sysinfo for specific ENV -->
  <xsl:template name="proc:sysinfo">
  	<xsl:param name="eid"		select="''"/>
	  <xsl:variable name="obj-type" select="env:eid2info($eid)/obj-type"/>
	  <xsl:variable name="counter-cpu" select="env:obj-type2counter-name($obj-type,'cpu')"/>
	  <xsl:variable name="counter-loadavg" select="env:obj-type2counter-name($obj-type,'loadavg')"/>
	  <xsl:variable name="counter-system" select="env:obj-type2counter-name($obj-type,'system')"/>
		<xsl:variable name="classes-rtf">
			<cpu>
				<xsl:value-of select="$counter-cpu"/>
			</cpu>
			<loadavg>
				<xsl:value-of select="$counter-loadavg"/>					
			</loadavg>
			<system>
				<xsl:value-of select="$counter-system"/>
			</system>
		</xsl:variable>
		<xsl:variable name="classes" select="exsl:node-set($classes-rtf)"/>
		<xsl:variable name="sysinfo-new-format" select="perfmon:get($eid,$classes/*)"/>
		<xsl:variable name="sysinfo-old-format-rtf">
			<system>
				<uptime>
					<xsl:value-of select="$sysinfo-new-format/data/class[name = $classes/system]/instance/counter[name = 'counter_system_uptime']/value/cur"/>
				</uptime>
				<cpu_states>
					<user>
						<xsl:value-of select="$sysinfo-new-format/data/class[name = $classes/cpu]/instance/counter[name = 'counter_cpu_user_states']/value/cur"/>
					</user>
					<nice>
						<xsl:variable name="nice" select="$sysinfo-new-format/data/class[name = $classes/cpu]/instance/counter[name = 'counter_cpu_nice_states']/value/cur"/>
						<xsl:value-of select="sw:if(not($nice != ''),0,$nice)"/>
					</nice>
					<system>
						<xsl:value-of select="$sysinfo-new-format/data/class[name = $classes/cpu]/instance/counter[name = 'counter_cpu_system_states']/value/cur"/>
					</system>
				</cpu_states>
				<load_avg>
					<l1>
						<xsl:value-of select="$sysinfo-new-format/data/class[name = $classes/loadavg]/instance/counter[name = 'counter_loadavg_l1']/value/cur"/>
					</l1>
					<l2>
						<xsl:value-of select="$sysinfo-new-format/data/class[name = $classes/loadavg]/instance/counter[name = 'counter_loadavg_l2']/value/cur"/>
					</l2>
					<l3>
						<xsl:value-of select="$sysinfo-new-format/data/class[name = $classes/loadavg]/instance/counter[name = 'counter_loadavg_l3']/value/cur"/>
					</l3>
				</load_avg>
			</system>
		</xsl:variable>

		<xsl:copy-of select="exsl:node-set($sysinfo-old-format-rtf)/system"/>
  </xsl:template>

  <xsl:template name="proc:cpualerts">
    <xsl:param name="sysinfo"/>
    <xsl:variable name="used" select="$sysinfo/system/cpu_states/user + $sysinfo/system/cpu_states/nice + $sysinfo/system/cpu_states/system"/>
    <xsl:variable name="level" select="exsl:node-set(sw:get-fake-alerts($used,100))"/>
    <alerts>
    	<alert>
    		<id>cpuunits</id>
      	<xsl:choose>
      		<xsl:when test="$level/level &gt;= 0 and $level/level &lt;= 3">
	          <type><xsl:value-of select="$level/level"/></type>
	        </xsl:when>
	        <xsl:otherwise>
	        	<type>-1</type>
	        </xsl:otherwise>
	      </xsl:choose>
			</alert>
    </alerts>
  </xsl:template>

	<!-- calculate cpu load by sysinfo -->
	<func:function name="proc:calc-cpu-load">
		<xsl:param name="system"/>
		<func:result>
			<xsl:for-each select="$system/cpu_states">
				<xsl:value-of select="(user + nice + system) div 100"/>
			</xsl:for-each>
		</func:result>
	</func:function>

	<!-- calculate load-average value and alert by sysinfo -->
	<func:function name="proc:calc-load-avg">
    <xsl:param name="load-avg-node" select="/.."/>
		<xsl:variable name="l1" select="format-number($load-avg-node/l1,'0.0#')"/>
		<xsl:variable name="l2" select="format-number($load-avg-node/l2,'0.0#')"/>
		<xsl:variable name="l3" select="format-number($load-avg-node/l3,'0.0#')"/>
		<xsl:variable name="load-avg-rtf">
			<value>
				<xsl:choose>
					<xsl:when test="$l1 &gt;= 0 and $l2 &gt;= 0 and $l3 &gt;= 0">
						<xsl:value-of select="concat($l1,', ',$l2,', ',$l3)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="sw:text('n/a')"/>
					</xsl:otherwise>
				</xsl:choose>
			</value>
			<alert>
				<xsl:choose>
					<xsl:when test="$l1 &gt;= 1.0 and $l2 &gt;= 1.0 and $l3 &gt;= 1.0">
						<level>2</level>
						<color>red</color>
					</xsl:when>
					<xsl:when test="$l1 &gt;= 0.9 and $l2 &gt;= 0.8 and $l3 &gt;= 0.7">
						<level>1</level>
						<color>yellow</color>
					</xsl:when>
					<xsl:when test="$l1 &gt;= 0 and $l2 &gt;= 0 and $l3 &gt;= 0">
						<level>0</level>
						<color>green</color>
					</xsl:when>
					<xsl:otherwise>
						<level>-1</level>
						<color>grey</color>
					</xsl:otherwise>
				</xsl:choose>
			</alert>
		</xsl:variable>
		<func:result select="exsl:node-set($load-avg-rtf)"/>
	</func:function>

	<!-- split time in sec, return node-set with day,hour,min,sec nodes -->
	<func:function name="proc:split-time">
		<xsl:param name="raw-time"/>
		<xsl:variable name="days"		select="$raw-time div 86400"/>
		<xsl:variable name="hrs"		select="($raw-time mod 86400) div 3600"/>
		<xsl:variable name="mins"		select="(($raw-time mod 86400) mod 3600) div 60"/>
		<xsl:variable name="secs"		select="(($raw-time mod 86400) mod 3600) mod 60"/>
		<xsl:variable name="format-time">
			<xsl:if test="$days &gt;= 1">
				<day>
					<xsl:value-of select="floor($days)"/>
				</day>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="$hrs &gt;= 1 and $mins &gt;= 1">
		      <hr>
		      	<xsl:value-of select="floor($hrs)"/>
		      </hr>
		      <min>
		      	<xsl:value-of select="floor($mins)"/>
		      </min>
				</xsl:when>
				<xsl:when test="$hrs &gt;= 1">
					<hr>
						<xsl:value-of select="floor($hrs)"/>
					</hr>
				</xsl:when>
				<xsl:when test="$mins &gt;= 1">
					<min>
						<xsl:value-of select="floor($mins)"/>
					</min>
				</xsl:when>				
				<xsl:otherwise>
					<sec>
						<xsl:value-of select="floor($secs)"/>
					</sec>
				</xsl:otherwise>				
			</xsl:choose>
		</xsl:variable>	
		<func:result select="exsl:node-set($format-time)"/>
	</func:function>

	<func:function name="proc:uptime-string">
		<xsl:param name="node-time"/>
		<xsl:variable name="day"	select="$node-time/day"/>
		<xsl:variable	name="hr"		select="$node-time/hr"/>
		<xsl:variable name="min"	select="$node-time/min"/>
		<xsl:variable name="sec"	select="$node-time/sec"/>
		<xsl:variable name="string-time">	
			<xsl:if test="$day &gt; 0">
				<sw:text>
					<xsl:with-param name="day"		select="$day"/>										
					<xsl:with-param name="modif"	select="sw:if($day &gt; 1,'s','')"/>
					%{day} day%{modif}&#160;
				</sw:text>
			</xsl:if>
			<xsl:if test="$hr &gt; 0">
				<sw:text>
					<xsl:with-param name="hr"		select="$hr"/>										
					<xsl:with-param name="modif"	select="sw:if($hr &gt; 1,'s','')"/>
					%{hr} hr%{modif}&#160;			
				</sw:text>
			</xsl:if>
			<xsl:if test="$min &gt; 0">
				<sw:text>
					<xsl:with-param name="min"		select="$min"/>										
					<xsl:with-param name="modif"	select="sw:if($min &gt; 1,'s','')"/>
					%{min} min%{modif}&#160;					
				</sw:text>
			</xsl:if>
			<xsl:if test="$sec &gt;= 0">
				<sw:text>
					<xsl:with-param name="sec"		select="$sec"/>										
					<xsl:with-param name="modif"	select="sw:if($sec &gt; 1,'s','')"/>
					%{sec} sec%{modif}&#160;
				</sw:text>
			</xsl:if>
		</xsl:variable>
		<func:result select="$string-time"/>
	</func:function>

</xsl:stylesheet>
