<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func show show-resource format"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"  
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:func	="http://exslt.org/functions"
	xmlns:show ="http://www.swsoft.com/xsl/cp/show"	
	xmlns:show-resource ="http://www.swsoft.com/xsl/cp/show-resource"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>
	
	<sw:include href="/lib/utils/format-number.xsl"/>	

	<xsl:template match="group" mode="resource">
		<xsl:choose>
			<xsl:when test="(id = 'cpu') or (id = 'system' and resource/id !=  'memory')">
				<ui:summary-block title="{title}" width="400">
					<ui:simple-table>
						<xsl:for-each select="resource">
							<row>
                <xsl:variable name="tip" select="show-resource:get-tips-by-alert(gauge,alert/type)"/>
								<xsl:variable name="color" select="show-resource:get-color-by-alert(alert/type)"/>
                <col align="left">
                	<xsl:if test="alert/show-by-icon">
                		<img style="padding-right:5px;" src="/{$theme}/icons/{$color}_16.gif" width="16" height="16"/>
                	</xsl:if>
									<xsl:copy-of select="name"/>
								</col>
								<xsl:choose>
									<xsl:when test="fraction">
										<col align="left">
											<ui:meter-block after="{format:percent(fraction)}" fraction="{sw:if(fraction/child::node(),fraction,sw:text('n/a'))}" tip="{$tip}">
                        <xsl:if test="alert/show-by-meter">
                          <xsl:attribute name="alert"><xsl:value-of select="show-resource:normalize-alert-type(alert/type,fraction)"/></xsl:attribute>
                        </xsl:if>
                      </ui:meter-block>												
										</col>
									</xsl:when>
									<xsl:otherwise>
										<!-- no fraction section, only column -->
										<col align="left"><xsl:value-of select="value"/></col>
									</xsl:otherwise>
								</xsl:choose>
							</row>
						</xsl:for-each>
					</ui:simple-table>
				</ui:summary-block>
			</xsl:when>

			<xsl:when test="((id = 'disk') or (id='mem') or ((id='system') and (resource/id = 'memory'))) and resource">
            <xsl:variable name="has-commitment" select="resource/commitment/value != ''"/>			
	    	<ui:summary-block title="{title}" width="{sw:if($has-commitment,850,600)}">   
          <ui:table>
            <col-header align="left" width="150"><sw:text>Resource</sw:text></col-header>
            <col-header align="center" width="250"><sw:text>Used</sw:text></col-header>
            <col-header align="right" width="100"><sw:text>Free</sw:text></col-header>
            <col-header align="right" width="100"><sw:text>Total</sw:text></col-header>

            <xsl:if test="$has-commitment">
		          <col-header align="center" width="250"><sw:text>Commitment</sw:text></col-header>
  		      </xsl:if>
            <xsl:for-each select="resource">
              <row>
                <xsl:variable name="tip" select="show-resource:get-tips-by-alert(gauge,alert/type)"/>
								<xsl:variable name="color" select="show-resource:get-color-by-alert(alert/type)"/>
                <xsl:variable name="before">
                  <xsl:apply-templates select="values/cur"/>
                </xsl:variable>
                <col align="left">
                	<xsl:if test="alert/show-by-icon">
    	            	<xsl:attribute name="icon">
    	            		<xsl:value-of select="$color"/>
										</xsl:attribute>
                	</xsl:if>
                	<xsl:value-of select="name"/>
                </col>
                <col>
                  <ui:meter-block  before="{$before}" after="{format:percent(fraction)}" fraction="{fraction}" tip="{$tip}">
										<xsl:if test="alert/show-by-meter">
		                	<xsl:attribute name="alert"><xsl:value-of select="show-resource:normalize-alert-type(alert/type,fraction)"/></xsl:attribute>
		                </xsl:if>
									</ui:meter-block>
                </col>
                <col><xsl:apply-templates select="values/free"/></col>
                <col><xsl:apply-templates select="values/total"/></col>
                				<xsl:if test="$has-commitment">
                					<col>
								<xsl:choose>
									<xsl:when test="commitment/value = -1">
										<xsl:attribute name="align">right</xsl:attribute>
										<img src="/{$theme}/icons/red_16.gif" style="margin-right: 5px"/>
										<sw:text>Unlimited</sw:text>
									</xsl:when>
									<xsl:when test="commitment/value !=''">
										<ui:meter-block  before="{format:int2bytes(commitment/value,'', 'yes', '#,##0.#')}" after="{format:percent(commitment/fraction)}" fraction="{commitment/fraction}" tip="{$tip}"/>
									</xsl:when>
									<xsl:otherwise>
										&#160;
									</xsl:otherwise>
								</xsl:choose>
							</col>				
						</xsl:if>                
              </row>
            </xsl:for-each>
          </ui:table>
				</ui:summary-block>   
			</xsl:when>

      <xsl:when test="id = 'network'">
        <ui:summary-block title="{title}" width="400">
          <ui:table>
            <col-header width="150" align="left"><sw:text>Class ID</sw:text></col-header>
            <col-header width="250" align="center"><sw:text>Bandwidth</sw:text></col-header>
            <xsl:for-each select="resource">
              <xsl:variable name="tip" select="show-resource:get-tips-by-alert(gauge,alert/type)"/>
              <xsl:variable name="color" select="show-resource:get-color-by-alert(alert/type)"/>
              <row>
                <col>
                	<xsl:if test="alert/show-by-icon">
    	            	<xsl:attribute name="icon">
    	            		<xsl:value-of select="$color"/>
										</xsl:attribute>
                	</xsl:if>
                	<xsl:value-of select="name"/>
                </col>
                <col>
                  <ui:meter-block before="&#160;&#160;&#160;&#160;&#160;" after="{format:percent(fraction)}" fraction="{fraction}" tip="{$tip}">
										<xsl:if test="alert/show-by-meter">  	
											<xsl:attribute name="alert">
												<xsl:value-of select="show-resource:normalize-alert-type(alert/type,fraction)"/>
											</xsl:attribute>
		                </xsl:if>
									</ui:meter-block>                  
                </col>              
              </row>
            </xsl:for-each>
          </ui:table>             
        </ui:summary-block>
      </xsl:when>  

			<xsl:when test="id = 'common'">
				<ui:block width="max">
					<ui:rows title="{title}">
						<xsl:for-each select="resource">
							<ui:row>
								<ui:cell cell-width="172"><xsl:value-of select="name"/></ui:cell>
								<ui:cell colspan="3"><xsl:value-of select="value"/></ui:cell>
							</ui:row>
						</xsl:for-each>
					</ui:rows>
				</ui:block>
			</xsl:when>
    </xsl:choose>
	</xsl:template>


  <xsl:template name="local:insert-fraction">
  	<xsl:param name="fraction" />
  	<xsl:if test="$fraction">
  		<!-- in resource description fraction specifyed -->
  		<fraction>
  			<xsl:choose>
  				<xsl:when test="$fraction/child::node()">
  					<xsl:choose>
  						<xsl:when test="$fraction &gt; 1">1</xsl:when>
  						<xsl:when test="$fraction &gt; 0">
  							<xsl:value-of select="$fraction" />
  						</xsl:when>
  						<xsl:otherwise>0</xsl:otherwise>
  					</xsl:choose>
  				</xsl:when>
  				<xsl:otherwise>
  					<special-status>
  						<xsl:value-of select="sw:text('n/a')" />
  					</special-status>
  				</xsl:otherwise>
  			</xsl:choose>
  		</fraction>
  	</xsl:if>
  </xsl:template>


	<func:function name="show-resource:get-color-by-alert">
		<xsl:param name="alert"/>		
		<func:result>
			<xsl:choose>
				<xsl:when test="$alert = 3">red</xsl:when>
				<xsl:when test="$alert = 2">red</xsl:when>
				<xsl:when test="$alert = 1">yellow</xsl:when>
				<xsl:when test="$alert = 0">green</xsl:when>				
				<xsl:when test="$alert = -1">grey</xsl:when>				
				<xsl:otherwise>green</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>


	<func:function name="show-resource:get-tips-by-alert">
		<xsl:param name="gauge"/>		
		<xsl:param name="alert-type"/>		
		<func:result>
			<xsl:choose>
				<xsl:when test="$alert-type = -1">
					<xsl:value-of select="'gauge_not_available'"/>
				</xsl:when>			
				<xsl:when test="$alert-type &gt;= 0 and $alert-type &lt;= 3">
					<xsl:value-of select="concat('gauge_',$gauge,'_',$alert-type)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="concat('gauge_',$gauge)"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>


	<func:function name="show-resource:normalize-alert-type">
		<xsl:param name="alert"/>
		<xsl:param name="val" select="''"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="string($val) = ''">
					<xsl:value-of select="-1"/>
				</xsl:when>
				<xsl:when test="$alert &gt;= 0 and $alert &lt;= 3">
					<xsl:value-of select="$alert"/>
				</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>


</xsl:stylesheet>
