<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="exsl sw func global"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"  
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:func	="http://exslt.org/functions"
	xmlns:user	="http://www.swsoft.com/xsl/cp/user"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
	xmlns:env   ="http://www.swsoft.com/xsl/cp/env"
  xmlns:vzenv ="http://www.swsoft.com/xsl/cp/vzenv"
>

  <sw:include href="/lib/vz/vzenv-core.xsl"/>

  <!--
    Request may contain SAML token, indicating that local account is already
    associated with some Federated Identity. In this case appropriate control
    might be shown on dashboard.
  -->

  <!-- SSO settings are stored per-environment, doesn't matter SVE or VE -->
  <xsl:variable name="sso-eid">
    <xsl:choose>
      <xsl:when test="not(sw:ve-eid() = $env:empty-eid)">
        <xsl:value-of select="sw:ve-eid()"/>        
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="vzenv:veid-to-eid(1,sw:local-hn-eid())"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="sso-sp-config" select="sw:sso-get-config($sso-eid)"/>


  <!-- Obtain SSO configuration for specified environment -->
  <func:function name="sw:sso-get-config">
    <xsl:param name="eid"/>
    <xsl:variable name="req">
      <packet>
        <target>sso</target>
        <data>
          <sso>
            <get_registered>
              <eid>
                <xsl:value-of select="$eid"/>
              </eid>
            </get_registered>
          </sso>
        </data>
      </packet>
    </xsl:variable>
    <!--<func:result select="sw:xchg($req)/packet/data/sso/application"/>
	-->
	<func:result select="/.."/>
</func:function>


  <!-- Obtain signed SAML token with authentication request, base64-encoded -->
  <func:function name="sw:sso-get-authn-request">
    <xsl:param name="sp-id"/>
    <xsl:param name="force-auth" select="false()"/>

    <xsl:variable name="req">
      <packet>
        <target>sso</target>
        <data>
          <sso>
            <create_authn_request>
              <eid>
                <xsl:value-of select="$sso-eid"/>
              </eid>
              <sp_id>
                <xsl:value-of select="$sp-id"/> 
              </sp_id>
              <xsl:if test="$force-auth">
                <force_auth/>
              </xsl:if>
            </create_authn_request>
          </sso>
        </data>
      </packet>
    </xsl:variable>
    <func:result select="sw:xchg($req)/packet/data/sso/sso_token"/>
  </func:function>


  <!--
    Authenticate user agains the specified realms and returns
    the first obtained SID. Please note that SID is returned base64-encoded
    and decoded SID has no ASCII representation.
  -->
  <func:function name="sw:get-sid">
    <xsl:param name="name"/>
    <xsl:param name="password"/>
    <xsl:param name="realms"/>
    <!-- authm accepts base64-encoded values -->
    <xsl:variable name="name-base64"			select="sw:base64-encode($name)"/>
    <xsl:variable name="password-base64"	select="sw:base64-encode($password)"/>
		<xsl:variable name="domain-base64"		select="sw:base64-encode($sso-eid)"/>
		<xsl:variable name="ve-realm-id"			select="$realms/realm[type = 1000]/id"/>
    <!-- request to authm/authenticate -->
    <xsl:variable name="req">
    	<packet>
      	<target>authm</target>
        <data>
        	<authm>
          	<authenticate>
            	<domain><xsl:value-of select="$domain-base64"/></domain>
              <name><xsl:value-of select="$name-base64"/></name>
              <realm><xsl:value-of select="$ve-realm-id"/></realm>
              <password><xsl:value-of select="$password-base64"/></password>
            </authenticate>
          </authm>
        </data>
      </packet>
    </xsl:variable>
    <xsl:variable name="vzl-token" select="sw:xchg($req)/packet/data/authm/token"/>
    <!-- stop on first SID been found -->
    <xsl:if test="$vzl-token/user">
    	<func:result select="string($vzl-token/user)"/>
    </xsl:if>
  </func:function>


</xsl:stylesheet>
