<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func dirm"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions" xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:vza_authm="http://www.swsoft.com/webservices/vzl/4.0.0/authm"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
	xmlns:local="http://www.swsoft.com/xsl/cp/local">

	<sw:include href="../swa/dirm.xsl"/>

	<func:function name="authm:vzadmin-group-name">
		<func:result select="concat('cn=vzadministrators,cn=Builtin,',$global:vzl-dn)"/>
	</func:function>

	<func:function name="authm:vzadmin-group-cn">
		<func:result select="'vzadministrators'"/>
	</func:function>

	<!--
		List groups
		Parameters:
			realm - optional, list groups from given realm only
			filter-attrs - optinal, overrides 'realm' parameter. 
				Node-set with one 'attr' child element:
					attr/
						name
						value
						realm
		result-attrs - optional. Node-set with desired attribute 'name's.
			By default returns all attributes.
		Result: 'error' or 'data' node-set	
	-->
	<func:function name="authm:get-groups">
		<xsl:param name="realm" select="/.."/>
		<xsl:param name="filter-attrs" select="/.."/>
		<xsl:param name="result-attrs" select="/.."/>
		
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<get_group>
							<xsl:choose>
								<xsl:when test="not($filter-attrs!='')">
									<group>
										<realm>
											<xsl:value-of select="$realm"/>
										</realm>
									</group>									
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="$filter-attrs/attr"/>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="not($result-attrs!='')">
									<attrs/>
								</xsl:when>
								<xsl:otherwise>
									<attrs>
										<xsl:copy-of select="$result-attrs/name"/>
									</attrs>
								</xsl:otherwise>
							</xsl:choose>
						</get_group>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data"/>
	</func:function>

	<func:function name="authm:add-group">
		<xsl:param name="group-data"/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<add_group>
							<group>
								<xsl:copy-of 
									select="$group-data/*[local-name()!='member_user' 
									and local-name()!='member_group']"/>
							</group>
						</add_group>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<xsl:variable name="add-result" select="sw:xchg($req)/packet/data/authm"/>

		<xsl:variable name="add-member-rtf">
			<xsl:choose>
				<xsl:when test="not($add-result//error)">
					<xsl:choose>
						<xsl:when test="$group-data/member_user|$group-data/member_group">
							<xsl:variable name="add-member-req">
								<packet>
									<target>authm</target>
									<data>
										<xsl:for-each select="$group-data/member_user">
											<xsl:copy-of 
												select="authm:cmd-add-to-groups(.,$group-data)/packet/data/authm"/>
										</xsl:for-each>
										<xsl:for-each select="$group-data/member_group">
											<xsl:copy-of 
												select="authm:cmd-add-to-groups(.,$group-data)/packet/data/authm"/>
										</xsl:for-each>
									</data>
									<vzcpauth/>
								</packet>
							</xsl:variable>
							<xsl:copy-of select="sw:xchg(exsl:node-set($add-member-req))/packet/data/authm"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$add-result"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$add-result"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($add-member-rtf)"/>
	</func:function>

	<!-- 
		Edit existing group.
		Parameters:
			group-auth-name - element with original group data (name, realm and domain)
			group-data - new group data
		Returns: node-set with 'ok' or/and 'error' children
	-->
	<func:function name="authm:set-group">
		<xsl:param name="group-auth-name"/>
		<xsl:param name="group-data"/>
		<xsl:variable name="orig-group" 
			select="authm:get-group(sw:base64-decode($group-auth-name/name),$group-auth-name/realm)"/>

		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<edit_group>
							<xsl:copy-of select="$group-auth-name/*[local-name()='name' 
								or local-name()='realm'
								or local-name()='domain']"/>
							<group>
								<xsl:copy-of select="$group-data/*[local-name()!='member_user' 
									and local-name()!='member_group']"/>
							</group>
						</edit_group>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<xsl:variable name="edit-result" select="sw:xchg($req)/packet/data/authm"/>
		
		<xsl:variable name="update-member-rtf">
			<xsl:choose>
				<xsl:when test="not($edit-result//error) 
					and ($group-data/member_user or $group-data/member_group)">
					<xsl:variable name="member-users-to-add"
						select="$group-data/member_user[not(string(name)=$orig-group/member_user/name 
							and string(realm)=$orig-group/member_user/realm)]"/>
					<xsl:variable name="member-groups-to-add"
						select="$group-data/member_group[not(string(name)=$orig-group/member_group/name 
						and string(realm)=$orig-group/member_group/realm)]"/>
					<xsl:variable name="member-users-to-del" 
						select="$orig-group/member_user[not(string(name)=$group-data/member_user/name 
						and string(realm)=$group-data/member_user/realm)]"/>
					<xsl:variable name="member-groups-to-del" 
						select="$orig-group/member_group[not(string(name)=$group-data/member_group/name 
						and string(realm)=$group-data/member_group/realm)]"/>					
					<xsl:choose>
						<xsl:when 
							test="$member-users-to-add|$member-groups-to-add|$member-users-to-del|$member-groups-to-del">
							<xsl:variable name="update-member-req">
								<packet>
									<target>authm</target>
									<data>
										<xsl:for-each select="$member-users-to-add|$member-groups-to-add">
											<xsl:copy-of 
												select="authm:cmd-add-to-groups(.,$group-data)/packet/data/authm"/>
										</xsl:for-each>
										<xsl:for-each select="$member-users-to-del|$member-groups-to-del">
											<xsl:copy-of 
												select="authm:cmd-del-from-groups(.,$group-data)/packet/data/authm"/>											
										</xsl:for-each>
									</data>
									<vzcpauth/>
								</packet>
							</xsl:variable>
							<xsl:copy-of select="sw:xchg(exsl:node-set($update-member-req))/packet/data/authm"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$edit-result"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$edit-result"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($update-member-rtf)"/>
	</func:function>

	<!--
		Add user/group to given groups.
		Parameters:
			principal - user/group with auth. elements in it (name, realm and domain)
			groups - list of groups to add principal into
		Returns: element with 'ok' or 'error' child
		-->
	<func:function name="authm:add-to-groups">
		<xsl:param name="principal"/>
		<xsl:param name="groups"/>
		<xsl:variable name="req" 
			select="authm:cmd-add-to-groups($principal,$groups)"/>
		<func:result select="sw:xchg($req)/packet/data/authm"/>
	</func:function>

	<!--
		Wrapper for authm/add_to_group.
		Parameters:
			principal - user/group element with auth. information (name, realm and domain)
			groups - node-set with group auth. names
		-->
	<func:function name="authm:cmd-add-to-groups">
		<xsl:param name="principal"/>
		<xsl:param name="groups"/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<add_to_group>
							<xsl:copy-of select="$principal/*[local-name()='name' 
								or local-name()='realm'
								or local-name()='domain']"/>
							<xsl:for-each select="$groups">
								<group>
									<xsl:copy-of select="name"/>
									<xsl:copy-of select="realm"/>
									<xsl:copy-of select="domain"/>
								</group>
							</xsl:for-each>
						</add_to_group>
					</authm>
				</data>
				<vzcpauth/>
			</packet>			
		</xsl:variable>
		<func:result select="exsl:node-set($req)"/>
	</func:function>

	<!--
		Delete user/group from given groups.
		Parameters:
			principal - user/group with auth. elements in it (name, realm and domain)
			groups - list of groups to delete principal from
		Returns: element with 'ok' or 'error' child
	-->
	<func:function name="authm:del-from-groups">
		<xsl:param name="principal"/>
		<xsl:param name="groups"/>
		<xsl:variable name="req" 
			select="authm:cmd-del-from-groups($principal,$groups)"/>
		<func:result select="sw:xchg($req)/packet/data/authm"/>
	</func:function>

	<!--
		Wrapper for authm/del_from_group.
		Parameters:
		principal - user/group element with auth. information (name, realm and domain)
		groups - node-set with group auth. names
	-->
	<func:function name="authm:cmd-del-from-groups">
		<xsl:param name="principal"/>
		<xsl:param name="groups"/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<del_from_group>
							<xsl:copy-of select="$principal/*[local-name()='name' 
								or local-name()='realm'
								or local-name()='domain']"/>
							<xsl:for-each select="$groups">
								<group>
									<xsl:copy-of select="name"/>
									<xsl:copy-of select="realm"/>
									<xsl:copy-of select="domain"/>
								</group>
							</xsl:for-each>
						</del_from_group>
					</authm>
				</data>
				<vzcpauth/>
			</packet>			
		</xsl:variable>
		<func:result select="exsl:node-set($req)"/>
	</func:function>
	
	<!-- get one group -->
	<func:function name="authm:get-group">
		<xsl:param name="name"/>
		<xsl:param name="realm" select="''"/>
		<xsl:param name="convert-attrs" select="true()"/>

		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<get_group>
							<group>
								<name>
									<xsl:value-of select="sw:base64-encode($name)"/>
								</name>
								<xsl:if test="string($realm) != ''">
									<realm>
										<xsl:value-of select="$realm"/>
									</realm>								
								</xsl:if>
							</group>
							<attrs/>
						</get_group>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>

		<xsl:choose>
			<xsl:when test="$convert-attrs">
				<xsl:variable name="res-rtf">
					<xsl:if test="$resp/authm/group">
						<group>
							<xsl:copy-of select="$resp/authm/group/*[not(self::data)]"/>
							<xsl:copy-of select="dirm:attrs2nodes($resp/authm/group/data)"/>
						</group>
					</xsl:if>
				</xsl:variable>
				<func:result select="exsl:node-set($res-rtf)/group"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/authm/group"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- Helper function for group's display name -->
	<func:function name="authm:group-display-name">
		<xsl:param name="group"/>
		<func:result>
			<xsl:choose>
				<xsl:when
					test="$group/cn = authm:vzadmin-group-cn() or string(authm:vzadmin-group-name()) = $group/name">
					<xsl:value-of select="authm:vzadmin-group-cn()"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$group/cn"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<!-- 
		List users
		Parameters:
			realm - optional, list users from given realm only
			filter-attrs - optinal, overrides 'realm' parameter. 
				Node-set with one 'attr' child element:
				attr/
					name
					value
					realm
			result-attrs - optional. Node-set with desired attribute 'name's.
				By default returns all attributes.
		Result: 'error' or 'data' node-set
	-->
	<func:function name="authm:get-users">
		<xsl:param name="realm" select="''"/>
		<xsl:param name="filter-attrs" select="/.."/>
		<xsl:param name="result-attrs" select="/.."/>
		
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<get_user>
							<xsl:choose>
								<xsl:when test="not($filter-attrs!='')">
									<user>
										<realm>
											<xsl:value-of select="$realm"/>
										</realm>
									</user>									
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="$filter-attrs/attr"/>
								</xsl:otherwise>
							</xsl:choose>
							<xsl:choose>
								<xsl:when test="not($result-attrs!='')">
									<attrs/>
								</xsl:when>
								<xsl:otherwise>
									<attrs>
										<xsl:copy-of select="$result-attrs/name"/>
									</attrs>
								</xsl:otherwise>
							</xsl:choose>
						</get_user>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data"/>
	</func:function>

	<!--
			List users by auth names.
			Paramaters:
				auth-names: node-set with elements of 'auth_nameType' type. See VZLCommonType.xsd for details.
			Returns: node-set with 'user' children.
		-->
	<func:function name="authm:get-users-by-authname">
		<xsl:param name="auth-names"/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<xsl:for-each select="$auth-names">
						<xsl:copy-of select="exsl:node-set(authm:cmd-get-user(.))/packet/data/authm"/>
					</xsl:for-each>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<func:result select="$resp/packet/data/authm"/>
	</func:function>

	<!--
		List groups by auth names.
		Paramaters:
			auth-names: node-set with elements of 'auth_nameType' type. See VZLCommonType.xsd for details.
		Returns: node-set with 'group' children.
	-->	
	<func:function name="authm:get-groups-by-authname">
		<xsl:param name="auth-names"/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<xsl:for-each select="$auth-names">
						<xsl:copy-of select="exsl:node-set(authm:cmd-get-group(.))/packet/data/authm"/>
					</xsl:for-each>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<func:result select="$resp/packet/data/authm"/>
	</func:function>
	
	<!--
		Helper function to compose user key which could be used in authm:get-user.
		Parameters:
			name - user name
			realm - user realm, default empty
			domain - user domain, default empty
		Returns: node with key elements
	-->
	<func:function name="authm:user-key">
		<xsl:param name="user-name"/>
		<xsl:param name="realm" select="''"/>
		<xsl:param name="domain" select="''"/>
		<xsl:variable name="user-key-rtf">
			<name><xsl:value-of select="sw:base64-encode($user-name)"/></name>
			<xsl:if test="$realm!=''">
				<realm><xsl:value-of select="$realm"/></realm>
			</xsl:if>
			<xsl:if test="$domain!=''">
				<xsl:value-of select="$domain"/>
			</xsl:if>
		</xsl:variable>
		<func:result select="exsl:node-set($user-key-rtf)"/>
	</func:function>
	
	<!--
		Get user by user key.
		Parameters:
			user-key - node-set of 'auth_nameType' type. See VZLCommonType.xsd for details.
			convert-attrs - boolean, true by default. Convert DirM attributes of user to nodes.
		Returns: 'user' node with user data, 'error' node on error
	-->
	<func:function name="authm:get-user">
		<xsl:param name="user-key"/>
		<xsl:param name="convert-attrs" select="true()"/>
		
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<get_user>
							<user>
								<xsl:copy-of select="$user-key/*"/>
							</user>
							<attrs/>
						</get_user>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="resp-error" select="$resp/error|$resp/authm/error"/>

		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="user-rtf">
					<xsl:if test="$resp/authm/user">
						<user>
							<login>
								<xsl:choose>
									<xsl:when test="$resp/authm/user/data/attr[name='sAMAccountName']/value">
										<xsl:value-of select="sw:base64-decode($resp/authm/user/data/attr[name='sAMAccountName']/value)"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of 
											select="sw:base64-decode($resp/authm/user/data/attr[name='name']/value | $resp/authm/user/name)"/>
									</xsl:otherwise>
								</xsl:choose>								
							</login>
							<xsl:choose>
								<xsl:when test="$convert-attrs">
									<xsl:copy-of select="$resp/authm/user/*[not(self::data)]"/>
									<data>
										<xsl:copy-of select="dirm:attrs2nodes($resp/authm/user/data)"/>
									</data>							
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="$resp/authm/user/*"/>
								</xsl:otherwise>
							</xsl:choose>							
						</user>
					</xsl:if>
				</xsl:variable>
				<func:result select="exsl:node-set($user-rtf)/user"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="authm:add-user">
		<xsl:param name="user"/>
		<xsl:param name="passwd"/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<add_user>
							<password>
								<xsl:value-of select="$passwd"/>
							</password>
							<user>
								<xsl:copy-of select="$user"/>
							</user>
						</add_user>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/authm"/>
	</func:function>

	<!-- Set User -->
	<func:function name="authm:set-user">
		<xsl:param name="name"/>
		<xsl:param name="user-rtf"/>
		<xsl:param name="password" select="/.."/>

		<xsl:variable name="user" select="exsl:node-set($user-rtf)"/>
		<xsl:variable name="old-user" select="authm:get-user(authm:user-key($name,$user/realm))"/>

		<xsl:variable name="group2add" select="$user/group[not(string(name) = $old-user/group/name)]"/>
		<xsl:variable name="group2del" select="$old-user/group[not(string(name) = $user/group/name)]"/>
		<xsl:variable name="new-name" select="sw:base64-decode($user/name)"/>

		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<edit_user>
							<name>
								<xsl:value-of select="sw:base64-encode($name)"/>
							</name>
							<realm>
								<xsl:value-of select="$user/realm"/>
							</realm>
							<user>
								<xsl:copy-of select="$user"/>
							</user>
							<xsl:if test="string($password)!=''">
								<password>
									<xsl:value-of select="sw:base64-encode($password)"/>
								</password>
							</xsl:if>
						</edit_user>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<xsl:variable name="edit-result" select="sw:xchg($req)/packet/data/authm"/>
		<xsl:variable name="add-result-rtf">
			<xsl:choose>
				<xsl:when test="not($edit-result//error)">
					<xsl:choose>
						<xsl:when test="count($group2add)">
							<xsl:copy-of select="authm:add-to-groups($user,$group2add)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$edit-result"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$edit-result"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="add-result" select="exsl:node-set($add-result-rtf)"/>

		<xsl:variable name="del-result">
			<xsl:choose>
				<xsl:when test="not($add-result//error)">
					<xsl:choose>
						<xsl:when test="count($group2del)">
							<xsl:copy-of select="authm:del-from-groups($user,$group2del)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$add-result"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$add-result"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<func:result select="exsl:node-set($del-result)"/>
	</func:function>

	<!-- Set User Data -->
	<func:function name="authm:set-user-attr">
		<xsl:param name="user-id"/>
		<xsl:param name="attr-name"/>
		<xsl:param name="attr-value"/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<edit_user>
							<name>
								<xsl:value-of select="sw:base64-encode($user-id)"/>
							</name>
							<user>
								<name>
									<xsl:value-of select="sw:base64-encode($user-id)"/>
								</name>
								<data>
									<mod>
										<name>
											<xsl:value-of select="$attr-name"/>
										</name>
										<value>
											<xsl:choose>
												<xsl:when
													test="contains($attr-name,'Sid') and substring-after($attr-name,'Sid')=''">
													<xsl:value-of select="$attr-value"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="sw:base64-encode($attr-value)"/>
												</xsl:otherwise>
											</xsl:choose>
										</value>
									</mod>
								</data>
							</user>
						</edit_user>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/authm"/>
	</func:function>

	<!-- Get User Data Attribute -->
	<func:function name="authm:get-user-attr">
		<xsl:param name="user-id"/>
		<xsl:param name="attr-name"/>

		<xsl:variable name="user" select="authm:get-user(authm:user-key($user-id),false())"/>

		<xsl:choose>
			<xsl:when test="contains($attr-name,'Sid') and substring-after($attr-name,'Sid')=''">
				<func:result select="$user/data/attr[name=$attr-name]/value"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:base64-decode($user/data/attr[name=$attr-name]/value)"/>
			</xsl:otherwise>
		</xsl:choose>

	</func:function>

	<func:function name="authm:list-realms">
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<get_realm/>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error" select="$resp/packet/data/error|$resp/packet/data/authm/error"/>

		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/authm/realms"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="authm:add-realm">
		<xsl:param name="realm"/>
		<xsl:param name="password"/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<add_realm>
							<vza_authm:realm xmlns:vza_dirm="http://www.swsoft.com/webservices/vzl/4.0.0/dirm"
								xsi:type="vza_dirm:dir_realmType">
								<xsl:copy-of select="exsl:node-set($realm)/*"/>
							</vza_authm:realm>
							<password>
								<xsl:value-of select="$password"/>
							</password>
						</add_realm>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error" select="$resp/packet/data/error|$resp/packet/data/authm/error"/>

		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/authm/id"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- 
		Update authentication database.
		Parameters:
			realm - realm data
			password - optional, realm password
		Returns: error/ok node
	 -->
	<func:function name="authm:set-realm">
		<xsl:param name="realm"/>
		<xsl:param name="password" select="/.."/>
		
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<set_realm>
							<vza_authm:realm xmlns:vza_dirm="http://www.swsoft.com/webservices/vzl/4.0.0/dirm"
								xsi:type="vza_dirm:dir_realmType">
								<xsl:copy-of select="exsl:node-set($realm)/*"/>
							</vza_authm:realm>
							<xsl:if test="$password">
								<password>
									<xsl:value-of select="$password"/>
								</password>
							</xsl:if>				
						</set_realm>
					</authm>
				</data>
			</packet>
		</xsl:variable>
		
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error" select="$resp/packet/data/error|$resp/packet/data/authm/error"/>

		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/authm/ok"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="authm:delete-realm">
		<xsl:param name="id"/>

		<xsl:variable name="resp" select="sw:xchg(authm:cmd-delete-realm($id))"/>
		<xsl:variable name="resp-error" select="$resp/packet/data/error|$resp/packet/data/authm/error"/>

		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/authm"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!--
		Get auth. names for given SIDs
		Parameters:
			sids - node-set with user/group SIDs
			realm-id - optional realm ID, if empty - try to find auth. names in all available realms
		Returns: node-set with 'auth_name' children 
	 -->
	<func:function name="authm:get-auth-names">
		<xsl:param name="sids"/>
		<xsl:param name="realm-id" select="/.."/>
		<xsl:variable name="req">
			<packet>
				<target>authm</target>
				<data>
					<xsl:for-each select="$sids">
						<xsl:copy-of select="exsl:node-set(authm:cmd-get-auth-name(.,$realm-id))/packet/data/authm"/>
					</xsl:for-each>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/authm"/>
	</func:function>
	
	<!--
		Get auth_name nodeset for given SID
		Parameters:
			sid - string with SID
			realm-id - optional realm ID, if empty - try to find auth. names in all available realms
		Returns: node-set with 'auth_name' children 
	 -->
	<func:function name="authm:sid2user-key">
		<xsl:param name="sid"/>
		<xsl:param name="realm-id" select="/.."/>
		<func:result select="sw:xchg(authm:cmd-get-auth-name($sid,$realm-id))/packet/data/authm/auth_name"/>
	</func:function>	

	<!-- 
		Helper function. Compose login name from user data 
		Parameters:
			user - node-set with user data with plain attributes
		Return value: string with user login
	-->
	<func:function name="authm:user-login">
		<xsl:param name="user"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$user/data/attr[name='sAMAccountName']/value">
					<xsl:value-of select="sw:base64-decode($user/data/attr[name='sAMAccountName']/value)"/>
				</xsl:when>
				<xsl:when test="$user/data/attr[sw:lc(name)='cn']/value">
					<xsl:value-of select="sw:base64-decode($user/data/attr[sw:lc(name)='cn']/value)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="sw:base64-decode($user/data/attr[name='name']/value | $user/name)"/>
				</xsl:otherwise>
			</xsl:choose>			
		</func:result>
	</func:function>
	
	<!-- 
		Helper function. Compose login name from group data 
		Parameters:
			group - node-set with group data with plain attributes
		Return value: string with group login
	-->
	<func:function name="authm:group-login">
		<xsl:param name="group"/>
		<!-- Groups and users shares principal format -->
		<func:result select="authm:user-login($group)"/>
	</func:function>

	<func:function name="authm:cmd-delete-realm">
		<xsl:param name="id"/>
		<func:result>
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<del_realm>
							<id>
								<xsl:value-of select="$id"/>
							</id>
						</del_realm>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<!--
		Wrapper for authm/get_auth_name packet.
		Parameters:
			sid - user/group SID
			realm-id - ID of realm
	-->
	<func:function name="authm:cmd-get-auth-name">
		<xsl:param name="sid"/>
		<xsl:param name="realm-id" select="/.."/>
		<func:result>
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<get_auth_name>
							<sid><xsl:value-of select="$sid"/></sid>
							<xsl:if test="$realm-id">
								<realm><xsl:value-of select="$realm-id"/></realm>
							</xsl:if>
						</get_auth_name>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>
	
	<!--
		Wrapper for authm/get_user packet.
		Parameters:
			user-key - node-set of 'auth_nameType' type. See VZLCommonType.xsd for details.
	-->
	<func:function name="authm:cmd-get-user">
		<xsl:param name="user-key"/>

		<func:result>
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<get_user>
							<user>
								<xsl:copy-of select="$user-key/*"/>
							</user>
							<attrs/>
						</get_user>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<!--
		Wrapper for authm/get_group packet.
		Parameters:
			group-key - node-set of 'auth_nameType' type. See VZLCommonType.xsd for details.
	-->
	<func:function name="authm:cmd-get-group">
		<xsl:param name="group-key"/>
		
		<func:result>
			<packet>
				<target>authm</target>
				<data>
					<authm>
						<get_group>
							<group>
								<xsl:copy-of select="$group-key/*"/>
							</group>
							<attrs/>
						</get_group>
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>
	
	<!-- 
		Helper function. split login name on user and domein
		Parameters:
		login  - login name in one of formats:
		username
		username@domainname (if domian not defined)
		domainname\username (if domian not defined)
		realm  - realm ID (optional)
		domain - domain name (optional, overrides above domains)
		Returns:
		<name>username</name>
		[<domain>domainname</domain>]
		[<realm>realmID</realm>]
	-->
	<func:function name="authm:auth-name">
		<xsl:param name="login"/>
		<xsl:param name="realm" select="/.."/>
		<xsl:param name="domain" select="/.."/>

		<xsl:variable name="auth-name">
			<xsl:choose>

				<!-- parse 'user@domain' syntax -->
				<xsl:when test="not($domain) and contains($login, '@')">
					<domain>
						<xsl:value-of select="sw:base64-encode(substring-after($login, '@'))"/>
					</domain>
					<name>
						<xsl:value-of select="sw:base64-encode(substring-before($login, '@'))"/>
					</name>
				</xsl:when>

				<!-- parse 'domain\user' syntax -->
				<xsl:when test="not($domain) and contains($login, '\')">
					<domain>
						<xsl:value-of select="sw:base64-encode(substring-before($login, '\'))"/>
					</domain>
					<name>
						<xsl:value-of select="sw:base64-encode(substring-after($login, '\'))"/>
					</name>
				</xsl:when>

				<!-- just username -->
				<xsl:otherwise>
					<name>
						<xsl:value-of select="sw:base64-encode($login)"/>
					</name>
				</xsl:otherwise>
			</xsl:choose>

			<xsl:if test="$domain">
				<domain><xsl:value-of select="sw:base64-encode($domain)"/></domain>
			</xsl:if>

			<xsl:if test="$realm">
				<realm><xsl:value-of select="$realm"/></realm>
			</xsl:if>
		</xsl:variable>

		<func:result select="exsl:node-set($auth-name)"/>
	</func:function>
	
	<!--
		Check of group with given name and realm is editable.
		Parameters:
			group-name - name of group as returned by get_group, decoded
			realm-info - node-set with realm info, should have at least @eid and @title
				attributes
		Returns: boolean  
	-->
	<func:function name="authm:is-group-editable">
		<xsl:param name="group-name"/>
		<xsl:param name="realm-info"/>
		<func:result select="sw:if($realm-info/@eid=sw:internal-realm-id() 
			and not(starts-with(sw:uc($group-name),'CN='))
			,true(),false())"/>
	</func:function>

	<func:function name="authm:switch-context">
		<xsl:param name="session-key" />
		<xsl:param name="get-key" select="'id'" />
		<xsl:param name="decode64" select="true()" />

		<xsl:variable name="get-id-src" select="sw:param($get-key)"/>
		<xsl:variable name="get-id">
			<xsl:choose>
				<xsl:when test="$get-id-src=''"/>
				<xsl:when test="$decode64">
					<xsl:value-of
						select="sw:base64-decode($get-id-src)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$get-id-src"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="curr-id"
			select="sw:sesgetstr($session-key)"/>

		<xsl:choose>
			<xsl:when test="$get-id='' and $curr-id=''">
				<sw:die>Item should be specified.</sw:die>
			</xsl:when>
			<xsl:when test="$get-id!='' and $get-id!=$curr-id">
				<xsl:if test="sw:sesputstr($session-key,$get-id)"/>
				<func:result select="$get-id"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$curr-id"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

</xsl:stylesheet>
