<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred trace func dirm"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:func			="http://exslt.org/functions"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:trace			="http://www.swsoft.com/xsl/cp/trace"
	xmlns:authm			="http://www.swsoft.com/xsl/cp/authm"		
	xmlns:dirm			="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"   
	xmlns:global		="http://www.swsoft.com/xsl/cp/global">

	<xsl:variable name="dirm:scope-self" select="0"/>
	<xsl:variable name="dirm:scope-childs" select="1"/>
	<xsl:variable name="dirm:scope-subtree" select="2"/>

	<xsl:variable name="dirm:attr-op-add" select="0"/>
	<xsl:variable name="dirm:attr-op-delete" select="1"/>
	<xsl:variable name="dirm:attr-op-replace" select="2"/>

	
	<!--
		obj/
			cookie/
			ref/
				dn/
				objectClass[]/
			data/
	-->
	<func:function name="dirm:packet-add">
		<xsl:param name="obj"/>
		<xsl:param name="attrs-prefix"/>
		
		<xsl:variable name="req">
			<packet>
				<target>dirm</target>
				<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>				
				<xsl:copy-of select="$obj/cookie"/>
				<data>
					<dirm>
						<add>							
							<id><xsl:value-of select="sw:internal-realm-id()"/></id>
							<dn><xsl:value-of select="$obj/ref/dn"/></dn>
							<xsl:copy-of select="dirm:nodes2attrs($obj/ref/objectClass,'')"/>							
							<xsl:copy-of select="dirm:nodes2attrs($obj/data/*,$attrs-prefix)"/>
						</add>							
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>				
			</packet>
		</xsl:variable>
		
		<func:result select="$req"/>
		
	</func:function>
	
	<!--
		obj/
			cookie/
			ref/
				old-dn
				dn/
			data/
	-->
	<func:function name="dirm:packet-modify">
		<xsl:param name="obj"/>		
		<xsl:param name="attrs-prefix" select="''"/>
		
		<xsl:variable name="dirm-id" select="sw:internal-realm-id()"/>
		
		<func:result>
			<packet>
				<target>dirm</target>
				<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>				
				<xsl:copy-of select="$obj/cookie"/>
				<data>
					<dirm>
						<xsl:if test="$obj/ref/old-dn and $obj/ref/old-dn!=$obj/ref/dn">
							<rename>							
								<id><xsl:value-of select="$dirm-id"/></id>
								<dn><xsl:value-of select="$obj/ref/old-dn"/></dn>
								<new_rdn><xsl:value-of select="substring-before($obj/ref/dn,',')"/></new_rdn>
								<parent_dn><xsl:value-of select="substring-after($obj/ref/dn,',')"/></parent_dn>
								<delete_old>true</delete_old>
							</rename>							
						</xsl:if>
						<modify>							
							<id><xsl:value-of select="$dirm-id"/></id>
							<dn><xsl:value-of select="$obj/ref/dn"/></dn>							
							<xsl:copy-of select="dirm:nodes2mods($obj/data/*,$attrs-prefix)"/>
						</modify>							
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>				
			</packet>
		</func:result>
		
	</func:function>
	
	<!--
		input/
			cookie/		
			attrs-prefix/	
			ref/
				base-dn/				
				id-attr/
				id-value[]
	-->
	<func:function name="dirm:packet-delete-objects">
		<xsl:param name="input"/>
		
		<xsl:variable name="dirm-id" select="sw:internal-realm-id()"/>
		
		<xsl:variable name="req">
			<packet>
				<target>dirm</target>
				<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>				
				<xsl:copy-of select="$input/cookie"/>
				<data>
					<dirm>
						<xsl:for-each select="$input/ref/id-value">
							<xsl:variable name="dn" select="concat($input/attrs-prefix,$input/ref/id-attr,'=',.,',',$input/ref/base-dn)"/>		
							<remove>							
								<id><xsl:value-of select="$dirm-id"/></id>
								<dn><xsl:value-of select="$dn"/></dn>
							</remove>							
						</xsl:for-each>
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>				
			</packet>
		</xsl:variable>
		
		<func:result select="$req"/>
		
	</func:function>
	
	<!--
		obj/
			cookie/
			ref/
				dn/
	-->
	<func:function name="dirm:delete-obj">
		<xsl:param name="obj"/>
		
		<xsl:variable name="dirm-id" select="sw:internal-realm-id()"/>
		
		<xsl:variable name="req">
			<packet>
				<target>dirm</target>
				<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>				
				<xsl:copy-of select="$obj/cookie"/>
				<data>
					<dirm>
						<remove>							
							<id><xsl:value-of select="$dirm-id"/></id>
							<dn><xsl:value-of select="$obj/ref/dn"/></dn>
						</remove>							
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>				
			</packet>
		</xsl:variable>
		
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<func:result select="$resp"/>
		
	</func:function>
	
	<!--
		look at dirm:packet-add() for arguments
	-->
	<func:function name="dirm:add-obj">
		<xsl:param name="obj"/>
		<xsl:param name="attrs-prefix"/>
		<!-- code -->
		<xsl:variable name="req" select="dirm:packet-add($obj,$attrs-prefix)"/>
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<func:result select="$resp"/>
	</func:function>
	
	<!--
		look at dirm:packet-modify() for arguments
	-->
	<func:function name="dirm:modify-obj">
		<xsl:param name="obj"/>
		<xsl:param name="attrs-prefix"/>
		<!-- code -->
		<xsl:variable name="req" select="dirm:packet-modify($obj,$attrs-prefix)"/>
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<func:result select="$resp"/>
	</func:function>
	
	<!--
		Params:
			dn
			filter: filter value
			attrs-prefix
			scope	: dirm:scope-*
			transform-dn
			
		Result
			nodeset[]
	-->
	<func:function name="dirm:search">
		<xsl:param name="dn"/>
		<xsl:param name="filter" select="''"/>
		<xsl:param name="scope" select="$dirm:scope-childs"/>
		<xsl:param name="transform-dn" select="false()"/>		
		
		<xsl:variable name="dirm-id" select="sw:internal-realm-id()"/>
		
		<xsl:choose>
			<xsl:when test="not($dirm-id!='')">		
				<!-- Dirm initialisation was failed-->
				<func:result select="/.."/>
			</xsl:when>
			<xsl:otherwise>
				<!-- Dirm was initialised, search... -->
				<xsl:variable name="req">
					<packet>
						<target>dirm</target>
						<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>						
						<data>
							<dirm>
								<search>							
									<id><xsl:value-of select="$dirm-id"/></id>
									<base><xsl:value-of select="$dn"/></base>
									<scope><xsl:value-of select="$scope"/></scope>
									<xsl:if test="$filter!=''">
										<filter>
											<xsl:value-of select="sw:base64-encode($filter)"/>
										</filter>
									</xsl:if>
								</search>							
							</dirm>
						</data>
						<!-- Skip auth for DirM operations -->
						<vzcpauth/>						
					</packet>
				</xsl:variable>
								
				<xsl:variable name="resp" select="sw:xchg($req)"/>
				<xsl:variable name="resp-error" select="$resp/packet/data/error|$resp/packet/data/dirm/error"/>
				
				<!-- Return result -->
				<xsl:choose>
					<xsl:when test="$resp-error">
						<func:result select="$resp-error"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="res-rtf">
							<xsl:for-each select="$resp/packet/data/dirm/set/entry">
								<obj dn="{dn}">
									<xsl:if test="$transform-dn">
										<xsl:for-each select="sw:split(dn,',')">
											<dn name="{substring-before(.,'=')}" value="{substring-after(.,'=')}" index="{position()}">
												<xsl:value-of select="."/>
											</dn>
										</xsl:for-each>
									</xsl:if>
									<xsl:for-each select="attr/value">
										<xsl:element name="{../name}">
											<xsl:choose>
												<xsl:when test="contains(../name,'Sid') and substring-after(../name,'Sid')=''">
													<xsl:value-of select="."/>
												</xsl:when>
												<xsl:otherwise>	
													<xsl:variable name="value" select="sw:base64-decode(.)"/>												
													<xsl:value-of select="sw:if($value!=' ',$value,'')"/>
												</xsl:otherwise>	
											</xsl:choose>
										</xsl:element>
									</xsl:for-each>
								</obj>
							</xsl:for-each>
						</xsl:variable>
						
						<func:result select="exsl:node-set($res-rtf)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Return result -->
				
				<!-- /Dirm was initialised, search... -->
			</xsl:otherwise>
		</xsl:choose>
				
	</func:function>		
	
	<!--
		Params:
			id-attr
			id-value
			base-dn
		Result
			nodeset[]
	-->
	<func:function name="dirm:search-obj">
		<xsl:param name="id-attr"/>
		<xsl:param name="id-value"/>
		<xsl:param name="base-dn"/>
		
		<xsl:variable name="dn" select="concat($id-attr,'=',$id-value,',',$base-dn)"/>		
		<func:result select="dirm:search($dn,'',$dirm:scope-self)/obj[1]"/>
				
	</func:function>		

	<func:function name="dirm:nodes2mods">
		<xsl:param name="nodes"/>
		<xsl:param name="prefix" select="''"/>
		<xsl:param name="op" select="'2'"/><!-- 2=Replace -->
	
		<func:result>	
			<xsl:for-each select="$nodes">		
				<mod>
					<name><xsl:value-of select="concat($prefix,name(.))"/></name>
					<xsl:choose>
						<xsl:when test="contains(name,'Sid') and substring-after(name,'Sid')=''">
							<value><xsl:value-of select="."/></value>
							<op><xsl:value-of select="$op"/></op>
						</xsl:when>
						<xsl:when test=".=''">
							<value><xsl:value-of select="sw:base64-encode(' ')"/></value>
							<op><xsl:value-of select="$op"/></op>
						</xsl:when>
						<xsl:otherwise>
							<value><xsl:value-of select="sw:base64-encode(.)"/></value>
							<op><xsl:value-of select="$op"/></op>
						</xsl:otherwise>
					</xsl:choose>
				</mod>
			</xsl:for-each>
		</func:result>
	</func:function>

	<func:function name="dirm:nodes2attrs">
		<xsl:param name="nodes"/>
		<xsl:param name="prefix" select="''"/>
		<xsl:param name="name" select="'attr'"/>
	
		<func:result>	
			<xsl:for-each select="$nodes">		
				<xsl:element name="{$name}">
					<name><xsl:value-of select="concat($prefix,name(.))"/></name>
					<xsl:choose>
						<xsl:when test="contains(name(.),'Sid') and substring-after(name(.),'Sid')=''">
							<value><xsl:value-of select="."/></value>
						</xsl:when>
						<xsl:when test=".!=''">					
							<value><xsl:value-of select="sw:base64-encode(.)"/></value>
						</xsl:when>
						<xsl:otherwise>
							<value><xsl:value-of select="sw:base64-encode(' ')"/></value>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:for-each>
		</func:result>
	</func:function>

	<func:function name="dirm:attrs2nodes">	
		<xsl:param name="attrs"/>
		<xsl:param name="prefix" select="''"/>
		
		<xsl:variable name="res">
			<xsl:for-each select="$attrs/attr/value">
				<xsl:element name="{$prefix}{../name}">
					<xsl:choose>
						<xsl:when test="contains(../name,'Sid') and substring-after(../name,'Sid')=''">
							<xsl:value-of select="."/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="sw:base64-decode(.)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="exsl:node-set($res)"/>		
	</func:function>
	
	<func:function name="dirm:dn-first-title">	
		<xsl:param name="dn"/>
		<func:result select="substring-before(substring-after($dn,'='),',')"/>
	</func:function>
	
	<func:function name="dirm:dn-second-title">	
		<xsl:param name="dn"/>
		<xsl:variable name="ss" select="substring-after($dn,',')"/>
		<func:result select="substring-before(substring-after($ss,'='),',')"/>
	</func:function>
	
	<!-- Transform DN to nodeset -->
	<func:function name="dirm:dn2nodes">	
		<xsl:param name="dn"/>
		
		<xsl:variable name="res-rtf">
			<xsl:for-each select="sw:split($dn,',')">
				<xsl:variable name="full-dn">
					<xsl:value-of select="."/><xsl:for-each 
						select="following-sibling::*"><xsl:value-of select="concat(',',.)"/></xsl:for-each>		
				</xsl:variable>				
				<dn full-dn="{$full-dn}" name="{substring-before(.,'=')}" value="{substring-after(.,'=')}"/>
			</xsl:for-each>
		</xsl:variable>
		
		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>

	<!-- Update only one attribute -->
	<func:function name="dirm:set-attr">
		<xsl:param name="dn"/>		
		<xsl:param name="attr-name"/>
		<xsl:param name="attr-value"/>
		<xsl:param name="was-existed" select="true()"/>
		<xsl:param name="base64-encode" select="true()"/>
		
		<xsl:variable name="dirm-id" select="sw:internal-realm-id()"/>
		
		<xsl:variable name="packet-rtf">
			<packet>
				<target>dirm</target>
				<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>				
				<data>
					<dirm>						
						<modify>							
							<id><xsl:value-of select="$dirm-id"/></id>
							<dn><xsl:value-of select="$dn"/></dn>
							<mod>
								<name><xsl:value-of select="$attr-name"/></name>
								<xsl:choose>
									<xsl:when test="contains($attr-name,'Sid') and substring-after($attr-name,'Sid')=''">
										<value><xsl:value-of select="$attr-value"/></value>
									</xsl:when>
									<xsl:when test="$base64-encode">
										<value><xsl:value-of select="sw:base64-encode($attr-value)"/></value>
									</xsl:when>
									<xsl:otherwise>
										<value><xsl:value-of select="$attr-value"/></value>
									</xsl:otherwise>
								</xsl:choose>
								<op><xsl:value-of select="sw:if($was-existed,2,0)"/></op>
							</mod>
						</modify>							
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>				
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($packet-rtf)"/>
		<func:result select="$resp"/>
		
	</func:function>
	
	<!-- Update only one attribute -->
	<func:function name="dirm:set-attrs">
		<xsl:param name="dn"/>	
		<xsl:param name="data"/>
		<xsl:param name="base64-encode" select="true()"/>
		
		<xsl:variable name="dirm-id" select="sw:internal-realm-id()"/>
		<xsl:variable name="old-data" select="dirm:search($dn,'',$dirm:scope-self)/obj[1]"/>		
		
		<xsl:variable name="packet-rtf">
			<packet>
				<target>dirm</target>
				<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>				
				<data>
					<dirm>				
						<modify>
							<id><xsl:value-of select="$dirm-id"/></id>
							<dn><xsl:value-of select="$dn"/></dn>
							<xsl:for-each select="$data/*">
								<xsl:variable name="attr-name" select="name()"/>							
								<xsl:variable name="attr-value" select="."/>			
								<xsl:variable name="attr-existed" select="$old-data/*[name()=$attr-name]"/>															
								<xsl:choose>
									<xsl:when test="$attr-value='' and not($attr-existed)">
									</xsl:when>
									<xsl:otherwise>
										<mod>
											<name><xsl:value-of select="$attr-name"/></name>
											<xsl:variable name="resulted-value">
												<xsl:choose>
													<xsl:when test="contains($attr-name,'Sid') and substring-after($attr-name,'Sid')=''">
														<xsl:value-of select="$attr-value"/>
													</xsl:when>
													<xsl:when test="$base64-encode">
														<xsl:value-of select="sw:base64-encode($attr-value)"/>
													</xsl:when>
													<xsl:otherwise>
														<xsl:value-of select="$attr-value"/>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:variable>
											<xsl:choose>
												<!-- delete attr -->
												<xsl:when test="$attr-value=''">
													<op><xsl:value-of select="$dirm:attr-op-delete"/></op>
												</xsl:when>
												<!-- replace attr -->
												<xsl:when test="$attr-existed">
													<op><xsl:value-of select="$dirm:attr-op-replace"/></op>
													<value><xsl:value-of select="$resulted-value"/></value>													
												</xsl:when>
												<!-- add attr -->
												<xsl:otherwise>
													<op><xsl:value-of select="$dirm:attr-op-add"/></op>
													<value><xsl:value-of select="$resulted-value"/></value>	
												</xsl:otherwise>
											</xsl:choose>
										</mod>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:for-each>
						</modify>							
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>				
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($packet-rtf)"/>
		<func:result select="$resp"/>
		
	</func:function>	
	
	<!-- Remove one attribute -->
	<func:function name="dirm:remove-attr">
		<xsl:param name="dn"/>		
		<xsl:param name="attr-name"/>
		
		<xsl:variable name="dirm-id" select="sw:internal-realm-id()"/>
		
		<xsl:variable name="packet-rtf">
			<packet>
				<target>dirm</target>
				<xsl:copy-of select="sw:env-dst(sw:master-eid())"/>				
				<data>
					<dirm>						
						<modify>							
							<id><xsl:value-of select="$dirm-id"/></id>
							<dn><xsl:value-of select="$dn"/></dn>
							<mod>
								<name><xsl:value-of select="$attr-name"/></name>
								<op>1</op>
							</mod>
						</modify>							
					</dirm>
				</data>
				<!-- Skip auth for DirM operations -->
				<vzcpauth/>				
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($packet-rtf)"/>
		<func:result select="$resp"/>
		
	</func:function>
	
	<!--
		Convert values list to string with filter for dirm:search()
	-->
	<func:function name="dirm:set2filter">
		<xsl:param name="value-list"/>		
		<xsl:param name="attr-name"/>		
		<func:result><xsl:if test="count($value-list)!=1">(|</xsl:if><xsl:for-each select="$value-list"
			><xsl:value-of select="concat('(',$attr-name,'=',
				dirm:attr-value4search(.,$attr-name)
			,')')"/></xsl:for-each><xsl:if test="count($value-list)!=1">)</xsl:if></func:result>
	</func:function>
	
	<!--
		Convert value to string with filter for dirm:search()
	-->
	<func:function name="dirm:string2filter">
		<xsl:param name="value"/>		
		<xsl:param name="attr-name"/>		
		<func:result><xsl:value-of select="concat('(',$attr-name,'=',
			dirm:attr-value4search($value,$attr-name),')')"/></func:result>
	</func:function>
	
	<func:function name="dirm:attr-value4search">
		<xsl:param name="value"/>		
		<xsl:param name="attr-name"/>		
		<func:result>
			<xsl:choose>
				<xsl:when test="contains($attr-name,'Sid') and substring-after($attr-name,'Sid')=''">
					<xsl:value-of select="sw:escape-bytes($value)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$value"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

</xsl:stylesheet>

