<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func envm"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:func	="http://exslt.org/functions" 
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:envm	="http://www.swsoft.com/xsl/cp/envm"
>

	<sw:include href="/lib/vt/env-core.xsl"/>
 
	<!-- 
		Get VT Settings
	-->
  <func:function name="envm:get-vt-settings">
  	<xsl:param name="eid" select="/.."/>
		<xsl:variable name="packet-target" select="env:get-target($eid)"/>
		<xsl:variable name="req">
			<packet>
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
				<data>
					<xsl:element name="{$packet-target}">
						<get_vt_settings>
							<offline_service/>
							<default_sample_id/>
						</get_vt_settings>
					</xsl:element>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/*[name() = $packet-target]/vt_settings"/>
  </func:function>

	<!-- 
		Set VT Settings
	-->
  <func:function name="envm:set-vt-settings">
  	<xsl:param name="eid" select="/.."/> 
		<xsl:param name="vt-settings" select="/.."/>
		<xsl:param name="impersonate" select="false()"/>
		<xsl:variable name="packet-target" select="env:get-target($eid)"/>  	
		<xsl:variable name="req">
			<packet>
				<target><xsl:value-of select="$packet-target"/></target>
				<xsl:copy-of select="sw:hn-dst($eid)"/>
				<data>
					<xsl:element name="{$packet-target}">
						<set_vt_settings>
							<xsl:copy-of select="$vt-settings"/>
						</set_vt_settings>
					</xsl:element>
				</data>
				<xsl:if test="$impersonate">
					<vzcpauth/>
				</xsl:if>
			</packet>
		</xsl:variable>
		<xsl:variable name="vt-settings-rc" select="sw:xchg($req)"/>
		<func:result select="$vt-settings-rc"/>
  </func:function>


	<func:function name="envm:config-native2virtual">
		<xsl:param name="body"/>
		<xsl:param name="hn-eid" select="sw:master-eid()"/>
		
	  <xsl:variable name="req">
	    <packet 
	    	xmlns:vzat="http://www.swsoft.com/webservices/vza/4.0.0/vzatypes"
	    	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	    >
	      <target>vzaenvm</target>
	      <xsl:copy-of select="sw:env-dst($hn-eid)"/>
	      <data>
	        <vzaenvm>
	          <get_virtual_config>
	          	<native_config xsi:type="vzat:virtuozzo_configType">
	          		<body><xsl:value-of select="sw:base64-encode($body)"/></body>
	          	</native_config>
	          </get_virtual_config>
	        </vzaenvm>
	      </data>
	    </packet>
	  </xsl:variable>

		<!-- Call VZA -->
 		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="resp-error" select="$resp/error|$resp/vzaenvm/error"/>
		
		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/vzaenvm/virtual_config"/>
			</xsl:otherwise>
		</xsl:choose>      

	</func:function>
	
	<func:function name="envm:config-virtual2natural">
		<xsl:param name="virtual-config"/>
		<xsl:param name="vt-version"/>
		<xsl:param name="hn-eid" select="sw:master-eid()"/>
		
	  <xsl:variable name="req">
	    <packet 
	    	xmlns:vzat="http://www.swsoft.com/webservices/vza/4.0.0/vzatypes"
	    	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
	    >
	      <target>vzaenvm</target>
	      <xsl:copy-of select="sw:env-dst($hn-eid)"/>
	      <data>
	        <vzaenvm>
	          <get_native_config>
	          	<virtual_config xsi:type="vzat:venv_configType">
	          		<xsl:copy-of select="$virtual-config/*"/>
	          		<architecture>
	          			<xsl:value-of select="$vt-version/architecture"/>
	          		</architecture>
	          	</virtual_config>
	          </get_native_config>
	        </vzaenvm>
	      </data>
	    </packet>
	  </xsl:variable>

		<!-- Call VZA -->
 		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="resp-error" select="$resp/error|$resp/vzaenvm/error"/>
		
		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/vzaenvm/native_config"/>
			</xsl:otherwise>
		</xsl:choose>      

	</func:function>
 
 
</xsl:stylesheet>
