 <!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet
	version="1.0"
	extension-element-prefixes="sw exsl func licensem format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:show="http://www.swsoft.com/xsl/cp/show"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>
	<sw:include href="/lib/utils/format-datetime.xsl"/>
	
	<xsl:variable name="licensem:zero-hwid" select="'0000.0000.0000.0000.0000.0000.0000.0000'"/>

	<!-- List all installed licenses -->
	<func:function name="licensem:get">
		<xsl:param name="hn-eid"/>
		<xsl:param name="transform" select="false()"/>
		<xsl:param name="filter-id" select="''"/>

		<!-- Prepare packet -->
		<xsl:variable name="req">
			<packet>
				<target>licensem</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<data>
					<licensem>
						<list>
							<xsl:if test="$filter-id!=''">
								<serial>
									<xsl:value-of select="$filter-id"/>
								</serial>
							</xsl:if>
						</list>
					</licensem>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<!-- Call VZA -->
 		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="resp-error" select="$resp/error|$resp/licensem/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error/.."/>
			</xsl:when>
			<xsl:when test="not($transform)">
				<func:result select="$resp/licensem/licenses"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="res-rtf">
					<xsl:for-each select="$resp/licensem/licenses/license">
						<license>
							<xsl:copy-of select="../body"/>
							<xsl:for-each select="parameter">
								<param>
									<id><xsl:value-of select="name"/></id>
									<value><xsl:value-of select="sw:base64-decode(value)"/></value>
								</param>
							</xsl:for-each>
						</license>
					</xsl:for-each>
				</xsl:variable>
				<func:result select="exsl:node-set($res-rtf)/license"/>
			</xsl:otherwise>
		</xsl:choose>

	</func:function>

	<func:function name="licensem:is-file-based">
		<xsl:param name="license"/>
		<func:result select="not($license/param[id='serial']/value=$license/body)"/>
	</func:function>

	<func:function name="licensem:classes">
		<xsl:variable name="res-rtf">
			<ui:filter-option value="VZSRV">
				<xsl:attribute name="title">
					<sw:text>Virtuozzo Hardware Node License</sw:text>
				</xsl:attribute>
			</ui:filter-option>
			<ui:filter-option value="VZGROUP">
				<xsl:attribute name="title">
					<sw:text>Virtuozzo Group License</sw:text>
				</xsl:attribute>
			</ui:filter-option>
			<ui:filter-option value="VZAKEY" hidden="yes">
				<xsl:attribute name="title">
					<sw:text>Activation Key</sw:text>
				</xsl:attribute>
			</ui:filter-option>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)/ui:filter-option"/>
	</func:function>

	<func:function name="licensem:statuses">
		<xsl:variable name="res-rtf">
			<ui:filter-option value="ACTIVE" icon="green_16.gif">
				<xsl:attribute name="title">
					<sw:text>Active</sw:text>
				</xsl:attribute>
			</ui:filter-option>
			<ui:filter-option value="VALID" icon="green_16.gif">
				<xsl:attribute name="title">
					<sw:text>Valid</sw:text>
				</xsl:attribute>
			</ui:filter-option>
			<ui:filter-option value="EXPIRED" icon="red_16.gif">
				<xsl:attribute name="title">
					<sw:text>Expired</sw:text>
				</xsl:attribute>
			</ui:filter-option>
			<ui:filter-option value="INVALID" icon="red_16.gif">
				<xsl:attribute name="title">
					<sw:text>Invalid</sw:text>
				</xsl:attribute>
			</ui:filter-option>
			<ui:filter-option value="GRACED" icon="yellow_16.gif">
				<xsl:attribute name="title">
					<sw:text>Graced</sw:text>
				</xsl:attribute>
			</ui:filter-option>
			<ui:filter-option value="" icon="red_16.gif">
				<xsl:attribute name="title">
					<sw:text>Not Installed</sw:text>
				</xsl:attribute>
			</ui:filter-option>			
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)/ui:filter-option"/>
	</func:function>


	<!-- Decode VZA license nodeset -->
	<func:function name="licensem:decode-license">
		<xsl:param name="lic"/>
		<xsl:variable name="res-rtf">
			<license>
				<xsl:for-each select="$lic/parameter">
					<param>
						<id><xsl:value-of select="name"/></id>
						<value><xsl:value-of select="sw:base64-decode(value)"/></value>
					</param>
				</xsl:for-each>
			</license>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)/license"/>
	</func:function>

	<func:function name="licensem:status2info">
		<xsl:param name="value"/>
		<xsl:param name="def-statuses"/>

		<xsl:variable name="def-status" select="$def-statuses[@value=$value]"/>

		<xsl:choose>
			<xsl:when test="$def-status">
				<func:result select="$def-status"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="res-rtf">
					<ui:filter-option value="{$value}" icon="alert_yellow.gif">
						<xsl:attribute name="title">
							<sw:text>
								<xsl:with-param name="value" select="$value"/>
								Unknown status %value
							</sw:text>
						</xsl:attribute>
					</ui:filter-option>
				</xsl:variable>
				<func:result select="exsl:node-set($res-rtf)/ui:filter-option"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>


	<func:function name="licensem:class2text">
		<xsl:param name="value"/>
		<xsl:param name="def-classes"/>

		<xsl:variable name="def-class" select="$def-classes[@value=$value]"/>

		<xsl:choose>
			<xsl:when test="$def-class">
				<func:result select="$def-class/@title"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="res">
					<sw:text>
						<xsl:with-param name="value" select="$value"/>
						Unknown class %value
					</sw:text>
				</xsl:variable>
				<func:result select="$res"/>
			</xsl:otherwise>
		</xsl:choose>

	</func:function>


	<!-- Put new license -->
	<func:function name="licensem:put">
		<xsl:param name="license"/>
		<xsl:param name="hn-eid"/>

		<!-- Prepare packet -->
		<xsl:variable name="req">
			<packet log="on">
				<target>licensem</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<cookie>
					<msg>
						<ok><sw:text>License installed </sw:text></ok>
						<error><sw:text>Failed to install the license.</sw:text></error>
					</msg>
					<operation>install_license</operation>
					<redirect-prev/>
				</cookie>
				<data>
					<licensem>
						<install>
							<license><xsl:value-of disable-output-escaping="yes" select="$license"/></license>
							<options>
								<transfer>0</transfer>
							</options>
						</install>
					</licensem>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<!-- Call VZA -->
 		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="resp-error" select="$resp/error|$resp/licensem/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error/.."/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/licensem"/>
			</xsl:otherwise>
		</xsl:choose>

	</func:function>

	<!-- transfer license -->
	<func:function name="licensem:transfer">
		<xsl:param name="key"/>
		<xsl:param name="src-hn-eid"/>
		<xsl:param name="dst-hn-eid"/>


		<!-- Prepare request -->
		<xsl:variable name="req">
			<packet  log="on">
				<target>licensem</target>
				<xsl:copy-of select="sw:hn-dst($dst-hn-eid)"/>
				<cookie>
					<msg>
						<ok>
							<sw:text>License transferred</sw:text>
						</ok>
						<error>
							<sw:text>Failed to transfer the license.</sw:text>
						</error>
					</msg>
					<operation>transfer_license</operation>
					<redirect-prev/>
				</cookie>
				<data>
					<licensem>
						<install>
							<license><xsl:value-of select="$key"/></license>
							<options>
								<transfer>1</transfer>
							</options>
						</install>
					</licensem>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<!-- Call VZA -->
 		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="resp-error" select="$resp/error|$resp/licensem/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error/.."/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/licensem"/>
			</xsl:otherwise>
		</xsl:choose>

	</func:function>

	<xsl:template name="licensem:update-packet">
		<xsl:param name="serial" />
		<xsl:param name="hn-eid" select="''" />
		<xsl:param name="cookie" select="/.."/>

		<packet log="on">
			<target>licensem</target>
			<xsl:copy-of select="sw:hn-dst($hn-eid)" />
			<cookie>
				<xsl:copy-of select="$cookie" />
				<operation>update_license</operation>
			</cookie>
			<data>
				<licensem>
					<update>
						<serial><xsl:value-of disable-output-escaping="yes" select="$serial"/></serial>
					</update>
				</licensem>
			</data>
			<vzcpauth/>
		</packet>
	</xsl:template>

	<xsl:template name="licensem:update-license-packet">
		<xsl:param name="license-id" />
		<xsl:param name="hn-eid"/>
		<xsl:param name="cookie" select="/.."/>

		<packet log="on">
			<target>licensem</target>
			<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
			<cookie>
				<xsl:copy-of select="$cookie" />
				<operation>update_license</operation>
			</cookie>
			<data>
				<licensem>
					<update>
						<serial><xsl:value-of disable-output-escaping="yes" select="$license-id"/></serial>
					</update>
				</licensem>
			</data>
			<vzcpauth/>
		</packet>
	</xsl:template>

	<!-- activate license -->
	<xsl:template name="licensem:activate">
		<xsl:param name="key"/>
		<xsl:param name="hn-eid"/>

		<xsl:variable name="req">
				<packet  log="on">
					<target>licensem</target>
					<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
					<cookie>
						<msg>
							<ok><sw:text>License activated</sw:text></ok>
							<error><sw:text>Failed to activate the license.</sw:text></error>
						</msg>
						<operation>activate_license</operation>
						<redirect-prev/>
					</cookie>
					<data>
						<licensem>
							<install>
								<license>
									<body><xsl:value-of select="$key"/></body>
								</license>
							</install>
						</licensem>
					</data>
					<vzcpauth/>
				</packet>
		</xsl:variable>
		<xsl:copy-of select="sw:xchg($req)"/>
	</xsl:template>

	<!-- filter licenses by class -->
	<func:function name="licensem:filter">
		<xsl:param name="type"/>
		<xsl:param name="licenses" select="/.."/>
		<func:result select="$licenses/license[parameter[name = 'CLASS' and sw:base64-decode(value) = $type]]"/>
	</func:function>

	<!-- parse license -->
	<func:function name="licensem:parse">
		<xsl:param name="body"/>

		<!-- Prepare packet -->
		<xsl:variable name="req">
			<packet>
				<target>licensem</target>
				<data>
					<licensem>
						<parse>
							<body><xsl:value-of select="$body"/></body>
						</parse>
					</licensem>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<!-- Call VZA -->
 		<xsl:variable name="resp" select="sw:xchg($req)/packet/data"/>
		<xsl:variable name="resp-error" select="$resp/error|$resp/licensem/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error/.."/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/licensem"/>
			</xsl:otherwise>
		</xsl:choose>

	</func:function>

	<!-- get single value from license -->
	<func:function name="licensem:value">
		<xsl:param name="key"/>
		<xsl:param name="lic" select="."/>
		<func:result>
			<xsl:for-each select="$lic/parameter[name = $key]">
				<xsl:value-of select="sw:base64-decode(value)"/>
				<xsl:if test="position() != last()">, </xsl:if>
			</xsl:for-each>
		</func:result>
	</func:function>

	<func:function name="licensem:time-value">
		<xsl:param name="key"/>
		<xsl:param name="lic" select="."/>
		<xsl:variable name="date" select="licensem:value($key, $lic)"/>
		<xsl:variable name="utime" select="date:seconds($date)"/>
		<xsl:choose>
			<xsl:when test="$utime &gt; 0">
				<func:result select="format:date-time($utime)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result>
					<sw:text>Never</sw:text>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	 <!-- get Hardware Node ID  -->
	 <func:function name="licensem:get-hwid">
	 	<xsl:param name="hn-eid" select="sw:hn-eid()" />
	 	<xsl:variable name="req">
	 		<packet>
	 			<target>licensem</target>
	 			<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
	 			<data>
	 				<licensem>
	 					<get_hwid />
	 				</licensem>
	 			</data>
	 			<vzcpauth/>
	 		</packet>
	 	</xsl:variable>
	 	<func:result select="sw:xchg($req)/packet/data/licensem/hwid" />
	 </func:function>

	<!-- return active license (from engine) -->
	<func:function name="licensem:get-active">
		<xsl:param name="class" select="'VZSRV'"/>
	  <xsl:variable name="class-base64" select="sw:base64-encode($class)"/>
		<xsl:variable name="valid"  select="sw:base64-encode('VALID')"/>
		<xsl:variable name="active" select="sw:base64-encode('ACTIVE')"/>
		<func:result select="
			sw:getlicense()/packet/licenses/license[
				parameter[name = 'CLASS'  and value = $class-base64 ] and
				parameter[name = 'status' and (value = $active or value = $valid) ]
			]
			"/>
	</func:function>

	<!--
			Check if workflow management allowed in license
			Parameters: none
			Returns: boolean
		-->
	<func:function name="licensem:is-workflow-mgmt-allowed">
		<func:result select="sw:if(licensem:value('workflow_mgmt_allowed',licensem:get-active()) = 1,true(),false())"/>
	</func:function>

	<!--
		Check if backup management allowed in license
		Parameters: none
		Returns: boolean
	-->
	<func:function name="licensem:is-backup-mgmt-allowed">
		<func:result select="sw:if(licensem:value('backup_mgmt_allowed',licensem:get-active()) = 1,true(),false())"/>
	</func:function>

</xsl:stylesheet>
