<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func dyn trace env task local op_log"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:func="http://exslt.org/functions"
  xmlns:dyn="http://exslt.org/dynamic"
  xmlns:op_log="http://www.swsoft.com/xsl/cp/op_log"
	xmlns:trace="http://www.swsoft.com/xsl/cp/trace"
 	xmlns:env  ="http://www.swsoft.com/xsl/cp/env"
 	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:task="http://www.swsoft.com/xsl/cp/task"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
>  
 
 	<sw:include href="/lib/vt/env-core.xsl"/>
 	<sw:include href="/lib/globals.xsl"/>
 
	<xsl:template name="vzlinfo-process-parameter">
		<xsl:param name="body" />
		<xsl:param name="text" />
		<xsl:variable name="before" select="substring-before($text, '%')" />
		<xsl:choose>
			<xsl:when test="$before">
				<xsl:apply-templates select="$body/parameter[name = $before]" mode="translate-vzlinfo" />
				<xsl:call-template name="vzlinfo-process-message">
					<xsl:with-param name="body" select="$body" />
					<xsl:with-param name="text" select="substring-after($text, '%')" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>%</xsl:text>
				<xsl:value-of select="$text" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="vzlinfo-process-message">
		<xsl:param name="body" />
		<xsl:param name="text" />
		<xsl:variable name="before" select="substring-before($text, '%')" />
		<xsl:variable name="after"  select="substring-after($text, '%')" />
		<xsl:choose>
			<xsl:when test="$before">
				<xsl:value-of select="$before" />
				<xsl:call-template name="vzlinfo-process-parameter">
					<xsl:with-param name="body" select="$body" />
					<xsl:with-param name="text" select="$after" />
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$after">
				<xsl:call-template name="vzlinfo-process-parameter">
					<xsl:with-param name="body" select="$body" />
					<xsl:with-param name="text" select="$after" />
				</xsl:call-template>				
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="message|parameter" mode="translate-vzlinfo">
		<xsl:if test="name = 'env'">"</xsl:if>
		<xsl:choose>
			<xsl:when test="translate">
				<xsl:call-template name="vzlinfo-process-message">
					<xsl:with-param name="body" select="." />
					<xsl:with-param name="text" select="sw:text(sw:base64-decode(message), 'vzagent-vocabulary')" />
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="decoded" select="sw:base64-decode(message)"/>
					<xsl:choose>
					<xsl:when test="name='eid_list'">
						<xsl:variable name="eid" select="substring-before(substring-after($decoded,'{'),'}')"/>
						<xsl:value-of select="env:env2title(env:get-env($eid)/env)" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$decoded" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="name = 'env'">"</xsl:if>
	</xsl:template>

	<func:function name="op_log:parse-message">
		<xsl:param name="message-tree"/>
		<func:result>
			<xsl:apply-templates select="$message-tree" mode="translate-vzlinfo"/>
		</func:result>
	</func:function>
  
  <!-- List HN templates -->
  <func:function name="op_log:get-ops">    
  	<xsl:param name="parent-id"/>
    
    <xsl:variable name="req">
      <packet>
				<target>op_log</target>
				<data>
					<op_log>
						<get_ops>							
							<parent_id><xsl:value-of select="$parent-id"/></parent_id>
						</get_ops>
					</op_log>
				</data>
				<vzcpauth/>
      </packet>
    </xsl:variable>
    <func:result select="sw:xchg($req)/packet/data"/>   
  </func:function>
  
	<func:function name="task:get-packet">
		<xsl:param name="id" />
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		
		<func:result>
			<packet>
				<target>op_log</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)" />
				<data>
					<op_log>
						<get_ops>
							<!--<directly/>-->
							<id>
								<xsl:value-of select="$id" />
							</id>
						</get_ops>
					</op_log>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="task:get">
		<xsl:param name="id" />
		<xsl:param name="hn-eid" select="sw:hn-eid()"/>
		<!-- Send Packet -->
		<xsl:variable name="response" select="sw:xchg(task:get-packet($id, $hn-eid))"/>
		<!-- Return data -->
		<xsl:variable name="tasks" select="$response/packet/data/op_log/progress" />
		<xsl:variable name="continued" select="contains($tasks[1]/op, 'vzaup2date')" />
		
		<func:result
			select="sw:if($continued, $tasks[not(contains(sw:base64-decode(message), 'op_log operator restart'))], $tasks)" />
	</func:function>
	
	<func:function name="task:is-running">
		<xsl:param name="details" />
		<func:result select="($details[last()]/status = 1) or ($details[last()]/status = 2)"/>
	</func:function>
	
	<func:function name="task:is-error">
		<xsl:param name="details" />
		<func:result select="$details[last()]/status = $global:task-failed"/>
	</func:function>
	
	<func:function name="task:percent">
		<xsl:param name="details" />
		<func:result select="$details[last()]/percent" />
	</func:function>	
	
	<func:function name="task:message">
		<xsl:param name="details" />
		<xsl:variable name="msg" select="task:message-src($details)" />
		
		<func:result select="sw:if(contains($msg,'|'), substring-before($msg,'|'), $msg)" />
	</func:function>
	
	<func:function name="task:message-src">
		<xsl:param name="details" />
		<func:result select="op_log:parse-message($details/message)" />
	</func:function>
	
	<func:function name="task:is-child">
		<xsl:param name="details" />
		
		<func:result select="contains(task:message-src($details),'xsl-child')" />
	</func:function>
	
	<func:function name="task:children">
		<xsl:param name="details" />
		
		<xsl:variable name="msg-src" select="task:message-src($details)"/>
		<xsl:variable name="child-hw" select="substring-after($msg-src,'|')" />
		<xsl:variable name="hw-id" select="substring-after($child-hw,'|')" />
		<xsl:variable name="child-id" select="sw:if(contains($child-hw,'|'),substring-before($child-hw,'|'),$child-hw)" />
		
		<xsl:choose>
			<xsl:when test="$child-id=''">
				<func:result select="/.."/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="task:get($child-id,$hw-id)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
</xsl:stylesheet>
