<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func server_group"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
    xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:func="http://exslt.org/functions"
    xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group">

	<func:function name="server_group:get-config">
    <xsl:param name="hn-eid" select="sw:master-eid()"/>
		<xsl:param name="impersonate" select="false()"/>
		<xsl:variable name="req">
			<packet>
			  <target>server_group</target>
			  <xsl:copy-of select="sw:hn-dst($hn-eid)"/>
			  <data>
				  <server_group>
					  <get_config/>
				  </server_group>
			  </data>
				<xsl:if test="$impersonate">
					<vzcpauth/>
				</xsl:if>
			</packet>
		</xsl:variable>
      
 		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error" select="$resp/packet/data/error|$resp/packet/data/server_group/error"/>
		
		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/server_group/config"/>
			</xsl:otherwise>
		</xsl:choose>      
	</func:function>
	
	<func:function name="server_group:set-config">
		<xsl:param name="config"/>
		<xsl:param name="hn-eid" select="sw:master-eid()"/>
		<xsl:variable name="req">
			<packet log="on">
				<target>server_group</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<data>
					<server_group>
						<set_config>
							<config>
								<xsl:copy-of select="$config/*"/>
							</config>
						</set_config>
					</server_group>
				</data>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error" select="$resp/packet/data/error|$resp/packet/data/server_group/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/server_group"/>
			</xsl:otherwise>
		</xsl:choose>		
	</func:function>

   <func:function name="server_group:get-sve-ip">
			<xsl:param name="hn-eid" select="sw:master-eid()"/>
      <xsl:variable name="req">
        <packet>
          <target>server_group</target>
          <xsl:copy-of select="sw:hn-dst($hn-eid)"/>            
            <data>
            <server_group>
              <get_info/>
            </server_group>
          </data>
        </packet>
      </xsl:variable>                            
      <func:result select="string(sw:xchg($req)/packet/data/server_group/env[parent_eid = $hn-eid]/virtual_config[veid = '1']/address/ip)"/>
    </func:function>

    <!-- return System realm ID (actually constant) -->
    <func:function name="server_group:get-system-realm">
      <xsl:variable name="ret">
        <realm>00000000-0000-0000-0000-000000000000</realm>
      </xsl:variable>
      <func:result select="exsl:node-set($ret)/realm"/>
    </func:function>
  
    <sw:include href="/lib/common.xsl"/>
</xsl:stylesheet>
