<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func servicem here"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:func	="http://exslt.org/functions"
  xmlns:servicem		="http://www.swsoft.com/xsl/cp/servicem"
	xmlns:here  ="http://www.swsoft.com/xsl/cp/here"
>

  <!-- List VE or HN templates -->
  <func:function name="servicem:get">
    <xsl:param name="eid"/> 
		<xsl:param name="services-pre" select="''"/>

		<xsl:variable name="services-rtf">
			<xsl:choose>
				<xsl:when test="exsl:object-type($services-pre) != 'node-set'">
					<xsl:choose>
						<xsl:when test="$services-pre = ''">
							<!-- no service defined, get all -->
							<service><all/></service>
						</xsl:when>
						<xsl:otherwise>
              <service>
                <name><xsl:value-of select="$services-pre"/></name>
              </service>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$services-pre"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>

    <xsl:variable name="req">
      <packet>
        <target>servicem</target>
        <xsl:copy-of select="sw:env-dst($eid)"/>
        <data>
          <servicem>
          	<xsl:choose>
          		<xsl:when test="not($services/service/all)">
          			<xsl:for-each select="$services/service/name">
          				<get>
          					<name><xsl:value-of select="."/></name>
										<state/>
										<level/>
										<dependencies/>
          				</get>
          			</xsl:for-each>
          		</xsl:when>
          		<xsl:otherwise>
                <get>
                  <state/>
                  <level/>
                  <dependencies/>
                </get>          		
          		</xsl:otherwise>
          	</xsl:choose>
          </servicem>
        </data>
      </packet>
    </xsl:variable>
    <func:result select="sw:xchg($req)/packet/data"/>
  </func:function>

	<func:function name="servicem:win-service-start">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:param name="services"/>
		<!-- simple wrapper -->
		<func:result select="servicem:sysv-service-start($eid,$services)"/>
  </func:function>

	<func:function name="servicem:win-service-stop">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:param name="services"/>
		<!-- simple wrapper -->
		<func:result select="servicem:sysv-service-stop($eid,$services)"/>
  </func:function>

	<func:function name="servicem:win-service-restart">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:param name="services"/>
		<!-- simple wrapper -->
		<func:result select="servicem:sysv-service-restart($eid,$services)"/>
  </func:function>

	<func:function name="servicem:win-startup-type">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:param name="service"/>

    <xsl:variable name="req">
 			<packet>
				<target>servicem</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
		        <ok>
		        	<sw:text>
		          	<xsl:with-param name="s" select="string($service/display-name)"/>
		          	<xsl:with-param name="t" select="string($service/startup-type)"/>
					      The startup type for the "%{s}" service has been successfully changed to %{t}.
		          </sw:text>
		      	</ok>
    		    <error>
		        	<sw:text>
		            <xsl:with-param name="s" select="string($service/display-name)"/>
		          	<xsl:with-param name="t" select="string($service/startup-type)"/>
					    	Failed to change the startup type to %{t} for the "%{s}" service.
		          </sw:text>
    		    </error>
          </msg>
          <operation>change_startup_type</operation>
          <xsl:choose>
          	<xsl:when test="$returl = 'redirect-prev'">
							<redirect-prev/>          	
          	</xsl:when>
          	<xsl:when test="$returl = 'redirect-last'">
							<redirect-last/>          	
          	</xsl:when>          	
          	<xsl:otherwise>
							<redirect><xsl:value-of select="$returl"/></redirect>          	
          	</xsl:otherwise>
          </xsl:choose>
        </cookie>			
				<data>
					<servicem>
						<set_startup_type>
							<name><xsl:value-of select="$service/name"/></name>
							<startup_type><xsl:value-of select="$service/startup-type"/></startup_type>
						</set_startup_type>
					</servicem>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
  </func:function>

	<func:function name="servicem:sysv-service-start">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:param name="services-pre"/>

		<xsl:variable name="services-rtf">
			<xsl:choose>
				<xsl:when test="exsl:object-type($services-pre) != 'node-set'">
					<service>
						<name><xsl:value-of select="$services-pre"/></name>
						<display-name><xsl:value-of select="$services-pre"/></display-name>
					</service>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$services-pre"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>
		
    <xsl:variable name="req">
 			<packet>
				<target>servicem</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<xsl:choose> 
							<xsl:when test="count($services/service) = 1">
		            <ok>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            The "%{s}" service has been successfully started.
		            	</sw:text>
		            </ok>
		            <sched>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            The starting of the "%{s}" service has been scheduled.
		            	</sw:text>
		            </sched>
    		        <error>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            Failed to start the "%{s}" service.
                 </sw:text>
    		        </error>
							</xsl:when>
							<xsl:otherwise>
		            <ok><sw:text>The services have been successfully started.</sw:text></ok>							
		            <sched><sw:text>The starting of the services has been scheduled.</sw:text></sched>
    		        <error><sw:text>Failed to start the services.</sw:text></error>
    		      </xsl:otherwise>
    		     </xsl:choose>
          </msg>
          <operation>start_service</operation>
          <xsl:choose>
          	<xsl:when test="$returl = 'redirect-prev'">
							<redirect-prev/>          	
          	</xsl:when>
          	<xsl:when test="$returl = 'redirect-last'">
							<redirect-last/>          	
          	</xsl:when>          	
          	<xsl:otherwise>
							<redirect><xsl:value-of select="$returl"/></redirect>          	
          	</xsl:otherwise>
          </xsl:choose>
        </cookie>			
				<data>
					<servicem>
						<xsl:for-each select="$services/service/name">
							<start>								
								<service>
									<name><xsl:value-of select="."/></name>
								</service>
							</start>
						</xsl:for-each>
					</servicem>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
  </func:function>

	<func:function name="servicem:xinetd-service-enable">
		<xsl:param name="eid"  select="sw:ve-eid()"/>
		<xsl:param name="services-pre"/>

		<xsl:variable name="services-rtf">
			<xsl:choose>
				<xsl:when test="exsl:object-type($services-pre) != 'node-set'">
					<service>
						<name><xsl:value-of select="$services-pre"/></name>
						<display-name><xsl:value-of select="$services-pre"/></display-name>	
					</service>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$services-pre"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>
		
    <xsl:variable name="req">
 			<packet>
				<target>servicem</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<xsl:choose> 
							<xsl:when test="count($services/service) = 1">
		            <ok>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            The "%{s}" service has been successfully enabled.
		            	</sw:text>
		            </ok>
    		        <error>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            Failed to enable the "%{s}" service.
		            	</sw:text>
    		        </error>
							</xsl:when>
							<xsl:otherwise>
		            <ok><sw:text>The services have been successfully enabled.</sw:text></ok>
    		        <error><sw:text>Failed to enable the service.</sw:text></error>
    		      </xsl:otherwise>
    		     </xsl:choose>
          </msg>
          <operation>enable_service</operation>
          <xsl:choose>
          	<xsl:when test="$returl = 'redirect-prev'">
							<redirect-prev/>          	
          	</xsl:when>
          	<xsl:when test="$returl = 'redirect-last'">
							<redirect-last/>          	
          	</xsl:when>          	
          	<xsl:otherwise>
							<redirect><xsl:value-of select="$returl"/></redirect>          	
          	</xsl:otherwise>
          </xsl:choose>
        </cookie>			
				<data>
					<servicem>
						<xsl:for-each select="$services/service/name">
							<set>
								<service>
									<name><xsl:value-of select="."/></name>
          				<level>0</level>
						     </service>
						  </set>
						</xsl:for-each>							
					</servicem>
				</data>
			</packet>
    </xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
  </func:function>
	
	<func:function name="servicem:sysv-service-stop">
		<xsl:param name="eid"  select="sw:ve-eid()"/>
		<xsl:param name="services-pre"/>

		<xsl:variable name="services-rtf">
			<xsl:choose>
				<xsl:when test="exsl:object-type($services-pre) != 'node-set'">
					<service>
						<name><xsl:value-of select="$services-pre"/></name>
						<display-name><xsl:value-of select="$services-pre"/></display-name>	
					</service>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$services-pre"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>

    <xsl:variable name="req">
 			<packet>
				<target>servicem</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<xsl:choose> 
							<xsl:when test="count($services/service) = 1">
		            <ok>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            The "%{s}" service has been successfully stopped.
		            	</sw:text>
		            </ok>							
		            <sched>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            The stopping of the "%{s}" service has been scheduled.
		            	</sw:text>
		            </sched>
    		        <error>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            Failed to stop the "%{s}" service.
		            	</sw:text>
    		        </error>
							</xsl:when>
							<xsl:otherwise>
								<ok><sw:text>The services have been successfully stopped.</sw:text></ok>							
		            <sched><sw:text>The stopping of the services has been scheduled.</sw:text></sched>
    		        <error><sw:text>Failed to stop the services.</sw:text></error>
    		      </xsl:otherwise>
    		     </xsl:choose>
          </msg>
          <operation>stop_service</operation>
          <xsl:choose>
          	<xsl:when test="$returl = 'redirect-prev'">
							<redirect-prev/>          	
          	</xsl:when>
          	<xsl:when test="$returl = 'redirect-last'">
							<redirect-last/>          	
          	</xsl:when>          	
          	<xsl:otherwise>
							<redirect><xsl:value-of select="$returl"/></redirect>          	
          	</xsl:otherwise>
          </xsl:choose>
        </cookie>			
				<data>
					<servicem>
						<xsl:for-each select="$services/service/name">
							<stop>
								<service>
									<name><xsl:value-of select="."/></name>
								</service>
							</stop>
						</xsl:for-each>
					</servicem>
				</data>
			</packet>
    </xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
  </func:function>

	<func:function name="servicem:xinetd-service-disable">
		<xsl:param name="eid"  select="sw:ve-eid()"/>
		<xsl:param name="services-pre"/>

		<xsl:variable name="services-rtf">
			<xsl:choose>
				<xsl:when test="exsl:object-type($services-pre) != 'node-set'">
					<service>
						<name><xsl:value-of select="$services-pre"/></name>
						<display-name><xsl:value-of select="$services-pre"/></display-name>	
					</service>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$services-pre"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>

    <xsl:variable name="req">
 			<packet>
				<target>servicem</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<xsl:choose> 
							<xsl:when test="count($services/service) = 1">
		            <ok>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            The "%{s}" service has been successfully disabled.
		            	</sw:text>
		            </ok>
    		        <error>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            Failed to disable the "%{s}" service.
		            	</sw:text>
    		        </error>
							</xsl:when>
							<xsl:otherwise>
		            <ok><sw:text>The services have been successfully disabled.</sw:text></ok>
    		        <error><sw:text>Failed to disable the service.</sw:text></error>
    		      </xsl:otherwise>
    		     </xsl:choose>
          </msg>
          <operation>stop_service</operation>
          <xsl:choose>
          	<xsl:when test="$returl = 'redirect-prev'">
							<redirect-prev/>          	
          	</xsl:when>
          	<xsl:when test="$returl = 'redirect-last'">
							<redirect-last/>          	
          	</xsl:when>          	
          	<xsl:otherwise>
							<redirect><xsl:value-of select="$returl"/></redirect>          	
          	</xsl:otherwise>
          </xsl:choose>
        </cookie>			
				<data>
					<servicem>
						<xsl:for-each select="$services/service/name">
							<set>
								<service>
									<name><xsl:value-of select="."/></name>
						    </service>
						  </set>
						</xsl:for-each>							
					</servicem>
				</data>
			</packet>
    </xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
  </func:function>
  
  <func:function name="servicem:sysv-service-restart">
		<xsl:param name="eid"  select="sw:ve-eid()"/>
		<xsl:param name="services-pre"/>

		<xsl:variable name="services-rtf">
			<xsl:choose>
				<xsl:when test="exsl:object-type($services-pre) != 'node-set'">
					<service>
						<name><xsl:value-of select="$services-pre"/></name>
						<display-name><xsl:value-of select="$services-pre"/></display-name>	
					</service>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$services-pre"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>

    <xsl:variable name="req">
 			<packet>
				<target>servicem</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<xsl:choose> 
							<xsl:when test="count($services/service) = 1">
		            <ok>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            The "%{s}" service has been successfully restarted.
		            	</sw:text>
		            </ok>							
		            <sched>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            The restarting of the "%{s}" service has been scheduled.
		            	</sw:text>
		            </sched>
    		        <error>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            Failed to restart the "%{s}" service.
		            	</sw:text>
    		        </error>
							</xsl:when>
							<xsl:otherwise>
								<ok><sw:text>The services have been successfully restarted.</sw:text></ok>							
		            <sched><sw:text>The restarting of the services has been scheduled.</sw:text></sched>
    		        <error><sw:text>Failed to restart the services.</sw:text></error>
    		      </xsl:otherwise>
    		     </xsl:choose>
          </msg>
          <operation>restart_service</operation>
          <xsl:choose>
          	<xsl:when test="$returl = 'redirect-prev'">
							<redirect-prev/>          	
          	</xsl:when>
          	<xsl:when test="$returl = 'redirect-last'">
							<redirect-last/>          	
          	</xsl:when>          	
          	<xsl:otherwise>
							<redirect><xsl:value-of select="$returl"/></redirect>          	
          	</xsl:otherwise>
          </xsl:choose>
        </cookie>			
				<data>
					<servicem>
						<xsl:for-each select="$services/service/name">
							<restart>
								<service>
									<name><xsl:value-of select="."/></name>
								</service>
							</restart>
						</xsl:for-each>
					</servicem>
				</data>
			</packet>
    </xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
	</func:function>        

	<func:function name="servicem:sysv-service-autostart-enable">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:param name="services-pre"/>

		<xsl:variable name="services-rtf">
			<xsl:choose>
				<xsl:when test="exsl:object-type($services-pre) != 'node-set'">
					<service>
						<name><xsl:value-of select="$services-pre"/></name>
						<display-name><xsl:value-of select="$services-pre"/></display-name>	
					</service>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$services-pre"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>

    <xsl:variable name="req">
 			<packet>
				<target>servicem</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<xsl:choose> 
							<xsl:when test="count($services/service) = 1">
		            <ok>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            Autostart has been successfully enabled for the "%{s}" service.
		            	</sw:text>
		            </ok>
    		        <error>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
		            			Failed to enable autostart for the "%{s}" service.
		            	</sw:text>
    		        </error>
							</xsl:when>
							<xsl:otherwise>
		            <ok><sw:text>Autostart has been successfully enabled for the services.</sw:text></ok>
    		        <error><sw:text>Failed to enable autostart for the services.</sw:text></error>
    		      </xsl:otherwise>
    		     </xsl:choose>
          </msg>
          <operation>autostart_enable</operation>
          <xsl:choose>
          	<xsl:when test="$returl = 'redirect-prev'">
							<redirect-prev/>          	
          	</xsl:when>
          	<xsl:when test="$returl = 'redirect-last'">
							<redirect-last/>          	
          	</xsl:when>          	
          	<xsl:otherwise>
							<redirect><xsl:value-of select="$returl"/></redirect>          	
          	</xsl:otherwise>
          </xsl:choose>
        </cookie>			
				<data>
					<servicem>
						<xsl:for-each select="$services/service/name">
							<set>
                <service>
                	<name><xsl:value-of select="."/></name>
	                <level>3</level>
                </service>
              </set>
						</xsl:for-each>
					</servicem>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
  </func:function>


	<func:function name="servicem:sysv-service-autostart-disable">
		<xsl:param name="eid" select="sw:ve-eid()"/>
		<xsl:param name="services-pre"/>

		<xsl:variable name="services-rtf">
			<xsl:choose>
				<xsl:when test="exsl:object-type($services-pre) != 'node-set'">
					<service>
						<name><xsl:value-of select="$services-pre"/></name>
						<display-name><xsl:value-of select="$services-pre"/></display-name>	
					</service>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$services-pre"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="services" select="exsl:node-set($services-rtf)"/>

    <xsl:variable name="req">
 			<packet>
				<target>servicem</target>
				<xsl:copy-of select="sw:env-dst($eid)"/>
        <cookie>
          <msg>
						<xsl:choose> 
							<xsl:when test="count($services/service) = 1">
		            <ok>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
					            Autostart has been successfully disabled for the "%{s}" service.
		            	</sw:text>
		            </ok>
    		        <error>
		            	<sw:text>
		            		<xsl:with-param name="s" select="string($services/service/display-name)"/>
		            			Failed to disable autostart for the "%{s}" service.
		            	</sw:text>
    		        </error>
							</xsl:when>
							<xsl:otherwise>
		            <ok><sw:text>Autostart has been successfully disabled for the services.</sw:text></ok>
    		        <error><sw:text>Failed to disable autostart for the services.</sw:text></error>
    		      </xsl:otherwise>
    		     </xsl:choose>
          </msg>
          <operation>autostart_disable</operation>
          <xsl:choose>
          	<xsl:when test="$returl = 'redirect-prev'">
							<redirect-prev/>          	
          	</xsl:when>
          	<xsl:when test="$returl = 'redirect-last'">
							<redirect-last/>          	
          	</xsl:when>          	
          	<xsl:otherwise>
							<redirect><xsl:value-of select="$returl"/></redirect>          	
          	</xsl:otherwise>
          </xsl:choose>
        </cookie>			
				<data>
					<servicem>
						<xsl:for-each select="$services/service/name">
							<set>
                <service>
                	<name><xsl:value-of select="."/></name>
                	<level>4</level>
                </service>
              </set>
						</xsl:for-each>
					</servicem>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="here:format-answer(sw:xchg($req))"/>
  </func:function>

	<!-- utility templates and functions -->
	<func:function name="here:format-answer">
    <xsl:param name="vzagent-answer"/>
		<func:result>
			<packet>
  	  	<cookie>
					<msg>
	  	    	<xsl:choose>
  		      	<xsl:when test="$vzagent-answer/packet/data/servicem/ok">
  		      		<set-ok>
									<xsl:value-of select="$vzagent-answer/packet/cookie/msg/ok"/>
  	    	  		</set-ok>
  	      		</xsl:when>

  		      	<xsl:when test="$vzagent-answer/packet/data/servicem/error">
  	      			<set-error>
									<short-desc>
										<xsl:value-of select="$vzagent-answer/packet/cookie/msg/error"/>
									</short-desc>
									<detail>
										<xsl:value-of select="$vzagent-answer/packet/data/servicem/error/message"/>
									</detail>
	  	      		</set-error>
  	      		</xsl:when>

  		      	<xsl:when test="$vzagent-answer/packet/data/progress">
  		      		<set-sched>
									<operation-id>
										<xsl:value-of select="$vzagent-answer/packet/@id"/>
									</operation-id>
									<short-desc>
										<xsl:value-of select="$vzagent-answer/packet/cookie/msg/sched"/>
									</short-desc>
  	    	  		</set-sched>
  	      		</xsl:when>
  		      </xsl:choose>
					</msg>
					<xsl:copy-of select="$vzagent-answer/packet/cookie/operation"/>
					<xsl:copy-of select="$vzagent-answer/packet/cookie/redirect"/>					
					<xsl:copy-of select="$vzagent-answer/packet/cookie/redirect-prev"/>					
					<xsl:copy-of select="$vzagent-answer/packet/cookie/redirect-last"/>					
    		</cookie>
			</packet>
		</func:result>
  </func:function>
  
</xsl:stylesheet>
