<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:func="http://exslt.org/functions"
  xmlns:swa-mailer	="http://www.swsoft.com/xsl/cp/swa-mailer"
  xmlns:vt					="http://www.swsoft.com/xsl/cp/vt"
>  
  
  <func:function name="swa-mailer:get-relay">
  	<xsl:param name="hn-eid" select="sw:hn-eid()"/>
    <xsl:variable name="req">
      <packet>
        <target>mailer</target>
        <xsl:copy-of select="sw:env-dst($hn-eid)"/>
        <data>
        	<mailer>
						<get_relay/>
        	</mailer>
        </data>
      </packet>
    </xsl:variable>
    <func:result select="sw:xchg($req)/packet/data/mailer"/>
	</func:function>
	
	<func:function name="swa-mailer:get-config">
		<xsl:param name="impersonate" select="false()"/>

		<xsl:variable name="req">
			<packet>
				<target>mailer</target>
				<data>
					<mailer>
						<get_config />
					</mailer>
				</data>
				<xsl:if test="$impersonate">
					<vzcpauth/>
				</xsl:if>
			</packet>
		</xsl:variable>
  	
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error" 
			select="$resp/packet/data/error|$resp/packet/data/mailer/error"/>
  	
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="config" select="sw:xchg($req)/packet/data/mailer/config"/>
				<xsl:variable name="config-rtf">
					<xsl:copy-of select="$config/*[local-name()!='notify']"/>
					<notify><xsl:value-of select="sw:if($config/notify and $config/notify!='0',true(),false())"/></notify>
				</xsl:variable>
				<func:result select="exsl:node-set($config-rtf)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<func:function name="swa-mailer:set-config">
		<xsl:param name="config"/>
		
		<xsl:variable name="req">
			<packet>
				<target>mailer</target>
				<xsl:copy-of select="sw:env-dst(sw:master-eid())" />
				<data>
					<mailer>
						<set_config>
							<config>
								<xsl:copy-of select="$config/*[local-name()!='notify']"/>
								<notify><xsl:value-of select="sw:if(string($config/notify) = 'true','1','0')"/></notify>
							</config>
						</set_config>
					</mailer>
				</data>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error" 
			select="$resp/packet/data/error|$resp/packet/data/mailer/error"/>
  	
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:xchg($req)/packet/data/mailer"/>
			</xsl:otherwise>
		</xsl:choose>			
	</func:function>

  <func:function name="swa-mailer:email-enabled">
		<xsl:param name="impersonate" select="false()"/>
    <xsl:variable name="req">
      <packet>
        <target>mailer</target>
        <data>
        	<mailer>
						<get_relay/>
        	</mailer>
        </data>
        <xsl:if test="$impersonate">
        	<vzcpauth/>
        </xsl:if>
      </packet>
    </xsl:variable>
    <func:result select="sw:xchg($req)/packet/data/mailer/relay!='' or vt:is-local-platform-linux()"/>
	</func:function>
	
	<func:function name="swa-mailer:send-email">
		<xsl:param name="msg-text"/>
		
		<xsl:variable name="packet">
			<packet>
				<target>mailer</target>
	      <data>
      	  <mailer>
			  	  <post>
	            <message><xsl:value-of select="sw:base64-encode($msg-text)"/></message>
  				  </post>
	        </mailer>
	     	</data>
				<vzcpauth/>
	    </packet>
		</xsl:variable>
		
		<xsl:variable name="res" select="sw:xchg($packet)"/>
		<xsl:variable name="error" select="$res/packet/data/error|$res/packet/data/mailer/error"/>
		
		<xsl:choose>
			<xsl:when test="$error">
				<func:result>
					<sw:text>
						<xsl:with-param name="error_code" select="$error/code"/>
						<xsl:with-param name="error_message" select="$error/message"/>
						Error #%{error_code} was received from VZAgent when sending the email: %{error_message}
					</sw:text>
				</func:result>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
</xsl:stylesheet>
