 <!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func vzcpsecuritym local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:vzcpsecuritym="http://www.swsoft.com/xsl/cp/vzcpsecuritym">

	<!-- Return roles list -->
	<func:function name="vzcpsecuritym:list-roles">
		<xsl:param name="roles-filter" select="''"/>
		<xsl:variable name="req">
			<packet>
				<target>vzcpsecuritym</target>
				<data>
					<vzcpsecuritym>
						<list_roles>
							<xsl:if test="$roles-filter">
								<filter>
									<xsl:copy-of select="$roles-filter"/>
								</filter>
							</xsl:if>
						</list_roles>
					</vzcpsecuritym>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error"
			select="$resp/packet/data/error|$resp/packet/data/vzcpsecuritym/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/vzcpsecuritym/role"/>
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Return result -->
	</func:function>


	<!-- Return role by ID -->
	<func:function name="vzcpsecuritym:find-role">
		<xsl:param name="role-id"/>

		<xsl:variable name="req">
			<packet>
				<target>vzcpsecuritym</target>
				<data>
					<vzcpsecuritym>
						<get_role>
							<role>
								<id>
									<xsl:value-of select="$role-id"/>
								</id>
							</role>
						</get_role>
					</vzcpsecuritym>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error"
			select="$resp/packet/data/error|$resp/packet/data/vzcpsecuritym/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/vzcpsecuritym/role"/>
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Return result -->
	</func:function>

	<func:function name="vzcpsecuritym:get-security-descriptor">
		<xsl:param name="security-object"/>
		<xsl:variable name="req">
			<packet>
				<target>vzcpsecuritym</target>
				<data>
					<vzcpsecuritym>
						<get_security_descriptor>
							<security_object>
								<xsl:copy-of select="$security-object"/>
							</security_object>
						</get_security_descriptor>
					</vzcpsecuritym>
				</data>
			</packet>
		</xsl:variable>

		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error"
			select="$resp/packet/data/error|$resp/packet/data/vzcpsecuritym/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/vzcpsecuritym/security_descriptor"/>
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Return result -->
	</func:function>

	<func:function name="vzcpsecuritym:set-security-descriptor">
		<xsl:param name="security-object"/>
		<xsl:param name="security-descriptor"/>
		<xsl:variable name="req">
			<packet>
				<target>vzcpsecuritym</target>
				<data>
					<vzcpsecuritym>
						<set_security_descriptor>
							<security_object>
								<xsl:copy-of select="$security-object"/>
							</security_object>
							<security_descriptor>
								<xsl:copy-of select="$security-descriptor"/>
							</security_descriptor>
						</set_security_descriptor>
					</vzcpsecuritym>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error"
			select="$resp/packet/data/error|$resp/packet/data/vzcpsecuritym/error"/>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/vzcpsecuritym"/>
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Return result -->
	</func:function>

	<!-- Helper function for ACE -->
	<func:function name="vzcpsecuritym:ace">
		<xsl:param name="sid"/>
		<xsl:param name="role-id"/>
		<xsl:variable name="ace">
			<xsl:choose>
				<xsl:when test="$sid != '' and $role-id != ''">
					<ace>
						<sid><xsl:value-of select="$sid"/></sid>
						<role><xsl:value-of select="$role-id"/></role>
					</ace>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($ace)"/>
	</func:function>
	
	<!-- Helper method for ACEs for one SID -->
	<func:function name="vzcpsecuritym:sid-aces">
		<xsl:param name="sid"/>
		<xsl:param name="roles-rtf"/>
		<xsl:variable name="roles" select="exsl:node-set($roles-rtf)"/>
		<xsl:variable name="aces">
			<xsl:for-each select="$roles/*">
				<xsl:if test="$sid and string(id)">
					<ace>
						<sid><xsl:value-of select="$sid"/></sid>
						<role><xsl:value-of select="id"/></role>
					</ace>
				</xsl:if>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($aces)"/>
	</func:function>

	<!-- Helper function for DACL modifier -->
	<func:function name="vzcpsecuritym:dacl-modifier">
		<xsl:param name="security-object"/>
		<xsl:param name="aces-rtf"/>
		
		<xsl:variable name="aces" select="exsl:node-set($aces-rtf)"/>
		<xsl:variable name="mod">
			<dacl_modifier>
				<security_object>
					<xsl:copy-of select="$security-object"/>
				</security_object>
				<xsl:for-each select="$aces/*">
					<ace>
						<xsl:copy-of select="./*"/>
					</ace>
				</xsl:for-each>
			</dacl_modifier>
		</xsl:variable>
		<func:result select="exsl:node-set($mod)"/>
	</func:function>

	<func:function name="vzcpsecuritym:set-access-rights">
		<xsl:param name="dacl-modifiers"/>
		<xsl:variable name="req">
			<packet>
				<target>vzcpsecuritym</target>
				<data>
					<vzcpsecuritym>
						<set_access_rights>
							<xsl:copy-of select="$dacl-modifiers/*"/>
						</set_access_rights>
					</vzcpsecuritym>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error"
			select="$resp/packet/data/error|$resp/packet/data/vzcpsecuritym/error"/>
		
		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/vzcpsecuritym"/>
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Return result -->		
	</func:function>
	
	<func:function name="vzcpsecuritym:add-access-rights">
		<xsl:param name="dacl-modifiers"/>
		<xsl:variable name="req">
			<packet>
				<target>vzcpsecuritym</target>
				<data>
					<vzcpsecuritym>
						<add_access_rights>
							<xsl:copy-of select="$dacl-modifiers/*"/>
						</add_access_rights>
					</vzcpsecuritym>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error"
			select="$resp/packet/data/error|$resp/packet/data/vzcpsecuritym/error"/>
		
		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/vzcpsecuritym"/>
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Return result -->		
	</func:function>

	<func:function name="vzcpsecuritym:del-access-rights">
		<xsl:param name="dacl-modifiers"/>
		<xsl:variable name="req">
			<packet>
				<target>vzcpsecuritym</target>
				<data>
					<vzcpsecuritym>
						<del_access_rights>
							<xsl:copy-of select="$dacl-modifiers/*"/>
						</del_access_rights>
					</vzcpsecuritym>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="resp" select="sw:xchg($req)"/>
		<xsl:variable name="resp-error"
			select="$resp/packet/data/error|$resp/packet/data/vzcpsecuritym/error"/>
		
		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$resp-error">
				<func:result select="$resp-error"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$resp/packet/data/vzcpsecuritym"/>
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Return result -->		
	</func:function>

	<func:function name="vzcpsecuritym:vzcp-security-object">
		<xsl:param name="id" select="'vzcp'"/>
		<xsl:param name="type" select="'vzcp'"/>
		<func:result>
			<id>
				<xsl:value-of select="$id"/>
			</id>
			<type>
				<xsl:value-of select="local:operator-obj-type($type)"/>
			</type>
		</func:result>
	</func:function>

	<func:function name="local:operator-obj-type">
		<xsl:param name="obj-type"/>
		<func:result>
			<xsl:choose>
				<xsl:when
					test="$obj-type = 'env.core.vt' or $obj-type = 've.vz.vt' or $obj-type = 'vm.vmware.vt'">
					<xsl:value-of select="'env.core.vt'"/>
				</xsl:when>
				<xsl:when
					test="$obj-type = 'hn.core.vt' or $obj-type = 'hn.vz.vt' or $obj-type = 'hn.vmware.vt'">
					<xsl:value-of select="'hn.core.vt'"/>
				</xsl:when>
				<xsl:when test="$obj-type = 'vzcc.vzcp' or $obj-type = 'vzpp.vzcp' or $obj-type = 'vzcp'">
					<xsl:value-of select="'vzcp'"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="''"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>
</xsl:stylesheet>
