<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date cred dirm groups func local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:groups="http://www.swsoft.com/xsl/cp/groups"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
>

	<sw:include href="/lib/swa/dirm.xsl"/>

	<!-- Return groups, all or required  -->
	<!--
	Params
		filter-id: nodeset or ID string or empty string
	Result
		/
			obj[]/
					cn/
					...
	-->
	<func:function name="groups:list">
		<xsl:param name="filter-id" select="''"/>
		<xsl:param name="id-attr" select="'cn'"/>

		<xsl:variable name="filter">
			<xsl:choose>
				<xsl:when test="exsl:object-type($filter-id)='node-set'">
					<xsl:value-of select="dirm:set2filter($filter-id,$id-attr)"/>
				</xsl:when>
				<xsl:when test="exsl:object-type($filter-id)='string' and $filter-id!=''">
					<xsl:value-of select="dirm:string2filter($filter-id,$id-attr)"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="groups" select="dirm:search(
			$def-users-dn,$filter
		)"/>
		<func:result select="$groups"/>
	</func:function>

	<!-- Return groups, all or required  -->
	<!--
	Params
		id
	Result
		obj/
			cn/
			...
	-->
	<func:function name="groups:get-group">
		<xsl:param name="group-id"/>

		<xsl:variable name="groups"
			select="dirm:search(
			concat('cn=',$group-id,',',$def-users-dn),'',0
		)"/>
		<func:result select="$groups/obj[1]"/>
	</func:function>

	<!-- Return group title -->
	<func:function name="groups:get-group-title">
		<xsl:param name="group-id"/>

		<func:result>
			<xsl:choose>
				<!-- Group undefined -->
				<xsl:when test="not($group-id!='')">
					<xsl:value-of select="''"/>
				</xsl:when>
				<!-- Group defined-->
				<xsl:otherwise>
					<xsl:variable name="group" select="authm:group-user($group-id)"/>
					<xsl:choose>
						<!-- User known -->
						<xsl:when test="$user">
							<xsl:value-of select="$user/data/displayName"/>
						</xsl:when>
						<!-- User unknown -->
						<xsl:otherwise>
							<xsl:value-of select="concat(sw:text('Unknown User'),' [',$user-id,']')"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
		
	</func:function>

	<func:function name="groups:name2sid">
		<xsl:param name="group-name"/>
		<xsl:variable name="group" select="groups:list($group-name)"/>
		<func:result select="$group/obj/objectSid"/>
	</func:function>
	
</xsl:stylesheet>
