<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl date cred perms func local browse dirm users roles groups env securitym authm"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" xmlns:date="http://exslt.org/dates-and-times"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm" xmlns:perms="http://www.swsoft.com/xsl/cp/perms"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm" xmlns:users="http://www.swsoft.com/xsl/cp/users"
	xmlns:roles="http://www.swsoft.com/xsl/cp/roles" xmlns:set="http://exslt.org/sets"
	xmlns:groups="http://www.swsoft.com/xsl/cp/groups" xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym" xmlns:global="http://www.swsoft.com/xsl/cp/global">

	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/swa/securitym.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms.xsl"/>
	<sw:include href="/lib/sysdir/securman/users.xsl"/>
	<sw:include href="/lib/sysdir/securman/roles.xsl"/>
	<sw:include href="/lib/sysdir/securman/groups.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl"/>


	<xsl:template name="perms:show-owner-perms">
		<xsl:param name="owner-sid"/>
		<xsl:param name="browse-id"/>
		<xsl:param name="browse-url"/>
		<xsl:param name="browse-empty-msg"/>
		<xsl:param name="add-screen-id"/>

		<!-- FIXME vap@ Owner permissions UI disabled-->
		<xsl:if test="1=0">
			<xsl:variable name="data"
				select="dirm:search($def-permissions-dn,concat('(ownerSid=',sw:escape-bytes($owner-sid),')') )"/>
			<xsl:variable name="obj-types" select="perms:get-obj-types()"/>
			<xsl:variable name="roles" select="roles:list()"/>

			<xsl:variable name="filter_init_">
				<xsl:call-template name="browse:init-filter">
					<xsl:with-param name="browse">
						<ui:browse-setup id="{$browse-id}" url="{$browse-url}"/>
						<ui:cols sorting-col="role">
							<ui:column id="icon" apply-templates="yes" width="20" show-url="yes"/>
							<ui:column id="id" nav-type="id" hidden="yes" for-select="yes"/>
							<ui:column id="role" title="{sw:text('Role')}" filter="auto"/>
							<ui:column id="obj" title="{sw:text('Object')}" filter="auto" show-url="yes"/>
							<ui:column id="obj-type" title="{sw:text('Object Type')}"> </ui:column>
							<ui:column id="obj-type-src" title="{sw:text('Object Type')}" hidden="yes"
								filter="select">
								<xsl:for-each select="$obj-types/type">
									<ui:filter-option value="{@id}" title="{@title}"/>
								</xsl:for-each>
							</ui:column>
						</ui:cols>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>

			<xsl:variable name="filter">
				<xsl:call-template name="browse:fill-filter">
					<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
					<xsl:with-param name="rows">
						<ui:browse-rows>
							<xsl:for-each select="$data/obj">
								<ui:row>
									<!-- Set url to object -->
									<xsl:choose>
										<xsl:when test="objectType='ve.vz.vt'">
											<xsl:attribute name="item-full-url">
												<xsl:value-of
													select="concat(
	            					$baseurl,
	            					'/vzdir/infrman/envs/env?id=',
	            					sw:base64-encode(objectId)
	            				)"
												/>
											</xsl:attribute>
										</xsl:when>
										<xsl:when test="objectType='hn.vz.vt'">
											<xsl:attribute name="item-full-url">
												<xsl:value-of
													select="concat(
	            					$baseurl,
	            					'/vt/hns/hn?id=',
	            					sw:base64-encode(objectId)
	            				)"
												/>
											</xsl:attribute>
										</xsl:when>
										<xsl:when test="objectType='vm.vmware.vt'">
											<xsl:attribute name="item-full-url">
												<xsl:value-of
													select="concat(
	            					$baseurl,
	            					'/vmwaredir/infrman/envs/env?branch=vmware-env-home,envs',
	            					'&amp;id=',
	            					sw:base64-encode(objectId)
	            				)"
												/>
											</xsl:attribute>
										</xsl:when>
										<xsl:when test="objectType='hn.vmware.vt'">
											<xsl:attribute name="item-full-url">
												<xsl:value-of
													select="concat(
	            					$baseurl,
	            					'/vmwaredir/infrman/hns/hn?branch=vmware-hn-home,hns',
	            					'&amp;id=',
	            					sw:base64-encode(objectId)
	            				)"
												/>
											</xsl:attribute>
										</xsl:when>
										<xsl:otherwise>
											<xsl:attribute name="disable-item-url">true</xsl:attribute>
										</xsl:otherwise>
									</xsl:choose>
									<!-- /Set url to object -->
									<id>
										<xsl:value-of select="permissionId"/>
									</id>
									<role>
										<xsl:value-of select="$roles/obj[roleId=current()/roleId]/title"/>
									</role>
									<obj-type-src>
										<xsl:value-of select="objectType"/>
									</obj-type-src>
									<obj-type>
										<xsl:value-of select="$obj-types/type[@id=current()/objectType]/@title"/>
									</obj-type>
									<icon>
										<xsl:value-of select="$obj-types/type[@id=current()/objectType]/@icon"/>
									</icon>
									<obj>
										<xsl:choose>
											<xsl:when test="objectType='vm.vmware.vt'">
												<xsl:value-of select="env:env2title(env:get-env(objectId)/env)"/>
											</xsl:when>
											<xsl:when test="objectType='hn.vmware.vt'">
												<xsl:value-of select="env:env2title(env:get-env(objectId)/env)"/>
											</xsl:when>
											<xsl:when test="objectType='ve.vz.vt'">
												<xsl:value-of select="env:env2title(env:get-env(objectId)/env)"/>
											</xsl:when>
											<xsl:when test="objectType='hn.vz.vt'">
												<xsl:value-of select="env:env2title(env:get-env(objectId)/env)"/>
											</xsl:when>
											<xsl:otherwise>
												<sw:text>n/a</sw:text>
											</xsl:otherwise>
										</xsl:choose>
									</obj>
								</ui:row>
							</xsl:for-each>
						</ui:browse-rows>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>

			<ui:browse>
				<xsl:attribute name="title">
					<sw:text>Permissions</sw:text>
				</xsl:attribute>

				<ui:browse-js-many>
					<ui:warn>
						<sw:text>Select at least one permission!</sw:text>
					</ui:warn>
				</ui:browse-js-many>

				<ui:filter>
					<xsl:copy-of select="$filter"/>
				</ui:filter>

				<ui:browse-buttons type="list-selection">

					<ui:button type="list-selection" tip="add_perm" icon="permissions"
						new-obj-title="{sw:text('Permission(s)')}"					
						submit-href="{$baseurl}/sysdir/securman/perms/owner-add?screen-id={$add-screen-id}&amp;owner-sid={sw:base64-encode($owner-sid)}"
						require-items="false" name="add">
						<sw:text>New Permission</sw:text>
					</ui:button>

					<ui:button type="list-selection" tip="delete_permission" icon="delete"
						submit-href="{$baseurl}/sysdir/securman/perms/owner-list-control?owner-sid={sw:base64-encode($owner-sid)}"
						confirmation="{sw:text('Are you sure you want to delete the selected permission(s)?')}"
						script="if (!atLeastOne()) return false;" name="delete" width="150">
						<sw:text>Delete</sw:text>
					</ui:button>
				</ui:browse-buttons>

				<ui:browse-empty-msg>
					<xsl:value-of select="$browse-empty-msg"/>
				</ui:browse-empty-msg>

			</ui:browse>

		</xsl:if>
	</xsl:template>

	<xsl:template name="perms:show-obj-perms">
		<xsl:param name="screen-url"/>
		<xsl:param name="action-url"/>
		<xsl:param name="item-url"/>
		<xsl:param name="obj-id"/>
		<xsl:param name="obj-type"/>

		<xsl:call-template name="perms:show-obj-perms-list">
			<xsl:with-param name="screen-url" select="$screen-url"/>
			<xsl:with-param name="item-url" select="$item-url"/>
			<xsl:with-param name="action-url" select="$action-url"/>
			<xsl:with-param name="obj-id" select="$obj-id"/>
			<xsl:with-param name="obj-type" select="$obj-type"/>
		</xsl:call-template>
	</xsl:template>

	<xsl:template name="perms:show-obj-perms-list">
		<xsl:param name="screen-url"/>
		<xsl:param name="action-url"/>
		<xsl:param name="item-url"/>
		<xsl:param name="obj-id"/>
		<xsl:param name="obj-type"/>

		<!-- TODO 
			cr-view - VZA task 'Users and groups information'
			cr-manage - VZA task 'Users and groups management'
		-->
		<xsl:variable name="cr-view" select="true()"/>
		<xsl:variable name="cr-manage" select="true()"/>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="permissions" url="{$screen-url}" item-url="{$item-url}"/>
					<ui:cols sorting-col="principal">
						<ui:column id="id" nav-type="id" hidden="yes">
							<xsl:attribute name="for-select">
								<xsl:value-of select="sw:if($cr-manage,'yes','no')"/>
							</xsl:attribute>
						</ui:column>
						<ui:column id="principal-icon" display-type="icon">
							<xsl:attribute name="show-url">
								<xsl:value-of select="sw:if($cr-manage and $item-url,'yes','no')"/>
							</xsl:attribute>
						</ui:column>
						<ui:column id="principal" nav-type="principal" title="{sw:text('User or Group')}"
							filter="auto">
							<xsl:attribute name="show-url">
								<xsl:value-of select="sw:if($cr-manage and $item-url,'yes','no')"/>
							</xsl:attribute>
						</ui:column>
						<ui:column id="role" title="{sw:text('Assigned Role')}" filter="auto"/>
						<ui:column id="realm" title="{sw:text('Authentication Database')}" filter-title="{sw:text('Database')}" filter="auto"/>						
						<ui:column id="principal-type" hidden="yes"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="realms" select="authm:list-realms()"/>
		<xsl:variable name="role-assignments"
			select="securitym:list-role-assignments(securitym:scope($obj-id,$obj-type))"/>
		<xsl:variable name="auth-names" select="authm:get-auth-names($role-assignments/member)"/>
		
		<xsl:variable name="realm-users-rtf">
			<xsl:if test="count($auth-names[string(type)=$global:auth-name-type-user]) &gt; 0">
				<xsl:copy-of 
					select="authm:get-users-by-authname($auth-names[string(type)=$global:auth-name-type-user]/auth_name)/user"/>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="realm-groups-rtf">
			<xsl:if test="count($auth-names[string(type)=$global:auth-name-type-group
				or string(type) = $global:auth-name-type-alias 
				or string(type) = $global:auth-name-type-wellknown-group]) &gt; 0">
				<xsl:copy-of 
					select="authm:get-groups-by-authname($auth-names[string(type)=$global:auth-name-type-group 
						or string(type) = $global:auth-name-type-alias
						or string(type) = $global:auth-name-type-wellknown-group]/auth_name)/group"/>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="realm-users" select="exsl:node-set($realm-users-rtf)"/>
		<xsl:variable name="realm-groups" select="exsl:node-set($realm-groups-rtf)"/>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="set:distinct($role-assignments/role)">
							<xsl:for-each select="set:distinct($role-assignments[role=string(current())]/member)">
								<xsl:variable name="memberSid" select="string(.)"/>
								<xsl:variable name="usergroup"
									select="$realm-users/user[data/attr[name = 'objectSid']/value = $memberSid]|$realm-groups/group[data/attr[name = 'objectSid']/value = $memberSid]"/>
								<xsl:if test="$usergroup">
									<xsl:variable name="pname">
										<xsl:choose>
											<xsl:when test="$usergroup[self::user]">
												<xsl:value-of select="authm:user-login($usergroup)"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of 
													select="sw:base64-decode($usergroup/data/attr[name='name']/value 
														| $usergroup/name)"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:variable>
									<ui:row>
										<id><xsl:value-of select="concat($memberSid,'|',string(../role))"/></id>
										<principal-icon>
											<xsl:value-of
												select="sw:if($usergroup[self::user],'user_16.gif','usergroup_16.gif')"/>
										</principal-icon>
										<principal>
											<xsl:value-of select="$pname"/>
										</principal>
										<realm>
											<xsl:value-of select="$realms/*[id=$usergroup/realm]/name"/>
										</realm>
										<role>
											<xsl:value-of select="../role"/>
										</role>
										<principal-type>
											<xsl:value-of select="sw:if(self::user,'user','group')"/>
										</principal-type>
									</ui:row>
								</xsl:if>
							</xsl:for-each>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:block width="full">
			<ui:hidden name="obj-id" value="{$obj-id}"/>
			<ui:hidden name="obj-type" value="{$obj-type}"/>
			
			<ui:browse>
				<xsl:attribute name="title">
					<sw:text>Permissions</sw:text>
				</xsl:attribute>

				<ui:browse-js-many>
					<ui:warn>
						<sw:text>Select at least one permission.</sw:text>
					</ui:warn>
				</ui:browse-js-many>

				<ui:filter>
					<xsl:copy-of select="$filter"/>
				</ui:filter>
				
				<ui:browse-buttons type="list-selection">
					<xsl:if test="$cr-manage">
					
						<ui:button type="list-selection" tip="add_perm" icon="permissions"
							new-obj-title="{sw:text('Permission')}"					
							submit-href="{$baseurl}/sysdir/securman/perms/obj-add?obj-type={$obj-type}"
							require-items="false" name="add"
						>
							<sw:text>New Permission</sw:text>
						</ui:button>

						<ui:button type="list-selection" tip="delete_permission" icon="delete"
							confirmation="{sw:text('Are you sure you want to delete the selected permission(s)?')}"
							script="if (!atLeastOne()) return false;" name="delete" width="150"
							submit-href="{$action-url}">
							<sw:text>Delete</sw:text>
						</ui:button>
					</xsl:if>
				</ui:browse-buttons>

				<ui:browse-empty-msg>
					<sw:text>No permissions could be found. </sw:text>
				</ui:browse-empty-msg>

			</ui:browse>
		</ui:block>
	</xsl:template>
</xsl:stylesheet>
