<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl date cred perms func local vzcpsecuritym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:perms="http://www.swsoft.com/xsl/cp/perms"
	xmlns:vzcpsecuritym="http://www.swsoft.com/xsl/cp/vzcpsecuritym">

	<sw:include href="/lib/swa/vzcpsecuritym.xsl"/>

	<func:function name="perms:get-obj-types">
		<xsl:variable name="types-rtf">
			<type id="ve.vz.vt" title="Virtuozzo VE" icon="nav_virtuozzo.gif"/>
			<type id="hn.vz.vt" title="Virtuozzo HN" icon="nav_server.gif"/>
			<type id="vm.vmware.vt" title="VMWare VM" icon="file_permissions_16.gif"/>
			<type id="hn.vmware.vt" title="VMWare HN" icon="file_permissions_16.gif"/>
			<type id="vzcp" title="VZCP" icon="file_permissions_16.gif"/>
		</xsl:variable>
		<func:result select="exsl:node-set($types-rtf)"/>
	</func:function>

	<func:function name="perms:get-packet-add">
		<xsl:param name="owner-sid"/>
		<xsl:param name="role-id"/>
		<xsl:param name="obj-id"/>
		<xsl:param name="obj-type"/>

		<xsl:variable name="perm-id" select="sw:generate-id()"/>
		<xsl:variable name="full-dn"
			select="concat(
			'permissionId=',$perm-id,',',$def-permissions-dn
		)"/>

		<func:result>
			<dirm>
				<add>
					<id>
						<xsl:value-of select="sw:internal-realm-id()"/>
					</id>
					<dn>
						<xsl:value-of select="$full-dn"/>
					</dn>
					<attr>
						<name>objectClass</name>
						<value>
							<xsl:value-of select="sw:base64-encode('VZCPPermission')"/>
						</value>
					</attr>
					<attr>
						<name>ownerSid</name>
						<value>
							<xsl:value-of select="$owner-sid"/>
						</value>
					</attr>
					<attr>
						<name>permissionId</name>
						<value>
							<xsl:value-of select="sw:base64-encode($perm-id)"/>
						</value>
					</attr>
					<attr>
						<name>roleId</name>
						<value>
							<xsl:value-of select="sw:base64-encode($role-id)"/>
						</value>
					</attr>
					<xsl:if test="$obj-id!=''">
						<attr>
							<name>objectId</name>
							<value>
								<xsl:value-of select="sw:base64-encode($obj-id)"/>
							</value>
						</attr>
					</xsl:if>
					<attr>
						<name>objectType</name>
						<value>
							<xsl:value-of select="sw:base64-encode($obj-type)"/>
						</value>
					</attr>
				</add>
			</dirm>
		</func:result>
	</func:function>

	<func:function name="perms:get-default-roles">
		<xsl:param name="sid"/>

		<!-- Security object -->
		<xsl:variable name="so">
			<id>vzcp</id>
			<type>vzcp</type>
		</xsl:variable>
		<!-- Security descriptor -->
		<xsl:variable name="sd" select="vzcpsecuritym:get-security-descriptor($so)"/>
		
		<xsl:variable name="roles-filter-rtf">
			<xsl:if test="$sd/dacl and count($sd/dacl/ace[sid=$sid]) > 0">
				<xsl:for-each select="$sd/dacl/ace[sid=$sid]">
					<id>
						<xsl:value-of select="role"/>
					</id>
				</xsl:for-each>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="roles-filter" select="exsl:node-set($roles-filter-rtf)"/>
		<xsl:choose>
			<xsl:when test="count($roles-filter/id) > 0">
				<func:result select="vzcpsecuritym:list-roles($roles-filter)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>


</xsl:stylesheet>
