<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl path local units"
	exclude-result-prefixes="func ui path local units ve layout"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:path="http://www.swsoft.com/xsl/cp/path"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"  
	xmlns:units="http://www.swsoft.com/xsl/cp/units"  
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
	xmlns:layout="http://www.swsoft.com/xsl/cp/layout"	
>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>
	
  <!-- show vzcp mode titlebar -->
  <xsl:template name="titlebar">
    <xsl:variable name="path" select="$layout:path-ext"/>
    <xsl:variable name="icon" select="sw:if(@icon!='',@icon,$screen-info/@icon)"/>
    <xsl:variable name="title" select="sw:if(@title!='',@title,sw:text-subst($screen-info/@title))"/>
    
    <div id="titleBar">
    <table border="0" cellpadding="0" cellspacing="0" width="100%">
      <tr>
        
        <td rowspan="2">
          <xsl:if test="$icon != 'unknown'">
            <img src="/{$theme}/icons/{$icon}_32.gif" width="32" height="32" border="0" hspace="2" alt="{$title}" title="{$title}"/>
          </xsl:if>
        </td>
        <td rowspan="2"><img src="/{$theme}/images/1x1.gif" width="5" height="1"/></td>
        <td>
          <span class="Path">
            <!-- display path without last element -->
            <xsl:copy-of select="path:display($path[position() != last()],$screen-info)"/>
          </span>
        </td>
        <td align="right" nowrap="1">
          <small>
            <sw:text>
              <xsl:with-param name="id" select="@id"/>
              Screen ID: %{id}
            </sw:text>
          </small>
        </td>
      </tr>
      <tr>
        <td width="100%">
          <span class="SWBig">
            <xsl:value-of select="$title"/>
          </span>
        </td>
        <td align="right" valign="bottom">
        	<!-- Custom actions -->
        	<xsl:for-each select="ui:properties/ui:top-action">
      			<a href="{@href}" onmouseover="callTip('{@tip}',event)" onmouseout="callTip()">
							<img src="/{$theme}/icons/{@icon}.gif" border="0" width="16" height="16"/>
						</a>
      		</xsl:for-each>
      		<!-- /Custom actions -->
          <!-- refresh control -->
          <xsl:choose>
          	<xsl:when test="ui:properties/ui:refresh-type = 'POST'">
	    				<a href="#" onClick="newHiddenObj('_lf','','1','defaultForm');doSubmit()"
	    					onmouseover="callTip('refresh',event)"
	        			onmouseout="callTip('')"
	    				>
	    					<img src="/{$theme}/icons/refresh_16.gif" alt="Refresh this Page"
	    						title="{sw:text('Refresh this page')}" border="0" width="16" height="16" hspace="4" />
	    				</a>
          	</xsl:when>

          	<xsl:when test="ui:properties/ui:refresh-type = 'none'" />

          	<xsl:otherwise>
	    				<a href="{$baseurl}{path:extend-url-lf($path[last()]/@href)}"
	    					onmouseover="callTip('refresh',event)"
	        			onmouseout="callTip('')"
	    				>
	    					<img src="/{$theme}/icons/refresh_16.gif" alt="Refresh this Page"
	    						title="{sw:text('Refresh this page')}" border="0" width="16" height="16" hspace="4" />
	    				</a>
          	</xsl:otherwise>
          </xsl:choose>
          
          <!-- help control -->
          <a href="javascript:callHelp()"
          	onmouseover="callTip('get_help',event)"
	        	onmouseout="callTip('')"
          >
            <img src="/{$theme}/icons/help_16.gif" alt="{sw:text('Help')}" title="{sw:text('Help')}" border="0" width="16" height="16" hspace="4"/>
          </a>
            
        </td>
      </tr>
    </table>
    </div>
    <xsl:variable name="curr-ve-state">
			<body>
				<xsl:call-template name="ui:current-ve-status"/>
		 </body>
		</xsl:variable>

    <script language="JavaScript">

  function callUpdateTop(){
    var msg = '<sw:text lang="C" select="sw:html-escape(sw:text(exsl:node-set($curr-ve-state)/body/node()), 'escape-quotes,no-escape-amp,no-escape-ltgt')"/>';
    top.changeInnerHTML('topframe', 've_state',msg);
  }
 
  function callRefreshTop(){
   <xsl:choose>
     <!-- Trasition - always refreshin' -->
     <xsl:when test="ve:context-transition()">
       var reload_mode = 'transition';
       var period = <xsl:value-of select="$config/vzcpcon/timeout/status_bar_refresh/transition"/>;
     </xsl:when>
     <xsl:when test="$refresh_period &gt; 0">
     <!-- State, Refresh by timer -->
       var reload_mode = 'timer';
       var period = '<xsl:value-of select="$refresh_period"/>';
     </xsl:when>
     <xsl:otherwise>
     <!-- State, Smart resfresh (click+timer) -->     
       var reload_mode = 'smart';
       var period = <xsl:value-of select="$config/vzcpcon/timeout/status_bar_refresh/smart"/>;       
     </xsl:otherwise>
   </xsl:choose>      
<![CDATA[  if(top && top.reloadManager) top.reloadManager(reload_mode,period);]]>   
  }
 
    </script>
  </xsl:template>
  
  
  
<!-- show plesk titlebar -->
<xsl:template name="titlebar-plesk">
	<xsl:variable name="icon" select="sw:if(@icon!='',@icon,$screen-info/@icon)"/>
	<xsl:variable name="title" select="sw:if(@title!='',@title,sw:text-subst($screen-info/@title))"/>	
	<xsl:variable name="path" select="$layout:path-ext"/>
	<xsl:variable name="return-path" select="$path[position() = last()-1][not(@hidden)]"/>
	<xsl:variable name="refresh-path" select="$path[last()]"/>
	<xsl:variable name="titlebar-icons">
		<item icon="help_16" onclick="callHelp()" title="{sw:text('Help')}" tip="get_help"/>
		<xsl:for-each select="ui:properties/ui:top-action">
			<item icon="{@icon}" href="{@href}" title="{@title}" tip="{@tip}"/>
		</xsl:for-each>
		<xsl:choose>
			<xsl:when test="ui:properties/ui:refresh-type = 'POST'">
				<item icon="refresh_16" href="javascript:newHiddenObj('_lf','','1','defaultForm');doSubmit()" title="{sw:text('Refresh')}" tip="refresh"/>
			</xsl:when>
			<xsl:when test="ui:properties/ui:refresh-type = 'none'"/>
			<xsl:otherwise>
				<item icon="refresh_16" href="{$baseurl}{path:extend-url-lf($refresh-path/@href)}" title="{sw:text('Refresh')}" tip="refresh"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="$return-path and not(ui:properties/ui:no-uplevel)">
			<item icon="uplevel" href="{$baseurl}{path:extend-url-lf($return-path/@href)}" title="{sw:text('Upper Level')}" tip="{sw:if($return-path/@tip, $return-path/@tip, sw:text('Go up to the parent page.'))}"/>
		</xsl:if>
	</xsl:variable>	

	
	<table cellpadding="0" cellspacing="0" border="0" width="100%" class="pageTop">
		<tr>
			<td valign="middle" class="screenIcon">
				<xsl:if test="$icon != 'unknown'">
					<img src="/{$theme}/icons/{$icon}_32.gif" width="32" height="32" border="0" alt="{$title}" title="{$title}"/>
				</xsl:if>
			</td>
			<td valign="middle" width="50%">
				<xsl:if test="count($path[not(@hidden)]) &gt; 1">
					<div class="pathbar">
						<xsl:copy-of select="path:display($path[position() != last()],$screen-info)"/>&#160;
					</div>
				</xsl:if>
				<span class="screenTitle"><xsl:value-of select="$title"/></span>	
			</td>			
			<td align="right" nowrap="nowrap" width="50%">
				<input type="hidden" id="current-ve-eid" value="{sw:ve-eid()}"/>
				<input type="hidden" id="current-hn-eid" value="{sw:hn-eid()}"/>
				<xsl:if test="$activeMode != 'plesk'">
					<div class="screenId" style="float:right">
						<small>
							<sw:text>
								<xsl:with-param name="id" select="@id"/>
								Screen ID: %{id}
							</sw:text>
						</small>
					</div>					
				</xsl:if>
				<div class="uplevel" style="clear:right;float:right;height:18px">
					<xsl:call-template name="local:titlebar-icons">
						<xsl:with-param name="icons" select="exsl:node-set($titlebar-icons)"/>
					</xsl:call-template>				
				</div>
			</td>
		</tr>
	</table>
</xsl:template>

<xsl:template name="local:titlebar-icons">
	<xsl:param name="icons"/>

	<xsl:for-each select="$icons/item">
		<img src="/{$theme}/images/1x1.gif" height="1" width="1" hspace="5"/>
		<xsl:if test="contains($toolbar-mode,'icon')">
			<a onmouseover="callTip('{@tip}',event)" onmouseout="callTip()">
				<xsl:choose>
					<xsl:when test="@onclick">
						<xsl:attribute name="onclick"><xsl:value-of select="@onclick"/>;return false</xsl:attribute>
						<xsl:attribute name="href">#</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="href"><xsl:value-of select="@href"/></xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
				<img class="titleBarIcon" src="/{$theme}/icons/{@icon}.gif" border="0" width="16" height="16"/>
			</a>
		</xsl:if>	
		<xsl:if test="contains($toolbar-mode,'text')">
			<span class="titlebarIconText">
				<a onmouseover="callTip('{@tip}',event)" onmouseout="callTip()">
					<xsl:choose>
						<xsl:when test="@onclick">
							<xsl:attribute name="onclick"><xsl:value-of select="@onclick"/>;return false</xsl:attribute>
							<xsl:attribute name="href">#</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="href"><xsl:value-of select="@href"/></xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:value-of select="@title"/>
				</a>
			</span>
		</xsl:if>
	</xsl:for-each>	
</xsl:template>


</xsl:stylesheet>

