<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>

	<!-- Return common error message with specified error code -->
	<func:function name="error:code2text">
  		<xsl:param name="error-code"/>
		<func:result>
			<sw:text>
				<xsl:with-param name="error-code" select="$error-code"/>
				System error #%{error-code} occurred. Please call your administrator for support.</sw:text>
		</func:result>
	</func:function>

	<!-- Return errors stack
		Result:
			*[error/text]
	-->
	<func:function name="error:get">
		<func:result select="sw:sesgettree('errors')"/>
	</func:function>

	<!-- Check errors stack for existing errors
		Result:
			true() or false()
	-->
	<func:function name="error:has-errors">
		<func:result select="count(sw:sesgettree('errors'))!=0 or sw:sesget('error')!=''"/>
	</func:function>

	<!-- Check if errors stack is empty
		Result:
			true() or false()
	-->	
	<func:function name="error:is-empty">
		<func:result select="not(error:has-errors())"/>
	</func:function>

	<!-- Reset errors list -->
	<func:function name="error:reset">
		<!--+-->
		<xsl:if test="sw:sesputtree('errors-old',sw:sesgettree('errors'))"/>
		<xsl:if test="sw:sesput('errors','')"/>
		<!--+-->
		<func:result/>
	</func:function>

	<!-- Remove control ID from error info
		Arguments:
			control: control name
	-->
	<func:function name="error:reset-error-control">
		<xsl:param name="control"/>
		<!-- filter errors stack -->
		<xsl:variable name="errors-new">
			<xsl:for-each select="sw:sesgettree('errors')/error">
				<xsl:choose>
					<!-- copy error to new stack withou control ID -->
					<xsl:when test="control=$control and count(control)!=1">
						<error>
							<xsl:copy-of select="*[.!=$control]"/>
						</error>
					</xsl:when>
					<!-- remove error from stack new stack -->
					<xsl:when test="control=$control and count(control)=1">
					</xsl:when>
					<!-- just copy error to new stack -->
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<!-- store new error stack -->
		<xsl:if test="sw:sesput('errors',$errors-new)"/>
  		<func:result/>
	</func:function>

	<!-- Add additional control ID to last error
		Arguments:
			control: control name
	-->
	<func:function name="error:add-control">
		<xsl:param name="control"/>
		<!-- filter errors stack -->
		<xsl:variable name="errors-new">
			<xsl:for-each select="sw:sesgettree('errors')/error">
				<xsl:choose>
					<!-- Add control info to last error -->
					<xsl:when test="position()=last()">
						<error>
							<xsl:copy-of select="*"/>
							<control>
								<xsl:value-of select="$control"/>
							</control>
						</error>
  					</xsl:when>
					<!-- just copy error to new stack -->
					<xsl:otherwise>
						<xsl:copy-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
  		</xsl:variable>
  		<!-- store new error stack -->
  		<xsl:if test="sw:sesput('errors',$errors-new)"/>
  		<func:result/>
	</func:function>
  
	<!-- Put error in errors list -->
	<func:function name="error:put">
		<xsl:param name="error"/> <!-- Error Message -->
		<xsl:param name="error_details" select="''"/> <!-- Error Details -->
		<xsl:param name="error_control" select="''"/> <!-- Name of form control contained error -->
		<!--+-->
		<xsl:variable name="errors-new">
			<xsl:copy-of select="sw:sesgettree('errors')"/>
			<error>
				<text><xsl:value-of select="$error"/></text>
				<details><xsl:value-of select="$error_details"/></details>
				<control><xsl:value-of select="$error_control"/></control>
			</error>
		</xsl:variable>
		<!--+-->
		<xsl:if test="sw:sesput('errors',$errors-new)"/>
		<func:result/>
	</func:function>

</xsl:stylesheet>
