<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func check"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
>

	<func:function name="format:normalize-number">
		<xsl:param name="count"/>
		<func:result select="sw:if(check:num($count),$count,0)"/>
	</func:function>

	<!-- display percent or n/a -->
	<func:function name="format:percent">
		<xsl:param name="raw-data"/>
		<xsl:variable name="format-data">
			<xsl:choose>
				<xsl:when test="check:nan($raw-data)">
					<xsl:value-of select="sw:text('n/a')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="format-number($raw-data,'0.00%')"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="$format-data"/>
	</func:function>

	<func:function name="format:int2str">
		<xsl:param name="num"/>
		<xsl:param name="show-digits" select="false()"/>
		<xsl:param name="divider" select="0"/><!-- 1/1024/1048576/1073741824 -->
		<xsl:param name="show-sq" select="false()"/>
		<!--+-->
		<xsl:variable name="format"
			select="sw:if($show-sq,
  				sw:if($show-digits,'#,##0.00','###0.00'),
  				sw:if($show-digits,'#,##0','###0'))" />
		<!--+-->
		<xsl:variable name="res">
			<xsl:choose>
				<xsl:when
					test="$num='' or not(sw:re-test($num,'^[0-9]+$'))">
					<xsl:value-of select="$num"/>
				</xsl:when>
				<xsl:when test="$num='0'">
					<xsl:value-of select="$num"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="format-number($num div $divider,$format)" />
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--+-->
		<func:result select="$res" />
	</func:function>

	<!-- Convert string value to int -->
	<func:function name="format:str2int">
		<xsl:param name="str"/>
		<xsl:param name="multi"/>

		<xsl:variable name="num" select="normalize-space($str)"/>

		<xsl:choose>
			<xsl:when
				test="check:nan($num)!='' or string($multi)='' or number($multi)=1">
				<func:result select="$num"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="format-number($num * $multi,'###0')"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

</xsl:stylesheet>
