<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
>

	<func:function name="format:bytes2str">
		<xsl:param name="num"/>
		<xsl:param name="show-digits" select="false()"/>
		<xsl:param name="unit" select="''"/>
		<xsl:param name="show-sq" select="false()"/>
		<!--+-->
		<xsl:variable name="format-nsq" select="sw:if($show-digits,'#,##0','###0')"/>
		<xsl:variable name="format" select="sw:if($show-sq,
			sw:if($show-digits,'#,##0.00','###0.00'),
			$format-nsq)"/>
		<!--+-->
		<xsl:variable name="res">
			<xsl:choose>
				<xsl:when 
				test="$num='' or not(sw:re-test($num,'^[0-9]+$')) or $num='0' or $unit='bytes'">
				<xsl:value-of
						select="concat(format-number($num,$format-nsq),' ',sw:text('bytes'))"/>
				</xsl:when>
				<xsl:when
  					test="$unit=1073741824 or $unit='gb' or 
  					($unit='' and floor($num div 1073741824) &gt; 0)">
					<xsl:value-of
						select="concat(format-number($num div 1073741824,$format),' GB')"/>
				</xsl:when>
  				<xsl:when
  					test="$unit=1048576 or $unit='mb' or 
  					($unit='' and floor($num div 1048576) &gt; 0)">
					<xsl:value-of
						select="concat(format-number($num div 1048576,$format),' MB')"/>
				</xsl:when>
				<xsl:when
					test="$unit=1024 or $unit='kb' or 
					($unit='' and floor($num div 1024) &gt; 0)">
					<xsl:value-of
						select="concat(format-number($num div 1024,$format),' KB')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="format-number($num,$format)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--+-->
		<func:result select="$res" />
	</func:function>

	<func:function name="format:str2bytes">
		<xsl:param name="str" />
		<!--+-->
		<xsl:variable name="num"
			select="normalize-space(substring($str,1,string-length($str) - 2))" />
		<xsl:variable name="measure"
			select="substring($str,string-length($str) - 1)" />
		<xsl:variable name="res">
			<xsl:choose>
				<xsl:when test="normalize-space($str)=''">
					<xsl:value-of select="''" />
				</xsl:when>
				<xsl:when test="sw:re-test($str,'^[0-9]+$')">
					<xsl:value-of select="$str" />
				</xsl:when>
				<xsl:when
					test="not(sw:re-test($str,'^[0-9]+( )?(kb|mb|gb|tb){1}$'))">
					<xsl:value-of select="''" />
				</xsl:when>
				<xsl:when test="$measure='kb'">
					<xsl:value-of
						select="format-number($num * 1024,'###0')" />
				</xsl:when>
				<xsl:when test="$measure='mb'">
					<xsl:value-of
						select="format-number($num * 1048576,'###0')" />
				</xsl:when>
				<xsl:when test="$measure='gb'">
					<xsl:value-of
						select="format-number($num * 1073741824,'###0') " />
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<func:result select="$res" />
		<!--+-->
	</func:function>

	<func:function name="format:kb2str">
		<xsl:param name="num"/>
		<xsl:param name="show-digits" select="false()"/>
		<xsl:param name="unit" select="0"/><!-- 1/1024/1048576/1073741824 -->
		<xsl:param name="show-sq" select="false()"/>
		<!--+-->
		<xsl:variable name="format" select="sw:if($show-sq,
			sw:if($show-digits,'#,##0.00','###0.00'),
			sw:if($show-digits,'#,##0','###0'))"/>
		<!--+-->
		<xsl:variable name="res">
			<xsl:choose>
				<xsl:when
					test="$num='' or not(sw:re-test($num,'^[0-9]+$'))">
					<xsl:value-of select="$num"/>
				</xsl:when>
				<xsl:when test="$num='0'">
					<xsl:value-of select="$num"/>
				</xsl:when>
				<xsl:when
					test="$unit=1073741824 or not(contains(string($num div 1073741824),'.'))">
					<xsl:value-of
						select="concat(format-number($num div 1073741824,$format),' TB')"/>
				</xsl:when>
				<xsl:when
					test="$unit=1048576 or not(contains(string($num div 1048576),'.'))">
					<xsl:value-of
						select="concat(format-number($num div 1048576,$format),' GB')"/>
				</xsl:when>
				<xsl:when
					test="$unit=1024 or not(contains(string($num div 1024),'.')) ">
					<xsl:value-of
						select="concat(format-number($num div 1024,$format),' MB')"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="concat(format-number($num,$format),' KB')"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!--+-->
		<func:result select="$res" />
	</func:function>

	<func:function name="format:str2kb">
		<xsl:param name="str" />
		<!--+-->
		<xsl:variable name="num"
			select="normalize-space(substring($str,1,string-length($str) - 2))"/>
		<xsl:variable name="measure"
			select="substring($str,string-length($str) - 1)"/>
		<xsl:variable name="res">
			<xsl:choose>
				<xsl:when test="normalize-space($str)=''">
					<xsl:value-of select="''"/>
				</xsl:when>
				<xsl:when test="sw:re-test($str,'^[0-9]+$')">
					<xsl:value-of select="$str"/>
				</xsl:when>
				<xsl:when
					test="not(sw:re-test($str,'^[0-9]+( )?(kb|mb|gb|tb){1}$'))">
					<xsl:value-of select="''"/>
				</xsl:when>
				<xsl:when test="$measure='kb'">
					<xsl:value-of select="$num"/>
				</xsl:when>
				<xsl:when test="$measure='mb'">
					<xsl:value-of
						select="format-number($num * 1024,'###0')"/>
				</xsl:when>
				<xsl:when test="$measure='gb'">
					<xsl:value-of
						select="format-number($num * 1048576,'###0')"/>
				</xsl:when>
				<xsl:when test="$measure='tb'">
					<xsl:value-of
						select="format-number($num * 1073741824,'###0')"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<func:result select="$res"/>
		<!--+-->
	</func:function>
	
	<func:function name="format:res2str">
		<xsl:param name="value" />
		<xsl:param name="measure" />
		<xsl:param name="show-digits" select="false()"/>
		<xsl:variable name="format"
			select="sw:if($show-digits,'#,##0','###0')"/>
		<xsl:choose>
			<xsl:when test="true()"><!-- todo: remove it in VZ 2.6.1 release -->
				<xsl:choose>
					<xsl:when
						test="$show-digits and sw:re-test($value,'^[0-9]+$')">
						<func:result
							select="format-number($value,$format)"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="$value"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$measure='1K-blocks'">
				<func:result select="format:kb2str($value,$show-digits)"/>
			</xsl:when>
			<xsl:when test="$measure='bytes'">
				<func:result
					select="format:bytes2str($value,$show-digits)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$value"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- Convert resource value to string -->
	<func:function name="format:str2res">
		<xsl:param name="str"/>
		<xsl:param name="measure"/>
		<xsl:choose>
			<xsl:when test="true()"><!-- todo: remove it in VZ 2.6.1 release -->
				<func:result select="$str" />
			</xsl:when>
			<xsl:when test="$measure='1K-blocks'">
				<xsl:variable name="num"
					select="format:str2kb(sw:lc(normalize-space($str)))" />
				<func:result select="sw:if($num='',$str,$num)" />
			</xsl:when>
			<xsl:when test="$measure='bytes'">
				<xsl:variable name="num"
					select="format:str2bytes(sw:lc(normalize-space($str)))" />
				<func:result select="sw:if($num='',$str,$num)" />
			</xsl:when>
			<xsl:otherwise>
				<func:result select="$str" />
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- vzagent fake alert emulator -->
	<func:function name="sw:get-fake-alerts">
		<xsl:param name="used" select="0"/>
		<xsl:param name="total" select="1"/>
		<xsl:param name="l1" select="0.9"/>
		<xsl:param name="l2" select="1.0"/>
		<func:result>
			<xsl:choose>
				<xsl:when
					test="check:nan($used) or check:nan($total)">
					<level>
						<xsl:value-of select="-1" />
					</level>
					<color>grey</color>
				</xsl:when>
				<xsl:when test="$used div $total &gt;= $l2">
					<level>
						<xsl:value-of select="2" />
					</level>
					<color>red</color>
				</xsl:when>
				<xsl:when test="$used div $total &gt; $l1">
					<level>
						<xsl:value-of select="1" />
					</level>
					<color>yellow</color>
				</xsl:when>
				<xsl:otherwise>
					<level>
						<xsl:value-of select="0" />
					</level>
					<color>green</color>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<func:function name="sw:get-color-by-category">
		<xsl:param name="fraction" />
		<xsl:param name="category" select="'default'"/>
		<xsl:variable name="color">
			<xsl:choose>
				<xsl:when test="$category = 'hn-disk'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1,0.6,0.9))/color"/>
				</xsl:when>
				<xsl:when test="$category = 'hn-mem-swap'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1,0.9,0.98))/color"/>
				</xsl:when>
				<xsl:when test="$category = 'hn-default'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1))/color"/>
				</xsl:when>
				<xsl:when test="$category = 've-load-average'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1,0.9,0.98))/color"/>
				</xsl:when>
				<xsl:when test="$category = 've-memory'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1,0.9,0.98))/color"/>
				</xsl:when>
				<xsl:when test="$category = 've-system'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1,0.9,0.98))/color"/>
				</xsl:when>
				<xsl:when test="$category = 've-disk'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1,0.6,0.9))/color"/>
				</xsl:when>
				<xsl:when test="$category = 've-default'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1))/color"/>
				</xsl:when>
				<xsl:when test="$category = 'default'">
					<xsl:value-of
						select="exsl:node-set(sw:get-fake-alerts(string($fraction),1))/color"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<func:result select="$color"/>
	</func:function>

	<!-- return combined string format for size by localized message, prefix and format -->
	<func:function name="local:get-size-format">
		<xsl:param name="msg" />
		<xsl:param name="prefix" />
		<xsl:param name="format" />
		<xsl:variable name="ret-fmt">
			<xsl:choose>
				<xsl:when test="$prefix = 'yes'">
					<sw:text>
						<xsl:with-param name="msg" select="$msg"/>
						<xsl:with-param name="fmt" select="$format"/>
						%{fmt} %{msg}
					</sw:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$format"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="string($ret-fmt)"/>
	</func:function>

	<!-- transform size to readable value -->
	<func:function name="format:int2bytes">
		<xsl:param name="value"/>
		<xsl:param name="mode"/><!-- mode can be '' - by value, gbyte|mbyte|kbyte|byte - specific format -->
		<xsl:param name="prefix" select="'yes'"/>
		<xsl:param name="format" select="'#0.00'"/>

		<func:result>
			<xsl:choose>
				<xsl:when test="check:nan($value)">
					<xsl:value-of select="sw:text('n/a')" />
				</xsl:when>
				<xsl:when test="$mode = 'gbyte'">
					<xsl:value-of
						select="format-number($value div 1073741824, local:get-size-format(sw:text('GB'), $prefix, $format))"/>
				</xsl:when>
				<xsl:when test="$mode = 'mbyte'">
  					<xsl:value-of
						select="format-number($value div 1048576, local:get-size-format(sw:text('MB'), $prefix, $format))" />
				</xsl:when>
				<xsl:when test="$mode = 'kbyte'">
					<xsl:value-of
						select="format-number($value div 1024, local:get-size-format(sw:text('KB'), $prefix, $format))" />
				</xsl:when>
				<xsl:when test="$mode = 'byte'">
					<xsl:value-of
						select="format-number($value, local:get-size-format(sw:text('b'), $prefix, $format))" />
				</xsl:when>
				<xsl:when test="$value &gt;= 1073741824">
					<xsl:value-of
						select="format-number($value div 1073741824, local:get-size-format(sw:text('GB'), $prefix, $format))" />
				</xsl:when>
				<xsl:when test="$value &gt;= 1048576">
					<xsl:value-of
						select="format-number($value div 1048576, local:get-size-format(sw:text('MB'), $prefix, $format))" />
				</xsl:when>
				<xsl:when test="$value &gt;= 1024">
					<xsl:value-of
						select="format-number($value div 1024, local:get-size-format(sw:text('KB'), $prefix, $format))" />
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of
						select="format-number($value, local:get-size-format(sw:text('b'), $prefix, $format))" />
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<!-- transform size in 1k blocks to readable value -->
	<func:function name="format:int2kbytes">
		<xsl:param name="kbytes" />
		<func:result>
			<xsl:value-of
				select="format:int2bytes($kbytes * 1024, /.., 'yes',sw:if(@format != '',@format,'#'))" />
		</func:result>
	</func:function>

	<!-- transform bps (byte per second) to readable value -->
	<func:function name="format:kbps2bps">
		<xsl:param name="value-kbps" />
		<xsl:param name="mode" /><!-- mode can be '' - by value, gbps|mbps|kbps|bps - specific format -->
		<xsl:param name="prefix" select="'yes'" />
		<xsl:param name="format" select="'#0.00'" />

		<xsl:variable name="value-bps" select="$value-kbps * 1000" />
		<xsl:variable name="bps-details-rtf">
			<xsl:choose>
				<xsl:when test="check:nan($value-kbps)">
					<value>
						<xsl:value-of select="sw:text('n/a')" />
					</value>
					<factor>
						<xsl:value-of select="sw:text('n/a')" />
					</factor>
				</xsl:when>
				<xsl:when test="$mode = 'gbps'">
					<value>
						<xsl:value-of
							select="format-number($value-bps div 1000000000, local:get-size-format(sw:text('Gbps'), $prefix, $format))" />
					</value>
					<factor>
						<xsl:value-of select="1000000000" />
					</factor>
				</xsl:when>
				<xsl:when test="$mode = 'mbps'">
					<value>
						<xsl:value-of
							select="format-number($value-bps div 1000000, local:get-size-format(sw:text('Mbps'), $prefix, $format))" />
					</value>
					<factor>
						<xsl:value-of select="1000000" />
					</factor>
				</xsl:when>
				<xsl:when test="$mode = 'kbps'">
					<value>
						<xsl:value-of
							select="format-number($value-bps div 1000, local:get-size-format(sw:text('Kbps'), $prefix, $format))" />
					</value>
					<factor>
						<xsl:value-of select="1000" />
					</factor>
				</xsl:when>
				<xsl:when test="$mode = 'bps'">
					<value>
						<xsl:value-of
							select="format-number($value-bps, local:get-size-format(sw:text('Bps'), $prefix, $format))" />
					</value>
					<factor>
						<xsl:value-of select="1" />
					</factor>
				</xsl:when>
				<xsl:when test="$value-bps &gt;= 1000000000">
					<value>
						<xsl:value-of
							select="format-number($value-bps div 1000000000, local:get-size-format(sw:text('Gbps'), $prefix, $format))" />
					</value>
					<factor>
						<xsl:value-of select="1000000000" />
					</factor>
				</xsl:when>
				<xsl:when test="$value-bps &gt;= 1000000">
					<value>
						<xsl:value-of
							select="format-number($value-bps div 1000000, local:get-size-format(sw:text('Mbps'), $prefix, $format))" />
					</value>
					<factor>
						<xsl:value-of select="1000000" />
					</factor>
				</xsl:when>
				<xsl:when test="$value-bps &gt;= 1000">
					<value>
						<xsl:value-of
							select="format-number($value-bps div 1000, local:get-size-format(sw:text('Kbps'), $prefix, $format))" />
					</value>
					<factor>
						<xsl:value-of select="1000" />
					</factor>
				</xsl:when>
				<xsl:otherwise>
					<value>
						<xsl:value-of
							select="format-number($value-bps, local:get-size-format(sw:text('Bps'), $prefix, $format))" />
					</value>
					<factor>
						<xsl:value-of select="1" />
					</factor>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($bps-details-rtf)" />
	</func:function>

	<!-- transform size to readable value with format-->
	<xsl:template match="size" name="size">
		<xsl:value-of select="format:int2bytes(.,'','yes','#,##0.00')"/>
	</xsl:template>

	<!-- transform size in 1k blocks to readable value -->
	<xsl:template match="sizekb" name="sizekb">
		<xsl:copy-of select="format:int2kbytes(.)"/>
	</xsl:template>
</xsl:stylesheet>
