<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc env"
	xmlns:xsl	="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:set="http://exslt.org/sets" 
	xmlns:func="http://exslt.org/functions"
	xmlns:sw	="http://www.swsoft.com/xsl/cp"
	xmlns:voc	="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env	="http://www.swsoft.com/xsl/cp/env"
	xmlns:vt	="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
>

	<!-- make request packet for vocabulary data -->
	<func:function name="voc:get-pkt">
		<xsl:param name="args"/>		
		<func:result>
			<xsl:choose>
				<xsl:when test="exsl:object-type($args) = 'string'">
					<category>
						<xsl:value-of select="$args"/>
					</category>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="$args"/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<!-- request vocabulary data -->
	<func:function name="voc:get">
		<xsl:param name="categories-arg"/>
		<xsl:param name="platform-ref"/><!-- use env:make-platform-ref() for ref generation -->
		<xsl:param name="id" select="''"/>
		<xsl:param name="any-result" select="false()"/>

		<xsl:variable name="categories-rtf" select="voc:get-pkt($categories-arg)"/>
		<xsl:variable name="categories" select="exsl:node-set($categories-rtf)/category"/>					

		<xsl:choose>
			<xsl:when test="$platform-ref/hn-eid">
				<xsl:variable name="voc" select="sw:get-voc($categories-rtf, $platform-ref/hn-eid)/packet/data/system/vocabulary"/>
				<xsl:choose>
					<xsl:when test="$any-result">
						<func:result select="$voc/*"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="$voc/parameter"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="$platform-ref/platform">
				<xsl:variable name="vza-platform" select="vt:platform2vza($platform-ref/platform)"/>
				<xsl:variable name="vza-arch" select="substring-after($platform-ref/platform,'.')"/>
				
				<xsl:variable name="voc" select="sw:get-voc()/packet/data/system/vocabulary[
						(
							parameter[id = 'platform'][data = $vza-platform] and 
						  parameter[id = 'architecture'][data = $vza-arch] and
						  parameter[id = 'vzversion']
						) or
					  ( 
							not( parameter[id = 'platform'] ) and 
							not( parameter[id = 'architecture'] )
					  )
					]
					[parameter[category=$categories and ($id='' or id=$id)]]
					[1]/parameter[category=$categories and ($id='' or id=$id)]"
				/>
				<func:result select="$voc"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					Error in voc:get(): HN platform or EID should be specified.							
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>

	<!-- check feature presence, return feature tree if exists -->
	<func:function name="voc:check-feature">
		<xsl:param name="feature"/>
		<xsl:param name="platform-ref"/>
		
		<func:result select="voc:get('features', $platform-ref)[id = $feature]"/>
	</func:function>
	
	<!-- 
		Check operation availability for current object 
		Arguments
			object-type
			operator
			cmd  (optional)
			subcmd (optional)
		Result
			boolean
	-->
	<func:function name="voc:check-current-object-operation">
		<xsl:param name="object-type"/>
		<xsl:param name="operator"/>
  	<xsl:param name="cmd" 		select="''"/>
  	<xsl:param name="subcmd"	select="''"/>
  	
		<xsl:choose>
			<xsl:when test="$object-type='env.vt'">
				<func:result select="voc:check-operation($operator,$cmd, $subcmd, sw:ve-eid())=''"/>
			</xsl:when>
			<xsl:when test="$object-type='hn.vt'">
				<func:result select="voc:check-operation($operator,$cmd, $subcmd,sw:hn-eid())=''"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="true()"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- Look on core/schema/types.xsd:object-operations for result details -->
	<func:function name="voc:object-operations">

		<!-- Get the vocabulary from master HN -->
		<xsl:variable name="req">
			<parameter>op_dict</parameter>
		</xsl:variable>
		<xsl:variable name="voc" select="voc:get($req, env:make-platform-ref(sw:local-hn-eid()))/data"/>	
		<!-- /Get the vocabulary from master HN -->
		
		<!-- Generate the result -->
		<xsl:variable name="result-rtf">
			<!-- VZ VE -->
			<object>
				<object-type>env.vt</object-type>
				<!-- vzcp-custom operations -->
				<operation>
					<operator>confixx</operator>
					<env-state><xsl:value-of select="$env-state/running"/></env-state>
				</operation>
				<operation>
					<operator>plesk</operator>
					<env-state><xsl:value-of select="$env-state/running"/></env-state>
				</operation>
				<operation>
					<operator>ssh</operator>
  				<env-state><xsl:value-of select="$env-state/running"/></env-state>
  				<env-state><xsl:value-of select="$env-state/repairing"/></env-state>
  				<!-- for #89258 fix -->
					<env-trans><xsl:value-of select="$env-trans/none"/></env-trans>  				
  				<env-trans><xsl:value-of select="$env-trans/setting"/></env-trans>
					<env-trans><xsl:value-of select="$env-trans/updating"/></env-trans>
					<env-trans><xsl:value-of select="$env-trans/cloning"/></env-trans>
					<env-trans><xsl:value-of select="$env-trans/migrating"/></env-trans>
					<env-trans><xsl:value-of select="$env-trans/backing-up"/></env-trans>  	
  			</operation>
  			<operation>
					<operator>rdp</operator>
  				<env-state><xsl:value-of select="$env-state/running"/></env-state>
					<!-- for #89258 fix -->
					<env-trans><xsl:value-of select="$env-trans/none"/></env-trans>  				
  				<env-trans><xsl:value-of select="$env-trans/setting"/></env-trans>
					<env-trans><xsl:value-of select="$env-trans/updating"/></env-trans>
					<env-trans><xsl:value-of select="$env-trans/cloning"/></env-trans>
					<env-trans><xsl:value-of select="$env-trans/migrating"/></env-trans>
					<env-trans><xsl:value-of select="$env-trans/backing-up"/></env-trans>  	
  			</operation>
 				<operation>
 					<operator>vzaenvm</operator>
					<command>show_ctl</command>
					<custom-rule>vzve-show-ctl</custom-rule>
  			</operation>
  			<!-- /vzcp-custom operations -->	
  			<!-- vza operations -->
 				<xsl:for-each select="$voc//states">
 					<xsl:variable name="is-local" select="name(../../..)='data'"/>
 					<xsl:variable name="operator" select="sw:if($is-local,name(../..),name(..))"/>
 					<xsl:variable name="cmd" select="sw:if($is-local,name(..),'')"/>
 					
 					<operation>
	 					<operator><xsl:value-of select="$operator"/></operator>
	 					<xsl:if test="$is-local">
	 						<command><xsl:value-of select="$cmd"/></command>
	 					</xsl:if>
	 					<!-- add some custom logic -->
						<xsl:if test="($operator='vzaenvm' and $cmd='destroy')">
		  				<env-state><xsl:value-of select="$env-state/running"/></env-state>
		  			</xsl:if>
	 					<xsl:if test="($operator='vzabackupm' and $cmd='list')">
	 						<env-trans><xsl:value-of select="$env-trans/backing-up"/></env-trans>
							<env-trans><xsl:value-of select="$env-trans/restoring"/></env-trans>
							<env-trans><xsl:value-of select="$env-trans/starting"/></env-trans>
							<env-trans><xsl:value-of select="$env-trans/stopping"/></env-trans>
	 					</xsl:if>
	 					<xsl:if test="($operator='vzaenvm' and ($cmd='start' or $cmd='restart'))">
	 						<deny-disabled-ve/>
						</xsl:if>
						<xsl:if test="$operator='vzaenvm' and ($cmd='start' or ($cmd='stop'))">
							<env-state><xsl:value-of select="$env-state/suspended"/></env-state>
						</xsl:if>

	 					<!-- post states from vocabulary -->
 						<xsl:for-each select="state">
 							<env-state><xsl:value-of select="."/></env-state>
 						</xsl:for-each> 										 						 					
 						
 					</operation>
 				</xsl:for-each>
			</object>
			<!-- /VZ VE -->			
			<!-- VZ HN -->
			<object>
				<object-type>hn.vt</object-type>
				<!-- vzcp-custom operations -->
				<operation>
					<operator>ssh</operator>
					<env-state><xsl:value-of select="$env-state/running"/></env-state>					
				</operation>
				<operation>
					<operator>rdp</operator>
					<env-state><xsl:value-of select="$env-state/running"/></env-state>					
				</operation>
				<!-- /vzcp-custom operations -->
			</object>
			<!-- /VZ HN -->
		</xsl:variable>
		
		<func:result select="exsl:node-set($result-rtf)"/>
		
	</func:function>

<!--
	Operator: any VZA operator or special VZCC operator(confixx,ssh,show_ctl,rdp)
-->
	<func:function name="voc:check-operation">
  	<xsl:param name="operator"/>
  	<xsl:param name="cmd" 		select="''"/>
  	<xsl:param name="subcmd"	select="''"/>
  	<xsl:param name="eid" 		select="sw:ve-eid()"/>
  	<!-- Load env info -->
		<xsl:variable name="env-info" select="sw:envinfo($eid,false())/packet/env"/>
		<xsl:variable name="is-hn" select="$env-info/parent_eid = $env:empty-eid"/>
		<xsl:variable name="voc-env-state">
			<xsl:choose>
				<xsl:when test="$env-info/status/state != ''">
					<xsl:value-of select="$env-info/status/state"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$env-state/unexist"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="voc-env-transition">
			<xsl:choose>
				<xsl:when test="$env-info/status/transition != ''">
					<xsl:value-of select="$env-info/status/transition"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$env-trans/none"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
  	<xsl:variable name="ve-disabled" select="$env-info/virtual_config/disabled='1'"/>

  	<!-- Find operations -->
  	<xsl:variable name="opers-obj" select="voc:object-operations()/object[
  		(object-type='hn.vt' and $is-hn) or (object-type='env.vt' and not($is-hn))
  	]/operation[operator=$operator]"/>
  	
		<xsl:variable name="opers-command" select="$opers-obj[$cmd!='' and command=$cmd][1]"/>
		<xsl:variable name="opers-common" select="$opers-obj[not(command)][1]"/>
		<xsl:variable name="oper" select="sw:if($opers-command,$opers-command,$opers-common)"/>
		
		
		<!-- Check operation -->
		<xsl:choose>
			<!-- Disable any checking -->
			<xsl:when test="$operator=''">
				<func:result/>			
			</xsl:when>
			<!-- Don`t show VE start/stop in case of disabled VE -->
			<xsl:when test="($oper/custom-rule='vzve-show-ctl' or $oper/deny-disabled-ve) and $ve-disabled">
				<func:result>
					<ui:type>custom</ui:type>
					<ui:reason><sw:text>The option has been disabled by the administrator.</sw:text></ui:reason>
					<xsl:choose>
						<xsl:when test="$activeMode != 'vzcc'">
							<ui:solution><sw:text>Call for support.</sw:text></ui:solution>
						</xsl:when>
						<xsl:otherwise>
							<ui:solution>
								<ui:link href="/vz/cp/vzdir/infrman/envs/manage?tab=gen">
									<sw:text>
										Enable the Container on the Container Preferences screen.
									</sw:text>
								</ui:link>
							</ui:solution>							
						</xsl:otherwise>
					</xsl:choose>
				</func:result>
			</xsl:when>
			<!-- /Don`t show ENV start/stop in case of disabled VE -->
			<!-- Ordinal checks -->
			<xsl:when test="
				( $voc-env-transition!=$env-trans/none and not($oper/env-transition=$voc-env-transition) )
				or 
				( not($oper/env-state=$voc-env-state) )
			">
				<!-- operation is unavailable-->
				<func:result>
					<ui:type>wrong-env-state</ui:type>
					<ui:operation>
						<xsl:copy-of select="$operator"/>
					</ui:operation>
					<xsl:if test="$cmd!=''">
						<ui:cmd>
							<xsl:copy-of select="$cmd"/>
						</ui:cmd>
					</xsl:if>
					<xsl:for-each select="$oper/env-state">
						<ui:required-state>
							<xsl:value-of select="."/>
						</ui:required-state>
					</xsl:for-each>
					<ui:env-state>
						<xsl:value-of select="$voc-env-state"/>
					</ui:env-state>
					<ui:env-transition>
						<xsl:value-of select="$voc-env-transition"/>
					</ui:env-transition>
					<ui:env-eid><xsl:value-of select="$eid"/></ui:env-eid>
				</func:result>
			</xsl:when>
			<xsl:otherwise>
				<func:result/>
			</xsl:otherwise>
		</xsl:choose>

 	</func:function> 	
	
	
<!--
	Operator: any VZA operator or special VZCC operator(confixx,ssh,show_ctl,rdp)
-->
	<func:function name="voc:check-operation-old">
  	<xsl:param name="operator"/>
  	<xsl:param name="cmd" 		select="''"/>
  	<xsl:param name="subcmd"	select="''"/>
  	<xsl:param name="eid" 		select="sw:ve-eid()"/>
  	<!--|-->
		<xsl:variable name="env-info" select="sw:envinfo($eid,false())/packet/env"/>
		<xsl:variable name="is-hn" select="$env-info/parent_eid = $env:empty-eid"/>
  	<!--|-->  	  	
  	<xsl:variable name="opers" select="voc:object-operations()/object[(object-type='hn.vt' and $is-hn) or (object-type='env.vt' and not($is-hn))]"/>

  	
  	
		<xsl:variable name="req">
			<parameter>op_dict</parameter>
		</xsl:variable>
		<xsl:variable name="env-info" select="sw:envinfo($eid,false())/packet/env"/>
		<xsl:variable name="is-hn" select="$env-info/parent_eid = $env:empty-eid"/>
		<xsl:choose>
			<xsl:when test="$is-hn">
				<func:result select="local:check-hn-operation($operator,$env-info)"/>
			</xsl:when>
			<xsl:otherwise>
		<xsl:variable name="voc" select="voc:get($req, env:make-platform-ref($env-info/parent_eid))/data"/>
		<xsl:variable name="state">
			<xsl:choose>
				<xsl:when test="$env-info/status/state != ''">
					<xsl:value-of select="$env-info/status/state"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$env-state/unexist"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="transition" select="$env-info/status/transition"/>

  	<xsl:variable name="disabled" select="$env-info/virtual_config/disabled='1'"/>

  	<xsl:variable name="backup-trans-src">
  		<trans><xsl:value-of select="$env-trans/backing-up"/></trans>
  		<trans><xsl:value-of select="$env-trans/restoring"/></trans>
  		<trans><xsl:value-of select="$env-trans/starting"/></trans>
  		<trans><xsl:value-of select="$env-trans/stopping"/></trans>
  	</xsl:variable>
  	<xsl:variable name="backup-trans" select="exsl:node-set($backup-trans-src)"/>
  	
  	<xsl:variable name="restart-trans-src">
  		<trans><xsl:value-of select="$env-trans/starting"/></trans>
  		<trans><xsl:value-of select="$env-trans/stopping"/></trans>
  	</xsl:variable>
  	<xsl:variable name="restart-trans" select="exsl:node-set($restart-trans-src)"/>

  	<xsl:variable name="ssh-rdp-trans-src">
  		<trans><xsl:value-of select="$env-trans/setting"/></trans>
  		<trans><xsl:value-of select="$env-trans/updating"/></trans>
  		<trans><xsl:value-of select="$env-trans/cloning"/></trans>
  		<trans><xsl:value-of select="$env-trans/migrating"/></trans>
  		<trans><xsl:value-of select="$env-trans/backing-up"/></trans>  		
  	</xsl:variable>
  	<xsl:variable name="ssh-rdp-trans" select="exsl:node-set($ssh-rdp-trans-src)"/>

  	<!--|-->
  	<xsl:variable name="states-src">
  		<xsl:choose>
  			<!-- Allow to stop/start VE -->
				<xsl:when test="($operator='vzaenvm' and ($cmd='start' or $cmd='restart') and $disabled)">
				</xsl:when>
				<xsl:when test="$operator='vzaenvm' and ($cmd='start' or ($cmd='stop' and $subcmd='fast')) and $state=$env-state/suspended">
					<state value="{$env-state/suspended}"/>
					<xsl:for-each select="$voc/*[name()=$operator]/*[name()=$cmd]/states/state">
  					<state value="{.}"/>
  				</xsl:for-each>
				</xsl:when>
				<xsl:when test="($operator='vzvenvm' and ($cmd='start' or $cmd='restart') and $disabled)">			</xsl:when>
  			<!--/-->
  			<xsl:when test="$operator='confixx'">
  				<state value="{$env-state/running}"/>
  			</xsl:when>
  			<xsl:when test="$operator='plesk'">
  				<state value="{$env-state/running}"/>
					<!-- offline plesk suport not handled here -->
  			</xsl:when>
  			<xsl:when test="$operator='ssh'">
  				<state value="{$env-state/running}"/>
  				<state value="{$env-state/repairing}"/>
  			</xsl:when>
  			<xsl:when test="$operator='rdp'">
  				<state value="{$env-state/running}"/>
  			</xsl:when>
  			<xsl:when test="$operator='vzaenvm' and $cmd='show_ctl'">
  				<xsl:for-each select="$voc/*[name()=$operator]/*[name()='restart']/states/state">
  					<state value="{.}"/>
  				</xsl:for-each>
  			</xsl:when>
  			<xsl:when test="$subcmd!=''">
  				<xsl:variable name="subcmd-states" select="$voc/*[name()=$operator]/*[name()=$cmd]/*[name()=$subcmd]/states/state"/>
  				<xsl:variable name="cmd-states" select="$voc/*[name()=$operator]/*[name()=$cmd]/states/state"/>
  				<xsl:choose>
  					<xsl:when test="$subcmd-states">
  						<xsl:for-each select="$subcmd-states">
		  					<state value="{.}"/>
		  				</xsl:for-each>
  					</xsl:when>
  					<xsl:when test="$cmd-states">
  						<xsl:for-each select="$cmd-states">
		  					<state value="{.}"/>
		  				</xsl:for-each>
  					</xsl:when>
  					<!-- Use operator's global states -->
  					<xsl:otherwise>
  						<xsl:for-each select="$voc/*[name()=$operator]/states/state">
		  					<state value="{.}"/>
		  				</xsl:for-each>
  					</xsl:otherwise>
  				</xsl:choose>
  			</xsl:when>
  			<xsl:when test="$cmd!=''">
  				<xsl:variable name="cmd-states" select="$voc/*[name()=$operator]/*[name()=$cmd]/states/state"/>
  				<xsl:choose>
  					<xsl:when test="$cmd-states">
  						<xsl:for-each select="$voc/*[name()=$operator]/*[name()=$cmd]/states/state">
		  					<state value="{.}"/>
		  				</xsl:for-each>
  					</xsl:when>
  					<!-- Use operator's global states -->
  					<xsl:otherwise>
  						<xsl:for-each select="$voc/*[name()=$operator]/states/state">
		  					<state value="{.}"/>
		  				</xsl:for-each>
  					</xsl:otherwise>
  				</xsl:choose>
  			</xsl:when>
  			<xsl:otherwise>
  				<xsl:for-each select="$voc/*[name()=$operator]/states/state">
  					<state value="{.}"/>
  				</xsl:for-each>
  			</xsl:otherwise>
  		</xsl:choose>
  	</xsl:variable>
  	<xsl:variable name="states" select="exsl:node-set($states-src)/state"/>

  	  	
  	<!--|-->
  	<!-- Check "show VE start/stop controls" -->
  	<xsl:variable name="show-ctl" select="$states[@value=$state] and $restart-trans[trans=$transition]    "/>
  	<!--|-->
		<xsl:choose>
			<xsl:when test="false()">
				<func:result select="''"/>
			</xsl:when>
			<!-- Allow to list backups -->
			<xsl:when test="($operator='vzabackupm' and $cmd='list') and $states[@value=$state] and $backup-trans[trans=$transition]">
				<func:result select="''"/>
			</xsl:when>
			<!-- Allow to ssh or rdp operation -->
			<xsl:when test="($operator='rdp' or $operator='ssh') and $states[@value=$state] and $ssh-rdp-trans[trans=$transition]">
				<func:result select="''"/>
			</xsl:when>
			<!-- Don`t show VE start/stop in case of disabled VE -->
			<xsl:when test="$operator='vzaenvm' and $cmd='show_ctl' and $disabled">
				<func:result>
					<ui:type>custom</ui:type>
					<ui:reason><sw:text>The option has been disabled by the administrator.</sw:text></ui:reason>
					<xsl:choose>
						<xsl:when test="$activeMode != 'vzcc'">
							<ui:solution><sw:text>Call for support.</sw:text></ui:solution>
						</xsl:when>
						<xsl:otherwise>
							<ui:solution>
								<ui:link href="/vz/cp/vzdir/infrman/envs/manage?tab=gen">
									<sw:text>
										Enable the Container on the Container Preferences screen.
									</sw:text>
								</ui:link>
							</ui:solution>							
						</xsl:otherwise>
					</xsl:choose>
				</func:result>
			</xsl:when>
			<!-- /Don`t show ENV start/stop in case of disabled VE -->
			<!-- Allow to show ENV start/stop controls -->
			<xsl:when test="$operator='vzaenvm' and $cmd='show_ctl' and $show-ctl and ($state!=$env-state/down or not($disabled))">
				<func:result select="''"/>
			</xsl:when>						
			<xsl:when test="(not($transition!='') or string($transition)=$env-trans/none) and $states[@value=$state]">
				<!-- All is ok, operation is available-->
				<func:result select="''"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- operation is unavailable-->
				<func:result>
					<ui:type>wrong-env-state</ui:type>
					<ui:operation>
						<xsl:copy-of select="$operator"/>
					</ui:operation>
					<xsl:if test="$cmd!=''">
						<ui:cmd>
							<xsl:copy-of select="$cmd"/>
						</ui:cmd>
					</xsl:if>
					<xsl:for-each select="$states">
						<ui:required-state>
							<xsl:value-of select="@value"/>
						</ui:required-state>
					</xsl:for-each>
					<ui:env-state>
						<xsl:value-of select="$state"/>
					</ui:env-state>
					<ui:env-transition>
						<xsl:value-of select="$transition"/>
					</ui:env-transition>
					<ui:env-eid><xsl:value-of select="$eid"/></ui:env-eid>
				</func:result>
			</xsl:otherwise>  		
		</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
  </func:function>
  	
	<func:function name="voc:get-pattern">
		<xsl:param name="platform-ref"/>
		<xsl:param name="name"/>
		
		<xsl:variable name="pattern" select="voc:get('pattern', $platform-ref,$name)[id=$name]" />
		<xsl:variable name="result-rtf">
			<xsl:if test="$pattern">
				<pattern>
					<xsl:copy-of select="$pattern/*" />
					<regexp>
						<xsl:value-of select="concat('^',$pattern/data,'$')" />
					</regexp>
				</pattern>
			</xsl:if>
		</xsl:variable>
		<func:result select="exsl:node-set($result-rtf)/pattern" />
	</func:function>
	
	<!-- Enumerates distinct HN platforms in group -->
	<func:function name="voc:enumerate-platforms">
		<xsl:variable name="data">
			<xsl:for-each select="sw:get-voc()/packet/data/system/vocabulary[parameter[id = 'platform'] 
										and parameter[id = 'architecture']]">
				<platform>
					<xsl:copy-of select="vt:vza2platform(parameter[id = 'platform']/data, 
											parameter[id = 'architecture']/data)"/>
				</platform>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="set:distinct(exsl:node-set($data)/platform)"/>
	</func:function>

	<func:function name="local:check-hn-operation">
  	<xsl:param name="operator"/>
  	<xsl:param name="env"/>
  	<!-- hn check know 2 operastions: ssh and rdp access. For both required node online -->
		<xsl:choose>
  		<xsl:when test="$env/status/state = $env-state/running">
				<func:result select="''"/>  				
  		</xsl:when>
  		<xsl:otherwise>
				<!-- operation is unavailable-->
				<func:result>
					<ui:type>wrong-env-state</ui:type>
					<ui:operation>
						<xsl:copy-of select="$operator"/>
					</ui:operation>
					<ui:required-state>
						<xsl:value-of select="$env-state/running"/>
					</ui:required-state>
					<ui:env-state>
						<xsl:value-of select="$env/status/state"/>
					</ui:env-state>
					<ui:env-transition>
						<xsl:value-of select="$env/status/transition"/>
					</ui:env-transition>
					<ui:env-eid><xsl:value-of select="$env/eid"/></ui:env-eid>
				</func:result>  		
  		</xsl:otherwise>
  	</xsl:choose>
	</func:function>
	
</xsl:stylesheet>
