<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.

	== Functions Specifications ==
	
	Backup Core Options Handling
		backups:set-core-options()
		backups:get-core-options()
		
		backups:find-actual-core-options()
		backups:find-actual-ve-limit()
		
	Backup Statistic
		backups:calc-backups-count-for-ve()

	Backup Storage Config Handling
		backups:set-storage-config()	
		backups:get-storage-config()

	Backups Management
	
		backups:find-backup()
		backups:find-ve-last-info()
		backups:find-env-info()		
		backups:new-action()
		backups:get-packet-remove()

	== Constant Functions ==

	backups:backup-types()
	backups:compression-levels()
	
	== Data Specification ==
	
	HN Backups Core Options.
		<core-options>
			<global/>  - or no such node		
			<limits>
				<backups-per-ve>
			</limits>
			<incremental>
				<chain-length>
				<chain-days>
			</incremental>
			<defaults>
				<backup-type>
				<compression-level>
				<storage-server-eid/>
			</defaults>
			<other-raw-data>
				... -  all other vza backup config data.
			</other-raw-data>
		</core-options>
	
	HN Backups Storage Configs.
		<storage-config>
			<location>
				<type>local|share</type>
				<local>
					<path></path>							
				</local>
				<share>
					<path></path>
					<login>
						<name></name>
						<domain>/domain>
						<password></password>
					<login>
				</share>
			</location>
		</storage-config>			
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func backups action local"
  xmlns:xsl							="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl						="http://exslt.org/common"
  xmlns:sw							="http://www.swsoft.com/xsl/cp"
  xmlns:func						="http://exslt.org/functions" 
  xmlns:xsi							="http://www.w3.org/2001/XMLSchema-instance"
	xmlns:vzat						="http://www.swsoft.com/webservices/vzl/4.0.0/types"
	xmlns:vzab						="http://www.swsoft.com/webservices/vzl/4.0.0/backupm" 	
  xmlns:ui							="http://www.swsoft.com/xsl/cp/ui"	
  xmlns:backups					="http://www.swsoft.com/xsl/cp/backups"
  xmlns:action					="http://www.swsoft.com/xsl/cp/action"
  xmlns:local						="http://www.swsoft.com/xsl/cp/local"
  xmlns:global					="http://www.swsoft.com/xsl/cp/global"  
>
	
	<sw:include href="/lib/utils/action.xsl"/>
	
	<!-- Backup Type Constanst Functions -->
	<func:function name="backups:backup-types">
		<xsl:variable name="res-rtf">
			<ui:filter-option value="{$global:backup-full}" id1="full" title="{sw:text('Full')}"/>
			<ui:filter-option value="{$global:backup-inc}" id1="inc" title="{sw:text('Incremental')}"/>
			<ui:filter-option value="{$global:backup-diff}" id1="diff" title="{sw:text('Differential')}"/>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)/ui:filter-option"/>		
	</func:function>

	
	<func:function name="backups:compression-levels">
		<xsl:variable name="res-rtf">
			<level id="0" title="{sw:text('None')}">
				<sw:text>
					Takes the least time to create, no compression.
				</sw:text>
			</level>
			<level id="1" title="{sw:text('Normal')}">
				<sw:text>
					This kind of backup needs more time to be created, but occupies less space.
				</sw:text>
			</level>
			<level id="2" title="{sw:text('High')}">
				<sw:text>
					The compression level is high, but creating the backup takes longer.
				</sw:text>
			</level>
			<level id="3" title="{sw:text('Maximum')}">
				<sw:text>
					The highest compression level, the longest backup creation time.
				</sw:text>
			</level>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>
	<!-- /Backup Type Constanst Functions -->
	

	<!-- request detailed backup info -->
	<func:function name="backups:find-backup">
		<xsl:param name="backup-id"/>

		<xsl:variable name="packet-rtf">
			<packet>
				<target>backupm</target>      
				<data>
					<backupm>		
						<list>				
							<xsl:choose>
                <xsl:when test="exsl:object-type($backup-id) = 'node-set'">
                  <xsl:for-each select="$backup-id">
                    <backup_id><xsl:value-of select="."/></backup_id>
                  </xsl:for-each>
                </xsl:when>
                <xsl:otherwise>
                  <backup_id><xsl:value-of select="$backup-id"/></backup_id>
                </xsl:otherwise>
              </xsl:choose>
						</list>
					</backupm>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="result" select="sw:xchg($packet-rtf)"/>
	
		<func:result select="$result/packet/data/backupm/backup|$result/packet/data/backupm/error|$result/packet/data/error"/>
	</func:function>

	<!-- request backup env info 
		backup=> ref to nodeset from backups:find-backup()
	-->	

	<func:function name="backups:find-env-info">
		<xsl:param name="backup"/>
		
		<sw:die test="exsl:object-type($backup) != 'node-set'">
			Wrong argument data type in backups:find-env-info() call.
		</sw:die>
		
		<xsl:variable name="packet-rtf">
			<packet
				xmlns:ns3="http://www.swsoft.com/webservices/vzl/4.0.0/types"
				xmlns:ns2="http://www.swsoft.com/webservices/vzl/4.0.0/backupm"  
				xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
			>
				<target>backupm</target>    
				<xsl:copy-of select="sw:env-dst($backup/storage_eid)"/>
				<data>
					<backupm>		
						<get_info>			
							<backup_id><xsl:value-of select="$backup/id"/></backup_id>
							<options xsi:type="ns2:get_env_info_optionsType">
								<ns2:env/>
								<ns2:excludes/>
							</options>    
						</get_info>
					</backupm>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="result" select="sw:xchg($packet-rtf)"/>
		<func:result select="$result/packet/data/backupm/info|$result/packet/data/backupm/error|$result/packet/data/error"/>
	</func:function>
	 
	<!-- 
		Request backup(s) restore.
		Arguments
			backup[]
				id
				dst-eid
	-->
	<func:function name="backups:get-packet-restore">
		<xsl:param name="backups"/>
		<xsl:param name="cookies" select="''"/>

		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vt/backups/restore.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched><sw:text>The Container(s) restoration from the backup(s) has been scheduled.</sw:text></sched>
						<error><sw:text>Failed to restore the Container(s) from the backup.</sw:text></error>
					</msg>
					<operation>restore_ve</operation>
					<xsl:copy-of select="$cookies"/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:for-each select="$backups">
							<backup>
								<xsl:copy-of select="*[self::id or self::dst-eid]"/>
							</backup>
						</xsl:for-each>
					</data>
				</xsl:with-param>
			</xsl:call-template>			
		</func:result>

	</func:function>
	 
	<!-- request backup(s) removal -->
	<func:function name="backups:get-packet-remove">
		<xsl:param name="ids"/>
		<xsl:param name="prev" select="false()"/>
		<xsl:param name="redirect-url" select="''"/>

		<func:result>
			<packet log="on" progress="on">
				<target>backupm</target>      
				<cookie>
					<msg>
						<ok><sw:text>The backup(s) has/have been removed.</sw:text></ok>
						<sched><sw:text>The removal of the Container backup(s) has been scheduled.</sw:text></sched>
						<error><sw:text>Failed to remove the backup(s).</sw:text></error>
					</msg>
					<operation>remove_backup</operation>
					<xsl:choose>
						<xsl:when test="$redirect-url=''">
							<redirect-last/>
						</xsl:when>
						<xsl:when test="$redirect-url='prev'">
							<redirect-prev/>
						</xsl:when>
						<xsl:otherwise>
							<redirect><xsl:value-of select="$redirect-url"/></redirect>
						</xsl:otherwise>
					</xsl:choose>
				</cookie>
				<data>
					<backupm>
						<xsl:for-each select="$ids">
							<xsl:sort select="." order="descending"/>
							<remove>
								<!--<global/>-->
								<backup_id><xsl:value-of select="."/></backup_id>
								<options>
									<xsl:if test="$prev">									
										<prev/>									
									</xsl:if>
								</options>
							</remove>
						</xsl:for-each>
					</backupm>
				</data>
			</packet>
		</func:result>
	</func:function>
	
	<!-- Backup VE -->
	<func:function name="backups:new-action">
		<xsl:param name="backup-set"/> <!-- ref to nodeset of <backup><ve-eid/><backup-id/></backup-id></backup>  -->
		<xsl:param name="options"/>
		<xsl:param name="cookie" select="/.."/> <!-- Cookie custom content -->
		<xsl:param name="cmd" select="'backup'"/> <!-- Backup command, backup or renew -->
		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vt/backups/new.xsl'"/>
				<xsl:with-param name="cookie">
					<xsl:choose>
						<xsl:when test="$cmd='backup'">
							<msg>
								<sched><sw:text>The Containers have been scheduled for backing up.</sw:text></sched>
								<error><sw:text>Failed to back up the Containers.</sw:text></error>
							</msg>
							<operation>backup_ve</operation>
						</xsl:when>
						<xsl:when test="$cmd='renew'">
							<msg>
								<sched><sw:text>The Container backups have been scheduled for renewing.</sw:text></sched>
								<error><sw:text>Failed to renew the Container backups.</sw:text></error>
							</msg>
							<operation>backupm.renew_backup</operation>
						</xsl:when>
						<xsl:otherwise>
							<sw:die>
								Uknown backup command '<xsl:value-of select="$cmd"/>'
							</sw:die>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:copy-of select="$cookie"/>
					<xsl:if test="not($cookie)">
						<redirect-prev/>
					</xsl:if>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:copy-of select="$backup-set"/>
						<cmd>
							<xsl:value-of select="$cmd"/>
						</cmd>
						<options>
							<xsl:copy-of select="$options"/>
						</options>
					</data>
				</xsl:with-param>
			</xsl:call-template>			
		</func:result>
		
	</func:function>
	
	<!-- Restore Backup Storage Config -->
	<!--
		Arguments
			hn-eid 
		Result
			config - nodeset with backup storage config. Look vt/backups-core/<storage-config> for details.
	-->
	<func:function name="backups:get-storage-config">	
		<xsl:param name="hn-eid"/>
		
		<xsl:variable name="packet">
			<packet>
				<target>backup_storagem</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<data>
					<backup_storagem>
						<get_storage_config/>
					</backup_storagem>
				</data>
			</packet>
		</xsl:variable>
		
		<xsl:variable name="resp" select="sw:xchg($packet)/packet/data"/>
		<xsl:variable name="error" select="$resp/error|$resp/backup_storagem/error"/>
		
		<xsl:choose>
			<xsl:when test="$error">
				<func:result select="$error"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="config-rtf">
					<xsl:variable name="location" select="$resp/backup_storagem/config/location"/>
					<location>
						<type>
							<xsl:choose>
								<xsl:when test="$location/type='0'">
									<xsl:value-of select="'local'"/>
								</xsl:when>
								<xsl:when test="$location/type='1'">
									<xsl:value-of select="'share'"/>
								</xsl:when>
								<xsl:otherwise>
									<sw:die>
										Uknown location type [<xsl:value-of select='$location/type'/>]
									</sw:die>
								</xsl:otherwise>								
							</xsl:choose>
						</type>
						<local>
							<path><xsl:value-of select="sw:base64-decode($location/path)"/></path>
						</local>
						<share>
							<path><xsl:value-of select="sw:base64-decode($location/path)"/></path>							
							<login>
								<name><xsl:value-of select="sw:base64-decode($location/login/name)"/></name>
								<domain><xsl:value-of select="sw:base64-decode($location/login/domain)"/></domain>
								<password><xsl:value-of select="$location/password"/></password>
							</login>
						</share>
					</location>
				</xsl:variable>
				<func:result select="exsl:node-set($config-rtf)"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	<!-- Set Backup Storage Config -->
	<!--
		Arguments
			hn-eid 
			config - nodeset with backup storage config. Look vt/backups-core/<storage-config> for details.
		Result
			empty string or error message text.			
	-->
	<func:function name="backups:set-storage-config">	
		<xsl:param name="hn-eid"/>
		<xsl:param name="config"/>
		
		<xsl:variable name="packet">
			<packet  xmlns:nstypes="http://www.swsoft.com/webservices/vzl/4.0.0/types">
				<target>backup_storagem</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<data>
					<backup_storagem>
						<set_storage_config>
							<config>								
								<location>
									<xsl:variable name="location" select="$config/location"/>
									<type><xsl:value-of select="sw:if($location/type='local','0','1')"/></type>
									<xsl:choose>
										<xsl:when test="$location/type='local'">
											<path><xsl:value-of select="sw:base64-encode($location/local/path)"/></path>
										</xsl:when>
										<xsl:when test="$location/type='share'">
											<path><xsl:value-of select="sw:base64-encode($location/share/path)	"/></path>			
											<login xsi:type="nstypes:auth_nameType">
												<name><xsl:value-of select="sw:base64-encode($location/share/login/name)"/></name>
												<domain><xsl:value-of select="sw:base64-encode($location/share/login/domain)"/></domain>	
											</login>
											<password><xsl:value-of select="$location/share/login/password"/></password>
										</xsl:when>
										<xsl:otherwise>
											<sw:die>
												Uknown location type "<xsl:value-of select='$location/type'/>"
											</sw:die>
										</xsl:otherwise>
									</xsl:choose>								
								</location>
							</config>
						</set_storage_config>
					</backup_storagem>
				</data>
			</packet>
		</xsl:variable>
		
		<xsl:variable name="resp" select="sw:xchg($packet)/packet/data"/>
		<xsl:variable name="error" select="$resp/error|$resp/backup_storagem/error"/>
		
		<xsl:choose>
			<xsl:when test="$error">
				<func:result select="$error/message"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	<!--
		Load backup core options for specified HN.
		Public Arguments
			hn-eid
		Internal Arguments
			global
		Result
			options - nodeset with backup core options. Look vt/backups-core/<core-options> for details.
				or
			empty nodeset - in case of absent HN config
				or
			ref to <error> node
	-->
	<func:function name="backups:get-core-options">	
		<xsl:param name="hn-eid"/>
		<xsl:param name="global" select="false()"/>		
				
		<xsl:variable name="packet">
			<packet>
				<target>backupm</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<data>
					<backupm>
						<get_config>
							<xsl:if test="not($global)">
								<local/>
							</xsl:if>
						</get_config>
					</backupm>
				</data>
				<!-- Skip auth -->
				<vzcpauth/>
			</packet>
		</xsl:variable>
		
		<xsl:variable name="resp" select="sw:xchg($packet)/packet/data"/>
		<xsl:variable name="error" select="$resp/error|$resp/backupm/error"/>
		
		<xsl:choose>
			<!--- Error 308 is not error itself. It means no config. -->
			<xsl:when test="$error and $error/code='308'">
				<xsl:choose>
					<xsl:when test="not($global)">
						<func:result select="backups:get-core-options($hn-eid,true())"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="/.."/>					
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!--- Unexpected error. -->
			<xsl:when test="$error">
				<func:result select="$error"/>
			</xsl:when>			
			<xsl:otherwise>
				<xsl:variable name="config" select="$resp/backupm/backupm_config"/>
				<!-- Convert VZA config to VZCP core options -->
				<xsl:variable name="converted-options-rtf">
					<xsl:if test="$global">
						<global/>
					</xsl:if>
					<limits>
						<backups-per-ve><xsl:value-of select="$config/pe_backups_limit"/></backups-per-ve>
					</limits>
					<incremental>
						<chain-length>
							<xsl:value-of select="sw:if($config/chain_length='0','',$config/chain_length)"/>
						</chain-length>
						<chain-days>
							<xsl:value-of select="sw:if($config/chain_days='0','',$config/chain_days)"/>
						</chain-days>
					</incremental>
					<defaults>
						<backup-type><xsl:value-of select="$config/type"/></backup-type>	
						<compression-level><xsl:value-of select="$config/compression"/></compression-level>	
						<storage-server-eid>
							<xsl:if test="$config/backup_server[protocol='agent' and address!='' and address!='local']">
								<xsl:value-of select="$config/backup_server/address"/>
							</xsl:if>
						</storage-server-eid>				
					</defaults>
					<other-raw-data>
						<xsl:copy-of select="$config/*[not(
							self::type or self::compression or self::backup_server or self::pe_backups_limit
						)]"/>
					</other-raw-data>
				</xsl:variable>
				<!-- Return data -->
				<func:result select="exsl:node-set($converted-options-rtf)"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	<!--
		Set backup core options on specified HN.
		Arguments
			hn-eid
			options - nodeset with backup core options. Look vt/backups-core/<core-options> for details.
		Result
			empty string or error message text.
	-->	
	<func:function name="backups:set-core-options">	
		<xsl:param name="hn-eid"/>
		<xsl:param name="options"/>
				
		<xsl:variable name="packet">
			<packet
				xmlns:xsi							="http://www.w3.org/2001/XMLSchema-instance"
				xmlns:vzat						="http://www.swsoft.com/webservices/vzl/4.0.0/types"
				xmlns:vzab						="http://www.swsoft.com/webservices/vzl/4.0.0/backupm" 	
			>
				<target>backupm</target>
				<xsl:copy-of select="sw:hn-dst($hn-eid)"/>
				<data>
					<vzab:backupm>
						<vzab:set_config>
							<xsl:if test="$options">
								<vzab:backupm_config>										
									<!-- Convert VZCP core options to VZA config -->
									<vzab:pe_backups_limit><xsl:value-of select="$options/limits/backups-per-ve"/></vzab:pe_backups_limit>
									<vzab:chain_days><xsl:value-of select="local:empty2zero($options/incremental/chain-days)"/></vzab:chain_days>
									<vzab:chain_length><xsl:value-of select="local:empty2zero($options/incremental/chain-length)"/></vzab:chain_length>
									<vzab:type><xsl:value-of select="$options/defaults/backup-type"/></vzab:type>	
									<vzab:compression><xsl:value-of select="$options/defaults/compression-level"/></vzab:compression>						
									<vzab:backup_server xsi:type="vzat:connection_infoType">
										<xsl:choose>
											<xsl:when test="$options/defaults/storage-server-eid!=''">
												<vzab:protocol>agent</vzab:protocol>
												<vzab:address><xsl:value-of select="$options/defaults/storage-server-eid"/></vzab:address>
											</xsl:when>
											<xsl:otherwise>
												<vzab:protocol>agent</vzab:protocol>
												<vzab:address>local</vzab:address>											
											</xsl:otherwise>
										</xsl:choose>
									</vzab:backup_server>										
									<xsl:copy-of select="$options/other-raw-data/*"/>
									<!-- / Convert VZCP core options to VZA config -->
								</vzab:backupm_config>
							</xsl:if>
						</vzab:set_config>
					</vzab:backupm>
				</data>
				<vzcpauth/>
			</packet>
		</xsl:variable>
		
		<xsl:variable name="resp" select="sw:xchg($packet)/packet/data"/>
		<xsl:variable name="error" select="$resp/error|$resp/backupm/error"/>
		
		<xsl:choose>
			<xsl:when test="$error">
				<func:result select="$error/message"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	<func:function name="local:empty2zero">
		<xsl:param name="value"/>
		<func:result select="sw:if(not($value!=''),'0',$value)"/>
	</func:function>
	<!-- /Set backup core options on specified HN. -->
	
	<!--
		Find actual(local or global) backup core options for specified HN. 
		Arguments
			hn-eid
		Result identical to backups:get-core-options.
	-->
	<func:function name="backups:find-actual-core-options">	
		<xsl:param name="hn-eid"/>
		
		<xsl:variable name="hn-local-options" select="backups:get-core-options($hn-eid,true())"/>
		<xsl:choose>
			<!-- Return HN local options -->
			<xsl:when test="$hn-local-options">
				<func:result select="$hn-local-options"/>
			</xsl:when>
			<!-- Return global options -->			
			<xsl:when test="$hn-eid!=sw:master-eid()">
				<func:result select="backups:get-core-options(sw:master-eid())"/>
			</xsl:when>
			<!-- No options for local master HN -->						
			<xsl:otherwise>
				<func:result select="/.."/>				
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
		<!--
		Find actual(local or global) backup core options for specified HN. 
		Arguments
			hn-eid
		Result 
			<count>
				or
			<error>
	-->
	<func:function name="backups:find-actual-ve-limit">	
		<xsl:param name="hn-eid"/>
		
		<xsl:variable name="core-options" select="backups:find-actual-core-options($hn-eid)"/>

		<func:result select="sw:if($core-options[self::error],$core-options,$core-options/limits/backups-per-ve)"/>
	
	</func:function>
	
	
	<!--
		Calculated existed backup counts for specified VE 
		Arguments
			ve-eid
		Result 
			count
	-->
	<func:function name="backups:calc-backups-count-for-ve">	
		<xsl:param name="ve-eid"/>

		<sw:die test="not($ve-eid!='')">
			VE eid should be specified.
		</sw:die>
		
		<xsl:variable name="req">
			<fields>
				<backup.eid/>
			</fields>
			<count/>
			<where>
				pager.backup.eid='<xsl:value-of select="$ve-eid"/>'
			</where>
		</xsl:variable>
		<func:result select="sw:xchg-sql($req)//count"/>
	</func:function>
	
	<!--
		Find last VE backup 
		Arguments
			ve-eid
		Result 
			nodeset
				id
				size
				time
				count
	-->
	<func:function name="backups:find-last-for-ve">	
		<xsl:param name="ve-eid"/>

		<sw:die test="not($ve-eid!='')">
			VE eid should be specified.
		</sw:die>
		
		<xsl:variable name="req">
			<fields>
				<backup.id/>
				<backup.size/>
				<backup.time/>	
				<backup.count/>	
			</fields>
			<where>
				(pager.backup.eid='<xsl:value-of select="$ve-eid"/>' and pager.backup.latest=1)
			</where>
		</xsl:variable>
		<func:result select="sw:xchg-sql($req)/pager/row_set/row/backup"/>
	</func:function>	
	
</xsl:stylesheet>
