<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.

	Public API
	
		backups:edit-core-options
		backups:restore-core-options
		backups:check-core-options

		backups:get-vzpp-limits-warning()
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func voc backups local"
  xmlns:xsl					="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl				="http://exslt.org/common"
  xmlns:func				="http://exslt.org/functions"
  xmlns:sw					="http://www.swsoft.com/xsl/cp"
	xmlns:cred				="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc					="http://www.swsoft.com/xsl/cp/voc"	
	xmlns:check				="http://www.swsoft.com/xsl/cp/check"		
	xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"
  xmlns:backups			="http://www.swsoft.com/xsl/cp/backups"		
  xmlns:hn					="http://www.swsoft.com/xsl/cp/hn"	
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"
 	xmlns:form				="http://www.swsoft.com/xsl/cp/form"  
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
>

	<sw:include href="/lib/cred-filter.xsl"/>
	<sw:include href="/layout/forms-list.xsl"/>
  <sw:include href="/lib/vt/backups-core.xsl"/>
 	<sw:include href="/lib/vt/hn-select.xsl"/>
 	
 	<!--
		Post UI control for backup options.
		Arguments:
			options - nodeset with backup core options. Look vt/backups-core.xsl/core-options/defaults for details.
		Result
			RTF with ui:* XML data
	-->
	<xsl:template name="backups:edit-backup-options">
		<xsl:param name="options"/>	
		<xsl:param name="force-hn-eid" select="''"/>			
		<xsl:param name="show-server-default" select="false()"/>	
	
		<ui:row>
			<ui:cell-label>
				<sw:text>Backup Type</sw:text>
			</ui:cell-label>
			<ui:cell-list id="backup_type" value="{$options/backup-type}" style="width:300px">			
				<xsl:if test="$show-server-default">
					<ui:list-item id="" title="{sw:text('Use Hardware Node Settings')}"/>				
				</xsl:if>
				<xsl:for-each select="backups:backup-types()">
					<ui:list-item id="{@value}" title="{@title}"/>
				</xsl:for-each>				
			</ui:cell-list>
		</ui:row>
		<ui:row>
			<ui:cell-label>
				<sw:text>Compression Level</sw:text>
			</ui:cell-label>
			<ui:cell-list id="compression_level" value="{$options/compression-level}" style="width:300px">
				<xsl:if test="$show-server-default">
					<ui:list-item id="" title="{sw:text('Use Hardware Node Settings')}"/>				
				</xsl:if>
				<xsl:if test="not($show-server-default)">
					<ui:list-item id="" title="&lt;{sw:text('System Default')}&gt;"/>
				</xsl:if>
				<xsl:for-each select="backups:compression-levels()/level">
					<ui:list-item id="{@id}" title="{@title}"/>
				</xsl:for-each>
			</ui:cell-list>
		</ui:row>
		<ui:row>
			<ui:cell-label>
				<sw:text>Backup Node</sw:text>
			</ui:cell-label>
			<xsl:choose>
				<xsl:when test="$force-hn-eid!=''">
					<xsl:variable name="hn" select="env:eid2info($force-hn-eid)"/><!-- todo: filter by VT type -->				
					<ui:cell-text>
						<xsl:choose>
							<xsl:when test="$hn/title!=''">
								<xsl:value-of select="$hn/title"/>
							</xsl:when>
							<xsl:otherwise>
								<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0"/>&#160;
								<sw:text>Unknown Hardware Node</sw:text>
							</xsl:otherwise>
						</xsl:choose>
						<ui:hidden name="storage_server_eid" value="{$force-hn-eid}"/>
					</ui:cell-text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="hn-list" select="hn:list()"/><!-- todo: filter by VT type -->	
					<ui:cell-list id="storage_server_eid" value="{$options/storage-server-eid}" style="width:300px">
						<xsl:if test="$show-server-default">
							<ui:list-item id="" title="{sw:text('Use Hardware Node Settings')}"/>				
						</xsl:if>
						<xsl:if test="not($show-server-default)">				
							<ui:list-item id="" title="&lt;{sw:text('Store backups on the same server')}&gt;"/>
						</xsl:if>
						<xsl:if test="count($hn-list/hn) &gt; 0">
							<xsl:variable name="valid-hn-eids"
								select="cred:filter-valid-env('vzcp.hn.backups.store',$hn-list/hn/eid,false())"/>
							<xsl:for-each select="$hn-list/hn[string(eid)=$valid-hn-eids]">
								<xsl:sort select="hostname"/>
								<ui:list-item id="{eid}">
									<xsl:attribute name="title">
										<xsl:value-of select="hostname"/>
									</xsl:attribute>
								</ui:list-item>
							</xsl:for-each>
						</xsl:if>
					</ui:cell-list>
				</xsl:otherwise>
			</xsl:choose>
		</ui:row>				
	</xsl:template>		
	
	
 	<!--
		Post UI control for backup include or exclude path options.
		Arguments:
			data : nodeset with backup path options
				hidden : 'true'/'false'
				system : 'true'/'false'		
				path[]		
			list-type: 'exclude' or 'include'
			allow-exclude-system-and-hidden 	: true/false, allow user to use 'Exclude hidden/system files' option.							
			ve-eid 									: The EID of one backuped VE. (optional)
			show-ve-paths-selector 	: true/false, show link to File Selector Popup. (optional)			
		Result
			RTF with ui:* XML data
	-->
	<xsl:template name="backups:edit-backup-paths">
		<xsl:param name="data"/>	
		<xsl:param name="list-type"/>	
		<xsl:param name="allow-exclude-system-and-hidden" select="false()"/>	
		<xsl:param name="show-system-and-hidden-warning" select="true()"/>			
		<xsl:param name="ve-eid" select="''"/>			
		<xsl:param name="show-ve-paths-selector" select="false()"/>	
		
		<xsl:variable name="list-excl" select="$list-type='exclude'"/>
					
		<xsl:if test="$allow-exclude-system-and-hidden">
			<xsl:if test="$show-system-and-hidden-warning">
				<ui:row>
					<ui:cell-text>
						<sw:text>
							The following two options will be used for backing up Windows Containers only.
						</sw:text>
					</ui:cell-text>
				</ui:row>	
			</xsl:if>				
			<ui:row>
				<ui:cell-check id="excl_hidden" close="false">
					<xsl:if test="$data/hidden='true'">
						<xsl:attribute name="checked">true</xsl:attribute>
					</xsl:if>
				</ui:cell-check>
				<ui:cell open="false"> &#160;<sw:text>Exclude hidden files</sw:text>
				</ui:cell>
			</ui:row>
			<ui:row>
				<ui:cell-check id="excl_system" close="false">
					<xsl:if test="$data/system='true'">
						<xsl:attribute name="checked">true</xsl:attribute>
					</xsl:if>
				</ui:cell-check>
				<ui:cell open="false"> &#160;<sw:text>Exclude system files</sw:text>
				</ui:cell>
			</ui:row>
		</xsl:if>

		<ui:row>
			<ui:cell>
				<xsl:choose>
					<xsl:when test="$list-excl">
						<sw:text>
							Specify the paths to exclude from the backup process.
						</sw:text>
					</xsl:when>
					<xsl:otherwise>
						<sw:text>
							Specify the paths to be backed up or leave the field empty to back up the whole Container.
						</sw:text>
					</xsl:otherwise>
				</xsl:choose>
			</ui:cell>
		</ui:row>
		<xsl:call-template name="form:show-list">
			<xsl:with-param name="config">
				<code><xsl:value-of select="$list-type"/>paths</code>
				<add_label>
					<sw:text>Add a new path.</sw:text>
				</add_label>
				<remove_label>
					<sw:text>Remove this path.</sw:text>
				</remove_label>
				<xsl:for-each select="$data/path">
					<ui:row>
						<ui:cell-input nowrap="1" width="40" maxlength="200"
							id="path" value="{.}" tip="backup_{$list-type}_path"
							process-node="true">
							<xsl:if test="$show-ve-paths-selector and $ve-eid!=''">
								&#160;&#160;&lt;a href="#" onclick="open_details('<xsl:value-of
								select="$baseurl"
								/>/vzdir/infrman/envs/files/selector-popup?mod=start&amp;dst-control=??id??&amp;base=<xsl:value-of
								select="$ve-eid"
								/>&amp;select-folders=true&amp;select-files=true','<xsl:value-of select="$list-type"/>',540,850);return
								false;"
								&gt;<sw:text>Browse</sw:text>&lt;/a&gt;&#160;&#160;
							</xsl:if>
						</ui:cell-input>
					</ui:row>
				</xsl:for-each>
				<ui:new-row>
					<ui:cell-input width="40" nowrap="1" maxlength="200" id="path"
						value="" tip="backup_{$list-type}_path" process-node="true">
							<xsl:if test="$show-ve-paths-selector  and $ve-eid!=''">
							&#160;&#160;&lt;a href="#"
								onclick="open_details('<xsl:value-of select="$baseurl"
								/>/vzdir/infrman/envs/files/selector-popup?mod=start&amp;dst-control=??id??&amp;base=<xsl:value-of
								select="$ve-eid"
							/>&amp;select-folders=true&amp;select-files=true','<xsl:value-of select="$list-type"/>',540,850);return
							false;"
							&gt;<sw:text>Browse</sw:text>&lt;/a&gt;&#160;&#160;
						</xsl:if>
					</ui:cell-input>
				</ui:new-row>
			</xsl:with-param>
		</xsl:call-template>

	</xsl:template> 	
 	
 	<!-- Restore Backup Excludes form -->
 	<xsl:template name="backups:restore-backup-paths">
 		<xsl:param name="list-type"/>	
 		
		<xsl:if test="sw:param('excl_hidden')='1'">
			<hidden>true</hidden>
		</xsl:if>
		<xsl:if test="sw:param('excl_system')='1'">
			<system>true</system>
		</xsl:if>
		<xsl:call-template name="form:restore-list">
			<xsl:with-param name="code" select="concat($list-type,'paths')"/>
			<xsl:with-param name="row-node-name" select="''"/>
		</xsl:call-template>								
	</xsl:template>
 	
 	
	<!--
		Post UI control for HN backups core options.
		Arguments:
			options - nodeset with backup core options. Look vt/backups-core/<core-options> for details.
			visible - Are UI controls visible?  true[default]/false
		Result
			RTF with ui:* XML data
	-->
	<xsl:template name="backups:edit-core-options">
		<xsl:param name="options"/>
		<xsl:param name="visible" select="true()"/>
	
	
		<!-- Default Backup Options -->
		<ui:rows
			div_id="div_core_defaults" div_display="{sw:if($visible,'block','none')}"
		>
			<xsl:attribute name="title">
				<sw:text>Default Backup Options</sw:text>
			</xsl:attribute>
			<xsl:call-template name="backups:edit-backup-options">
				<xsl:with-param name="options" select="$options/defaults"/>
			</xsl:call-template>
		</ui:rows>
		<!-- /Default Backup Options -->		
		
		<!-- Limits  -->
		<ui:rows
			div_id="div_core_limits" div_display="{sw:if($visible,'block','none')}"
		>
			<xsl:attribute name="title">
				<sw:text>Number of Backups Available From Parallels Power Panel</sw:text>
			</xsl:attribute>
			<ui:row>
				<ui:cell-label>
					<sw:text>Number of Backups per Container</sw:text>
				</ui:cell-label>
				<ui:cell-input id="limits_backups_per_ve" maxlength="5" width="5" value="{$options/limits/backups-per-ve}"/>
			</ui:row>
		</ui:rows>
		<!-- /Limits  -->
		
		<!-- Incremental Options  -->
		<ui:rows
			div_id="div_core_incremental" div_display="{sw:if($visible,'block','none')}"
		>
			<xsl:attribute name="title">
				<sw:text>Incremental Backup Settings</sw:text>
			</xsl:attribute>
			<ui:row>
				<ui:cell-check id="incremental_chain_length_limited" 
					checked="{$options/incremental/chain-length-enabled or $options/incremental/chain-length!=''}" 
					colspan="2"
				>
					<ui:control-slave>incremental_chain_length</ui:control-slave>
					&#160;<sw:text>
						Limit the maximum number of incremental backups before creating a new full backup
					</sw:text>
				</ui:cell-check>
			</ui:row>
			<ui:row>
				<ui:cell-input offset="4" id="incremental_chain_length" maxlength="5" width="5" value="{$options/incremental/chain-length}"/>	
				<ui:cell-text cell-width="100%">
					<sw:text>Maximum backups chain length (includes one full backup)</sw:text>
				</ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-check id="incremental_chain_days_limited" 
					checked="{$options/incremental/chain-days-enabled or $options/incremental/chain-days!=''}" 
					colspan="2"
				>
					<ui:control-slave>incremental_chain_days</ui:control-slave>
					&#160;<sw:text>
						Limit the maximum period of time before creating a new full backup
					</sw:text>
				</ui:cell-check>
			</ui:row>
			<ui:row>
				<ui:cell-input offset="4" id="incremental_chain_days" maxlength="5" width="5" value="{$options/incremental/chain-days}"/>	
				<ui:cell-label cell-width="100%">
					<sw:text>Period (in days)</sw:text>
				</ui:cell-label>
			</ui:row>
		</ui:rows>
		<!-- / Incremental Options   -->
	
	</xsl:template>
	
	

	<!--
		Read form data contains backup options.
		Result
			options  - RTF with backup options. Look vt/backups-core/<core-options>/default for details.
	-->
	<xsl:template name="backups:restore-backup-options">	
	
		<compression-level>
			<xsl:value-of select="sw:param('compression_level')"/>
		</compression-level>
		<backup-type>
			<xsl:value-of select="sw:param('backup_type')"/>
		</backup-type>
		<storage-server-eid>
			<xsl:value-of select="sw:param('storage_server_eid')"/>
		</storage-server-eid>

	</xsl:template>	

	<!--
		Read form data contains HN backup core options.
		Result
			options  - RTF with backup core options. Look vt/backups-core/<core-options> for details.
	-->
	<xsl:template name="backups:restore-core-options">	
		<xsl:param name="old-options"/>
	
		<limits>
			<backups-per-ve>
				<xsl:value-of select="sw:param('limits_backups_per_ve')"/>
			</backups-per-ve>
		</limits>
		<incremental>
		
			<xsl:choose>
				<xsl:when test="sw:param('incremental_chain_length_limited')">
					<chain-length-enabled/>
					<chain-length>
						<xsl:value-of select="sw:param('incremental_chain_length')"/>
					</chain-length>
				</xsl:when>
				<xsl:otherwise>
					<chain-length/>
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:choose>
				<xsl:when test="sw:param('incremental_chain_days_limited')">
					<chain-days-enabled/>
					<chain-days>
						<xsl:value-of select="sw:param('incremental_chain_days')"/>
					</chain-days>
				</xsl:when>
				<xsl:otherwise>
					<chain-length/>
				</xsl:otherwise>
			</xsl:choose>

		</incremental>
		<defaults>
			<xsl:call-template name="backups:restore-backup-options"/>
		</defaults>
		
		<xsl:copy-of select="$old-options/other-raw-data"/>
	</xsl:template>
	
	<!--
		Check backup core options. Uses error:put() for error posting.
		Arguments:
			options - nodeset with backup core options. Look vt/backups-core/<core-options> for details.
		Result
			none
	-->
	<func:function name="backups:check-core-options">
		<xsl:param name="options"/>
	
		<!-- check limit-backups-per-ve -->
		<xsl:choose>
			<!-- empty -->
			<xsl:when test="$options/limits/backups-per-ve=''">
				<xsl:if test="error:put(sw:text('The backup limit should be a positive number.'),'','limits_backups_per_ve')"/>			
			</xsl:when>
			<!-- is num-->				       
			<xsl:when test="not(check:num($options/limits/backups-per-ve)) or number($options/limits/backups-per-ve) &lt; 0">
				<xsl:if test="error:put(sw:text('The backup limit should be a positive number.'),'','limits_backups_per_ve')"/>
			</xsl:when>				       
		</xsl:choose>
		
		<!-- check incremental options -->
		<xsl:if test="$options/incremental/chain-length-enabled and not(check:num($options/incremental/chain-length))">
			<xsl:if test="error:put(sw:text('The maximum number should be a positive number.'),'','incremental_chain_length')"/>		
		</xsl:if>
		<xsl:if test="$options/incremental/chain-days-enabled and not(check:num($options/incremental/chain-days))">
			<xsl:if test="error:put(sw:text('The days limit should be a positive number.'),'','incremental_chain_days')"/>		
		</xsl:if>
		<!-- /check incremental options -->

		
		<func:result select="error:has-errors()"/>
	</func:function>
	
	<!-- Check VE backups limits and return a message.
		Arguments
			backups-limit - maximum backups-per-ve limit		
			backups-count - precalculated count of existed backups. Default is empty string.
			compact-mode - should message be compact?. Default is false.
		Result
			text message with html tags.
	-->
	<func:function name="backups:get-vzpp-limits-warning">
		<xsl:param name="backups-limit" select="''"/><!-- REQUIRED FIELD -->	
		<xsl:param name="backups-count" select="''"/>
		<xsl:param name="compact-mode" select="false()"/>
		<xsl:param name="allow-renew" select="true()"/>	
		
		<sw:die test="$backups-limit=''">
			backups-limit argument should be filled.
		</sw:die>
		
		<xsl:variable name="count">
			<xsl:choose>
				<!-- Use count passed as function argument -->
				<xsl:when test="$backups-count!=''">
					<xsl:value-of select="$backups-count"/>
				</xsl:when>
				<!-- Calc count -->				
				<xsl:otherwise>
					<xsl:value-of select="backups:calc-backups-count-for-ve(sw:ve-eid())"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="icon-warning">
			<xsl:if test="not($compact-mode)">
				<br/>
				<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16" border="0"
				/>&#160;
			</xsl:if>
		</xsl:variable>
		
		<xsl:variable name="icon-problem">
			<xsl:if test="not($compact-mode)">
				<br/>		
				<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0"
				/>&#160;
			</xsl:if>
		</xsl:variable>
		
		<func:result>
			<xsl:choose>
				<!-- Uknown limits -->
				<xsl:when test="not($backups-limit) or $backups-limit[self::error]">
					<xsl:copy-of select="$icon-problem"/>
					<sw:text>
						Cannot create a new backup due to system error cp1301.
					</sw:text>
				</xsl:when>
				<!-- Unlimited -->
				<xsl:when test="$backups-limit=''">
				</xsl:when>
				<!-- Limited, no backups allowed, limit is 0 -->
				<xsl:when test="$backups-limit = 0">
					<xsl:copy-of select="$icon-warning"/>
					<sw:text>The backup creation is not allowed.</sw:text>&#160;
					<sw:text>You can only delete old backup(s) or restore Container(s) from it/them.</sw:text>
				</xsl:when>
				<!-- Limited, but no any existed backups -->			
				<xsl:when test="$count = 0 and not($compact-mode)">
					<sw:text>
						<xsl:with-param name="max" select="$backups-limit"/>
						No backups created yet. You can create a maximum of %max backup(s). 
					</sw:text>
				</xsl:when>
				<!-- exact number of available backups created -->
				<xsl:when test="$backups-limit = $count">
					<xsl:copy-of select="$icon-warning"/>
					<sw:text>
						You have reached the maximum of the allowed number of backups. To make a new backup, you should either remove or renew an existing one.
					</sw:text>
				</xsl:when>
				<!-- Limited, but limit has not reached yet  -->
				<xsl:when test="number($backups-limit) &gt; number($count)">
				</xsl:when>
				<!-- Other cases -->
				<xsl:otherwise>
					<xsl:copy-of select="$icon-warning"/>
					<sw:text>
						You have reached the maximum of the allowed number of backups.
					</sw:text>
					<sw:text>
						To make a new backup, you should remove an existing one.
					</sw:text>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
		
	</func:function>

</xsl:stylesheet>
