<!-- Copyright (c) SWsoft, 1999-2007 All rights reserved. -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func browse backups voc cred vt local"
  xmlns:xsl						="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl					="http://exslt.org/common"
  xmlns:sw						="http://www.swsoft.com/xsl/cp"
  xmlns:func					="http://exslt.org/functions" 
  xmlns:env						="http://www.swsoft.com/xsl/cp/env"
  xmlns:ui						="http://www.swsoft.com/xsl/cp/ui"
  xmlns:cred					="http://www.swsoft.com/xsl/cp/cred"
  xmlns:voc						="http://www.swsoft.com/xsl/cp/voc"
  xmlns:local					="http://www.swsoft.com/xsl/cp/local"
  xmlns:global				="http://www.swsoft.com/xsl/cp/global"    
  xmlns:vt						="http://www.swsoft.com/xsl/cp/vt"
  xmlns:backups				="http://www.swsoft.com/xsl/cp/backups"
  xmlns:browse				="http://www.swsoft.com/xsl/cp/browse"
>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/core/browse-filter-vza.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include	href="/lib/vt/core.xsl"/> 
	<sw:include	href="/lib/vt/env-core.xsl"/> 
	<sw:include href="/lib/vt/backups-core.xsl"/>	
	
 	<xsl:template name="backups:get-browse-cols">
		<ui:column id="eid" vza-id="backup.eid" for-url="yes" hidden="yes"/>
		<ui:column id="backup-ve-title" post-apply-templates="no"
			vza-id="backup.info.title" show-url="yes" filter="auto" title="{sw:text('Container Name')}"
		/>	
		<ui:column id="backuped" vza-id="backup.time" data-type="datetime" filter="interval"
			filter-from-title="{sw:text('Last Backup From')}"
			filter-to-title="{sw:text('Last Backup To')}"
			filter-from-tip="backup_from_filter"
			filter-to-tip="backup_to_filter"
			title="{sw:text('Last Backup')}"/>
 		<ui:column id="parent-eid" vza-id="backup.info.parent_eid" hidden="yes"/>
 		<ui:column id="storage-eid" vza-id="backup.storage_eid" hidden="yes"/>
<!-- XXX: temporray disable, until fix of #78450
				<ui:column id="size" vza-id="backup.size" data-type="int" display-type="size/byte" title="{sw:text('Total Size')}"/>
-->				
		<ui:column id="storage-node" vza-id="backup.info.storage.title" title="{sw:text('Backup Node')}" filter="auto"/>
		<ui:column id="num" vza-id="backup.count" data-type="int" title="{sw:text('Total Backups')}"/>
		<ui:column id="id" vza-id="backup.id" hidden="yes" for-select="yes" for-url="yes"/>

	</xsl:template>
	
 	<xsl:template name="backups:get-single-ve-browse-cols">
		<ui:column id="eid" vza-id="backup.eid" for-url="yes" hidden="yes"/>
		<ui:column id="backuped" vza-id="backup.time" data-type="datetime" filter="interval"
			nav-type="id" for-url="no" 
			filter-from-title="{sw:text('Backed Up from')}"
			filter-to-title="{sw:text('Backed Up to')}"
			filter-from-tip="backup_from_filter"
			filter-to-tip="backup_to_filter"
			title="{sw:text('Backed Up')}"
		/>
		<xsl:if test="$activeMode = 'vzcc'">		
			<ui:column id="env-parent" vza-id="backup.info.storage.title" title="{sw:text('Backup Node')}" filter="auto"/>		
		</xsl:if>			
		<ui:column id="size" vza-id="backup.size" data-type="int" display-type="size/byte" title="{sw:text('Size')}"/>
		<ui:column id="description" vza-id="backup.description" title="{sw:text('Description')}"/>
		<ui:column id="id" vza-id="backup.id" hidden="yes" for-select="yes" for-url="yes"/>
		<ui:column id="ve-backup-type" vza-id="backup.type" title="{sw:text('Backup Type')}" filter="select" apply-templates="yes">
			<xsl:copy-of select="backups:backup-types()"/>
		</ui:column>
	</xsl:template>	

	<xsl:template name="backups:fill-filter">
		<xsl:param name="filter-rtf"/>			
		<xsl:param name="filter-hn-eid" select="''"/>		
		<xsl:param name="filter-ve-eid" select="''"/>			
		<xsl:param name="filter-dn" select="''"/>
		
		<xsl:call-template name="browse:fill-from-vza">
			<xsl:with-param name="filter" select="exsl:node-set($filter-rtf)"/>
			<xsl:with-param name="sql-where">
				<xsl:variable name="conditions">		
					<xsl:if test="$filter-hn-eid!=''">
						<cond>
					   	(pager.backup.info.parent_eid='<xsl:value-of select="sw:sql-escape($filter-hn-eid)"/>') 
					   	  OR
					   	(pager.backup.storage_eid='<xsl:value-of select="sw:sql-escape($filter-hn-eid)"/>')
						</cond>
					</xsl:if>
					<xsl:if test="$filter-ve-eid!=''">
						<cond>pager.backup.eid='<xsl:value-of select="sw:sql-escape($filter-ve-eid)"/>'</cond>
					</xsl:if>
					<xsl:if test="$filter-dn!='' and not(units:are-dns-equal($filter-dn, units:infra-top-dn()))">				
						<cond>pager.env.eid in (unit '<xsl:value-of select="sw:sql-escape(units:decode-dn($filter-dn))"/>',recursive)</cond>
					</xsl:if>
					<xsl:if test="$filter-ve-eid=''">
						<cond>pager.backup.latest=1</cond>
					</xsl:if>
				</xsl:variable>
				<xsl:for-each select="exsl:node-set($conditions)/cond">
					<xsl:if test="position() != 1">
					  <xsl:text> AND </xsl:text>
					</xsl:if>
					<xsl:value-of select="concat('(', ., ')')"/>
				</xsl:for-each>
			</xsl:with-param>
			<xsl:with-param name="forward-to-master">
				<xsl:value-of select="true()"/>
			</xsl:with-param>
		</xsl:call-template>	
	</xsl:template>

	<xsl:template name="local:post-single-ve-browse">		
		<xsl:param name="filter"/>
		<xsl:param name="new-allowed" select="false()"/>				
		<xsl:param name="renew-allowed" select="false()"/>		
		<xsl:param name="restore-allowed" select="false()"/>
		<xsl:param name="remove-allowed" select="false()"/>
				
		<ui:browse title="{sw:text('Backups')}">
		
			<ui:browse-js-array name="renew">
				<ui:warn>
					<sw:text>You can renew only full backups.</sw:text>
				</ui:warn>
				<xsl:for-each select="$filter/ui:browse-rows/ui:row[ve-backup-type!=$global:backup-full]/id">
					<ui:value>
						<xsl:value-of select="."/>
					</ui:value>
				</xsl:for-each>
			</ui:browse-js-array>

			<ui:browse-js-many>
				<ui:warn>
					<sw:text>Select at least one backup!</sw:text>
				</ui:warn>
			</ui:browse-js-many>
			
			<ui:browse-js-one>
				<ui:warn>
					<sw:text>Please select one Container backup!</sw:text>
				</ui:warn>
			</ui:browse-js-one>
			
			<ui:browse-empty-msg><sw:text>No backups.</sw:text></ui:browse-empty-msg>
			
			<ui:filter>
				<xsl:copy-of select="$filter"/>
			</ui:filter>
	
			<ui:browse-buttons type="list-selection">
			
				<ui:button tip="backup_ve" sandclock="false" icon="backup_new"
					submit-href="{$baseurl}/vt/backups/new?cmd=backup&amp;env-set=current"
					disabled="{boolean(not($new-allowed))}" require-items="false"
					new-obj-title="{sw:text('Backup')}"
				>
					<sw:text>New Backup</sw:text>
				</ui:button>
				<ui:button tip="renew_selected_backup" sandclock="false" icon="backup_renew"
					script="if(!onlyOne() || !check_renew_array()) return false;"
					submit-href="{$baseurl}/vt/backups/new?cmd=renew&amp;backup-set=selected-multi" name="renew"
					disabled="{boolean(not($renew-allowed))}"
				>
					<sw:text>Renew Backup</sw:text>
				</ui:button>
				<ui:button tip="restore_ves" sandclock="false" icon="backup_restore" 
					submit-href="{$baseurl}/vt/backups/restore?id-src=post" 
					script="if (!onlyOne()) return false;" name="confirm_restore" width="150"
					disabled="{boolean(not($restore-allowed))}"
				>
					<sw:text>Restore Container</sw:text>
				</ui:button>
				<ui:button type="list-selection" tip="delete_backups" 
					icon="delete" submit-href="{$baseurl}/vt/backups/list-control?cmd=remove" 
					confirmation="{sw:text('Are you sure you want to delete the selected backup(s)?')}" 
					script="if (!atLeastOne()) return false;" name="remove_selected" width="150"
					disabled="{boolean(not($remove-allowed))}"					
				>
					<sw:text>Remove Backups</sw:text>
				</ui:button>
			</ui:browse-buttons>

		</ui:browse>
	</xsl:template>

	<!--======================================== PUBLIC FUNCTIONS =====================================-->
		
	<xsl:template name="backups:browse">
		<xsl:param name="browse-url"/>
		<xsl:param name="filter-hn-eid" select="''"/>
		<xsl:param name="filter-dn" select="''"/>
		<xsl:param name="first-buttons" select="/.."/>	
		
		<xsl:variable name="filter-rtf">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="vt-backups" url="{$browse-url}" item-url="/vz/ves/backups/index?context=current"
						item-url-tip="ve_backups" items-title="{sw:text('Backups')}"
					/>
					<ui:cols sorting-col="backup-ve-title" sorting-direction="desc">
						<xsl:call-template name="backups:get-browse-cols">
						</xsl:call-template>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>    
		<xsl:variable name="filter-data-rtf">
			<xsl:call-template name="backups:fill-filter">
				<xsl:with-param name="filter-rtf" select="$filter-rtf"/>
				<xsl:with-param name="filter-dn" select="$filter-dn"/>		
				<xsl:with-param name="filter-hn-eid" select="$filter-hn-eid"/>
			</xsl:call-template>
		</xsl:variable>
    <xsl:variable name="filter" select="exsl:node-set($filter-data-rtf)"/>
	
		<ui:browse title="{sw:text('Backups')}">
			<ui:browse-js-many>
				<ui:warn><sw:text>Select at least one backup!</sw:text></ui:warn>
			</ui:browse-js-many>
			<ui:browse-js-one>
				<ui:warn>
					<sw:text>Select only one backup!</sw:text>
				</ui:warn>
			</ui:browse-js-one>
			
			<ui:filter>
				<xsl:copy-of select="$filter"/>
			</ui:filter>
	
			<ui:browse-empty-msg><sw:text>No backups.</sw:text></ui:browse-empty-msg>

			<ui:browse-buttons type="list-selection">
			
				<ui:button type="list-selection" tip="backup_envs" icon="backup" require-items="false"
					new-obj-title="{sw:text('Container Backup')}" 
					submit-href="{$baseurl}/vt/backups/new?env-set=select-multi&amp;_sesput=units-tab,backups"
				>
					<sw:text>New Container Backups</sw:text>
				</ui:button>
			
				<ui:button tip="restore_ves" sandclock="false" icon="backup_restore" 
					submit-href="{$baseurl}/vt/backups/restore?id-src=post" 
					script="if (!atLeastOne()) return false;" name="confirm_restore" width="150"
				>
					<sw:text>Restore Container</sw:text>
				</ui:button>
				<ui:button type="list-selection" tip="delete_backups" 
					icon="delete" submit-href="{$baseurl}/vt/backups/list-control?cmd=remove-all" 
					confirmation="{sw:text('Are you sure you want to delete the selected backup(s)?')}" 
					script="if (!atLeastOne()) return false;" name="remove_selected" width="150"
					>
					<sw:text>Remove Backups</sw:text>
				</ui:button>
			</ui:browse-buttons>

		</ui:browse>

	</xsl:template>
	
	<xsl:template name="backups:browse-single-ve">
		<xsl:param name="filter-ve-eid"/><!-- REQUIRED FIELD -->
		<xsl:param name="backups-limit" select="''"/><!-- REQUIRED FIELD -->
		<xsl:param name="first-buttons" select="/.."/>	
		
		<sw:die test="$backups-limit=''">
			backups-limit argument should be filled.
		</sw:die>
		
		<xsl:variable name="access-map-rtf">
			<xsl:call-template name="cred:access-map">
				<xsl:with-param name="creds-rtf">
					<cred id="vzcp.env.backups.backup" security-obj-type="ve.vz.vt" security-obj-id="{$filter-ve-eid}"/>
					<cred id="vzcp.env.backups.restore" security-obj-type="ve.vz.vt" security-obj-id="{$filter-ve-eid}"/>
					<cred id="vzcp.env.backups.remove" security-obj-type="ve.vz.vt" security-obj-id="{$filter-ve-eid}"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="access-map" select="exsl:node-set($access-map-rtf)/cred"/>
		
		<!-- Init Filter -->
		<xsl:variable name="filter-rtf">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="ve-backups" url="/vz/ves/backups/index" 
						item-url="/vt/backups/backup"
						item-url-tip="ve_backups" items-title="{sw:text('Backups')}"
					/>
					<ui:cols sorting-col="backuped" sorting-direction="desc">
						<xsl:call-template name="backups:get-single-ve-browse-cols">
						</xsl:call-template>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>    
		
		<!-- Fill Filter -->
		<xsl:variable name="filter-data-rtf">
			<xsl:call-template name="backups:fill-filter">
				<xsl:with-param name="filter-rtf" select="$filter-rtf"/>
				<xsl:with-param name="filter-ve-eid" select="$filter-ve-eid"/>
			</xsl:call-template>
		</xsl:variable>
    <xsl:variable name="filter" select="exsl:node-set($filter-data-rtf)"/>
    
		<!-- Init some browse data -->
		<xsl:variable name="skip-limits" 	select="$activeMode='vzcc'"/>			
		<xsl:variable name="count" 	select="$filter/ui:coords/@total"/>
		<xsl:variable name="backup-problem" select="voc:check-operation(
			'vzabackupm','backup_env','',$filter-ve-eid
		)"/>
		
		<!-- Show Browse -->	
		<xsl:call-template name="local:post-single-ve-browse">
	    <xsl:with-param name="filter" select="$filter"/>		
	    <xsl:with-param name="new-allowed" 
	    	select="$backup-problem='' 
	    		and ($skip-limits or ($count &lt; $backups-limit ))
	    		and cred:match-access($access-map,'vzcp.env.backups.backup','ve.vz.vt',$filter-ve-eid)"/>	    
	    <xsl:with-param name="renew-allowed" 
	    	select="$backup-problem='' 
	    		and ($skip-limits or ($count &lt;= $backups-limit ))
	    		and cred:match-access($access-map,'vzcp.env.backups.backup','ve.vz.vt',$filter-ve-eid)
	    		and cred:match-access($access-map,'vzcp.env.backups.remove','ve.vz.vt',$filter-ve-eid)"/>			    
	    <xsl:with-param name="restore-allowed" 
	    	select="voc:check-operation('vzabackupm','restore_env','',$filter-ve-eid) = ''
	    		and cred:match-access($access-map,'vzcp.env.backups.restore','ve.vz.vt',$filter-ve-eid)"/>		
 	    <xsl:with-param name="remove-allowed" 
 	    	select="voc:check-operation('vzabackupm','remove','',$filter-ve-eid) = ''
 	    		and cred:match-access($access-map,'vzcp.env.backups.remove','ve.vz.vt',$filter-ve-eid)"/>		
		</xsl:call-template>
		
	</xsl:template>

</xsl:stylesheet>
