<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred func voc vt dirm"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:func			="http://exslt.org/functions"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"	
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:dirm			="http://www.swsoft.com/xsl/cp/dirm"
>
	<sw:include href="/lib/swa/dirm.xsl"/>	
	
	
	<func:function name="vt:split-baseset">
		<xsl:param name="base-set"/>
		<xsl:variable name="res">
			<xsl:choose>
				<xsl:when test="contains(string($base-set),'/')">
					<base><xsl:value-of select="substring-before(string($base-set),'/')"/></base>
					<version><xsl:value-of select="substring-after(string($base-set),'/')"/></version>
				</xsl:when>
				<xsl:otherwise>
					<base><xsl:value-of select="$base-set"/></base>
					<version></version>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($res)"/>		
	</func:function>	
 
 	<func:function name="vt:techs">
		<xsl:variable name="res-rtf">
			<tech id="vz.vt" title="Virtuozzo"/>
			<!-- Disabled in VZ 4.0 
			<tech id="vmware.vt" title="VMWare"/>
			-->
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>
 
	<func:function name="vt:platforms">
		<xsl:variable name="res-rtf">
			<platform id="windows.i386" title="Windows / i386"/>
			<platform id="windows.x86_64" title="Windows / x86-64"/>		
			<platform id="windows.ia64" title="Windows / ia64"/>						
			<platform id="linux.i386" title="Linux / i386"/>
			<platform id="linux.x86_64" title="Linux / x86-64"/>			
			<platform id="linux.ia64" title="Linux / ia64"/>			
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>
	
	<func:function name="vt:vza-platform-oses">
		<xsl:param name="use-other" select="true()"/>
		<xsl:variable name="res-rtf">
			<ui:filter-option value="Windows" title="{sw:text('Windows')}"/>
			<ui:filter-option value="Linux" title="{sw:text('Linux')}"/>
			<xsl:if test="$use-other">
				<ui:filter-option value="Other" title="{sw:text('Other')}"/>
			</xsl:if>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)/ui:filter-option"/>
	</func:function>
	
	<!-- 
		Check platform for complexity. Does it contains architecture id? 
		Arguments:
			platform 
		Result
			boolean()
	-->	
	<func:function name="vt:platform-contains-arch">
		<xsl:param name="platform"/>	
		<func:result select="contains($platform,'.')"/>
	</func:function>
	
	<!--
		Return platform title by platform ID.
		Argument
			platform - platform id (in VZCC format)
		Result
			title - platform title
	-->
	<func:function name="vt:platform2title">
		<xsl:param name="platform"/>
		<xsl:variable name="platform-info" select="vt:platforms()/platform[@id=$platform]"/>
		<xsl:choose>
			<xsl:when test="$platform-info">
				<func:result select="$platform-info/@title"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:text('Unknown platform')"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Returns VZCP Linux platform. Use only when explicit platform is needed to be passed to VZAgent -->
	<func:function name="vt:platform-linux">
		<func:result select="'linux.i386'"/>
	</func:function>
	
	<!-- Returns VZCP Windows platform. Use only when explicit platform is needed to be passed to VZAgent -->
	<func:function name="vt:platform-windows">
		<func:result select="'windows.i386'"/>
	</func:function>
	
	<!-- Convert platform value from VZCP format to VZA format-->
	<func:function name="vt:platform2vza">
		<xsl:param name="platform"/>
		<xsl:choose>
			<xsl:when test="contains(sw:lc($platform),'linux')">
				<func:result select="'Linux'"/>
			</xsl:when>
			<xsl:when test="contains(sw:lc($platform),'windows')">
				<func:result select="'Windows'"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					Platform '<xsl:value-of select="$platform"/>' is unknown.
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Convert platform value from VZCP format to VZA architecture format-->
	<func:function name="vt:platform2vza-architecture">
		<xsl:param name="platform"/>
		<xsl:choose>
			<xsl:when test="contains($platform,'i386')">
				<func:result select="'i386'"/>
			</xsl:when>
			<xsl:when test="contains($platform,'x86_64')">
				<func:result select="'x86_64'"/>
			</xsl:when>
			<xsl:when test="contains($platform,'ia64')">
				<func:result select="'ia64'"/>
			</xsl:when>			
			<xsl:otherwise>
				<sw:die>
					Platform '<xsl:value-of select="$platform"/>' is unknown.
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Check if platform is backwards-compatible with target platform-->
	<func:function name="vt:platform-backwards-compatible">
		<xsl:param name="target-platform"/>
		<xsl:param name="platform"/>
		
		<func:result 
			select="vt:compare-platforms($platform, $target-platform) 
						or (vt:platform2vza($platform)=vt:platform2vza($target-platform) 
								and vt:platform2vza($platform)=vt:platform2vza(vt:platform-linux())
								and vt:platform2vza-architecture($platform)='i386')"/>
	</func:function>
	
	<!-- Convert OS value from VZCP format to VZA format-->
	<func:function name="vt:os2vza">
		<xsl:param name="os"/>
		<xsl:choose>
			<xsl:when test="$os='linux'">
				<func:result select="'Linux'"/>
			</xsl:when>
			<xsl:when test="$os='windows'">
				<func:result select="'Windows'"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					OS '<xsl:value-of select="$os"/>' is unknown.
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Convert OS value from VZA format to VZCP format-->
	<func:function name="vt:vza2os">
		<xsl:param name="os"/>
		<xsl:choose>
			<xsl:when test="sw:lc($os)='linux'">
				<func:result select="'linux'"/>
			</xsl:when>
			<xsl:when test="sw:lc($os)='windows'">
				<func:result select="'windows'"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					OS '<xsl:value-of select="$os"/>' is unknown.
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- Convert platform value from VZA format to VZCP format -->
	<func:function name="vt:vza2platform"> 
		<xsl:param name="vza-platform"/>
		<xsl:param name="vza-arch" select="''"/>	

		<xsl:variable name="os" select="sw:if(not($vza-platform) or sw:lc($vza-platform)='linux','linux','windows')"/>
		<xsl:variable name="arch" select="sw:if(not($vza-arch) or string($vza-arch)='' or $vza-arch='i386','i386', $vza-arch)"/>

		<func:result select="concat($os,'.',$arch)"/>
		
	</func:function>
	
	<!-- Compare two platforms 
	
		ATTN! Do not try optimize this function by dividing to some small functions. 
   				This function should have maximum speed 
	-->
	<func:function name="vt:compare-platforms"> 
		<xsl:param name="provider-platform"/>
		<xsl:param name="client-platform-src"/>
		
		<xsl:variable name="client-platform" select="sw:if(contains($client-platform-src,'.')
			,$client-platform-src
			,concat($client-platform-src,'.')
		)"/>
		
		<func:result select="starts-with($provider-platform,$client-platform)"/>

	</func:function>

</xsl:stylesheet>
