<!-- Copyright (c) SWsoft, 1999-2007 All rights reserved. -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func tem voc cred sample ve vt"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:func="http://exslt.org/functions" 
  xmlns:vt			="http://www.swsoft.com/xsl/cp/vt"  
  xmlns:env			="http://www.swsoft.com/xsl/cp/env"
  xmlns:ve			="http://www.swsoft.com/xsl/cp/ve"
  xmlns:hn			="http://www.swsoft.com/xsl/cp/hn" 
  xmlns:sample	="http://www.swsoft.com/xsl/cp/sample"
  xmlns:env-samplem="http://www.swsoft.com/xsl/cp/env-samplem"
  xmlns:tem="http://www.swsoft.com/xsl/cp/tem"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
  xmlns:voc			="http://www.swsoft.com/xsl/cp/voc"  
  xmlns:global		="http://www.swsoft.com/xsl/cp/global" 
>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	
	<!-- Special constant for "VZA INVALID EID"  -->
	<xsl:variable name="env:empty-eid" select="'00000000-0000-0000-0000-000000000000'"/>		

	<!-- 
		Get Env information
			Arguments:
				[eid] : nodeset with ENVs ID
				full-access : full access to all ENVs
				dst-eid : ask specified HN about env info
	-->
	<func:function name="env:get-env">
	  <xsl:param name="eid"/>
    <xsl:param name="full-access" select="false()"/>
    <xsl:param name="hn-eid" select="''"/>    
    <xsl:choose>
    	<xsl:when test="string($eid)=''">
				<func:result select="/.."/>    
			</xsl:when>
			<xsl:when test="$hn-eid!=''">
				<xsl:variable name="packet-rtf">
					<packet>
						<target>server_group</target>
						<xsl:copy-of select="sw:env-dst($hn-eid)"/>
						<data>
							<server_group>
								<get_info>
									<eid><xsl:value-of select="$eid"/></eid>
									<status/>
									<config/>
								</get_info>
							</server_group>
						</data>
					</packet>
				</xsl:variable>
				<func:result select="sw:xchg($packet-rtf)/packet/data/server_group"/>
			</xsl:when>
    	<xsl:otherwise>
				<func:result select="sw:envinfo($eid,$full-access)/packet"/>    
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!--
	<xsl:template name="env:get-statuses">
		<xsl:variable name="voc-statuses" select="voc:get('states', env:make-platform-ref(sw:master-eid()))"/>	
		<xsl:for-each select="$voc-statuses">
			<ui:filter-option value="{id}">
				<xsl:attribute name="title">
					<sw:text domain="vzagent-vocabulary" select="name($env-state/*[.=current()/id])"/>
				</xsl:attribute>
			</ui:filter-option>
		</xsl:for-each>
	</xsl:template>
	-->
	
	<xsl:template name="env:get-transitions">
		<xsl:variable name="voc-transitions" select="voc:get('transitions', env:make-platform-ref(sw:master-eid()))"/>	
		<xsl:for-each select="$voc-transitions">
			<ui:filter-option value="{id}">
				<xsl:attribute name="title">
					<sw:text domain="vzagent-vocabulary" select="name($env-trans/*[.=current()/id])"/>
				</xsl:attribute>
			</ui:filter-option>
		</xsl:for-each>
	</xsl:template>		
		
	<!-- PLATFORM FUNCTIONS -->
		
	<!-- was vt: sample2platform -->
	<func:function name="sample:sample2platform">
		<xsl:param name="sample"/>
		<func:result select="sample:vza2platform($sample/vt_version/platform,$sample/vt_version/architecture)"/>
	</func:function>
	
	<!-- was vt: sample-platform2platform -->
	<func:function name="sample:vza2platform"> 
		<xsl:param name="vza-platform"/>
		<xsl:param name="vza-arch" select="''"/>	
		<func:result select="vt:vza2platform($vza-platform,$vza-arch)"/>
	</func:function>
	
	<!-- was  vt: platform2sample-platform  -->
	<func:function name="sample:platform2vza"> 
		<xsl:param name="platform"/>
		<func:result select="ve:platform2vza($platform)"/>
	</func:function>
	
	<!-- was env: env2platform -->
	<func:function name="ve:ve2platform">
		<xsl:param name="ve"/>
		<func:result select="ve:vza2platform($ve/virtual_config/os/platform,$ve/virtual_config/architecture)"/>
	</func:function>
	
	<!-- was env: env-platform2platform -->
	<func:function name="ve:vza2platform">
		<xsl:param name="vza-platform"/>
		<xsl:param name="vza-arch" select="''"/>	
	
		<func:result select="vt:vza2platform($vza-platform,$vza-arch)"/>
	</func:function>
	
		<!-- was env: platform2env-platform -->
	<func:function name="ve:platform2vza">
		<xsl:param name="vza-platform"/>
		<func:result select="vt:platform2vza($vza-platform)"/>
	</func:function>
	
	<!-- was hn: env2platform -->
	<func:function name="hn:hn2platform">
		<xsl:param name="hn"/>
		<func:result select="hn:vza2platform($hn/config/os/platform,$hn/config/architecture)"/>
	</func:function>
	
	<!-- was hn: env-platform2platform -->
	<func:function name="hn:vza2platform">
		<xsl:param name="vza-platform"/>
		<xsl:param name="vza-arch" select="''"/>	
		<func:result select="vt:vza2platform($vza-platform,$vza-arch)"/>
	</func:function>
	
	<!-- was hn: platform2env-platform -->
	<func:function name="hn:platform2vza">
		<xsl:param name="vza-platform"/>
		<func:result select="vt:platform2vza($vza-platform)"/>
	</func:function>
	
	<func:function name="env:env2platform">
		<xsl:param name="env"/>
		<xsl:choose>
			<xsl:when test="not($env)">
				<func:result select="'unknown'"/>
			</xsl:when>
			<xsl:when test="$env/config/type='generic'">
				<func:result select="hn:hn2platform($env)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="ve:ve2platform($env)"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	
	<!-- /PLATFORM FUNCTIONS -->
	
	<!-- was hn: env2title -->
	<!-- was vzhn: env2title -->
	<func:function name="env:env2title">
		<xsl:param name="env"/>
		<xsl:choose>
			<xsl:when test="$env/status/state=$env-state/unexist">		
				<func:result select="sw:text('Deleted')"/>			
			</xsl:when>
			<xsl:when test="$env">
				<func:result select="env:title(
					sw:if($env/virtual_config/name!='',$env/virtual_config/name,$env/config/name),
					sw:if($env/virtual_config/hostname!='',$env/virtual_config/hostname,$env/config/hostname),			
					$env/virtual_config/veid
				)"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:text('Unknown')"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- was vzhn: title-->
	<func:function name="env:title">
		<xsl:param name="name"/>
		<xsl:param name="hostname"/>
		<xsl:param name="id-int"/>
		<xsl:param name="ip-address" select="''"/>
		
		<xsl:choose>
			<xsl:when test="$name!=''">
				<func:result select="$name"/>				
			</xsl:when>
			<xsl:when test="$hostname!=''">
				<func:result select="$hostname"/>
			</xsl:when>
			<xsl:when test="$id-int!=''">
				<func:result select="concat('# ',$id-int)"/>				
			</xsl:when>
			<xsl:when test="$ip-address!=''">
				<func:result select="$ip-address"/>				
			</xsl:when>
			<xsl:otherwise>				
				<func:result>
					<sw:text>
						Unnamed
					</sw:text>
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<!-- was hn: eid2info -->
	<func:function name="env:eid2info">
		<xsl:param name="eid"/>
		<xsl:variable name="env" select="env:get-env($eid)/env"/>
		<func:result select="env:env2info($env)"/>
	</func:function>
	
	<!-- was hn: eid2info -->
	<func:function name="env:env2info">
		<xsl:param name="env"/>

		<xsl:variable name="env-platform" select="env:env2platform($env)"/>
		<xsl:variable name="env-title" select="env:env2title($env)"/>
	
		<xsl:variable name="res-rtf">
			<!-- copy common VE/HN data -->
			<eid><xsl:value-of select="$env/eid"/></eid>
			<title><xsl:value-of select="$env-title"/></title>
			<platform><xsl:value-of select="$env-platform"/></platform>
			<xsl:if test="vt:is-platform-linux($env-platform)">
				<linux/>
			</xsl:if>
			<xsl:if test="vt:is-platform-windows($env-platform)">
				<windows/>
			</xsl:if>
			<xsl:choose>
				<!-- handle empty env -->
				<xsl:when test="not($env)">
				</xsl:when>
				<!-- copy HN data -->
				<xsl:when test="$env/config/type='generic'">
					<xsl:copy-of select="$env/config/hostname"/>
					<xsl:copy-of select="$env/config/ip_text"/>
					<!-- workaround for #96558 -->
					<xsl:variable name="hn-vt-type" select="sw:if($env/config/child_type,$env/config/child_type[1],'virtuozzo')"/>
					<obj-type><xsl:value-of select="$global:classes/class[@super-type='hn.vt' and vt-vza-type=$hn-vt-type]/@vzcp-type"/></obj-type>
				</xsl:when>
				<!-- copy VE data -->
				<xsl:otherwise>
					<hn-eid><xsl:value-of select="$env/parent_eid"/></hn-eid>
					<obj-type><xsl:value-of select="$global:classes/class[@super-type='ve.vt' and @vza-type=$env/virtual_config/type]/@vzcp-type"/></obj-type>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>
	
	<!--
		Make special nodeset with platform information.
		Returns the following nodeset- 
			/platform
			/hn-eid
	-->
	<func:function name="env:make-platform-ref">
		<xsl:param name="hn-eid"/>
		<xsl:param name="platform" select="''"/>
	
		
		<xsl:variable name="res-rtf">
			<xsl:if test="$hn-eid!=''">
				<hn-eid><xsl:value-of select="$hn-eid"/></hn-eid>
			</xsl:if>
			<platform>
				<xsl:choose>
					<xsl:when test="$platform!=''">
						<xsl:value-of select="$platform"/>
					</xsl:when>
					<xsl:when test="$hn-eid!=''">
						<xsl:value-of select="env:env2platform(env:get-env($hn-eid)/env)"/>
					</xsl:when>
					<xsl:otherwise>
						<sw:die>platform and hn-eid are both undefined</sw:die>
					</xsl:otherwise>
				</xsl:choose>
			</platform>
		</xsl:variable>
		<func:result select="exsl:node-set($res-rtf)"/>
	</func:function>

	<!-- replace for sw:envstate()  -->
	<func:function name="ve:context-state">
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<func:result select="sw:envinfo($ve-eid,false())/packet/env/status/state"/>
	</func:function>

	<!-- replace for sw:envtransition()  -->
	<func:function name="ve:context-transition">
		<xsl:param name="ve-eid" select="sw:ve-eid()"/>
		<func:result select="sw:envinfo($ve-eid,false())/packet/env/status/transition"/>
	</func:function>

	<!-- input: object id, counter group name: cpu,loadavg,system,mem,disk -->
	<func:function name="env:obj-type2counter-name">
		<xsl:param name="obj-id"/>
		<xsl:param name="counter-group-name"/>
		<func:result>
			<xsl:value-of select="normalize-space($global:classes/class[@id = string($obj-id)]/counters/*[name() = $counter-group-name])"/>
		</func:result>
	</func:function>					


	<!-- was ve:get-target -->
	<func:function name="env:get-target">
		<xsl:param name="eid"/>		
		<xsl:param name="operator" select="'envm'"/>		
		
    <xsl:variable name="vzcp-obj-type" select="env:eid2info($eid)/obj-type"/>
    <xsl:variable name="env-class" select="$global:classes/class[@vzcp-type = $vzcp-obj-type]"/>
		<xsl:choose>
			<xsl:when test="$env-class">
				<func:result select="concat($env-class/vza-operator-prefix,$operator)"/>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					Not supported VE type <xsl:value-of select="$vzcp-obj-type"/>
				</sw:die>
			</xsl:otherwise>						
		</xsl:choose>		
	</func:function>
	
</xsl:stylesheet>
