<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func env vzenv math vzapackagem vz tem"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:math="http://exslt.org/math"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:env="http://www.swsoft.com/xsl/cp/env"
  xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
  xmlns:tem="http://www.swsoft.com/xsl/cp/tem"
  xmlns:vzapackagem="http://www.swsoft.com/xsl/cp/vzapackagem"
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"  
>
  <sw:include href="/lib/vz/core.xsl"/>
  <sw:include href="/lib/vza/tem.xsl"/>
  <sw:include href="/lib/vza/vzapackagem.xsl"/>
  
  <!--
  	Requires:
  -->
	<func:function name="env:list-oses">
		<xsl:param name="hw-eid"/>
		
		
		<xsl:variable name="old-oses" select="tem:list('os', $hw-eid)/packet/data"/>
		<xsl:variable name="new-oses" select="vzapackagem:list4hn('os',$hw-eid)/packet/data"/>
		
		<xsl:variable name="res">		
			<xsl:choose>
				<xsl:when test="$old-oses/error|$old-oses/tem/error">			
					<package>
						<name><sw:text>Cannot list standard templates.</sw:text></name>
						<version>
							<mark><sw:text>n/a</sw:text></mark>
						</version>
						<disabled/>
					</package>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="$old-oses/tem/package[version/cached=1]">
						<xsl:sort select="name"/>
						<xsl:if test="position()=1">
							<package>
								<name><sw:text>-- Standard --</sw:text></name>
								<version>
									<mark></mark>
									<cached>1</cached>
								</version>
								<disabled/>
							</package>	
						</xsl:if>
						<xsl:copy-of select="."/>					
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:choose>
				<xsl:when test="$new-oses/error|$new-oses/vzapackagem/error">			
					<package>
						<name><sw:text>Cannot list EZ templates.</sw:text></name>
						<version>
							<mark><sw:text>n/a</sw:text></mark>
						</version>
						<disabled/>
					</package>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="$new-oses/vzapackagem/packages/package[os_template='1']">
						<xsl:sort select="name"/>
						<xsl:if test="position()=1">
							<package>
								<name><sw:text>-- EZ --</sw:text></name>
								<version>
									<mark></mark>
									<cached>1</cached>
								</version>
								<disabled/>
							</package>	
						</xsl:if>
						<package>
							<xsl:copy-of select="name"/>
							<version>
								<mark>00000001</mark>
								<cached>1</cached>
							</version>
						</package>	
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<func:result select="exsl:node-set($res)/package"/>
		
	</func:function>
  
 <func:function name="env:restore-os">
		<func:result>
			<os_template>
				<name><xsl:value-of select="sw:param('os_template_name')"/></name>
				<version><xsl:value-of select="sw:param('os_template_ver')"/></version>
			</os_template>
		</func:result>
 </func:function>  
 
 <func:function name="env:check-os">
		<xsl:param name="os"/>
    <xsl:if test="not($os/name!='')">
			<xsl:if test="error:put(sw:text('Please select an operating system.'),'','os_template_name')"/>
    </xsl:if>
    <xsl:if test="not(sw:is-ez-package($os/name)) and not($os/version!='')">
			<xsl:if test="error:put(sw:text('Please select an OS version.'),'','os_template_ver')"/>
    </xsl:if>
		<func:result/>
	</func:function>
 
	<func:function name="env:show-os">
	 	<xsl:param name="config"/><!--|
	 		os_template
	 		os_templates
	 		show_empty_var
	 		init_on_start
	 		empty_os_text
	 		empty_ver_text
	 		change-os-js 
	 		required
	 	|-->
	 	
		<xsl:variable name="os" select="$config/os_template"/>
		<xsl:variable name="os_templates" select="$config/os_templates/package"/>
		<xsl:variable name="show_empty_ver" select="$config/show_empty_ver"/>
		<xsl:variable name="init_on_start" select="$config/init_on_start"/>
		<xsl:variable name="empty_os_text" select="$config/empty_os_text"/>
		<xsl:variable name="change-os-js" select="$config/change-os-js"/>
			
		<func:result>
			<ui:cell-label><xsl:value-of select="sw:text('Operating System/Version')"/></ui:cell-label>
			<ui:cell-list id="os_template_name" close="false" value="{$os/name}">
				<xsl:attribute name="onchange">updateOS('');<xsl:value-of select="$change-os-js"/></xsl:attribute>
				<xsl:if test="$config/required">
					<xsl:attribute name="required">true</xsl:attribute>
				</xsl:if>
				<xsl:if test="$empty_os_text">
					<ui:list-item id="" title="{$empty_os_text}"/>
				</xsl:if>
				<xsl:for-each select="$os_templates[version/cached=1]">
					<xsl:variable name="mark" select="math:max(version/mark)"/>
					<ui:list-item title="{sw:app-id2title(name)}">
						<xsl:choose>
							<xsl:when test="disabled">
								<xsl:attribute name="disabled">true</xsl:attribute>
								<xsl:attribute name="id"></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="id"><xsl:value-of select="name"/></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>					
					</ui:list-item>
				</xsl:for-each>				
			</ui:cell-list>		
			<ui:cell open="false" close="false">&#160;/&#160;</ui:cell>
			<!--|-->
			<ui:cell-list id="os_template_ver" open="false">
				<xsl:copy-of select="sw:getOSJS(
					$os_templates,
					$show_empty_ver,
					$init_on_start,
					$os/version,
					sw:if($config/empty_os_ver,$config/empty_os_ver,sw:text('Any'))
				)"/>
			</ui:cell-list>
			<!--|-->
		</func:result>
	</func:function>
	
	<func:function name="sw:getOSJS">
		<xsl:param name="os_templates"/>
		<xsl:param name="show_empty_ver"/>
		<xsl:param name="init_on_start" select="true()"/>
		<xsl:param name="init_version" select="''"/>
		<xsl:param name="empty_os_ver"/>
		
		<func:result>
			<script type="text/javascript">	
				<![CDATA[
				function updateOS(req_version){
					os_view=document.getElementById('os_template_name');
					os_version=document.getElementById('os_template_ver');
				]]>
					os_version.options.length=0;
					os_version.options.selectedIndex=-1;
					//
					if(os_view.options[ os_view.selectedIndex ].value==''){
						o = new Option('<xsl:value-of select="$empty_os_ver"/>','');
						os_version.options[0]=o;
						os_version.options[0].selected = true;
					}
					<xsl:for-each select="$os_templates">
						if(os_view.value=='<xsl:value-of select="name"/>'){
							<xsl:for-each select="version[cached=1]">
								<xsl:sort select="mark" data-type="number"/>
								<xsl:choose>
									<xsl:when test="$show_empty_ver">
										o = new Option('<xsl:value-of select="mark"/>','<xsl:value-of select="mark"/>');
									</xsl:when>
									<xsl:when test="not($show_empty_ver) and (position()=last())">
										o = new Option('<xsl:value-of select="mark"/>&#160;<sw:text>(latest)</sw:text>','<xsl:value-of select="mark"/>');
										if(req_version.length==0){
											o.selected=true;
										}
									</xsl:when>
									<xsl:otherwise>
										o = new Option('<xsl:value-of select="mark"/>','<xsl:value-of select="mark"/>');
									</xsl:otherwise>
								</xsl:choose>								
								os_version.options[<xsl:value-of select="position()-1"/>]=o;								
								<![CDATA[			
									if(req_version!='' && req_version==o.value){
										os_version.selectedIndex = os_version.options.length-1;
									}																							
								]]>					
							</xsl:for-each>
						}
					</xsl:for-each>
					<xsl:if test="$show_empty_ver">
						if(os_view.value!=''){
							a = new Option('<xsl:value-of select="sw:text('latest')"/>','');							
							os_version.options[os_version.options.length]=a;
							if(req_version.length==0){
								os_version.selectedIndex = os_version.options.length-1;
							}
						}
					</xsl:if>
					if(os_view.options[ os_view.selectedIndex ].value.charAt(0)=='.'){
						os_version.disabled = true;	
					}else{	
						os_version.disabled = false;	
					}
				<![CDATA[				
				}
				]]>
				<xsl:if test="$init_on_start">
					updateOS('<xsl:value-of select="$init_version"/>');
				</xsl:if>
			</script> 
		</func:result>
		
	</func:function>
	
	
</xsl:stylesheet>
