<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date cred requests func local swa-mailer show error dirm env format"
	xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl		="http://exslt.org/common"
	xmlns:func		="http://exslt.org/functions"
	xmlns:date		="http://exslt.org/dates-and-times"	
	xmlns:sw			="http://www.swsoft.com/xsl/cp"
	xmlns:cred  	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:global  ="http://www.swsoft.com/xsl/cp/global"
	xmlns:requests="http://www.swsoft.com/xsl/cp/requests"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:swa-mailer		="http://www.swsoft.com/xsl/cp/swa-mailer"
	xmlns:show		="http://www.swsoft.com/xsl/cp/show"
	xmlns:error		="http://www.swsoft.com/xsl/cp/error"
	xmlns:authm		="http://www.swsoft.com/xsl/cp/authm"
	xmlns:dirm		="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>
	
	<sw:include href="../common.xsl"/>	
	<sw:include href="../cred.xsl"/>	
	<sw:include href="../swa/dirm.xsl"/>	
	<sw:include href="../vt/core.xsl"/>			
	<sw:include href="../vt/env-core.xsl"/>		
	<sw:include href="/lib/swa/swa-mailer.xsl"/>	
	<sw:include href="/lib/swa/authm.xsl"/>		
	<sw:include href="/lib/utils/format-datetime.xsl"/>
	
	<xsl:variable name="mail-config" select="swa-mailer:get-config(true())"/>
	
	<!-- Return the LDAP base DN for EnvRequests list -->
	<func:function name="requests:dn">
		<func:result select="concat('cn=EnvRequests,cn=vzcp,',$global:vzl-dn)"/>
	</func:function>	
	
	<func:function name="requests:get-config">
		<func:result select="$config/vzcpcon/ordering"/>
	</func:function>
	
	<func:function name="requests:set-config">
		<xsl:param name="ordering-config"/>
		<func:result select="sw:update-config('/vzcpcon/ordering',$ordering-config)"/>
	</func:function>
	
	<func:function name="requests:find-request">
		<xsl:param name="request-id"/>
		
		<xsl:choose>
			<xsl:when test="$request-id!=''">
				<xsl:variable name="request" select="dirm:search-obj(
					'requestId',$request-id,requests:dn()
				)"/>
				<func:result select="$request"/>				   
			</xsl:when>
			<xsl:otherwise>
				<func:result select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- 
		Result - string
			''=ok
			other string=error message
	-->
	<func:function name="local:notify-email">
		<xsl:param name="ordering-config"/>
		<xsl:param name="order"/>
		<xsl:param name="tmpl-name"/>
		<xsl:param name="error-message"/>
		
		<xsl:choose>
			<!-- Mail messaing disabled -->
			<xsl:when test="$mail-config[self::error] 
				or string($mail-config/notify) != 'true'">			
				<func:result/>
			</xsl:when>
			
			<!-- Mail transport disabled. Impersonated call to mailer used. -->			
			<xsl:when test="not(swa-mailer:email-enabled(true()))">							
				<func:result/>
			</xsl:when>
			
			<xsl:otherwise>			
				<xsl:variable name="args-rtf">
					<vzcc-url><xsl:value-of select="concat('https://',
						sw:if(sw:sesget('request-env'),sw:sesget('request-env')/env/vzcc-host,$request/http_request/env/parameter[name = 'HTTP_HOST']/value),
						'/vz/cp')"/>
					</vzcc-url>
				</xsl:variable>
			
				<xsl:variable name="msgtext">
		 			<xsl:apply-templates select="sw:document($tmpl-name)/message/child::node()" mode="msg">
		  			<xsl:with-param name="order" select="$order"/>	
		  			<xsl:with-param name="args" select="exsl:node-set($args-rtf)"/>	
		  			<xsl:with-param name="ordering-config" select="$ordering-config"/>	
		  		</xsl:apply-templates>
		    </xsl:variable>		   		
		    
		    <xsl:variable name="mail-res" select="swa-mailer:send-email($msgtext)"/>
		    <xsl:choose>
		    	<xsl:when test="$mail-res!=''">
		    		<!-- error occured -->
		    		<func:result>
		    			<xsl:value-of select="error:code2text('cp1100')"/>
		    		</func:result>
		    	</xsl:when>
		    	<xsl:otherwise>
		    		<!-- ok -->
		    		<func:result/>
		    	</xsl:otherwise>
		    </xsl:choose>		  
		    
		  </xsl:otherwise>
		</xsl:choose>
		
	</func:function>
	
	
	<func:function name="requests:cancel-request">
		<xsl:param name="request-id"/>
		
		<sw:die test="$request-id=''">
			Error in requests:cancel-request().
			request-ids argument is empty string.
		</sw:die>
		
		<func:result select="local:set-order-state($request-id,'CANCELED')"/>
		
	</func:function>
		
	<!--
		Output:
			empty string - success
			other string - error message
	-->
	<func:function name="requests:cancel-requests">
		<xsl:param name="request-ids"/>
		
		<sw:die test="count($request-ids)=0">
			Error in requests:cancel-requests().
			request-ids argument is empty nodeset.
		</sw:die>
		
		<func:result>
			<xsl:for-each select="$request-ids">
				<xsl:value-of select="requests:cancel-request(.)"/>
			</xsl:for-each>
		</func:result>		
		
	</func:function>
	
	<func:function name="requests:get-statuses">
		<xsl:variable name="res">
			<status value="NONEXISTS" title="{sw:text('Non-existent')}"/>
			<status value="OPEN" title="{sw:text('Open')}"/>
			<status value="PROCESSING" title="{sw:text('Processing')}"/>
			<status value="COMPLETED" title="{sw:text('Completed')}"/>
		</xsl:variable>
		<func:result select="exsl:node-set($res)/status"/>
	</func:function>
	
	<!--
		data/
			ownerSid
			description
			requestEnvHostname
			requestEnvName
			requestSampleId
			requestSampleName
			requestEnvPassword
	-->
	<func:function name="requests:new-order">
		<xsl:param name="data"/>
				
		<!-- Init data -->
		<xsl:variable name="ownerSid" select="$data/ownerSid"/>
		<xsl:variable name="user-key" select="authm:sid2user-key($ownerSid)"/>
		<sw:die test="not($user-key)">
			Can`t find user by SID <xsl:value-of select="$ownerSid"/>.
		</sw:die>
		<xsl:variable name="user" select="authm:get-user($user-key)"/>
		<sw:die test="not($user)">
			Can`t get user by SID <xsl:value-of select="$ownerSid"/>.
		</sw:die>
		<xsl:variable name="user-name" select="sw:if(normalize-space($user/data/displayName)!='',$user/data/displayName,$user/login)"/>
		<!-- Load existing data -->
		<xsl:variable name="ordering-config" select="requests:get-config()"/>		
		
		<!-- Generate Request ID -->				
		<xsl:variable name="request-id" select="sw:generate-id()"/>
				
		<!-- Prepare order  -->		
		<xsl:variable name="order-rtf">
			<ref>
				<dn>requestId=<xsl:value-of select="$request-id"/>,<xsl:value-of select="requests:dn()"/></dn>
				<objectClass>VZEnvRequest</objectClass>
			</ref>
			<data>
				<requestId><xsl:value-of select="$request-id"/></requestId>
				<ownerSid><xsl:value-of select="$ownerSid"/></ownerSid>
				<ownerName><xsl:value-of select="$user-name"/></ownerName>
				<xsl:if test="$user/data/mail!=''">
					<ownerMail><xsl:value-of select="$user/data/mail"/></ownerMail>
				</xsl:if>
				<requestStatus>OPEN</requestStatus>
				<postedDate>
					<xsl:value-of select="sw:vzatime2utime(sw:time2vzatime(date:date-time()))"/>
				</postedDate>
				<postedIp>
					<xsl:value-of select="$request/http_request/env/parameter[name = 'REMOTE_ADDR']/value"/>
				</postedIp>
				<xsl:copy-of select="$data/*[not(self::ownerSid)]"/>
			</data>
		</xsl:variable>
		<xsl:variable name="object" select="exsl:node-set($order-rtf)"/>
		<xsl:variable name="order" select="$object/data"/>
				
		<!-- Send notifications -->
		<xsl:variable name="notify-error" select="
			local:notify('NONEXISTS',$order/requestStatus,$order,$ordering-config)
		"/>
		<!-- /Send notifications -->
		
		<!-- Handle notification result and save order -->
		<xsl:choose>
			<xsl:when test="$notify-error!=''">
				<func:result select="$notify-error"/>
			</xsl:when>
			<xsl:otherwise>
				<!-- Save new order -->
				<xsl:variable name="dirm-resp" select="dirm:add-obj($object)"/>				
				<xsl:variable name="resp-error" select="$dirm-resp/packet/data/error|$dirm-resp/packet/data/dirm/error"/>
				<!-- /Save new order -->
				
				<xsl:choose>
					<xsl:when test="$resp-error">
						<func:result select="sw:text('A system error occurred.')"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="''"/>
					</xsl:otherwise>
				</xsl:choose>
				
				<!-- Post log -->
				<!--<xsl:if test="local:log-success('NONEXISTS',$order/status,$order,$config)"/>-->
				<!-- /Post log -->												
			</xsl:otherwise>
		</xsl:choose>
		<!-- /Handle notification result and save order -->
				
	</func:function>
	
	<!-- Set order to PROCESSING state
		return XML output
	-->			
	<func:function name="requests:set-processing">
		<xsl:param name="request-id"/>										
		
		<func:result select="local:set-order-state($request-id,'PROCESSING')"/>
	</func:function>
	
	<!-- Set order to COMPLETED state
		return XML output
	-->			
	<func:function name="requests:complete-order">
		<xsl:param name="request-id"/>								
		<xsl:param name="env-eid"/>
		
		<func:result select="local:set-order-state($request-id,'COMPLETED',$env-eid)"/>
	</func:function>
	
	<!-- Set order to OPEN state
		return '' or error
	-->			
	<func:function name="requests:reopen-order">
		<xsl:param name="request-id"/>								
		<func:result select="local:set-order-state($request-id,'OPEN')"/>
	</func:function>
	
	<!-- Internal function
		return '' or error
	-->			
	<func:function name="local:set-order-state">
		<xsl:param name="request-id"/>						
		<xsl:param name="new-status"/>
		<xsl:param name="env-eid" select="''"/>				
		
		<xsl:variable name="check-user" select="not(cred:check('vzcp.env.ordering.admin'))"/>
		<xsl:variable name="ordering-config" select="requests:get-config()"/>
		<xsl:variable name="order" select="requests:find-request($request-id)"/>
		<xsl:variable name="old-status" select="$order/requestStatus"/>
		<xsl:variable name="logged-sid" select="authm:get-user(sw:login()/login)/data/objectSid"/>
		
		<!-- check statuses -->
		<xsl:choose>
			<xsl:when test="not($order)">
				<func:result select="'Can`t find request.'"/>
			</xsl:when>
			<xsl:when test="$check-user and $order[ownerSid!=$logged-sid]">
				<func:result select="sw:text('Access forbidden.')"/>
			</xsl:when>
			<xsl:when test="$new-status='PROCESSING' and not($old-status='OPEN')">
				<func:result select="'Can`t process request.'"/>
			</xsl:when>
			<xsl:when test="$new-status='COMPLETED' and not($env-eid!='')">
				<func:result select="'VE should be defined'"/>
			</xsl:when>
			<xsl:when test="$new-status='COMPLETED' and not($old-status='PROCESSING' or $old-status='OPEN')">
				<func:result select="'Can`t complete request.'"/>
			</xsl:when>
			<xsl:when test="$new-status='OPEN' and not($old-status='PROCESSING' or $old-status='COMPLETED')">
				<func:result select="'Can`t reopen order.'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="request" select="requests:find-request($request-id)"/>
				<xsl:variable name="new-order-rtf">
					<ref>
						<dn>requestId=<xsl:value-of select="$request-id"/>,<xsl:value-of select="requests:dn()"/></dn>
					</ref>
					<data>
						<xsl:if test="$env-eid!=''">
							<objectId>
								<xsl:value-of select="$env-eid"/>
							</objectId>
						</xsl:if>
						<xsl:if test="$new-status='OPEN'">
							<objectId></objectId>
						</xsl:if>
						<requestStatus><xsl:value-of select="$new-status"/></requestStatus>						
						<xsl:for-each select="$request">
							<xsl:copy-of select="postedDate|ownerName|ownerMail|objectId"/>
						</xsl:for-each>
					</data>
				</xsl:variable>
				<xsl:variable name="new-object" select="exsl:node-set($new-order-rtf)"/>
				<xsl:variable name="new-order" select="$new-object/data"/>				

				<!-- Send notifications -->
				<xsl:variable name="notify-error" select="
					local:notify($old-status,$new-status,$new-order,$ordering-config)
				"/>
				<!-- /Send notifications -->				
				
				<!-- Handle notification result and save order -->
				<xsl:choose>
					<xsl:when test="$notify-error!=''">
						<func:result select="$notify-error"/>
					</xsl:when>
					<xsl:when test="$new-status='CANCELED'">
						<!-- cancel request -->
						<xsl:variable name="dirm-resp" select="dirm:delete-obj($new-object)"/>
						<!-- check result -->
						<xsl:choose>
							<xsl:when test="$dirm-resp//error">
								<func:result>
									VZAgent error #<xsl:value-of select="$dirm-resp//error/code"/> was occured. <xsl:value-of select="$dirm-resp//error/message"/>
								</func:result>
							</xsl:when>
							<xsl:otherwise>
								<func:result select="''"/>
							</xsl:otherwise>
						</xsl:choose>						
					</xsl:when>
					<xsl:otherwise>
						<!-- store request -->						
						<xsl:variable name="dirm-resp" select="dirm:modify-obj($new-object)"/>										
						<xsl:variable name="resp-error" select="$dirm-resp//error"/>										
						<!-- check result -->
						<xsl:choose>
							<xsl:when test="$resp-error">
								<func:result>
									VZAgent error #<xsl:value-of select="$resp-error/code"/> was occured. <xsl:value-of select="$resp-error/message"/>
								</func:result>
							</xsl:when>
							<xsl:otherwise>
								<func:result select="''"/>
							</xsl:otherwise>
						</xsl:choose>				
					</xsl:otherwise>
				</xsl:choose>					
				<!-- /Handle notification result and save order -->	
				
			</xsl:otherwise>
		</xsl:choose>
				
	</func:function>
	
	<!-- Internal function, send notyfications
		return '' or error
	-->			
	<func:function name="local:notify">
		<xsl:param name="old-status"/>
		<xsl:param name="new-status"/>
		<xsl:param name="new-order"/>
		<xsl:param name="ordering-config"/>
				
		<xsl:variable name="admin-mail-enabled"	select="$mail-config/accounts/admin/email!=''"/>
		<xsl:variable name="user-mail-enabled"	select="normalize-space($new-order/ownerMail) !=''"/>

		<!-- Send notification -->
		<xsl:variable name="res">
			<xsl:choose>				
				<xsl:when test="$new-status='OPEN' and $old-status='NONEXISTS' and $admin-mail-enabled">
					<xsl:value-of select="local:notify-email($ordering-config,$new-order,'mail-ordering-admin.xml','Can`t notify adminstrator about new VE Request.')"/>			
				</xsl:when>
				<xsl:when test="$new-status='COMPLETED' and $user-mail-enabled">
					<!-- Send Notification to User -->
					<xsl:value-of select="local:notify-email($ordering-config,$new-order,'mail-ordering-user-completed.xml','Can`t notify user about completed order.')"/>			
					<!-- /Send Notification to User -->
				</xsl:when>
				<xsl:when test="$new-status='CANCELED' and $user-mail-enabled">
					<!-- Send Notification to User -->
					<xsl:value-of select="local:notify-email($ordering-config,$new-order,'mail-ordering-user-canceled.xml','Can`t notify user about canceled order.')"/>			
					<!-- /Send Notification to User -->
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!-- /Send notification -->
		<func:result select="$res"/>
	</func:function>
	
	<!-- Internal function, write success to log
		return '' or error
	-->			
	<func:function name="local:log-success">
		<xsl:param name="old-status"/>
		<xsl:param name="new-status"/>
		<xsl:param name="new-order"/>
		<xsl:param name="config"/>
		
		<!-- Prepare log message -->
		<xsl:variable name="text">
			<xsl:choose>
				<xsl:when test="$new-status='OPEN' and $old-status='NONEXISTS'">
					<sw:text>
						Make a new Container request
					</sw:text>
				</xsl:when>
				<xsl:when test="$new-status='OPEN' and $old-status!='NONEXISTS'">
					<sw:text>
						Reopened Container request
					</sw:text>
				</xsl:when>
				<xsl:when test="$new-status='COMPLETED'">
					<sw:text>
						Completed Container request
					</sw:text>
				</xsl:when>
				<xsl:when test="$new-status='CANCELED'">
					Canceled VE request
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!-- /Prepare log message -->
		
		<!-- Post message to log -->
		<xsl:if test="sw:report-progress($text, 0, 3, sw:generate-id() , '')"/>
		<!-- /Post message to log -->
		
	</func:function>
	
	
	<!-- Mail Notification Template Placeholders -->
	<xsl:template match="order-posted"  mode="msg">
		<xsl:param name="order"/>	
		<xsl:value-of select="format:date-time($order/postedDate)"/>
	</xsl:template>
	<xsl:template match="user-email"  mode="msg">
		<xsl:param name="order"/>	
		<xsl:value-of select="$order/ownerMail"/>
	</xsl:template>
	<xsl:template match="user-name"  mode="msg">
		<xsl:param name="order"/>	
		<xsl:value-of select="$order/ownerName"/>
	</xsl:template>
	<xsl:template match="admin-email"  mode="msg">
		<xsl:value-of select="$mail-config/accounts/admin/email"/>
	</xsl:template>
	<xsl:template match="admin-name"  mode="msg">
		<xsl:value-of select="$mail-config/accounts/admin/name"/>
	</xsl:template>
	<xsl:template match="system-email"  mode="msg">
		<xsl:value-of select="$mail-config/accounts/system/email"/>
	</xsl:template>
	<xsl:template match="system-name"  mode="msg">
		<xsl:value-of select="$mail-config/accounts/system/name"/>
	</xsl:template>
	<xsl:template match="ve-hostname"  mode="msg">
		<xsl:param name="order"/>	
		<xsl:value-of select="env:get-env($order/objectId)/env/virtual_config/hostname"/>
	</xsl:template>
	<xsl:template match="ve-name"  mode="msg">
		<xsl:param name="order"/>	
		<xsl:value-of select="env:get-env($order/objectId)/env/virtual_config/name"/>
	</xsl:template>
	<xsl:template match="vzcc-url"  mode="msg">
		<xsl:param name="args"/>	
		<xsl:value-of select="$args/vzcc-url"/>
	</xsl:template>
	<!-- /Mail Notification Template Placeholders -->
	
</xsl:stylesheet>
