<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func hn voc env cred"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:func="http://exslt.org/functions" 
  xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
  xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:ui			="http://www.swsoft.com/xsl/cp/ui" 
  xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
  xmlns:env		="http://www.swsoft.com/xsl/cp/env"
>
	<sw:include href="core.xsl"/>
	<sw:include href="env-core.xsl"/>

	<!-- HN Constansts -->
	<xsl:variable name="hn:empty-hwid" select="'0000.0000.0000.0000.0000.0000.0000.0000'"/>			
	
	<xsl:variable name="hn:state-rtf">
		<state id="unexist">
			<vza-value><xsl:value-of select="$env-state/unexist"/></vza-value>
			<text-capitalized><sw:text>Non-existent</sw:text></text-capitalized>			
			<text><sw:text>non-existent</sw:text></text>
			<icon>env_state_stopped.gif</icon>
			<left-icon>hw_node_disabled_16.gif</left-icon>
			<list-icon>env_state_stopped.gif</list-icon>
			<tip>hn_unexist_icon</tip>	
		</state>
		<state id="online">
			<vza-value><xsl:value-of select="$env-state/running"/></vza-value>
			<text-capitalized><sw:text>Online</sw:text></text-capitalized>			
			<text><sw:text>online</sw:text></text>
			<icon>env_state_running.gif</icon>
			<left-icon>hw_node_16.gif</left-icon>
			<list-icon>env_state_running.gif</list-icon>
			<tip>hn_online_icon</tip>
		</state>	
		<state id="nolicense">
			<vza-value><xsl:value-of select="$env-state/nolicense"/></vza-value>
			<text-capitalized><sw:text>Not Licensed</sw:text></text-capitalized>			
			<text><sw:text>not licensed</sw:text></text>
			<icon>env_state_inact.gif</icon>
			<left-icon>hw_node_disabled_16.gif</left-icon>
			<tip>hn_nolicense_icon</tip>	
		</state>	
		<state id="offline">
			<vza-value><xsl:value-of select="$env-state/unknown"/></vza-value>
			<text-capitalized><sw:text>Offline</sw:text></text-capitalized>			
			<text><sw:text>offline</sw:text></text>
			<icon>env_state_stopped.gif</icon>
			<left-icon>hw_node_disabled_16.gif</left-icon>
			<list-icon>env_state_stopped.gif</list-icon>
			<tip>hn_offline_icon</tip>	
		</state>	
	</xsl:variable>
	<xsl:variable name="hn:state" select="exsl:node-set($hn:state-rtf)/state"/>
	<!-- /HN Constansts -->	

	<func:function name="hn:set-current">
		<xsl:param name="hn-eid"/>
		<xsl:param name="die-on-error" select="true()"/>
		
		<xsl:variable name="hn-env" select="env:get-env($hn-eid)/env"/>
		<xsl:choose>
			<xsl:when test="not($hn-env) and $die-on-error">
				<sw:die>
					HN '<xsl:value-of select="$hn-eid"/>' is unknown.
				</sw:die>
			</xsl:when>
			<xsl:when test="$hn-env">
				<xsl:if test="sw:sesputstr('hn-eid',$hn-eid)"/>
				<xsl:if test="sw:sesputstr('hn-name',env:env2title($hn-env))"/>
				<func:result select="$hn-env"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	
	<!--
		Clean HN hwid from crazy $hn:empty-hwid  values.
		hwid 
	-->
	<func:function name="hn:clean-hwid">
		<xsl:param name="hwid"/>
	
		<xsl:choose>
			<xsl:when test="$hwid!='' and $hwid!=$hn:empty-hwid and $hwid!=$env:empty-eid">
				<func:result select="$hwid"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>	
	
	<!--
		Transform HN hwid to HN eid
		hwid 
	-->
	<func:function name="hn:hwid2eid">
		<xsl:param name="hwid"/>
	
		<xsl:choose>
			<xsl:when test="$hwid!='' and $hwid!=$hn:empty-hwid and $hwid!=$env:empty-eid">
				<xsl:variable name="hns-query">				
					<fields>
						<env.eid/>
						<env.hwids/>
					</fields>
					<where>
						pager.env.hwids='<xsl:value-of select="$hwid"/>'
					</where>
				</xsl:variable>
				<func:result select="string(sw:xchg-sql($hns-query)/pager/row_set/row/env/eid[1])"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>	
	</func:function>	


	<!-- Convert HN numeric status into text representation  
		Arguments:
			state - numeric VZA state.
		Resut
			info - nodeset with HN State information
				@id
				text
				text-capitalizard
	-->
	<func:function name="hn:state2info">
		<xsl:param name="state"/>
		<xsl:variable name="state-descr" select="$hn:state[vza-value=$state]"/>
		<xsl:choose>
			<!-- Handle known state -->
			<xsl:when test="$state-descr">
				<func:result select="$state-descr"/>
			</xsl:when>
			<!-- Handle unknown state, show it as offline -->
			<xsl:otherwise>
				<func:result select="$hn:state[@id='offline']"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>	
	
	<!--
		Translate HN states (in vzcp translation) to ui:filter-option list
	-->
	<xsl:template name="hn:get-states">
		<xsl:for-each select="$hn:state">
			<ui:filter-option value="{@id}" title="{text-capitalized}">
				<xsl:choose>
					<xsl:when test="vza-value">
						<xsl:attribute name="type">in</xsl:attribute>			
						<xsl:for-each select="vza-value">
							<ui:filter-option-value><xsl:value-of select="."/></ui:filter-option-value>
						</xsl:for-each>
					</xsl:when>
					<xsl:when test="vza-value-not">
						<xsl:attribute name="type">custom</xsl:attribute>			
						<xsl:attribute name="value-custom">!='<xsl:value-of select="vza-value-not"/>'</xsl:attribute>
					</xsl:when>
				</xsl:choose>
			</ui:filter-option>
		</xsl:for-each>
	</xsl:template>
	
	<!-- Transform HN state r into text representation 
		Arguments:
			state - HN state, in VZA integer format
		Result
			text
	-->
	<func:function name="hn:status2text">
		<xsl:param name="state"/>
		
		<xsl:variable name="state-info" select="hn:state2info($state)"/>
		
		<func:result>
			<sw:text>
				<xsl:with-param name="state" select="$state-info/text"/>
				The HN is %{state} at the moment.
			</sw:text>
		</func:result>

	</func:function>
  

</xsl:stylesheet>
