<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred hn computerm func voc proc"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:func	="http://exslt.org/functions"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:units	="http://www.swsoft.com/xsl/cp/units"	
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"	
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"
	xmlns:computerm	="http://www.swsoft.com/xsl/cp/computerm"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"
	xmlns:proc			="http://www.swsoft.com/xsl/cp/proc"
	xmlns:licensem	="http://www.swsoft.com/xsl/cp/licensem"
>
	
	<!-- Imports -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>
	<sw:include href="/lib/swa/computerm.xsl"/>
	<sw:include href="/lib/proc.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/utils/format-resusage.xsl"/>		
	<sw:include href="/lib/vt/env-core.xsl"/>
	<!-- /Imports -->

	<!-- 
		Load HN information for summary
	-->
	<func:function name="hn:load-summary-info">
		<xsl:param name="eid"/>
		<xsl:param name="return-as-rtf" select="false()"/>
		<!-- Load Data -->
		<xsl:variable name="hn-info" select="env:eid2info($eid)"/>	
		<xsl:variable name="cr-hw-resource" select="cred:check-hw('vzcp.hn.view',$eid)"/>
		<xsl:variable name="hw-lic" select="licensem:filter('VZSRV', licensem:get($eid))"/>
		<xsl:variable name="hw-system"	select="computerm:get-system($eid)"/>

		<xsl:variable name="hw-network" select="computerm:get-network($eid)"/>
		<xsl:variable name="hw-disk" select="computerm:get-disk($eid)"/>
		<xsl:variable name="sysinfo-rtf">
			<xsl:call-template name="proc:sysinfo">
				<xsl:with-param name="eid" select="$eid"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="sysinfo" select="exsl:node-set($sysinfo-rtf)"/>
		<xsl:variable name="cpu-load" select="proc:calc-cpu-load($sysinfo/system)"/>
		<!-- /Load Data -->

		<xsl:variable name="result-rtf">
			<!-- Resources -->
			<resources>
				<!-- COMMON resource group -->
				<group>
					<id>common</id>
					<title>
						<sw:text>General Information</sw:text>
					</title>

					<!-- OS name -->
					<resource>
						<id>os</id>
						<for-desktop/>
						<name>
							<sw:text>OS</sw:text>
						</name>
						<value>
							<xsl:choose>
								<xsl:when
									test="true() or $hw-system/os/release = 'unknown' or not($hw-system/os/release)">
									<xsl:value-of select="$hw-system/os/name"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$hw-system/os/release"/>
								</xsl:otherwise>
							</xsl:choose>
						</value>
					</resource>

					<!-- KERNEL -->
					<resource>
						<id>kernel</id>
						<for-desktop/>
						<name>
							<sw:text>Kernel ID</sw:text>
						</name>
						<value>
							<xsl:choose>
								<xsl:when test="$hw-system/os/kernel">
									<xsl:value-of select="$hw-system/os/kernel"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$hw-system/os/version"/>
								</xsl:otherwise>
							</xsl:choose>
						</value>
					</resource>

					<!-- ARCHITECTURE -->
					<resource>
						<id>arch</id>
						<name>
							<sw:text>Architecture</sw:text>
						</name>
						<value>
							<raw>
								<architecture>
									<xsl:value-of select="$hw-system/architecture"/>
								</architecture>
								<platform>
									<xsl:value-of select="$hw-system/os/platform"/>
								</platform>
								<name>
									<xsl:value-of select="$hw-system/os/name"/>
								</name>
								<cpu-model>
									<xsl:value-of select="$hw-system/cpu/model"/>
								</cpu-model>
								<cpu-family>
									<xsl:value-of select="$hw-system/cpu/family"/>
								</cpu-family>
								<cpu-name>
									<xsl:value-of select="$hw-system/cpu/name"/>
								</cpu-name>
							</raw>
							<formatted>
								<sw:text>
									<xsl:with-param name="arch" select="$hw-system/architecture"/>
									<xsl:with-param name="name" select="$hw-system/cpu/name"/>
									%{arch}, %{name}
								</sw:text>							
							</formatted>
						</value>
					</resource>					

					<!-- PROCESSOR name, number and feature -->
					<resource>
						<id>processor</id>
						<mhz-num>
							<name>
								<sw:text>
									<xsl:with-param name="modif" select="sw:if($hw-system/cpu/number &gt; 1,'s','')"
									/>
									Processor%{modif}
								</sw:text>
							</name>
							<value>
								<xsl:value-of
									select="concat($hw-system/cpu/number,' x ',$hw-system/cpu/mhz,' MHz')"
								/>
							</value>
						</mhz-num>
						<cores><xsl:value-of select="$hw-system/cpu/cores"/></cores>
						<hyperthreads><xsl:value-of select="$hw-system/cpu/hyperthreads"/></hyperthreads>						
					</resource>

					<!-- UPTIME -->					
					<resource>
						<for-desktop/>
						<id>uptime</id>
						<name>
							<sw:text>Uptime</sw:text>
						</name>
						<xsl:variable name="raw-time" select="$sysinfo/system/uptime"/>
						<xsl:variable name="format-time"
							select="proc:split-time(sw:if($raw-time &gt; 60,$raw-time +30,$raw-time))"/>
						<xsl:variable name="human-readable-time" select="proc:uptime-string($format-time)"/>
						<value>
							<xsl:value-of select="$human-readable-time"/>
						</value>
					</resource>
					
					<!-- HOSTNAME -->
					<resource>
						<id>hostname</id>
						<name>
							<sw:text>Hostname</sw:text>
						</name>
						<value>
							<xsl:value-of select="$hw-network/hostname"/>
						</value>
					</resource>
					
					<!-- IPADDRESSES -->
					<resource>
						<id>ips</id>
						<value>
							<xsl:variable name="lo-name"
								select="exsl:node-set(voc:get('net', env:make-platform-ref($eid)))[id = 'loopback_interface']/data"/>
							<xsl:for-each select="$hw-network/interface[name != $lo-name]">
								<xsl:value-of select="ipaddress"/>
								<xsl:if test="position() != last()">
									<xsl:text>, </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</value>
					</resource>					
					
					<!-- LICENSE info -->
					<resource>
						<for-desktop href="{$baseurl}/core/licenses/index"/>
						<id>license</id>
						<name>
							<sw:text>License status</sw:text>
						</name>
						<ve-total>
							<xsl:value-of select="licensem:value('ct_total',$hw-lic)"/>
						</ve-total>
						<lic-status>
							<xsl:variable name="lic-status" select="licensem:value('status',$hw-lic)"/>
							<id>
								<xsl:value-of select="$lic-status"/>
							</id>
							<text>
								<xsl:choose>
									<xsl:when test="not($lic-status = '')">
										<value>
											<xsl:value-of select="sw:text($lic-status)"/>
										</value>
									</xsl:when>
									<xsl:otherwise>
										<value>
											<sw:text>Not Installed</sw:text>
										</value>
									</xsl:otherwise>
								</xsl:choose>
							</text>
						</lic-status>
					</resource>
				</group>
				<!-- /COMMON resources group -->

				<!-- CPU related -->
				<group>
					<id>cpu</id>
					<title>
						<sw:text>CPU</sw:text>
					</title>

					<!-- CPU -->
					<resource>
						<xsl:if test="$cr-hw-resource">
							<link>/vzdir/infrman/hns/resources</link>
						</xsl:if>
						<id>cpu</id>
						<gauge>hw_cpu</gauge>
						<name>
							<sw:text>Load</sw:text>
						</name>
						<fraction>
							<xsl:value-of select="$cpu-load"/>
						</fraction>
						<level>0</level>
					</resource>

					<!-- LOAD AVERAGE -->
					<xsl:if test="$hn-info/linux">
						<xsl:variable name="load-avg-node" select="proc:calc-load-avg($sysinfo/system/load_avg)"/>
						<resource>
							<id>loadavg</id>
							<name>
								<sw:text>Load Average</sw:text>
							</name>
							<value>
								<xsl:value-of select="$load-avg-node/value"/>
							</value>
							<xsl:copy-of select="$load-avg-node/alert"/>
						</resource>
					</xsl:if>
				</group>
				<!-- /CPU related -->

				<!-- MEMORY and SWAP -->
				<group>
					<id>mem</id>
					<title>
						<sw:text>Memory</sw:text>
					</title>
					
					<!-- MEMORY: total, used, free -->
					<xsl:for-each select="$hw-system/memory">
						<resource>
							<xsl:if test="$cr-hw-resource">
								<link>/vzdir/infrman/hns/resources</link>
							</xsl:if>
							<id>mem</id>
							<gauge>hw_mem</gauge>
							<name>
								<sw:text>Physical Memory</sw:text>
							</name>
							<fraction>
								<xsl:value-of select="used div total"/>
							</fraction>
							<level>0</level>
							<values>
								<total>
									<size>
										<xsl:value-of select="total"/>
									</size>
								</total>
								<cur>
									<size>
										<xsl:value-of select="used"/>
									</size>
								</cur>
								<free>
									<size>
										<xsl:value-of select="free"/>
									</size>
								</free>
							</values>
						</resource>
					</xsl:for-each>
					
					<!-- SWAP: total, used free -->
					<xsl:for-each select="$hw-system/swap[total &gt; 0]">
						<resource>
							<xsl:if test="$cr-hw-resource">
								<link>/vzdir/infrman/hns/resources</link>
							</xsl:if>
							<id>swap</id>
							<gauge>hw_swap</gauge>
							<alert/>
							<name>
								<sw:text>Swap Space</sw:text>
							</name>
							<fraction>
								<xsl:value-of select="used div total"/>
							</fraction>
							<xsl:copy-of select="sw:get-fake-alerts(used,total)"/>
							<values>
								<total>
									<size>
										<xsl:value-of select="total"/>
									</size>
								</total>
								<cur>
									<size>
										<xsl:value-of select="used"/>
									</size>
								</cur>
								<free>
									<size>
										<xsl:value-of select="free"/>
									</size>
								</free>
							</values>
						</resource>
					</xsl:for-each>
				</group>
				<!-- /MEMORY and SWAP -->


				<!-- DISK -->
				<group>
					<id>disk</id>
					<title>
						<sw:text>Disk Usage</sw:text>
					</title>
					
					<!-- DISKSPACE: total,used,free -->
					<xsl:for-each select="$hw-disk/partition">
						<resource>
							<xsl:if test="$cr-hw-resource">
								<link>/vzdir/infrman/hns/resources</link>
							</xsl:if>
							<id>diskspace</id>
							<gauge>hw_diskspace</gauge>
							<alert/>
							<name>
								<xsl:value-of select="mount_point"/>
							</name>
							<fraction>
								<xsl:value-of select="blocks/used div blocks/total"/>
							</fraction>
							<xsl:copy-of select="sw:get-fake-alerts(blocks/used,blocks/total)"/>
							<values>
								<total>
									<size>
										<xsl:value-of select="blocks/total * block_size"/>
									</size>
								</total>
								<cur>
									<size>
										<xsl:value-of select="blocks/used * block_size"/>
									</size>
								</cur>
								<free>
									<size>
										<xsl:value-of select="blocks/free * block_size"/>
									</size>
								</free>
							</values>
						</resource>
					</xsl:for-each>
				</group>
				<!-- /DISK -->
				
			</resources>
		</xsl:variable>

		<!-- Return result -->
		<xsl:choose>
			<xsl:when test="$return-as-rtf">
				<func:result select="$result-rtf"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="exsl:node-set($result-rtf)/resources"/>
			</xsl:otherwise>
			<!-- Return result -->
		</xsl:choose>
		<!-- /Return result -->
	</func:function>


</xsl:stylesheet>
