<!-- Copyright (c) SWsoft, 1999-2007 All rights reserved. -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func browse hn voc cred vt"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:func="http://exslt.org/functions" 
  xmlns:env="http://www.swsoft.com/xsl/cp/env"
  xmlns:tem="http://www.swsoft.com/xsl/cp/tem"
  xmlns:units			="http://www.swsoft.com/xsl/cp/units" 
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"  
  xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"
  xmlns:hn				="http://www.swsoft.com/xsl/cp/hn"
  xmlns:browse="http://www.swsoft.com/xsl/cp/browse" 
>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include	href="/lib/core/browse-filter-vza.xsl"/> 
	<sw:include href="/lib/core/units-core.xsl"/>			
	<sw:include	href="/lib/vt/core.xsl"/> 
	<sw:include	href="/lib/vt/env-core.xsl"/> 
	<sw:include	href="/lib/vt/hn-core.xsl"/> 
	
 	<xsl:template name="hn:get-browse-cols">
		<xsl:param name="show-url" select="false()"/>
		<xsl:param name="id-cols" select="''"/>
		<xsl:param name="state" select="false()"/>
		<xsl:param name="compact" select="false()"/>

		
		<xsl:copy-of select="$id-cols"/>				
				
		<ui:column id="hostname" vza-id="env.config.hostname" nav-type="title" show-url="{sw:if($show-url,'yes','no')}" title="{sw:text('Hostname')}" filter="auto"/> 
		<ui:column id="ips" vza-id="env.config.ip_text" data-type="ip" title="{sw:text('IP Address')}"/>	
		<ui:column id="hn-vt-type" vza-id="env.config.child_type" apply-templates="yes" title="{sw:text('VT')}"
			custom-hidden="yes"
			custom-filter-hidden="yes"
		/>						
		<ui:column id="platform-os" title="{sw:text('Platform')}" vza-id="env.config.os.platform" filter="select" 
			filter-uncase="true" apply-templates="yes" align="center"
			filter-group="hn-status"
		>
			<xsl:copy-of select="vt:vza-platform-oses()"/>
		</ui:column>
		<ui:column id="os-name" vza-id="env.config.os.name" title="{sw:text('Operating System')}"/>			
		<ui:column id="architecture" vza-id="env.config.architecture" title="{sw:text('Architecture')}"/>			

		<xsl:if test="not($compact)">
			<ui:column id="env-cpu" title="{sw:text('CPU')}" vza-id="env.resource.cpu.percent" 
				align="left" apply-templates="yes"
				custom-hidden="yes"
			/>
			
				<ui:column id="env-disk" title="{sw:text('Disk')}" vza-id="env.resource.disk.percent" 
				align="left" apply-templates="yes" 
				 custom-filter-hidden="yes"
			/>
			<ui:column id="env-disk-usage"  vza-id="env.resource.disk.usage" hidden="yes"/>
			
			<ui:column id="env-memory" title="{sw:text('Memory')}" vza-id="env.resource.memory.percent" 
				align="left" apply-templates="yes" 
				 custom-filter-hidden="yes"
			/>
			<ui:column id="env-memory-usage"  vza-id="env.resource.memory.usage" hidden="yes"/>
			
			<ui:column id="hn-alert-type-icon" vza-id="env.alert_type" 
				title="{sw:text('Alert')}" align="center" apply-templates="yes"
				custom-hidden="yes" custom-filter-hidden="yes"  filter="select"
				filter-group="hn-status">
				<ui:filter-option type="custom" value-custom="='0'" 	value="not-ra"	title="{sw:text('Normal Operation')}"/>
				<ui:filter-option type="custom" value-custom="!='0'"	value="ra" 			title="{sw:text('Attention Required')}"/>
			</ui:column>
		</xsl:if>
 		<ui:column id="hn-status" vza-id="env.state" apply-templates="yes" title="{sw:text('Status')}"
			filter-group-title="{sw:text('Filter')}">  
			<xsl:attribute name="filter">select</xsl:attribute>
			<xsl:choose>
				<xsl:when test="$state">
					<xsl:attribute name="value"><xsl:value-of select="$state"/></xsl:attribute>
					<xsl:attribute name="filter">equal</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="filter">select</xsl:attribute>
					<xsl:call-template name="hn:get-states"/>
				</xsl:otherwise>
			</xsl:choose>
 		</ui:column>
			<ui:column id="transition" vza-id="env.transition" title="{sw:text('Transition')}" hidden="yes" vza-sort-with="hn-status" vza-sort-ord="1">
				<xsl:call-template name="env:get-transitions"/>
			</ui:column>
		<ui:column id="env-type" vza-id="env.config.type" hidden="yes">
			<ui:cond expr="in">
				<ui:cond-value>generic</ui:cond-value>
			</ui:cond>
		</ui:column>
		<ui:column id="parent-eid" vza-id="env.parent_eid" hidden="yes"/>
 	</xsl:template>

	<xsl:template name="hn:fill-filter">
		<xsl:param name="filter-rtf"/>			
		<xsl:param name="filter-dn" select="''"/>				
		
		<xsl:call-template name="browse:fill-from-vza">
			<xsl:with-param name="filter" select="exsl:node-set($filter-rtf)"/>
			<xsl:with-param name="sql-where">								
				<xsl:if test="$filter-dn!='' and not(units:are-dns-equal($filter-dn,units:infra-top-dn()))">				
				 (pager.env.eid in (unit '<xsl:value-of select="sw:sql-escape(units:decode-dn($filter-dn))"/>',recursive) )
				</xsl:if>
			</xsl:with-param>	
		</xsl:call-template>		
	</xsl:template>
		
	<xsl:template name="hn:browse">
		<xsl:param name="browse-url"/>
		<xsl:param name="filter-dn" select="''"/>
		<xsl:param name="first-buttons" select="/.."/>	
		
		<xsl:variable name="filter-rtf">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="hns" url="{$browse-url}" item-url="/vt/hns/hn"
						select-on-left="true"
						items-title="{sw:text('Nodes')}"
					>
					</ui:browse-setup>
	        <ui:cols sorting-col="hostname">
         		<ui:column id="id" hidden="yes" vza-id="env.eid" nav-type="id">
					    <xsl:attribute name="for-select">yes</xsl:attribute>					    
	         	</ui:column>
	         	<xsl:call-template name="hn:get-browse-cols">
	         		<xsl:with-param name="show-url" select="true()"/>
	         	</xsl:call-template>
	        </ui:cols>
				</xsl:with-param>
			</xsl:call-template>
    </xsl:variable>    
    <xsl:variable name="filter-data-rtf">
    	<xsl:call-template name="hn:fill-filter">
				<xsl:with-param name="filter-rtf" select="$filter-rtf"/>
				<xsl:with-param name="filter-dn" select="$filter-dn"/>				
			</xsl:call-template>
    </xsl:variable>
    <xsl:variable name="filter" select="exsl:node-set($filter-data-rtf)"/>
	
		<ui:browse>
		<xsl:attribute name="oncontext">linux.hn.vz.vt</xsl:attribute>
		<xsl:attribute name="oncontextplatform">platform-os</xsl:attribute>

    	<xsl:attribute name="title"><sw:text>Hardware Nodes</sw:text></xsl:attribute>    
        
        <ui:filter>
        	<xsl:copy-of select="$filter"/>
        </ui:filter>

				<ui:browse-js-many>
					<ui:warn>
						<sw:text>
							To perform any action on HNs in this list, you have to select at least one.
						</sw:text>
					</ui:warn>
				</ui:browse-js-many>

				<xsl:copy-of select="$first-buttons"/>
        <ui:browse-buttons>
  	    	<ui:button type="list-selection" tip="unregister_hw"
  	    		submit-href="{$baseurl}/vt/hns/list-control" icon="delete"
  	    		confirmation="{sw:text('Are you sure you want to unregister the selected Hardware Node(s)?')}" script="if (!atLeastOne()) return false;"
  	    		name="unregister" cred="vzcp.virtuozzo_group.manage">
						<sw:text>Unregister</sw:text>
					</ui:button>
        </ui:browse-buttons>
        
        <ui:browse-empty-msg>
          <sw:text>There are no available HNs.</sw:text>
        </ui:browse-empty-msg>        

      </ui:browse>

	</xsl:template>

</xsl:stylesheet>
