<!-- Copyright (c) SWsoft, 1999-2007 All rights reserved. -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc hn env"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:func="http://exslt.org/functions" 
  xmlns:vt="http://www.swsoft.com/xsl/cp/vt" 
  xmlns:env="http://www.swsoft.com/xsl/cp/env"
  xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"  
  xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
  xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>
	<sw:include href="/lib/cred-filter.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>		
	<sw:include	href="/lib/vt/core.xsl"/> 	
	<sw:include	href="/lib/vt/env-core.xsl"/> 
	<sw:include	href="/lib/vt/hn-core.xsl"/> 

<!--
	arguments:
			platform : 'os.arch' or 'os' or ''
	result:
	hns
		hn[]
			\eid
			\hostname			
			\ip
-->
	
	<func:function name="hn:list">
		<xsl:param name="filter-platform" select="''"/>
	
		<xsl:variable name="hns-query">				
			<fields>
				<env.eid/>
				<env.state />
				<env.config.hostname/>								
				<env.config.ip_text/>
				<env.config.os.platform/>
				<env.config.architecture/>
			</fields>
			<where>
				pager.env.config.type='generic'
				<xsl:choose>
					<xsl:when test="$filter-platform=''"/>
					<xsl:when test="not(vt:platform-contains-arch($filter-platform))">				
						and ( lower(pager.env.config.os.platform)='<xsl:value-of select="sw:lc(hn:platform2vza($filter-platform))"/>' )
					</xsl:when>
					<xsl:otherwise>
						and ( lower(pager.env.config.os.platform)='<xsl:value-of select="sw:lc(hn:platform2vza($filter-platform))"/>' )
						and ( pager.env.config.architecture='<xsl:value-of select="vt:platform2vza-architecture($filter-platform)"/>' )
					</xsl:otherwise>
				</xsl:choose>
			</where>
		</xsl:variable>
				

		<xsl:variable name="result-rtf">				
			<hns>
				<xsl:for-each select="sw:xchg-sql($hns-query)/pager/row_set/row/env">
					<hn>
						<eid><xsl:value-of select="eid"/></eid>
						<hostname><xsl:value-of select="config/hostname"/></hostname>
						<ip><xsl:value-of select="config/ip_text"/></ip>
						<platform><xsl:value-of select="hn:vza2platform(config/os/platform,config/architecture)"/></platform>
						<status><xsl:value-of select="state" /></status>
						<tech>vz.vt</tech>
					</hn>
				</xsl:for-each>
			</hns>
		</xsl:variable>
		
		<func:result select="exsl:node-set($result-rtf)/hns"/>
		
	</func:function>
	
	
	<!--
		arguments:
			platform : 'os.arch' or 'os' or ''
		result:
			eid
	-->
	<func:function name="hn:autoselect-for-create-ve">
		<xsl:param name="filter-platform" select="''"/>
		
		<func:result 
			select="cred:filter-valid-hw('vzcp.env.create',
				hn:list( $filter-platform )/hn[status=$env-state/running]/eid,false())[1]"/>
	</func:function>

	<!-- Transform ENVs NODESET to RTF with ui:list-item data -->
	<func:function name="hn:envs2ui-items">
		<xsl:param name="envs"/>
		<func:result>					
			<xsl:for-each select="$envs">				
				<xsl:sort select="env:env2title(.)"/>
				<ui:list-item id="{eid}" title="{env:env2title(.)}"/>
			</xsl:for-each>
		</func:result>
	</func:function>

	<xsl:template name="hn:multi-selector">
		<xsl:param name="eids"/>
		<xsl:param name="size" select="'20'"/>
		<xsl:param name="control-id" select="'hns'"/>
		<xsl:param name="parent-dn" select="''"/>
		<xsl:param name="state" select="''"/>
		<xsl:param name="platform" select="''"/>
		<xsl:param name="architecture" select="''"/>
		<xsl:param name="required" select="false()"/>
		
		<xsl:variable name="envs" select="env:get-env($eids)/env"/>
		
		<ui:row>
			<ui:cell-list-picker id="{$control-id}" size="{$size}" style="width:400px;" required="{$required}" 
				script-add="open_details('{$baseurl}/vt/hns/select-popup?id={$control-id}&amp;dn={$parent-dn}&amp;state={$state}&amp;platform={$platform}&amp;arch={$architecture}&amp;mode=list');"
			>
				<xsl:copy-of select="hn:envs2ui-items($envs)"/>
			</ui:cell-list-picker>
		</ui:row>				
		
	</xsl:template>
		
</xsl:stylesheet>
