<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date math func"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:math="http://exslt.org/math" 
	xmlns:func="http://exslt.org/functions">



	<!-- *************** Templates and functions used to calculate vzagent periods ************** -->
	
	<!-- This function is used when interval is specified by start and stop time points -->
	<func:function name="sw:vzagent-time-interval">
		<xsl:param name="from-date" />
		<xsl:param name="to-date" />

		<xsl:variable name="period-rtf">
			<xsl:call-template name="prepare-period-for-from-to-mode">
				<xsl:with-param name="from-date" select="$from-date" />
				<xsl:with-param name="to-date" select="$to-date" />
			</xsl:call-template>
		</xsl:variable>
		<func:result select="exsl:node-set($period-rtf)/one-record-period" />
	</func:function>
	
	
  <!-- This function is used when interval is specified by start and stop time points, going one interval back -->
  <func:function name="sw:vzagent-time-pre-interval">
    <xsl:param name="from-date" />
    <xsl:param name="to-date" />
    
    <xsl:variable name="period-rtf">
      <xsl:call-template name="prepare-period-for-pre-from-to-mode">
        <xsl:with-param name="from-date" select="$from-date" />
        <xsl:with-param name="to-date" select="$to-date" />
      </xsl:call-template>
    </xsl:variable>
    <func:result select="exsl:node-set($period-rtf)/one-record-period" />
  </func:function>
  
  
  <!-- This function is used when interval is specified by start date and  name of interval.
		Valid names are: 'day', 'month', 'year'		
	-->
	<func:function name="sw:vzagent-date-interval">
		<xsl:param name="interval-name" select="'day'" />
		<xsl:param name="start-date" select="date:date()" />

		<xsl:variable name="period-rtf">
			<xsl:choose>
				<xsl:when test="$interval-name = 'day'">
					<xsl:call-template name="prepare-period-for-day-mode">
						<xsl:with-param name="start-date" select="$start-date" />
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$interval-name = 'month'">
					<xsl:call-template name="prepare-period-for-month-mode">
						<xsl:with-param name="start-date" select="$start-date" />
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$interval-name = 'year'">
					<xsl:call-template name="prepare-period-for-year-mode">
						<xsl:with-param name="start-date" select="$start-date" />
					</xsl:call-template>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($period-rtf)/one-record-period" />
	</func:function>

	<xsl:template name="prepare-period-for-from-to-mode">
		<xsl:param name="from-date" />
		<xsl:param name="to-date" />

		<xsl:variable name="end-date-xml-format" select="$to-date" />
		<xsl:variable name="start-date-xml-format" select="$from-date" />

		<xsl:variable name="start-date-agent-format" select="sw:time2vzatime($start-date-xml-format)" />
		<xsl:variable name="end-date-agent-format" select="sw:time2vzatime($end-date-xml-format)" />
		<one-record-period>
			<start_time>
				<xsl:value-of select="$start-date-agent-format" />
			</start_time>
			<end_time>
				<xsl:value-of select="$end-date-agent-format" />
			</end_time>
			<period>
				<xsl:value-of select="date:seconds($end-date-xml-format) - date:seconds($start-date-xml-format)" />
			</period>
		</one-record-period>
	</xsl:template>

  <xsl:template name="prepare-period-for-pre-from-to-mode">
    <xsl:param name="from-date" />
    <xsl:param name="to-date" />
    
    <xsl:variable name="end-date-xml-format" select="$to-date" />
    <xsl:variable name="start-date-xml-format" select="$from-date" />
    
    <xsl:variable name="start-sec" select="date:seconds($start-date-xml-format)"/>
    <xsl:variable name="end-sec" select="date:seconds($end-date-xml-format)"/>
    <xsl:variable name="period" select="$end-sec - $start-sec"/>
    
    <xsl:variable name="start-date-agent-format" select="sw:utime2vzatime($start-sec - (2 * $period))" />
    <xsl:variable name="end-date-agent-format" select="sw:utime2vzatime($end-sec)" />
    <one-record-period>
      <start_time>
        <xsl:value-of select="$start-date-agent-format" />
      </start_time>
      <end_time>
        <xsl:value-of select="$end-date-agent-format" />
      </end_time>
      <period>
        <xsl:value-of select="$period" />
      </period>
    </one-record-period>
  </xsl:template>
  
  <xsl:template name="prepare-period-for-day-mode">
		<xsl:param name="start-date" select="date:date()" />

		<!-- calc start	and end date -->
		<xsl:variable name="start-date-xml-format" select="$start-date" />
		<xsl:variable name="end-date-xml-format" select="date:add($start-date-xml-format,string('P1D'))" />

		<!-- convert date to agent format -->
		<xsl:variable name="start-date-agent-format" select="sw:time2vzatime($start-date-xml-format)" />
		<xsl:variable name="end-date-agent-format" select="sw:time2vzatime($end-date-xml-format)" />

		<one-record-period>
			<start_time>
				<xsl:value-of select="$start-date-agent-format" />
			</start_time>
			<end_time>
				<xsl:value-of select="$end-date-agent-format" />
			</end_time>
			<period>
				<xsl:value-of select="3600" />
			</period>
		</one-record-period>
	</xsl:template>

	<xsl:template name="prepare-period-for-month-mode">
		<xsl:param name="start-date" select="date:date()" />

		<!-- calc start	and end date -->
		<xsl:variable name="start-date-xml-format" select="$start-date" />
		<xsl:variable name="end-date-xml-format" select="date:add($start-date-xml-format,string('P1M'))" />
		<!-- convert date to agent format -->
		<xsl:variable name="start-date-agent-format" select="sw:time2vzatime($start-date-xml-format)" />
		<xsl:variable name="end-date-agent-format" select="sw:time2vzatime($end-date-xml-format)" />
		<one-record-period>
			<start_time>
				<xsl:value-of select="$start-date-agent-format" />
			</start_time>
			<end_time>
				<xsl:value-of select="$end-date-agent-format" />
			</end_time>
			<period>
				<xsl:value-of select="86400" />
			</period>
		</one-record-period>
	</xsl:template>

	<xsl:template name="prepare-period-for-year-mode">
		<xsl:param name="start-date" select="date:date()" />

		<xsl:variable name="month-list-rtf">
			<month>
				<id>01</id>
				<days>31</days>
			</month>
			<month>
				<id>02</id>
				<days>
					<xsl:value-of select="sw:if(date:leap-year($start-date),'29','28')" />
				</days>
			</month>
			<month>
				<id>03</id>
				<days>31</days>
			</month>
			<month>
				<id>04</id>
				<days>30</days>
			</month>
			<month>
				<id>05</id>
				<days>31</days>
			</month>
			<month>
				<id>06</id>
				<days>30</days>
			</month>
			<month>
				<id>07</id>
				<days>31</days>
			</month>
			<month>
				<id>08</id>
				<days>31</days>
			</month>
			<month>
				<id>09</id>
				<days>30</days>
			</month>
			<month>
				<id>10</id>
				<days>31</days>
			</month>
			<month>
				<id>11</id>
				<days>30</days>
			</month>
			<month>
				<id>12</id>
				<days>31</days>
			</month>
		</xsl:variable>
		<xsl:variable name="month-list" select="exsl:node-set($month-list-rtf)" />

		<!-- calc start	and end date -->
		<xsl:variable name="start-date-xml-format" select="$start-date" />
		<xsl:variable name="end-date-xml-format" select="date:add($start-date-xml-format,string('P1Y'))" />

		<xsl:for-each select="$month-list/month">

			<xsl:variable name="start-diff" select="concat('P',number(id)-1,'M')" />
			<xsl:variable name="end-diff" select="concat('P',number(id),'M')" />

			<xsl:variable name="shifted-start-date" select="date:add($start-date-xml-format,string($start-diff))" />
			<xsl:variable name="shifted-end-date" select="date:add($start-date-xml-format,string($end-diff))" />

			<!-- convert date to agent format -->
			<xsl:variable name="start-date-agent-format" select="sw:time2vzatime($shifted-start-date)" />
			<xsl:variable name="end-date-agent-format" select="sw:time2vzatime($shifted-end-date)" />
			<one-record-period>
				<start_time>
					<xsl:value-of select="$start-date-agent-format" />
				</start_time>
				<end_time>
					<xsl:value-of select="$end-date-agent-format" />
				</end_time>
				<period>
					<xsl:value-of select="days * 86400" />
				</period>
			</one-record-period>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
