<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred local desktop func"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:func  ="http://exslt.org/functions"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"  
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:desktop ="http://www.swsoft.com/xsl/cp/desktop"
	xmlns:user-profile	="http://www.swsoft.com/xsl/cp/user-profile"
>
	<!--
		This file provides functions for VZCC customized desktop data storage.
	-->

	<!-- Includes -->
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/core/user-profile.xsl"/>	
	<!-- /Includes -->
	
	<!--
		Save customized desktop for current user
	
		data
			desktop
				actions
					show
					screen-id[]
				vz-lics
					show
					show-install
					show-request
				desktop
					save-default  (for sveuser)
	-->
	
	<func:function name="desktop:save">
		<xsl:param name="data" />
		<xsl:param name="replace-default" select="false()" />
		
		<xsl:if test="user-profile:set-attr(user-profile:logged-ref(),'desktopSettings', sw:base64-encode(sw:text($data)) )" />

		<!-- Replace default desktop -->
		<xsl:if test="$replace-default">
			<xsl:if test="not(sw:update-config('/vzcpcon/desktop-default/desktop',$data))">
				<sw:die>An error occured while config /vzcpcon/desktop updating.</sw:die>
			</xsl:if>
		</xsl:if>
		<!-- Replace default desktop -->
	</func:function>

	<!--
		Return default desktop content 
	-->
	<func:function name="desktop:load-default">
		<func:result select="$config/vzcpcon/desktop-default[@panel=$activeMode]/desktop"/>
	</func:function>
	
	<!-- 
		Load customized desktop data for current user 
	-->
	<func:function name="desktop:load">
		<xsl:param name="die-auth" select="true()"/>

		<xsl:variable name="user-desktop" select="user-profile:get-attr(user-profile:logged-ref(),'desktopSettings')"/>
		<xsl:choose>
			<xsl:when test="$user-desktop!=''">
				<func:result select="sw:node-set(sw:base64-decode($user-desktop))/desktop"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="desktop:load-default()"/>
			</xsl:otherwise>
		</xsl:choose>
		
	</func:function>
</xsl:stylesheet>
