<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
>
	<xsl:template match="/">
		<packet>
			<!--call status, config-->
			<xsl:apply-templates select="packet/event"/>
			<!--call alerts-->
			<xsl:apply-templates select="packet/data/event"/>
		</packet>
	</xsl:template>


	<xsl:template match="event">

	<xsl:variable name="status_type" select="info/parameter/parameter/name[.='type']"/>
	<xsl:variable name="status_dec">
		<xsl:if test="$status_type/../message!=''"><xsl:value-of select="sw:base64-decode($status_type/../message)"/></xsl:if>
	</xsl:variable>
		<xsl:choose>

			<xsl:when test="category='resource_alert'">
				<xsl:choose>
					<xsl:when test="$status_dec='virtuozzo'">
						<xsl:variable name="counter" select="data/event_data/counter"/>
						<xsl:variable name="cpu_val">
							<xsl:if test="$counter='cpu'"><xsl:value-of select="number(data/event_data/cur) div number(data/event_data/hard)*100"/></xsl:if>
						</xsl:variable>
						<xsl:variable name="disk_val">
							<xsl:if test="$counter='diskspace'"><xsl:value-of select="number(data/event_data/cur) div number(data/event_data/hard)*100"/></xsl:if>
						</xsl:variable>
						<xsl:variable name="mem_val">
							<xsl:if test="$counter='memory'"><xsl:value-of select="number(data/event_data/cur) div number(data/event_data/hard)*100"/></xsl:if>
						</xsl:variable>
						<!--
						ENV syntax:
						0	1			2			3			4	5		6	7		8		9			10			11		12		13					14
						%id,%type,%base64_name,%base64_host,%state, %cpu,%disk,%memory,%alert,%enabled,%base64_hn_name,%ve_id,%ips,%base64_ve_template,%base64_ve_desc
						-->
						<result><xsl:value-of select="data/event_data/eid"/>,eid,,,,<xsl:value-of select="$cpu_val"/>,<xsl:value-of select="$disk_val"/>,<xsl:value-of select="$mem_val"/>,<xsl:value-of select="data/event_data/type"/>,,,,,,,</result>
					</xsl:when>
					<xsl:when test="$status_dec='generic'">
						<!--
						HID syntax:
						0	1			2		3		4	5		6		7	8
						%id,%type,%base64_name,%state,%cpu,%disk,%memory,%alert,%ip';
						-->
						<result><xsl:value-of select="data/event_data/eid"/>,hid,,,,,,<xsl:value-of select="data/event_data/type"/>,,</result>
					</xsl:when>
				</xsl:choose>
			</xsl:when>

			<xsl:when test="category='env_status'">
				<xsl:choose>
					<xsl:when test="$status_dec='virtuozzo'">
						<!--
						ENV syntax:
						0	1			2			3			4	5		6	7		8		9			10			11		12		13					14
						%id,%type,%base64_name,%base64_host,%state, %cpu,%disk,%memory,%alert,%enabled,%base64_hn_name,%ve_id,%ips,%base64_ve_template,%base64_ve_desc
						-->
						<xsl:choose>
							<xsl:when test="data/event_data/new/transition">
								<result><xsl:value-of select="data/event_data/eid"/>,eid,,,tr-<xsl:value-of select="data/event_data/new/transition"/>,,,,,,,,,,,</result>
							</xsl:when>
							<xsl:otherwise>
								<result><xsl:value-of select="data/event_data/eid"/>,eid,,,<xsl:value-of select="data/event_data/new/state"/>,,,,,,,,,,,</result>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="$status_dec='generic'">
						<!--
						HID syntax:
						0	1			2		3		4	5		6		7	8
						%id,%type,%base64_name,%state,%cpu,%disk,%memory,%alert,%ip';
						-->
						<xsl:choose>
							<xsl:when test="data/event_data/new/transition">
								<result><xsl:value-of select="data/event_data/eid"/>,hid,<xsl:value-of select="sw:base64-encode(data/event_data/name)"/>,tr-<xsl:value-of select="data/event_data/new/transition"/>,,,,,,</result>
							</xsl:when>
							<xsl:otherwise>
								<result><xsl:value-of select="data/event_data/eid"/>,hid,<xsl:value-of select="sw:base64-encode(data/event_data/name)"/>,<xsl:value-of select="data/event_data/new/state"/>,,,,,,</result>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:variable name="unreg" select="'0'"/>
						<xsl:if test="data/event_data/old/state = $unreg and data/event_data/new/state != $unreg">
							<!--refresh if added-->
							<result><xsl:value-of select="data/event_data/eid"/>,refresh,<xsl:value-of select="$status_dec"/>,add,<xsl:value-of select="data/event_data/parent_eid"/>,<xsl:value-of select="data/event_data/old/state"/>,<xsl:value-of select="data/event_data/new/state"/>,</result>
						</xsl:if>
					</xsl:when>
				</xsl:choose>

				<!-- add refresh event -->
				<xsl:variable name="unexist" select="'1'"/>
				<xsl:if test="data/event_data/new/state = $unexist and data/event_data/old/state != $unexist">
					<!--refresh if deleted-->
					<result><xsl:value-of select="data/event_data/eid"/>,refresh,<xsl:value-of select="$status_dec"/>,delete,<xsl:value-of select="data/event_data/parent_eid"/>,<xsl:value-of select="data/event_data/old/state"/>,<xsl:value-of select="data/event_data/new/state"/>,</result>
				</xsl:if>
				<xsl:if test="data/event_data/old/state = $unexist and data/event_data/new/state != $unexist">
					<!--refresh if added-->
					<result><xsl:value-of select="data/event_data/eid"/>,refresh,<xsl:value-of select="$status_dec"/>,add,<xsl:value-of select="data/event_data/parent_eid"/>,<xsl:value-of select="data/event_data/old/state"/>,<xsl:value-of select="data/event_data/new/state"/>,</result>
				</xsl:if>

			</xsl:when>

			<xsl:when test="category='server_group_alert'">
				<!--
				HID syntax:
				0	1			2		3		4	5		6		7	8
				%id,%type,%base64_name,%state,%cpu,%disk,%memory,%alert,%ip';
				-->
				<result><xsl:value-of select="data/event_data/eid"/>,hid,<xsl:value-of select="sw:base64-encode(data/event_data/virtual_config/name)"/>,,,,,<xsl:value-of select="data/event_data/type"/>,,</result>
			</xsl:when>

			<xsl:when test="category='env_config'">
				<xsl:variable name="var_blank" select="'/|blank/|'"/>
				<xsl:choose>
					<xsl:when test="data/event_data/virtual_config/type='virtuozzo'">
						<xsl:variable name="var_hostname">
							<xsl:choose>
								<xsl:when test="data/event_data/virtual_config/hostname !=''"><xsl:value-of select="data/event_data/virtual_config/hostname"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="$var_blank"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="var_name">
							<xsl:choose>
								<xsl:when test="data/event_data/virtual_config/name !=''"><xsl:value-of select="data/event_data/virtual_config/name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="data/event_data/virtual_config/hostname"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="var_ip">
							<xsl:choose>
								<xsl:when test="data/event_data/virtual_config/net_device/ip_address/ip !=''"><xsl:value-of select="data/event_data/virtual_config/net_device/ip_address/ip"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="$var_blank"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="var_osname">
							<xsl:choose>
								<xsl:when test="data/event_data/virtual_config/os/name !=''"><xsl:value-of select="data/event_data/virtual_config/os/name"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="$var_blank"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="var_description">
							<xsl:choose>
								<xsl:when test="data/event_data/virtual_config/description !=''"><xsl:value-of select="data/event_data/virtual_config/description"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="sw:base64-encode($var_blank)"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="var_sample">
							<xsl:choose>
								<xsl:when test="data/event_data/virtual_config/origin_sample !=''"><xsl:value-of select="data/event_data/virtual_config/origin_sample"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="$var_blank"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="var_apps">
							<xsl:choose>
								<xsl:when test="data/event_data/virtual_config/template">
									<xsl:variable name="os_template" select="data/event_data/virtual_config/os_template/name"/>
									<xsl:variable name="platform" select="data/event_data/virtual_config/os/platform"/>
									<xsl:value-of select="data/event_data/parent_eid"/>|
									<xsl:for-each select="data/event_data/virtual_config/template">
										<xsl:if test="name!=''">app/<xsl:value-of select="$platform"/>//<xsl:value-of select="$os_template"/>/<xsl:value-of select="name"/>/<xsl:value-of select="version"/>|</xsl:if>
									</xsl:for-each>
								</xsl:when>
								<xsl:otherwise><xsl:value-of select="$var_blank"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						
						<!--
						ENV syntax:
						0	1			2			3			4	5		6	7		8		9			10			11		12		13				14				15				16				17						18
						%id,%type,%base64_name,%base64_host,%state,%cpu,%disk,%memory,%alert,%enabled,%base64_hn_name,%ve_id,%ips,%base64_ve_template,%base64_ve_desc,%base64_platform,%base64_arch,%base64_os_template,%base64_applications
						-->
						<result><xsl:value-of select="data/event_data/eid"/>,eid,<xsl:value-of select="sw:base64-encode($var_name)"/>,<xsl:value-of select="sw:base64-encode($var_hostname)"/>,,,,,,<xsl:value-of select="data/event_data/virtual_config/disabled"/>,,<xsl:value-of select="data/event_data/virtual_config/veid"/>,<xsl:value-of select="sw:base64-encode($var_ip)"/>,<xsl:value-of select="sw:base64-encode($var_sample)"/>,<xsl:value-of select="$var_description"/>,<xsl:value-of select="sw:base64-encode(data/event_data/virtual_config/os/platform)"/>,<xsl:value-of select="sw:base64-encode(data/event_data/virtual_config/architecture)"/>,<xsl:value-of select="sw:base64-encode($var_osname)"/>,<xsl:value-of select="sw:base64-encode($var_apps)"/></result>
					</xsl:when>
					<xsl:when test="data/event_data/config/type='generic'">
						<!--
						HID syntax:
						0	1			2		3		4	5		6		7	8
						%id,%type,%base64_name,%state,%cpu,%disk,%memory,%alert,%ip';
						-->
						<result><xsl:value-of select="data/event_data/eid"/>,hid,<xsl:value-of select="sw:base64-encode(data/event_data/config/hostname)"/>,,,,,,<xsl:value-of select="data/event_data/config/net_device/ip_address/ip"/></result>
					</xsl:when>
				</xsl:choose>
			</xsl:when>

		</xsl:choose>
	</xsl:template>
       
</xsl:stylesheet>
