<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"	
  xmlns:func="http://exslt.org/functions"	
>
	<!-- ****************** COMMON WIZARD FUNCTIONS ***************** 
		
			Every wizard screen/request files should declarate $wizard-code variable
			with wizard code, for example "newve" for VE Creation Wizard. That variable value
			will be used as a prefix for session keys.
	
	-->
	
	<xsl:param name="wiz_data" select="concat($wiz_code,'_wiz_data')"/>
	<xsl:param name="wiz_steps" select="concat($wiz_code,'_wiz_steps')"/>
	<xsl:param name="wiz_step" select="concat($wiz_code,'_wiz_step')"/>
	
	<func:function name="wiz:reset">
		<xsl:if test="sw:sesput($wiz_data,'')"/>
		<xsl:if test="sw:sesput($wiz_steps,'')"/>
		<xsl:if test="sw:sesput($wiz_step,'')"/>
		<func:result/>
	</func:function>
	
	<func:function name="wiz:post-form-step">
		<xsl:param name="form-data"/>	
		<xsl:param name="step"/>
		<func:result>
			<!-- Prevent session hack -->
			<ui:hidden name="_wiz_id" value="{$form-data/wizard-id}"/>    		
			<!-- Post step id -->
			<ui:hidden name="step" value="gen"/> 
		</func:result>
	</func:function>
	
	<func:function name="wiz:check-form-id">
		<xsl:param name="form-data"/>
		<xsl:variable name="session-form-id" select="$form-data/wizard-id"/>	
		<xsl:variable name="get-form-id" select="string(sw:param('_wiz_id'))"/>
		<func:result select="$get-form-id!='' and $session-form-id!='' and $get-form-id=$session-form-id"/>
	</func:function>
	
	<func:function name="wiz:clicked-back">
		<func:result select="sw:param('back')"/>
	</func:function>
	
	<func:function name="wiz:clicked-next">
		<func:result select="sw:param('next')"/>
	</func:function>
	
	<!-- Return key name for wizard data stored in session, you can also use $wiz_data variable -->
	<func:function name="wiz:getDataKey">
		<func:result select="$wiz_data"/>
	</func:function>
	
	<!-- Return key name for wizard data stored in session, you can also use $wiz_data variable -->
	<func:function name="wiz:data">
		<func:result select="sw:sesgettree($wiz_data)"/>
	</func:function>
	
	<func:function name="wiz:getStepID">
		<func:result select="sw:sesget($wiz_step)"/>
	</func:function>
	
	<func:function name="wiz:processing-step-id">
		<func:result select="string(sw:param('step'))"/>
	</func:function>
	
	<func:function name="wiz:init-data">
		<xsl:param name="step-now" select="wiz:processing-step-id()"/>
		<xsl:if test="$step-now!=''">
			<xsl:if test="sw:sesput($wiz_step,$step-now)"/>			
		</xsl:if>
		<func:result select="wiz:data()"/>
	</func:function>
	
	
	<func:function name="wiz:getStep">
		<func:result select="wiz:getSteps()/step[@id=wiz:getStepID()]"/>
	</func:function>
	
	<func:function name="wiz:getSteps">
		<func:result select="sw:sesget($wiz_steps)"/>
	</func:function>
	
	<func:function name="wiz:setSteps">
		<xsl:param name="steps"/>
		<xsl:variable name="res" select="sw:sesput($wiz_steps,exsl:node-set($steps))"/>
		<func:result/> 
	</func:function>
	
	<func:function name="wiz:goNext">
		<xsl:variable name="new_step" select="wiz:calcNext()"/>
		<xsl:if test="not($new_step)">
			<xsl:message terminate="yes">
				wizCalcNext() returned empty value
			</xsl:message>
		</xsl:if>
		<xsl:variable name="res" select="sw:sesput($wiz_step,$new_step)"/>
		<func:result/> 
	</func:function>	
	
	<func:function name="wiz:goBack">
		<xsl:variable name="new_step" select="wiz:calcBack()"/>
		<xsl:if test="not($new_step)">
			<xsl:message terminate="yes">
				wizCalcBack() returned empty value
			</xsl:message>
		</xsl:if>
		<xsl:variable name="res" select="sw:sesput($wiz_step,$new_step)"/>
		<func:result/>
	</func:function>
	
	<func:function name="wiz:calcBack">
		<xsl:param name="step" select="sw:sesget($wiz_step)"/><!-- Current Step ID-->
		<xsl:variable name="steps" select="sw:sesget($wiz_steps)/step[not(@enabled='0')]"/>
		
		<!-- Check current step ID -->
		<xsl:if test="not($steps[@id=$step])">
			<xsl:message terminate="yes">
				Can not find step with ID '<xsl:value-of select="$step"/>'
			</xsl:message>
		</xsl:if>
		
		<xsl:for-each select="$steps">
			<xsl:if test="@id=$step">
				<xsl:variable name="next_pos" select="position()-1"/>
				<xsl:choose>
					<xsl:when test="$next_pos=1">
						<func:result select="string($steps[1]/@id)"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="string($steps[position()=$next_pos]/@id)"/>
					</xsl:otherwise>
				</xsl:choose>				
			</xsl:if>
		</xsl:for-each>
		
	</func:function>
	
	<func:function name="wiz:calcNext">
		<xsl:param name="step" select="sw:sesget($wiz_step)"/><!-- Current Step ID-->
		<xsl:variable name="steps" select="sw:sesget($wiz_steps)/step[not(@enabled='0')]"/>
		
		<!-- Check current step ID -->
		<xsl:if test="not($steps[@id=$step])">
			<xsl:message terminate="yes">
				Can not find step with ID '<xsl:value-of select="$step"/>'
			</xsl:message>
		</xsl:if>
		
		<xsl:for-each select="$steps">
			<xsl:if test="@id=$step">
				<xsl:variable name="next_pos" select="position()+1"/>
				<xsl:choose>
					<xsl:when test="$next_pos > last()">
						<func:result select="string($steps[ position()=last()]/@id)"/>
					</xsl:when>
					<xsl:otherwise>
						<func:result select="string($steps[position()=$next_pos]/@id)"/>
					</xsl:otherwise>
				</xsl:choose>				
			</xsl:if>
		</xsl:for-each>
	</func:function>	  
	
	<xsl:template name="wiz:showButtons">
		<xsl:param name="buttons_" select="false()"/>
		<xsl:param name="buttons-ext" select="''"/>
		<xsl:param name="step" select="sw:sesget($wiz_step)"/><!-- Current Step ID-->
		<xsl:param name="show-back" select="true()"/>		
		<xsl:param name="show-cancel" select="true()"/>
		<xsl:param name="cancel-title" select="sw:text('Cancel')"/>
		<xsl:param name="show-submit" select="true()"/>
		<xsl:param name="force-show-submit" select="false()"/>
		<xsl:param name="submit-title" select="sw:text('Submit')"/>
		<xsl:param name="submit-tip" select="'wizard_finish'"/>
		<xsl:param name="submit-script" select="''"/>
		<xsl:param name="submit-sandclock" select="true()"/>		
		<xsl:param name="disable-submit" select="false()"/>
		<xsl:param name="next-title" select="sw:text('Next')"/>
		<xsl:param name="next-tip" select="'wizard_next_step'"/>				
		<xsl:param name="next-sandclock" select="false()"/>		
		<xsl:param name="next-script" select="''"/>	
		<xsl:param name="disable-next" select="false()"/>		
		<!--|-->
		<xsl:variable name="buttons">
			<xsl:if test="not($buttons_)">
				<xsl:if test="$show-back">
      		<ui:button type="back" tip="wizard_prev_step" name="back" sandclock="false" wizard="true"><sw:text>Back</sw:text></ui:button>
      	</xsl:if>
      	<xsl:copy-of select="$buttons-ext"/>
      	<ui:button id="ok" type="next" tip="{$next-tip}" name="next" sandclock="{sw:if($next-sandclock,'true','false')}">
      		<xsl:if test="$next-script!=''">
      			<xsl:attribute name="script"><xsl:value-of select="$next-script"/></xsl:attribute>
      		</xsl:if>
      		<xsl:if test="$disable-next">
	      			<xsl:attribute name="disabled">true</xsl:attribute>
	      		</xsl:if>
      		<xsl:value-of select="$next-title"/>
      	</ui:button>
      	<xsl:if test="$show-submit">
	      	<ui:button id="ok" type="ok" tip="{$submit-tip}" name="next" sandclock="{sw:if($submit-sandclock,'true','false')}">
	      		<xsl:if test="$force-show-submit">
	      			<xsl:attribute name="name">ok</xsl:attribute>
	      		</xsl:if>
	      		<xsl:if test="$submit-script!=''">
	      			<xsl:attribute name="script"><xsl:value-of select="$submit-script"/></xsl:attribute>
	      		</xsl:if>
	      		<xsl:if test="$disable-submit">
	      			<xsl:attribute name="disabled">true</xsl:attribute>
	      		</xsl:if>
	      		<xsl:value-of select="$submit-title"/>
	      	</ui:button>
	      </xsl:if>
      </xsl:if>     
      <xsl:if test="$buttons_">
      	<xsl:copy-of select="exsl:node-set($buttons_)"/>
      </xsl:if>
      <xsl:if test="$show-cancel">
      	<ui:button type="cancel" sandclock="false" tip="wizard_cancel">
      		<xsl:value-of select="$cancel-title"/>
      	</ui:button>
      </xsl:if>
    </xsl:variable>
		<!--|-->
		<xsl:variable name="last-step" select="wiz:isLastStep()"/>
		<xsl:variable name="first-step" select="wiz:isFirstStep()"/>
		
		<xsl:for-each select="exsl:node-set($buttons)/ui:button">
			<xsl:choose>
				<xsl:when test="@type='back' and @wizard='true' and $first-step">					
				</xsl:when>
				<xsl:when test="@type='next' and $last-step">					
				</xsl:when>
				<xsl:when test="@type='ok' and not($last-step) and not($force-show-submit)">					
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="."/>
				</xsl:otherwise>
			</xsl:choose>			
		</xsl:for-each>			
	</xsl:template>
		
	<func:function name="wiz:isLastStep">
		
		<xsl:variable name="step" select="wiz:getStepID()"/>
		<xsl:variable name="steps" select="wiz:getSteps()/step[not(@enabled='0')]"/>
		
		<!-- Check current step ID -->
		<xsl:if test="not($steps[@id=$step])">
			<xsl:if test="sw:sesput('xxxxxxxxxxxxxxxxxxxxxxxx-catch-for-88585',$steps)"/>
			<xsl:message terminate="yes">
				wiz:isLastStep(): Can not find step with ID '<xsl:value-of select="$step"/>'
			</xsl:message>
		</xsl:if>
		
		<func:result select="not( $steps[@id=$step]/following-sibling::step[not(@enabled='0')] )"/>				
	</func:function>	  
	
	<func:function name="wiz:isFirstStep">
	
		<xsl:variable name="step" select="wiz:getStepID()"/>
		<xsl:variable name="steps" select="wiz:getSteps()/step[not(@enabled='0')]"/>
		
		<!-- Check current step ID -->
		<xsl:if test="not($steps[@id=$step])">
			<xsl:if test="sw:sesput('xxxxxxxxxxxxxxxxxxxxxxxx-catch-for-88585',$steps)"/>		
			<xsl:message terminate="yes">
				wiz:isFirstStep(): Can not find step with ID '<xsl:value-of select="$step"/>'
			</xsl:message>
		</xsl:if>
		
		<func:result select="$steps[1]/@id=$step"/>				
	</func:function>	 
	
	<func:function name="wiz:setStepEnabled">
		<xsl:param name="step_id"/>
		<xsl:param name="enabled_bool"/> <!-- true or false -->
		
		<xsl:variable name="enabled" select="sw:if($enabled_bool,'1','0')"/>
		<xsl:variable name="steps" select="sw:sesget($wiz_steps)/step"/>
		
		<xsl:if test="$steps[@id=$step_id and string(enabled)!=$enabled]">
				<xsl:variable name="new_steps">
					<xsl:for-each select="$steps">
						<xsl:choose>
							<xsl:when test="@id!=$step_id">
								<xsl:copy-of select="."/>
							</xsl:when>
							<xsl:otherwise>
								<step>
									<xsl:copy-of select="@*[name()!='enabled']"/>
									<xsl:attribute name="enabled"><xsl:value-of select="$enabled"/></xsl:attribute>
								</step>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:if test="wiz:setSteps($new_steps)"/>
		</xsl:if>
		<func:result/>
	</func:function>
	
	<func:function name="wiz:setStepsEnabledExcept">
		<xsl:param name="except_step_id"/>
		<xsl:param name="enabled_bool"/> <!-- true or false -->
		
		<xsl:variable name="enabled" select="sw:if($enabled_bool,'1','0')"/>
		<xsl:variable name="steps" select="sw:sesget($wiz_steps)/step"/>
		
			<xsl:variable name="new_steps">
				<xsl:for-each select="$steps">
					<xsl:choose>
						<xsl:when test="not(@id=$except_step_id)">
							<step enabled="{$enabled}">
								<xsl:copy-of select="@*[not(self::enabled)]"/>
							</step>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:for-each>
			</xsl:variable>
			<xsl:if test="wiz:setSteps($new_steps)"/>
		<func:result/>
	</func:function>
	
</xsl:stylesheet>	
