<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local desktop"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:desktop		="http://www.swsoft.com/xsl/cp/desktop"
>
	<!-- Includes -->
	<sw:include href="/lib/vzcc/desktop.xsl"/>
	<!-- /Includes -->
	
	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'desktop-setup'"/>
	
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
										
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::desktop"></xsl:when>
							<xsl:when test="self::default"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<desktop>
						<!-- Restore 'actions' -->
						<actions>
							<show>
								<xsl:value-of select="
									sw:if(sw:param('actions_show')='1','true','false')
								"/>
							</show>
							<xsl:for-each select="sw:param('actions')">
								<screen-id><xsl:value-of select="."/></screen-id>
							</xsl:for-each>
						</actions>
						<!-- /Restore 'actions' -->
						<!-- Restore 'memo' -->
						<memo>
							<show>
								<xsl:value-of select="sw:if(sw:param('memo_show')='1','true','false')"/>
							</show>
							<text><xsl:value-of select="sw:html-escape(sw:param('memo_text'))"/></text>
						</memo>
						<!-- /Restore 'memo' -->
						<!-- Restore 'sections' -->
						<sections>
							<xsl:for-each select="sw:param('sections_left')">
								<section pos="left" id="{string(.)}"/>
							</xsl:for-each>
							<xsl:for-each select="sw:param('sections')">
								<section pos="right" id="{string(.)}"/>
							</xsl:for-each>
						</sections>
						<!-- /Restore 'sections' -->
						<!-- Restore 'vz-lics' -->
						<vz-lics>
							<show>
								<xsl:value-of select="sw:if(sw:param('vz_lics_show')='1','true','false')	"/>
							</show>
							<show-install>
								<xsl:value-of select="sw:if(sw:param('vz_lics_install')='1','true','false')"/>
							</show-install>
							<show-request>
								<xsl:value-of select="sw:if(sw:param('vz_lics_request')='1','true','false')"/>
							</show-request>
						</vz-lics>
						<!-- /Restore 'vz-lics' -->
						<!-- Restore 'vz-hn' -->
						<vz-hn>
							<show>
								<xsl:value-of select="sw:if(sw:param('vz_hn_show')='1','true','false')"/>
							</show>
							<show-links>
								<xsl:value-of select="
									sw:if(sw:param('vz_hn_links')='1','true','false')
								"/>
							</show-links>						
						</vz-hn>
						<!-- /Restore 'vz-hn' -->
						<!-- Restore 'vzpp-env' -->
						<vzpp-env>
							<show>
								<xsl:value-of select="
									sw:if(sw:param('vzpp_env_show')='1','true','false')
								"/>
							</show>							
						</vzpp-env>
						<!-- /Restore 'vzpp-env' -->
						<!-- Restore 'vzpp-download' -->
						<vzpp-download>
							<show>
								<xsl:value-of select="
									sw:if(sw:param('vzpp_download_show')='1','true','false')
								"/>
							</show>							
						</vzpp-download>
						<!-- /Restore 'vzpp-download' -->
						<vzcc-home>
							<xsl:value-of select="
								sw:if(sw:param('vzcc_home')='1','true','false')
							"/>
						</vzcc-home>
						<!-- Copy other data -->
						<xsl:copy-of select="$form/src/*"/>
						<!-- /Copy other data -->
					</desktop>
					<!-- Default desktop setting -->
					<default>
						<xsl:value-of select="
							sw:if(sw:param('desktop_default')='1','true','false')
						"/>
					</default>
					<!-- /Default desktop setting -->					
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				
				<xsl:if test="wiz:clicked-next()">
					<!-- check data -->	
				</xsl:if>
				
				<xsl:call-template name="local:complete-form-handling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:complete-form-handling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="wiz:clicked-next() and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:final-packet($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="wiz:clicked-back()">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<!-- Init form data -->
			<xsl:variable name="desktop-data" select="desktop:load()"/>
			<xsl:variable name="new_form">
				<xsl:copy-of select="$desktop-data"/>
				<src>
					<xsl:copy-of select="$desktop-data/favorites"/>
				</src>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<!-- *********************************************************** -->
	<func:function name="local:final-packet">
		<xsl:param name="data"/>
		<!-- Save new data -->
		<xsl:if test="desktop:save($data/desktop,$data/default='true')"/>
		<!-- /Save new data -->
		<!-- Refresh frameset in case of homepage changes -->
		<xsl:if test="$data/src/desktop/vzcc-home!=$data/desktop/vzcc-home">
			<xsl:if test="sw:sesput('frameset_redirect','yes')"/>
	    <xsl:if test="sw:sesput('frameset_url','core/desktop/index')"/>
	  </xsl:if>
		<!-- /Refresh frameset in case of homepage changes -->		
		<!-- Redirect with message -->
		<func:result>
 			<packet>
        <cookie>
          <msg>
            <set-ok><sw:text>Desktop has been customized.</sw:text></set-ok>
          </msg>
          <redirect-prev/>
        </cookie>						
			</packet>
		</func:result>
		<!-- /Redirect with message -->		
		
	</func:function>
	
	
  <!-- credentials -->	
	<sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
