<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:error			="http://www.swsoft.com/xsl/cp/error"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred 		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:jobs		="http://www.swsoft.com/xsl/cp/jobs"
>
  <sw:include href="/lib/common.xsl"/>
  <sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/core/jobs/core.xsl"/>		  

  <xsl:output method="xml"/>

  <!-- check permissions to this page -->
	<xsl:variable name="cr-enable"	select="cred:check('vzcp.full_control')"/>
  <xsl:variable name="cr-disable"	select="$cr-enable"/>
	<xsl:variable name="cr-delete"	select="$cr-enable"/>
  
	<xsl:template match="/">
		<xsl:variable name="ids" select="sw:param('id')"/>
		<xsl:choose>
		
				<xsl:when test="sw:param('remove') and not($cr-delete)">	
					<!-- no delete cred -->
					<packet/>
				</xsl:when>
				
				<xsl:when test="sw:param('enable') and not($cr-enable)">	
					<!-- no enable cred -->
					<packet/>
				</xsl:when>
				
				<xsl:when test="sw:param('disable') and not($cr-disable)">	
					<!-- no disable cred -->
					<packet/>
				</xsl:when>
				

        <!-- Check selected items -->
        <xsl:when test="not($ids)">
          <xsl:if test="error:put(sw:text('Please select at least one operation.'),'')"/>
          <packet/>
        </xsl:when>

        <!-- Delete item -->
        <xsl:when test="sw:param('remove')">
        	<xsl:copy-of select="local:get-packet-delete($ids)"/>
        	<xsl:if test="sw:response('lib/opredirect.xsl')"/>	
        </xsl:when>
        
         <!-- Enable item -->
        <xsl:when test="sw:param('enable')">
        	<xsl:copy-of select="local:get-packet-enable($ids)"/>
        	<xsl:if test="sw:response('lib/opredirect.xsl')"/>	
        </xsl:when>
        
        <!-- Disable item -->
        <xsl:when test="sw:param('disable')">
        	<xsl:copy-of select="local:get-packet-disable($ids)"/>
        	<xsl:if test="sw:response('lib/opredirect.xsl')"/>	
        </xsl:when>
        
        <!-- Unknown post -->
        <xsl:otherwise>
          <packet/>
        </xsl:otherwise>

      </xsl:choose>
  </xsl:template>
  
  <func:function name="local:get-packet-delete">
  	<xsl:param name="ids"/>
 		<func:result>
 			<packet log="on">
				<target>scheduler</target>
				<cookie>
					<msg>
						<ok><sw:text>The task(s) has/have been deleted.</sw:text></ok>
						<error><sw:text>Failed to delete the task(s).</sw:text></error>
					</msg>
					<operation>delete_task</operation>
					<redirect-last/>
				</cookie>			
				<data>
					<scheduler>						
						<xsl:for-each select="$ids">									
							<remove>	
								<id>
									<xsl:value-of select="."/>
								</id>
							</remove>
						</xsl:for-each>													
					</scheduler>
				</data>
			</packet>
 		</func:result>
  </func:function> 
  
  <func:function name="local:get-packet-enable">
  	<xsl:param name="ids"/>
 		<func:result>
 			<packet log="on"
 				xmlns:xsi ="http://www.w3.org/2001/XMLSchema-instance"	
				xmlns:vza-scheduler ="http://www.swsoft.com/webservices/vzl/4.0.0/scheduler"	 			
 			>
				<target>scheduler</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>The task(s) has/have been enabled.</sw:text></ok>
	            <error><sw:text>Failed to enable the task(s).</sw:text></error>
	          </msg>
	          <operation>enable_task</operation>
	          <redirect-last/>
	        </cookie>			
				<data>
					<scheduler>						
						<xsl:for-each select="$ids">									
							<xsl:variable name="src-job" select="jobs:find-by-id(.)"/>
							<xsl:variable name="new-job-rtf">
								<job>
									<xsl:copy-of select="$src-job/*[not(self::enabled)]"/>
									<enabled>true</enabled>
								</job>
							</xsl:variable>
							<update>
								<xsl:call-template name="jobs:construct-task-from-job">
									<xsl:with-param name="job" select="exsl:node-set($new-job-rtf)/job"/>
								</xsl:call-template>
							</update>
						</xsl:for-each>													
					</scheduler>
				</data>
			</packet>
 		</func:result>
  </func:function> 
  
  <func:function name="local:get-packet-disable">
  	<xsl:param name="ids"/>
 		<func:result>
 			<packet log="on"
 				xmlns:xsi ="http://www.w3.org/2001/XMLSchema-instance"	
				xmlns:vza-scheduler ="http://www.swsoft.com/webservices/vzl/4.0.0/scheduler"	
 			>
				<target>scheduler</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>The task(s) has/have been disabled.</sw:text></ok>
	            <error><sw:text>Failed to disable the task(s).</sw:text></error>
	          </msg>
	          <operation>disable_operation</operation>
	          <redirect-last/>
	        </cookie>			
				<data>
					<scheduler>						
						<xsl:for-each select="$ids">									
							<xsl:variable name="src-job" select="jobs:find-by-id(.)"/>
							<xsl:variable name="new-job-rtf">
								<job>
									<xsl:copy-of select="$src-job/*[not(self::enabled)]"/>
									<enabled>false</enabled>
								</job>
							</xsl:variable>
							<xsl:variable name="new-task-rtf">
								<xsl:call-template name="jobs:construct-task-from-job">
									<xsl:with-param name="job" select="exsl:node-set($new-job-rtf)/job"/>
								</xsl:call-template>							
							</xsl:variable>
							<update>
								<xsl:copy-of select="$new-task-rtf"/>
							</update>
						</xsl:for-each>									
					</scheduler>
				</data>
			</packet>
 		</func:result>
  </func:function> 
 
</xsl:stylesheet>
