<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error action date time jobs"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action		="http://www.swsoft.com/xsl/cp/action"	
	xmlns:date			="http://exslt.org/dates-and-times"
	xmlns:time			="http://www.swsoft.com/xsl/cp/time" 
	xmlns:jobs			="http://www.swsoft.com/xsl/cp/jobs"
	xmlns:backups		="http://www.swsoft.com/xsl/cp/backups"	
>
	<!-- Import required modules -->
	<sw:include href="/lib/wizard.xsl"/>	
	<sw:include href="/lib/date-time.xsl"/>	
	<sw:include href="/lib/core/jobs/core.xsl"/>			
	<sw:include href="/lib/vt/backups-core.xsl"/>		
	<sw:include href="/lib/vt/backups-forms.xsl"/>			
	<!-- /Import required modules -->

	<xsl:output method="xml"/>
	
	<xsl:param name="wiz_code" select="'jobs_manage'"/>	
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "Start" -->
			<xsl:when test="$step='start'">
						
					<xsl:variable name="cats" select="jobs:categories()"/>						
					<xsl:variable name="category" select="sw:param('category')"/>
					<xsl:variable name="category-changed" select="$category!=$form/job/category"/>

						
					<xsl:variable name="new-form-rtf">
						<xsl:copy-of select="$form/*[not(self::job)]"/>
						<job>
							<xsl:copy-of select="$form/job/*[not(self::category or self::title)]"/>
							<category><xsl:value-of select="$category"/></category>
							<title>
								<xsl:choose>
									<xsl:when test="$category-changed">
										<xsl:value-of select="$cats[@value=$category]/@title"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$form/job/title"/>
									</xsl:otherwise>
								</xsl:choose>
							</title>
						</job>
					</xsl:variable>
					<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- CHECK DATA -->
						<!-- Check childs-type -->
			      <xsl:choose>
 				      <!-- check presence -->
				      <xsl:when test="$new-form/job/category=''">
				      	<xsl:value-of select="error:put(sw:text('Please select an action.'),'','category')"/>
				      </xsl:when>
						</xsl:choose>
						<!-- /Check childs-type -->
						<!-- /CHECK DATA -->
					</xsl:if>
					
					<xsl:if test="wiz:setStepsEnabledExcept('start',false())"/>
					<xsl:choose>
						<xsl:when test="$new-form/job/category='vz.backup.ves'">
							<xsl:if test="wiz:setStepEnabled('vz-backup-ves',true())"/>
						</xsl:when>												
						<xsl:when test="$new-form/job/category='vz.restart.ves'">
							<xsl:if test="wiz:setStepEnabled('vz-restart-ves',true())"/>
						</xsl:when>												
					</xsl:choose>
										
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new-form"/>
					</xsl:call-template>
					
			</xsl:when>			
			
			<!-- Step "Backup VEs" -->
			<xsl:when test="$step='vz-backup-ves'">					
				<xsl:variable name="new-form-rtf">
					<xsl:copy-of select="$form/*[not(self::job)]"/>
					<job>
						<xsl:copy-of select="$form/job/*[not(
							self::specific or	self::title or self::description or self::timer or self::ves or self::enabled
						)]"/>
						<xsl:call-template name="local:copy-common-job-from-post"/>
						<xsl:call-template name="local:copy-ves-from-post"/>
						<specific>
							<backup-options>
								<xsl:call-template name="backups:restore-backup-options"/>
							</backup-options>
							<backup-exclude>
								<xsl:call-template name="backups:restore-backup-paths">
									<xsl:with-param name="list-type" select="'exclude'"/>								
								</xsl:call-template>							
							</backup-exclude>
							<backup-include>
								<xsl:call-template name="backups:restore-backup-paths">
									<xsl:with-param name="list-type" select="'include'"/>								
								</xsl:call-template>														
							</backup-include>
						</specific>
					</job>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
					
				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA -->												
					<xsl:if test="not($new-form/job/ves/eid)">
						<xsl:if test="error:put(sw:text('Please select at least one Container.'),'','')"/>
					 </xsl:if>
					<xsl:if test="local:check-common-job($new-form)"/>
					<!-- /CHECK DATA -->
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>								
			<!-- /Step "Backup VEs" -->
			
			<!-- Step "Restart VEs" -->
			<xsl:when test="$step='vz-restart-ves'">					
				<xsl:variable name="new-form-rtf">
					<xsl:copy-of select="$form/*[not(self::job)]"/>
					<job>
						<xsl:copy-of select="$form/job/*[not(
							self::specific or	self::title or self::description or self::timer or self::ves or self::enabled
						)]"/>						
						<xsl:call-template name="local:copy-common-job-from-post"/>
						<xsl:call-template name="local:copy-ves-from-post"/>
					</job>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
					
				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA -->												
					<xsl:if test="not($new-form/job/ves/eid)">
						<xsl:if test="error:put(sw:text('Please select at least one Container.'),'','')"/>
					 </xsl:if>
					<xsl:if test="local:check-common-job($new-form)"/>
					<!-- /CHECK DATA -->
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>								
			<!-- /Step "Restart VEs" -->
			
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:call-template name="local:get-final-packet">
									<xsl:with-param name="data" select="$data"/>
								</xsl:call-template>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.full_control'))"/>
		<xsl:if test="$step = ''">						
			<xsl:choose>
				<xsl:when test="sw:param('mode')='new'">					
					<xsl:call-template name="local:init-form-create"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="job-id" select="sw:sesgetstr('job-id')"/>		
					<sw:die test="$job-id=''">
						No Job ID in session.
					</sw:die>
					<xsl:call-template name="local:init-form-edit">
						<xsl:with-param name="job-id" select="$job-id"/>
					</xsl:call-template>					
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<xsl:template name="local:init-form-edit">
		<xsl:param name="job-id"/>
		
		<xsl:variable name="job" select="jobs:find-by-id($job-id)"/>
		
		<xsl:variable name="new-form-rtf">	
			<job>
				<xsl:copy-of select="$job/*"/>
			</job>
		</xsl:variable>
		
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<xsl:choose>
				<xsl:when test="$job/category='vz.backup.ves'">
					<step id="vz-backup-ves" screen-id="14.00.00.02.01" enabled="1"/>			
				</xsl:when>
				<xsl:when test="$job/category='vz.restart.ves'">
					<step id="vz-restart-ves" screen-id="14.00.00.02.02" enabled="1"/>			
				</xsl:when>
				<xsl:otherwise>
					<sw:die>
						Unknown task type '<xsl:value-of select="$task-category"/>'
					</sw:die>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[@enabled='1'][1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new-form-rtf))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template name="local:init-form-create">
		<!-- Read current time -->
		<xsl:variable name="now-day" select="date:day-in-month()"/>
		<xsl:variable name="now-month" select="date:month-in-year()"/>
		<xsl:variable name="now-week" select="date:week-in-month()"/>
		<xsl:variable name="now-weekday" select="date:day-in-week()-1"/>
		<!-- Init default data -->
		<xsl:variable name="start-type" select="string(sw:param('unit-type'))"/>		
		<xsl:variable name="new-form-rtf">		
			<job>
				<title>New Task</title>
				<xsl:if test="$start-type">
					<category>
						<xsl:value-of select="$start-type"/>
					</category>
				</xsl:if>
				<xsl:call-template name="local:copy-ves-from-post"/>
				<enabled>true</enabled>
				<timer>
					<time>23:59</time>
					<start-date><xsl:value-of select="time:time2web(date:date())"/></start-date>
					<recurrence-type>none</recurrence-type>
					<end-mode>none</end-mode>
					<daily-type>every</daily-type>
					<daily-every-days>1</daily-every-days>
					<weekly-weeks>1</weekly-weeks>
					<weekly-day><xsl:value-of select="$now-weekday"/></weekly-day>
					<monthly-mode>day</monthly-mode>
					<monthly-day-day><xsl:value-of select="$now-day"/></monthly-day-day>
					<monthly-day-month><xsl:value-of select="$now-month"/></monthly-day-month>
					<monthly-ext-month>1</monthly-ext-month>
					<yearly-mode>every</yearly-mode>
					<yearly-every-month><xsl:value-of select="$now-month"/></yearly-every-month>
					<yearly-every-day><xsl:value-of select="$now-day"/></yearly-every-day>
				</timer>
			</job>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="start" screen-id="14.00.00.01.00" enabled="{sw:if($start-type='','1','0')}"/>
			<step id="vz-backup-ves" screen-id="14.00.00.01.01" enabled="{sw:if($start-type='' or $start-type='vz.backup.ves','1','0')}"/>			
			<step id="vz-restart-ves" screen-id="14.00.00.01.02" enabled="{sw:if($start-type='' or $start-type='vz.restart.ves','1','0')}"/>			
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[@enabled='1'][1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new-form-rtf))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
		
	</xsl:template>
	
	<!-- *********************************************************** -->
	<xsl:template name="local:get-final-packet">
		<xsl:param name="data"/>
		
		<xsl:call-template name="jobs:construct-update-packet">
			<xsl:with-param name="job" select="$data/job"/>
		</xsl:call-template>

	</xsl:template>
	
	<func:function name="local:make-start-time">
		<xsl:param name="data"/>
		<func:result>
			<start_time>
				<xsl:value-of select="time:web2vzatime($data/task/start-date, $data/task/time)"/>
			</start_time>	
		</func:result>
	
	</func:function>
	
	<func:function name="local:make-schedule">
		<xsl:param name="data"/>
		<xsl:variable name="task" select="$data/task"/>
		<xsl:variable name="time-set" select="sw:split($task/time,':')"/>
		<xsl:choose>			
			<!-- daily -->
			<xsl:when test="$task/recurrence-type='daily'">				
				<func:result>	
					<time>
						<id>minute</id>
						<value><xsl:value-of select="$time-set[2]"/></value>
					</time>
					<time>
						<id>hour</id>
						<value><xsl:value-of select="$time-set[1]"/></value>
					</time>
					<time>
						<id>day_of_month</id>
						<each_of><xsl:value-of select="$task/daily-every-days"/></each_of>
					</time>
					<time>
						<id>month</id>
					</time>
					<time>
						<id>year</id>
					</time>
				</func:result>
			</xsl:when>
			<!-- /daily -->
			<!-- weekly -->
			<xsl:when test="$task/recurrence-type='weekly'">	
				<func:result>	
					<time>
						<id>minute</id>
						<value><xsl:value-of select="$time-set[2]"/></value>
					</time>
					<time>
						<id>hour</id>
						<value><xsl:value-of select="$time-set[1]"/></value>
					</time>
					<time>
						<id>day_of_week</id>
						<xsl:for-each select="$task/weekly-day">
							<value><xsl:value-of select="."/></value>
						</xsl:for-each>
					</time>
					<time>
						<id>week</id>
						<each_of><xsl:value-of select="$task/weekly-weeks"/></each_of>
					</time>
					<time>
						<id>year</id>
					</time>
				</func:result>
			</xsl:when>		
			<!-- /weekly -->
			<!-- Monthly -->
			<xsl:when test="$task/recurrence-type='weekly'">	
				<func:result>	
					<time>
						<id>minute</id>
						<value><xsl:value-of select="$time-set[2]"/></value>
					</time>
					<time>
						<id>hour</id>
						<value><xsl:value-of select="$time-set[1]"/></value>
					</time>	
					<!-- day -->
					<xsl:if test="$task/monthly-mode='day'">
						<time>
							<id>day_of_month</id>
							<value><xsl:value-of select="$task/monthly-day-day"/></value>
						</time>	
						<time>
							<id>month</id>
							<each_of><xsl:value-of select="$task/monthly-day-month"/></each_of>
						</time>							
					</xsl:if>	
					<!-- /day -->
					<!-- ext -->
					<xsl:if test="$task/monthly-mode='ext'">	
						<xsl:copy-of select="local:day($task/monthly-ext-day-index,$task/monthly-ext-day)"/>
						<time>
							<id>month</id>
							<each_of><xsl:value-of select="$task/monthly-ext-month"/></each_of>
						</time>						
					</xsl:if>
					<!-- /ext -->
					<time>
						<id>year</id>
					</time>						
				</func:result>	
			</xsl:when>	
			<!-- Monthly -->
			<!-- Yearly -->
			<xsl:when test="$task/recurrence-type='yearly'">	
				<func:result>	
					<time>
						<id>minute</id>
						<value><xsl:value-of select="$time-set[2]"/></value>
					</time>
					<time>
						<id>hour</id>
						<value><xsl:value-of select="$time-set[1]"/></value>
					</time>	
					<xsl:choose>	
						<!-- yearly_mode_every -->
						<xsl:when test="$task/yearly-mode='every'">			
							<time>
								<id>day_of_month</id>
								<value><xsl:value-of select="$task/yearly-every-day"/></value>
							</time>		
							<time>
								<id>month</id>
								<value><xsl:value-of select="$task/yearly-every-month"/></value>
							</time>		
						</xsl:when>
						<!-- /yearly_mode_every -->
						<!-- yearly_mode_ext -->
						<xsl:when test="$task/yearly-mode='every'">										
							<xsl:copy-of select="local:day($task/yearly-ext-week,$task/yearly-ext-day)"/>
							<time>
								<id>month</id>
								<value><xsl:value-of select="$task/yearly-ext-month"/></value>
							</time>
						</xsl:when>
						<!-- /yearly_mode_ext -->
					</xsl:choose>
					<time>
						<id>year</id>
					</time>	
				</func:result>
			</xsl:when>
			<!-- /Yearly -->
		</xsl:choose>
	</func:function>
	
	<func:function name="local:days">
		<xsl:param name="week"/>
		<xsl:param name="day"/>
		<func:result>
		
			<xsl:choose>					
				<xsl:when test="$day='day'">					
					<time>
						<id>day_of_month</id>
						<value><xsl:value-of select="$task/monthly-ext-day-index"/></value>
					</time>							
				</xsl:when>
				<!--|-->
				<xsl:when test="$day='weekday'">					
					<time>
						<id>day_of_week</id>
						<value>1</value>
					</time>
					<time>
						<id>day_of_month</id>
						<xsl:copy-of select="local:week-days($week)"/>
					</time>		
				</xsl:when>
				<!--|-->
				<xsl:when test="$day='weekend'">					
					<time>
						<id>day_of_week</id>
						<value>6</value>
					</time>
					<time>
						<id>day_of_month</id>
						<xsl:copy-of select="local:week-days($week)"/>
					</time>		
				</xsl:when>
				<!--|-->
				<xsl:otherwise>
					<time>
						<id>day_of_week</id>
						<value><xsl:value-of select="$day"/></value>
					</time>
					<time>
						<id>day_of_month</id>
						<xsl:copy-of select="local:week-days($week)"/>
					</time>		
				</xsl:otherwise>
				<!--|-->
			</xsl:choose>
			
		</func:result>
	</func:function>
	
	<func:function name="local:week-days">
		<xsl:param name="week"/>
		<func:result>
			<xsl:choose>
				<xsl:when test="$week=l">
					<value>1</value><value>2</value><value>3</value><value>4</value>
					<value>5</value><value>6</value><value>7</value>
				</xsl:when>
				<xsl:when test="$week=2">
					<value>8</value><value>9</value><value>10</value><value>11</value>
					<value>12</value><value>13</value><value>14</value>
				</xsl:when>
				<xsl:when test="$week=3">
					<value>15</value><value>16</value><value>17</value><value>18</value>
					<value>19</value><value>20</value><value>21</value>
				</xsl:when>
				<xsl:when test="$week=4">
					<value>22</value><value>23</value><value>24</value><value>25</value>
					<value>26</value><value>27</value><value>28</value>
				</xsl:when>
			</xsl:choose>
		</func:result>
	</func:function>
	

	
	<func:function name="local:make-internal-packet-task">
		<xsl:param name="data"/>
		<func:result>
			<task-data>
				<xsl:copy-of select="$data/*[not(self::task-id or self::task-gen)]"/>
			</task-data>
		</func:result>
	</func:function>

	<!-- Read Job common data from POST -->
	<xsl:template name="local:copy-common-job-from-post">			
		
		<!-- Read modified data from POST -->
		<title>
			<xsl:value-of select="sw:param('title')"/>
		</title>
		<description>
			<xsl:value-of select="sw:param('description')"/>
		</description>
		<enabled>
			<xsl:value-of select="sw:if(sw:param('enabled')='1','true','false')"/>
		</enabled>
		<timer>
			<xsl:call-template name="jobs:restore-timer-time"/>
			<xsl:variable name="recurrence-type" select="sw:param('recurrence_type')"/>
			<recurrence-type>
				<xsl:value-of select="$recurrence-type"/>
			</recurrence-type>
			<end-mode>
				<xsl:value-of select="sw:param('end_mode')"/>
			</end-mode>
			<end-date>
				<xsl:value-of select="sw:param('end_date')"/>
			</end-date>
			<!-- Daily -->
			<xsl:variable name="daily-type" select="sw:param('daily_type')"/>
			<daily-type>
				<xsl:value-of select="$daily-type"/>
			</daily-type>
			<daily-every-days>
				<xsl:value-of select="sw:param('daily_every_days')"/>
			</daily-every-days>
			<!-- /Daily -->
			<!-- Weekly -->
			<weekly-weeks>	
				<xsl:value-of select="sw:param('weekly_weeks')"/>		
			</weekly-weeks>
			<xsl:for-each select="sw:param('weekly_day')">
				<weekly-day>
					<xsl:value-of select="."/>
				</weekly-day>
			</xsl:for-each>
		</timer>
	</xsl:template>   
	<!-- /Read Job common data from POST -->
	
	<!-- Read Job common data from POST -->
	<xsl:template name="local:copy-ves-from-post">	
		<ves>															
			<xsl:for-each select="sw:param('envs')">
				<eid>
					<xsl:value-of select="."/>
				</eid>
			</xsl:for-each>	
		</ves>
	</xsl:template>
	
	<func:function name="local:check-common-job">			
		<xsl:param name="new-form"/>
		
		<xsl:variable name="timer" select="$new-form/job/timer"/>

		
		<!-- Check title -->
    <xsl:choose>
      <!-- check presence -->
      <xsl:when test="string($new-form/job/title)=''">
      	<xsl:if test="error:put(sw:text('Please specify the task title.'),'','title')"/>
      </xsl:when>
		</xsl:choose>
		<!-- /Check title -->

		<!-- Check time  and date -->
		<xsl:call-template name="jobs:check-timer-time">
			<xsl:with-param name="timer" select="$timer"/>
		</xsl:call-template>
		
		<!-- Check end date-->
    <xsl:choose>
    	<!-- check for none -->
      <xsl:when test="$timer/end-mode='none'">      	
      </xsl:when>
      <!-- check presence -->
      <xsl:when test="string($timer/end-date)=''">
      	<xsl:if test="error:put(sw:text('Please specify the end date.'),'','end_date')"/>
      </xsl:when>
      <!-- check format -->
      <xsl:when test="not(sw:re-test($timer/end-date,$global-date-regexp-check))">
		<xsl:variable name="err">
			<sw:text>
				<xsl:with-param name="format" select="$global-date-format"/>
				Please correct the end date. The valid format is %{format}.
			</sw:text>
		</xsl:variable>
      	<xsl:if test="error:put($err,'','end_date')"/>
      </xsl:when>
		</xsl:choose>
		<!-- /Check start date-->
		
		<!-- Check recurr/daily -->
		<xsl:if test="$timer/recurrence-type='daily'">
			<xsl:if test="not($timer/daily-type!='')">
				<xsl:if test="error:put(sw:text('Please specify the daily recurrence type.'),'','daily_every')"/>
				<xsl:if test="error:add-control('daily_every_days')"/>
				<xsl:if test="error:add-control('daily_weekday')"/>
				<xsl:if test="error:add-control('daily_sunday')"/>
			</xsl:if>
			<xsl:if test="$timer/daily-type='every'">
				<!-- check days -->
	      <xsl:if test="$timer/daily-every-days='' or not(check:num($timer/daily-every-days)) or number($timer/daily-every-days)=0">
	      	<xsl:if test="error:put(sw:text('Please correct the days value.'),'','daily_every_days')"/>
	      </xsl:if>
				<!-- /check days -->
			</xsl:if>
		</xsl:if>
		<!-- /Check recurr/daily -->
		
		<!-- Check recurr/weekly -->
		<xsl:if test="$timer/recurrence-type='weekly'">
			<!-- check weeks -->
      <xsl:if test="not(check:num($timer/weekly-weeks))">
      	<xsl:if test="error:put(sw:text('Please correct the weeks value.'),'','weekly_weeks')"/>
      </xsl:if>
			<!-- /check weeks -->
			<!-- check days -->
      <xsl:if test="not($timer/weekly-day)">
      	<xsl:if test="error:put(sw:text('Please select at least one week day.'),'','weekly_day')"/>
      </xsl:if>
			<!-- /check days -->
		</xsl:if>
		<!-- /Check recurr/weekly -->
	
	</func:function>
  
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>				
	
	
</xsl:stylesheet>
