<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error action"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action		="http://www.swsoft.com/xsl/cp/action"	
	xmlns:hn				="http://www.swsoft.com/xsl/cp/hn"  	
	xmlns:licensem	="http://www.swsoft.com/xsl/cp/licensem"  
	xmlns:filem			="http://www.swsoft.com/xsl/cp/filem"	
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"	
>
<!-- Import required modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>	
	<sw:include href="/lib/vt/hn-core.xsl"/>				
	<sw:include href="/lib/vt/hn-select.xsl"/>			
	<sw:include href="/lib/vza/filem.xsl"/>	
	<sw:include href="/lib/vz/vzenv-core.xsl"/>		
	<!-- /Import required modules -->

	<xsl:output method="xml"/>
	
	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'add_license_core'"/>
 	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">	
		<xsl:choose>
			
			<!-- Step "Input Key" -->
			<xsl:when test="$step='input_key'">
				<xsl:variable name="key-content" select="string(sw:param('key_content'))"/>
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::key or self::body or self::parsed or self::target"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<key>
						<content><xsl:value-of select="$key-content"/></content>
					</key>
					<body>
							<xsl:value-of select="$key-content"/>
					</body>
					<xsl:call-template name="local:parse-license">
						<xsl:with-param name="body" select="$key-content"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new_form_)"/>
				
				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA -->
					<!-- check key -->
					<xsl:choose>
						<!-- check key presence -->
						<xsl:when test="$new-form/key/content=''">
							<xsl:if test="error:put(sw:text('You should enter a license key value.'),'','key_content')"/>
						</xsl:when>
						<!-- validate license -->
						<xsl:when test="$new-form/parsed/error">
							<xsl:if test="error:put($new-form/parsed/error/vzcp-message,$new-form/parsed/error/message,'key_content')"/>
						</xsl:when>
					</xsl:choose>
					<!-- /check key -->							
					<!-- /CHECK DATA -->
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>		
			
			
			<!-- Step "Upload File" -->
			<xsl:when test="$step='upload_file'">

				<xsl:variable name="file-src" select="$request/http_request/files/file[input_name = 'file']"/>
				<xsl:variable name="text-src" select="sw:param('text')"/>
				
				
				<!-- Convert provided text or uploaded file to text content -->
				<xsl:variable name="text">
					<xsl:choose>
						<xsl:when test="
							$file-src/remote_path!='' and $file-src/local_path=''
						">
							<xsl:if test="error:put(sw:text('An error occurred during the license uploading.'),'','file')"/>
						</xsl:when>
						<xsl:when test="
							$file-src/remote_path!=''
						">
							<!-- Impersonated download to SVE -->
							<xsl:variable name="file-res" select="filem:get($file-src/local_path, vzenv:veid-to-eid(1,sw:local-hn-eid()), true(), true())"/>
							<xsl:choose>
								<xsl:when test="exsl:object-type($file-res)='node-set'">
									<xsl:if test="error:put(sw:text('An error occurred during the license uploading.'),$file-res/message,'file')"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of disable-output-escaping="yes" select="$file-res"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="
							not(string($text-src)='')
						">
							<xsl:value-of select="$text-src"/>
						</xsl:when>
					</xsl:choose>
				</xsl:variable>
				<!-- /Convert provided text or uploaded file to text content -->
				
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::file or self::body or self::parsed or self::target"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<file>
						<text><xsl:value-of select="$text-src"/></text>
					</file>
					<body>
						<xsl:value-of select="$text"/>
					</body>
					<xsl:if test="$text!=''">
						<xsl:call-template name="local:parse-license">
							<xsl:with-param name="body" select="$text"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new_form_)"/>
								
				<xsl:if test="sw:param('next') and error:is-empty()">
					<!-- CHECK DATA -->
					<!-- check key -->
					<xsl:choose>
						<!-- check key presence -->
						<xsl:when test="$text=''">
							<xsl:if test="error:put(sw:text('You should either specify a license file or paste its contents directly.'),'','file')"/>
						</xsl:when>
						<!-- validate license -->
						<xsl:when test="$new-form/parsed/error">
							<xsl:if test="error:put($new-form/parsed/error/vzcp-message,$new-form/parsed/error/message,
								sw:if($file-src/remote_path!='','file','text')
							)"/>
						</xsl:when>
					</xsl:choose>
					<!-- /check key -->							
					<!-- /CHECK DATA -->
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
				
			</xsl:when>		
			
			<!-- Step "Review" -->
			<xsl:when test="$step='review'">
				
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::review or self::target"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<target>
						<xsl:copy-of select="$form/target/*[not(self::hn-eid)]"/>
						<xsl:variable name="posted-hn-eid" select="sw:param('hn')"/>
						<hn-eid>
							<xsl:choose>
								<xsl:when test="$posted-hn-eid">
									<xsl:value-of select="$posted-hn-eid"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$form/target/hn-eid"/>
								</xsl:otherwise>
							</xsl:choose>
						</hn-eid>
					</target>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new_form_)"/>
						
				<xsl:if test="sw:param('next') or sw:param('submit')">
					<!-- Try install license -->
					<xsl:variable name="result" select="licensem:put($new-form/body,$new-form/target/hn-eid)"/>

					<!-- check installation result -->
					<xsl:if test="$result/error">
						<xsl:if test="error:put(sw:text('An error occurred during the license installation. Please return to the previous step and provide another license.'),$result/error/message,'')"/>
					</xsl:if>
					<!-- /check installation result -->

				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>	
			
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="cred:detail-check('vzcp.license')"/>
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
										<xsl:copy-of select="local:get-final-packet($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>										
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.license'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<xsl:template name="local:init-new">
		<!-- Init default data -->
		<xsl:variable name="start-type" select="string(sw:param('license-type'))"/>		
		<sw:die test="not($start-type='key' or $start-type='file')">
			Wrong license-type "<xsl:value-of select='$start-type'/>"
		</sw:die>
		<xsl:variable name="new-form">
			<def>
				<xsl:if test="not(licensem:get-active())">
					<no-local-license/>
				</xsl:if>
			</def>
			<xsl:if test="$start-type">
				<license-type>
					<xsl:value-of select="$start-type"/>
				</license-type>
			</xsl:if>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="all_steps_">
			<xsl:choose>
				<xsl:when test="$start-type='key'">
					<step id="input_key" screen-id="25.00.00.01.00"  cred="vzcp.license"/>			
				</xsl:when>
				<xsl:when test="$start-type='file'">
					<step id="upload_file" screen-id="25.00.00.01.01" cred="vzcp.license"/>			
				</xsl:when>
			</xsl:choose>
			<step id="review" screen-id="25.00.00.01.02" cred="vzcp.license"/>			
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($all_steps_)/step[not(@cred) or cred:check(@cred)]"/>
			<xsl:variable name="new_step" select="string($new_steps[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new-form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
		
	</xsl:template>

	<!-- Parse and decode license -->
	<xsl:template name="local:parse-license">
		<xsl:param name="body"/>
		
		<xsl:variable name="parsed" select="licensem:parse($body)"/>
		
		<xsl:choose>
			<xsl:when test="$parsed/error">
				<parsed>
					<error>
						<vzcp-message>
							<sw:text>An error occurred during the license validation. Please provide another license.</sw:text>
						</vzcp-message>
						<xsl:copy-of select="$parsed/error/message"/>
					</error>
				</parsed>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="decoded" select="exsl:node-set(licensem:decode-license($parsed/license))"/>
				<xsl:variable name="hwid" select="hn:clean-hwid($decoded/param[id='hwid']/value)"/>
				<xsl:variable name="hn-eid" select="hn:hwid2eid($hwid)"/>
	
				<!-- Check target HN EID -->
				<xsl:choose>
					<xsl:when test="$hwid!='' and $hn-eid=''">
						<parsed>
							<error>
								<vzcp-message>
									<sw:text>
										<xsl:with-param name="hwid" select="$hwid"/>
										The provided license is valid only for the Node with the HWID of %{hwid}, but no such Node is registered. <br/> Please provide another license or register the Node for which the license has been issued.
									</sw:text>
								</vzcp-message>
							</error>
						</parsed>
					</xsl:when>
					<xsl:otherwise>	
						<parsed>
							<xsl:copy-of select="$decoded"/>
						</parsed>
						<target>
							<license-hwid>
								<xsl:value-of select="$hwid"/>
							</license-hwid>
							<hn-eid>
								<xsl:choose>
									<!-- License specifies HN -->
									<xsl:when test="$hn-eid!=''">
										<xsl:value-of select="$hn-eid"/>
									</xsl:when>
									<!-- Preselect Master HN for VZGROUP license -->
									<xsl:when test="$decoded/param[id='CLASS']/value='VZGROUP'">
										<xsl:value-of select="sw:master-eid()"/>
									</xsl:when>
									<!-- Preselect Master HN if no license installed in local HN -->
									<xsl:when test="$form/def/no-local-license">
										<xsl:value-of select="sw:master-eid()"/>
									</xsl:when>
									<!-- Check HNs total count and try to preselect HN if only one HN in cluster -->
									<xsl:otherwise>
										<xsl:variable name="all-hns" select="hn:list()/hn"/>
										<xsl:choose>
											<!-- Preselect master  -->
											<xsl:when test="count($all-hns)=1">
												<xsl:value-of select="sw:master-eid()"/>
											</xsl:when>
											<!-- No preselected HN -->											
											<xsl:otherwise>
												<xsl:value-of select="''"/>											
											</xsl:otherwise>
										</xsl:choose>
									</xsl:otherwise>
									<!-- /Check HNs total count and try to preselect HN if only one HN in cluster -->
								</xsl:choose>
							</hn-eid>
						</target>
					</xsl:otherwise>
				</xsl:choose>
			
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>
	
	
	<!-- *********************************************************** -->
	<func:function name="local:get-final-packet">
		<xsl:param name="data"/>
		<func:result>
			<packet>
				<cookie>
					<msg>
						<set-ok><sw:text>The license has been installed successfully.</sw:text></set-ok>
					</msg>
					<redirect-prev/>       
			  </cookie>		
			</packet>
		</func:result>
	</func:function>
  
	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>				
	
	
</xsl:stylesheet>
