<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
>

	<sw:include href="/lib/swa/licensem.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="cr-manage" select="cred:check('vzcp.license')"/>
	<xsl:variable name="licenses" select="local:split-ids()"/>

	<xsl:template match="/">
		<xsl:choose>
			
			<!-- there is no post -->
			<xsl:when test="not($licenses)">
				<packet/>
			</xsl:when>
		
			<!-- there is no cred -->
			<xsl:when test="not($cr-manage)">
				<packet/>
			</xsl:when>

			<!-- Refresh licenses -->
			<xsl:when test="string(sw:param('refresh'))">
				<xsl:copy-of select="local:refresh-packet($licenses)"/>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>				
			</xsl:when>
			
			<!-- Unknown post -->
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>

	<func:function name="local:refresh-packet">
		<xsl:param name="licences"/>

		<func:result>
			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/core/licenses/refresh.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>Licenses have been scheduled for refreshing.</sched>
						<error>Failed to refresh the licenses.</error>
					</msg>
					<operation>refresh_license</operation>
					<redirect-last/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:copy-of select="$licenses"/>
					</data>
				</xsl:with-param>
			</xsl:call-template>
		</func:result>

	</func:function>

	<func:function name="local:split-ids">
		<xsl:variable name="result-rtf">
			<xsl:for-each select="sw:param('id')">
				<license>
					<id><xsl:value-of select="substring-before(.,'|')"/></id>
					<hn-eid><xsl:value-of select="substring-after(.,'|')"/></hn-eid>
				</license>
			</xsl:for-each>
		</xsl:variable>
		<func:result select="exsl:node-set($result-rtf)/license"/>
	</func:function>


	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
