<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error action"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action		="http://www.swsoft.com/xsl/cp/action"	
	xmlns:request			="http://www.swsoft.com/xsl/cp/request"	
	xmlns:licensem	="http://www.swsoft.com/xsl/cp/licensem"  
	xmlns:env="http://www.swsoft.com/xsl/cp/env"	
>
	<!-- Import required modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>	
	<sw:include href="/lib/vt/env-core.xsl"/>		
	<!-- /Import required modules -->

	<xsl:output method="xml"/>
	
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>
	
	<xsl:param name="wiz_code" select="'transfer_license_core'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			
			<!-- Step "Transfer" -->
			<xsl:when test="$step='transfer'">
			
				<xsl:variable name="hn-eid" select="sw:param('hn')"/>
			
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::hn or self::key"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<hn>
						<xsl:if test="$hn-eid!=''">
							<xsl:copy-of select="env:eid2info($hn-eid)"/>
						</xsl:if>
					</hn>
					<xsl:if test="$form/license/file-based">
						<key><xsl:value-of select="sw:param('key')"/></key>
					</xsl:if>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new_form_)"/>
				
				<xsl:if test="sw:param('next') or sw:param('submit')">
					<!-- CHECK DATA -->
					<!-- check key -->
					<xsl:choose>
						<!-- check target selection -->
						<xsl:when test="not($new-form/hn/eid!='')">
							<xsl:if test="error:put(sw:text('You should select some Hardware Node to transfer the license.'),'','hn')"/>
						</xsl:when>
					</xsl:choose>
					<xsl:if test="$form/license/file-based">
						<xsl:if test="not($new-form/key!='')">
							<xsl:if test="error:put(sw:text('You should specify the activation key.'),'','key')"/>
						</xsl:if>	
					</xsl:if>
					<!-- /check key -->							
					<!-- /CHECK DATA -->
					
					<!-- Try transfer -->
					<xsl:if test="error:is-empty()">
						<xsl:variable name="result" select="licensem:transfer(
							sw:if($new-form/license/file-based,$new-form/key,$new-form/license/body),
							$new-form/license/hn-eid,$new-form/hn/eid
						)"/>
						<xsl:if test="$result/error">
							<xsl:if test="error:put(sw:text('An error occurred during the license transfer.'),$result/error/message)"/>
						</xsl:if>
					</xsl:if>
					
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>		
						
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:get-final-packet($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.license'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	
	<xsl:template name="local:init-new">
		<!-- Init default data -->
		<xsl:variable name="license-id" select="sw:sesgetstr('license-id')"/>		
		<xsl:variable name="license-hn-eid" select="sw:sesgetstr('license-hn-eid')"/>		
		
		<xsl:variable name="license" select="licensem:get('',true(),$license-id)"/>

		<sw:die test="not($license-id!='')">
			Uknown license ID.
		</sw:die>
		<sw:die test="not($license-hn-eid!='')">
			Uknown license hn eid.
		</sw:die>
		
		<xsl:variable name="new-form">
			<license>
				<id><xsl:value-of select="$license-id"/></id>
				<hn-eid><xsl:value-of select="$license-hn-eid"/></hn-eid>
				<body><xsl:value-of select="$license/body"/></body>
				<xsl:if test="licensem:is-file-based($license)">
					<file-based/>
				</xsl:if>
			</license>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="transfer" screen-id="25.00.00.00.02" screen-icon="license"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new-form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
		
	</xsl:template>


	<!-- *********************************************************** -->
	<func:function name="local:get-final-packet">
		<xsl:param name="data"/>
		<func:result>
			<packet>
				<cookie>
					<msg>
						<set-ok><sw:text>The license has been transferred.</sw:text></set-ok>
					</msg>
					<redirect-prev/>       
			  </cookie>		
			</packet>
		</func:result>
	</func:function>
  
	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>				
	
	
</xsl:stylesheet>
