<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred check local hwm error"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>
	<sw:include href="/lib/core/check-funcs.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:param name="wiz_code" select="'problem_report'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>

			<!-- Step "Submit" -->
			<xsl:when
				test="$step='submit'">

				<xsl:variable name="new_form_">
					<xsl:copy-of select="$form/*[not(self::contact or self::problem)]"/>
					<contact>
						<name>
							<xsl:value-of select="sw:param('name')"/>
						</name>
						<email>
							<xsl:value-of select="sw:param('email')"/>
						</email>
						<company>
							<xsl:value-of select="sw:param('company')"/>
						</company>
					</contact>
					<problem>
						<hn-eid><xsl:value-of select="sw:param('hn_eid')"/></hn-eid>						
						<ticket-id><xsl:value-of select="sw:param('ticket_id')"/></ticket-id>
						<subject>
							<xsl:value-of select="sw:param('subject')"/>
						</subject>
						<descr>
							<xsl:value-of select="sw:param('descr')"/>
						</descr>
					</problem>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- check name -->
					<xsl:choose>
						<!-- check name presence -->
						<xsl:when test="string($new_form/contact/name)=''">
							<xsl:value-of select="error:put(sw:text('You should specify the person name.'),'','name')"/>
						</xsl:when>
						<!-- check name for max.length -->
						<xsl:when test="string-length($new_form/contact/name)&gt;255">
							<xsl:value-of select="error:put(sw:text('The person name cannot be longer than 255 characters.'),'','name')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check company -->
					<xsl:choose>
						<!-- check presence -->
						<xsl:when test="string($new_form/contact/company)=''">
							<xsl:value-of select="error:put(sw:text('You should specify the company name.'),'','company')"/>
						</xsl:when>
						<!-- check for max.length -->
						<xsl:when test="string-length($new_form/contact/company)&gt;255">
							<xsl:value-of select="error:put(sw:text('The company name cannot be longer than 255 characters.'),'','company')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check email -->
					<xsl:choose>
						<!-- check presence -->
						<xsl:when test="string($new_form/contact/email)=''">
							<xsl:value-of select="error:put(sw:text('You should specify your email address.'),'','email')"/>
						</xsl:when>
						<!-- check for max.length -->
						<xsl:when test="not(check:email($new_form/contact/email))">
							<xsl:value-of select="error:put(sw:text('The specified email address is invalid. Please correct it.'),'','email')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check subject -->
					<xsl:choose>
						<!-- check presence -->
						<xsl:when test="string($new_form/problem/subject)=''">
							<xsl:value-of select="error:put(sw:text('You should specify the subject.'),'','subject')"/>
						</xsl:when>
						<!-- check name for max.length -->
						<xsl:when test="string-length($new_form/problem/subject)&gt;65535">
							<xsl:value-of select="error:put(sw:text('The subject cannot be longer than 65635 characters.'),'','descr')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check descr-->
					<xsl:choose>
						<!-- check presence -->
						<xsl:when test="string($new_form/problem/descr)=''">
							<xsl:value-of select="error:put(sw:text('You should provide a problem description.'),'','descr')"/>
						</xsl:when>
						<!-- check name for max.length -->
						<xsl:when test="string-length($new_form/problem/descr)&gt;65535">
							<xsl:value-of select="error:put(sw:text('The problem description cannot be longer than 65635 characters.'),'','descr')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check hn id -->
					<xsl:choose>
						<!-- check ticket for empty value -->
						<xsl:when test="$new_form/problem/hn-eid=''">
							<xsl:value-of select="error:put(sw:text('You should select the Hardware Node.'),'','hn_eid')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<!-- Try to report problem  -->
				<xsl:variable name="form-resulted-rtf">
					<xsl:copy-of select="$new_form/*[not(self::result)]"/>
					<xsl:if test="sw:param('next') and error:is-empty()">
						<xsl:if test="cred:detail-check('vzcp.support.troubleshooting')"/>
						<xsl:if test="error:is-empty()">
							<xsl:variable name="report" select="local:report-problem($new_form)"/>
							<xsl:choose>
								<xsl:when test="$report/error">
									<xsl:if
										test="error:put(sw:text('An error occurred during the problem reporting.'),$report/error/message)"
									/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:if test="sw:sesputstr('msg',sw:text('Your problem report was sent to the Parallels support team.'))"/>
									<result>
										<ticket-id>
											<xsl:value-of select="$report/ticket"/>
										</ticket-id>
									</result>
									<!-- ticket ID not only for all customer -->
									<xsl:if test="not($report/ticket!='')">
										<xsl:if test="wiz:setStepEnabled('final',false())"/>
									</xsl:if>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:if>
					</xsl:if>
				</xsl:variable>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="exsl:node-set($form-resulted-rtf)"/>
				</xsl:call-template>

			</xsl:when>

			<!-- Step "Final" -->
			<xsl:when
				test="$step='final'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- Check data -->
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>

			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="cred:detail-check('vzcp.support.troubleshooting')"/>
								<xsl:choose>
									<xsl:when test="error:is-empty()">
										<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.support.troubleshooting'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
 		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
 	
	<xsl:template name="local:init-new">
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<contact>
				<name/>
				<email/>
				<company/>
			</contact>
			<problem>
				<descr/>
				<subject/>
			</problem>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="submit" screenid="15.00.00.00.00"/>
			<step id="final" screenid="15.00.00.00.01"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet>
				<cookie>
					<redirect-prev/>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<!-- Submit Problem -->
	<func:function name="local:report-problem">
		<xsl:param name="data"/>

		<xsl:variable name="req">
			<packet>
				<target>vzasupport</target>
				<xsl:copy-of select="sw:env-dst($data/problem/hn-eid)"/>
				<data>
					<vzasupport>
						<problem_report>
							<xsl:if test="not(string($data/problem/ticket-id)='')">
								<ticket>
									<xsl:value-of select="sw:base64-encode($data/problem/ticket-id)"/>
								</ticket>						
							</xsl:if>
							<name>
								<xsl:value-of select="sw:base64-encode($data/contact/name)"/>
							</name>
							<company>
								<xsl:value-of select="sw:base64-encode($data/contact/company)"/>
							</company>
							<email>
								<xsl:value-of select="sw:base64-encode($data/contact/email)"/>
							</email>
							<subject>
								<xsl:value-of select="sw:base64-encode($data/problem/subject)"/>
							</subject>
							<problem_description>
								<xsl:value-of select="sw:base64-encode($data/problem/descr)"/>
							</problem_description>
						</problem_report>
					</vzasupport>
				</data>
			</packet>
		</xsl:variable>
		<func:result select="sw:xchg($req)/packet/data/vzasupport"/>

	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
