<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl form func wiz check local authm error user users"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check" xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:func="http://exslt.org/functions" xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:user="http://www.swsoft.com/xsl/cp/user"
	xmlns:users="http://www.swsoft.com/xsl/cp/users" xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:requests="http://www.swsoft.com/xsl/cp/requests"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"
	xmlns:perms="http://www.swsoft.com/xsl/cp/perms"
	xmlns:vzcpsecuritym="http://www.swsoft.com/xsl/cp/vzcpsecuritym">

	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/vt/envrequests.xsl"/>
	<sw:include href="/lib/swa/vzcpsecuritym.xsl"/>
	<sw:include href="/lib/sysdir/securman/users.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms.xsl"/>

	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'registration-user'"/>
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when test="not($config/vzcpcon/user-registration/enabled='true')">
				<packet>
					<target>ticketm</target>
					<data>
						<ticketm>
							<logout>
								<ticket>
									<xsl:value-of select="$ticket"/>
								</ticket>
								<ip>
									<xsl:value-of select="/http_request/env/parameter[name = 'REMOTE_ADDR']/value"/>
								</ip>
							</logout>
						</ticketm>
					</data>
				</packet>
			</xsl:when>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:when test="name()='user'"/>
							<xsl:when test="name()='roles'"/>
							<xsl:when test="name()='js_mode'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<username>
							<xsl:value-of select="sw:param('username')"/>
						</username>
						<pwd>
							<xsl:value-of select="sw:param('pwd')"/>
						</pwd>
						<pwd_re>
							<xsl:value-of select="sw:param('pwd_re')"/>
						</pwd_re>
					</gen>
					<js_mode>
						<xsl:value-of select="sw:param('js_mode')"/>
					</js_mode>
					<!-- User -->
					<user>
						<displayName>
							<xsl:value-of select="sw:param('displayName')"/>
						</displayName>
						<mail>
							<xsl:value-of select="sw:param('mail')"/>
						</mail>
					</user>

					<!-- Fill roles -->
					<xsl:variable name="roles" select="vzcpsecuritym:list-assignable-roles()"/>
					<roles>
						<xsl:for-each select="$config/vzcpcon/user-registration/user-role">
							<xsl:if test="string(.)=$roles/id">
								<role>
									<id>
										<xsl:value-of select="string(.)"/>
									</id>
								</role>
							</xsl:if>
						</xsl:for-each>
					</roles>
					<!-- VE -->
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="wis:clicked-next()">
					<!-- Check data -->
					<!-- check password -->
					<xsl:choose>
						<!-- check password identity -->
						<xsl:when test="$new_form/gen/pwd!=$new_form/gen/pwd_re">
							<xsl:if test="error:put(sw:text('The passwords do not match.'),'','pwd')"/>
							<xsl:if test="error:add-control('pwd_re')"/>
						</xsl:when>
						<!-- check password presence -->
						<xsl:when test="$new_form/gen/pwd='' and not($edit-mode)">
							<xsl:if test="error:put(sw:text('You should specify a password.'),'','pwd')"/>
							<xsl:if test="error:add-control('pwd_re')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="wiz:clicked-next() and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:variable name="user-data">
									<xsl:call-template name="local:getFinalPacketCommon">
										<xsl:with-param name="data" select="$data"/>
									</xsl:call-template>
								</xsl:variable>
								<xsl:variable name="add-user-result"
									select="authm:add-user($user-data,sw:base64-encode($data/gen/pwd))"/>
								<xsl:choose>
									<xsl:when test="not($add-user-result//error)">
										<xsl:variable name="user-sid" select="users:login2sid($data/gen/username)"/>
										<xsl:if
											test="vzcpsecuritym:set-access-rights(vzcpsecuritym:dacl-modifier(
											vzcpsecuritym:vzcp-security-object(),
											vzcpsecuritym:sid-aces($user-sid,$data/roles)))"/>

										<!-- user created, make new session  -->
										<xsl:variable name="new-session-data">
											<frameset_redirect>yes</frameset_redirect>
											<old_layout>framed</old_layout>
											<js_mode><xsl:value-of select="$data/js_mode"/></js_mode>
											<msg><sw:text>You have been successfully registered.</sw:text></msg>
										</xsl:variable>
										<xsl:variable name="new-ticket"
											select="sw:new-cc-session($data/gen/username,$data/gen/pwd,exsl:node-set($new-session-data)/*)"/>
										<packet>
											<cookie>
												<redirect>
													<xsl:value-of select="concat($baseurl,'?LoginTicket=',$new-ticket)"/>
												</redirect>
											</cookie>
										</packet>
									</xsl:when>
									<xsl:otherwise>
										<!-- fail -->
										<packet>
											<cookie>
												<msg>
													<set-error>
														<short-desc>
															<xsl:value-of select="sw:text('Failed to register the new user.')"/>
														</short-desc>
														<detail>
															<xsl:value-of select="$add-user-result//message"/>
														</detail>
													</set-error>
												</msg>
												<redirect-last/>
											</cookie>
										</packet>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="wiz:clicked-back()">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.virtuozzo_group.security.usergroups'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:initCreate"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<gen>
				<username/>
				<pwd/>
				<pwd_re/>
			</gen>
			<user>
				<displayName/>
				<mail/>
			</user>
			<roles/>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screenid="03.00.03.02.00" title="{sw:text('Registration')}"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:getFinalPacketCommon">
		<xsl:param name="data"/>
		<!--/-->
		<name>
			<xsl:value-of select="sw:base64-encode($data/gen/username)"/>
		</name>
		<data>
			<!-- Define our own classes -->
			<attr>
				<name>objectClass</name>
				<value>
					<xsl:value-of select="sw:base64-encode('VZCPUser')"/>
				</value>
			</attr>
			<!-- /Define our own classes -->
			<xsl:copy-of select="dirm:nodes2attrs($data/user/*,'','attr')"/>
		</data>
	</xsl:template>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="../../../layout/forms-list.xsl"/>


	<sw:include href="/lib/vocabulary.xsl"/>
	<!-- creds -->
	<sw:include href="/lib/cred.xsl"/>

</xsl:stylesheet>
