<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred env check local error securitym request global"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check" xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
>

	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/swa/securitym.xsl"/>

	<xsl:output method="xml"/>
	<!-- check permissions to show this page -->
	<xsl:variable name="cr-role-create" select="cred:check('vzcp.virtuozzo_group.security.roles')"/>
	<xsl:variable name="cr-role-edit" select="$cr-role-create"/>

	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:param name="wiz_code" select="'sm-role'"/>
	<xsl:variable name="edit-mode" select="$form/src/role/name"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- No cred  -->
			<xsl:when test="not($cr-role-create) and not($cr-role-edit)">
				<packet/>
			</xsl:when>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<show-roles><xsl:value-of select="sw:param('show_roles')"/></show-roles>	
						<role>
							<name>
								<xsl:choose>
									<xsl:when test="$edit-mode and string($form/src/role/assignable)='false'">
										<xsl:value-of select="$form/src/role/name"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="normalize-space(sw:param('name'))"/>
									</xsl:otherwise>
								</xsl:choose>
							</name>
							<description>
								<xsl:value-of select="sw:base64-encode(sw:param('description'))"/>
							</description>
							<xsl:for-each select="sw:param('sub_roles')">
								<role>
									<xsl:value-of select="." disable-output-escaping="yes"/>
								</role>
							</xsl:for-each>
							<xsl:call-template name="local:post_tasks2tasks"/>
						</role>
					</gen>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- check name -->
					<xsl:choose>
						<!-- check name presence -->
						<xsl:when test="string($new_form/gen/role/name)=''">
							<xsl:if test="error:put(sw:text('You should specify a name.'),'','name')"/>
							<xsl:if test="error:add-control('name')"/>
						</xsl:when>
						<!-- check name for max.length -->
						<xsl:when test="string-length($new_form/gen/role/name)&gt;255">
							<xsl:if
								test="error:put(sw:text('The name cannot be longer than 255 characters.'),'','name')"
							/>
							<xsl:if test="error:add-control('name')"/>
						</xsl:when>
						<xsl:when test="check:get-voc-pattern-match-error(
							env:make-platform-ref(sw:master-eid(),''),
							$new_form/gen/role/name,
							'pattern.role_name')">
							<xsl:if test="error:put(sw:text('The role name is invalid. A role name may consist of letters, digits, dots, dashes, underscores, and spaces only.'),'','name')"/>
							<xsl:if test="error:add-control('name')"/>							
						</xsl:when>
					</xsl:choose>
					<!-- /check name -->
					<!-- check description -->
					<!-- 
					<xsl:choose>
						<xsl:when test="string($new_form/gen/role/description)=''">
							<xsl:if test="error:put(sw:text('You should specify a description.'),'','description')"
							/>
						</xsl:when>
					</xsl:choose>
					-->
					<!-- /check description -->
				</xsl:if>
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:choose>
									<xsl:when test="$data/src/role">
										<xsl:copy-of select="local:processUpdateRole($data)"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:copy-of select="local:processCreateRole($data)"/>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:if test="error:is-empty()">
									<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:variable name="get-id" select="sw:param('id')"/>
			<xsl:choose>
				<xsl:when test="sw:param('mode')='edit' and $get-id">
					<xsl:call-template name="local:initEdit">
						<xsl:with-param name="id" select="sw:base64-decode($get-id)"/>
						<xsl:with-param name="step" select="'gen'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initCreate"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<gen>
				<role>
					<name/>
					<description/>
				</role>
			</gen>
			<all-tasks>
				<xsl:call-template name="local:tasks2tasks">
					<xsl:with-param name="all-tasks" select="securitym:get-tasks-tree()/task"/>
				</xsl:call-template>
			</all-tasks>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screenid="24.00.00.00.01" screen-icon="role_new"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:initEdit">
		<xsl:param name="step"/>
		<xsl:param name="id"/>
		<!-- Init steps -->
		<xsl:variable name="all_steps_">
			<step id="gen" screenid="24.00.00.00.02"/>
		</xsl:variable>
		<!-- Init Step -->
		<xsl:variable name="new_step">
			<xsl:choose>
				<xsl:when test="string(sw:param('tab')) != ''">
					<xsl:value-of select="string(sw:param('tab'))"/>
				</xsl:when>
				<xsl:otherwise>gen</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_steps" select="exsl:node-set($all_steps_)/step[@id=$new_step]"/>
		<!-- Check startup conditions -->
		<xsl:variable name="new_form">
			<xsl:choose>
				<xsl:when test="count($new_steps)=0">
					<xsl:message terminate="yes">
						Requested tab '<xsl:value-of select="$new_step"
						/>' is unknown for Roles Management code.
					</xsl:message>
				</xsl:when>
				<xsl:when test="not($id)">
					<xsl:message terminate="yes">
						Role ID should be specified.
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initEditData">
						<xsl:with-param name="step" select="$step"/>
						<xsl:with-param name="id" select="$id"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:initEditData">
		<xsl:param name="step"/>
		<xsl:param name="id"/>
		<!-- Load data -->
		<xsl:variable name="role" select="securitym:find-role($id)"/>
		<xsl:variable name="builtin-roles" select="sw:get-builtin-roles()"/>
		<!--|-->
		<gen>
			<role>
				<name>
					<xsl:value-of select="$role/name"/>
				</name>
				<description>
					<xsl:value-of select="$role/description"/>
				</description>
				<xsl:copy-of select="$role/role"/>
				<xsl:copy-of select="$role/task"/>
			</role>
			<xsl:if test="$role/role">
				<show-roles>1</show-roles>
			</xsl:if>
		</gen>
		<all-tasks>
			<xsl:call-template name="local:tasks2tasks">
				<xsl:with-param name="all-tasks" select="securitym:get-tasks-tree()/task"/>
			</xsl:call-template>
		</all-tasks>
		<src>
			<role>
				<name>
					<xsl:value-of select="$role/name"/>
				</name>
				<assignable>
					<xsl:value-of select="sw:if($builtin-roles/roles/role[sw:lc(name)=sw:lc($role/name)]/wellknown,'false','true')"/>
				</assignable>
			</role>
		</src>
	</xsl:template>

	<!--
		Auxiliary template. Copy VZA tasks tree adding generated @id and @full-task-id
		attributes to each task.
		-->
	<xsl:template name="local:tasks2tasks">
		<xsl:param name="all-tasks"/>
		<xsl:param name="parent-id" select="'/'"/>
		<xsl:for-each select="$all-tasks">
			<xsl:variable name="task-id" select="generate-id()"/>
			<xsl:variable name="full-task-id" select="concat($parent-id,$task-id)"/>
			<xsl:copy>
				<xsl:attribute name="id"><xsl:value-of select="$task-id"/></xsl:attribute>
				<xsl:attribute name="full-task-id"><xsl:value-of select="$full-task-id"/></xsl:attribute>
				<xsl:copy-of select="@order"/>
				<xsl:copy-of select="name"/>				
				<xsl:copy-of select="description"/>
				<xsl:call-template name="local:tasks2tasks">
					<xsl:with-param name="all-tasks" select="task"/>
					<xsl:with-param name="parent-id" select="concat($full-task-id,'/')"/>
				</xsl:call-template>
			</xsl:copy>
		</xsl:for-each>
	</xsl:template>

	<!--
		Auxiliary template. Constructs list of tasks which are posted, 
		but should not be added to role because not all sub-tasks checked
	-->
	<xsl:template name="local:exclude-post-tasks">
		<xsl:param name="tasks"/>
		<xsl:param name="post-tasks"/>
		<xsl:for-each select="$tasks">
			<xsl:choose>
				<xsl:when 
					test="count($post-tasks[string(.)=string(current()/@full-task-id)]) = 0">
					<xsl:for-each select="sw:split(@full-task-id,'/')[string(.) != '']">
						<exclude-task id="{.}"/>
					</xsl:for-each>		
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:exclude-post-tasks">
						<xsl:with-param name="tasks" select="task"/>
						<xsl:with-param name="post-tasks" select="$post-tasks"/>
					</xsl:call-template>					
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<!--
		Auxiliary template. Compose list of tasks that should be added to role.
	-->
	<xsl:template name="local:compose-submit-tasks">
		<xsl:param name="tasks"/>
		<xsl:param name="excl-tasks"/>
		<xsl:param name="post-tasks"/>
		<xsl:for-each select="$tasks">
			<xsl:choose>
				<xsl:when 
					test="count($post-tasks[string(.)=string(current()/@full-task-id)]) &gt; 0">
					<xsl:choose>
						<xsl:when 
							test="count($excl-tasks/exclude-task[@id=string(current()/@id)]) &gt; 0">
							<!-- Task submitted, but in exclusions list - check sub-tasks -->
							<xsl:call-template name="local:compose-submit-tasks">
								<xsl:with-param name="tasks" select="task"/>
								<xsl:with-param name="excl-tasks" select="$excl-tasks"/>
								<xsl:with-param name="post-tasks" select="$post-tasks"/>
							</xsl:call-template>							
						</xsl:when>
						<xsl:otherwise>
							<!-- Task submitted and not in exclusion -->
							<task><xsl:value-of select="name"/></task>							
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>

	<!--
		Auxiliary template. Restore tasks from post.
		See local:exclude-post-tasks and local:compose-submit-tasks
		-->
	<xsl:template name="local:post_tasks2tasks">
		<xsl:variable name="post-tasks" select="sw:param('cred')[string(.)!='']"/>
		<xsl:variable name="excl-tasks-rtf">
			<xsl:call-template name="local:exclude-post-tasks">
				<xsl:with-param name="tasks" select="$form/all-tasks/task"/>
				<xsl:with-param name="post-tasks" select="$post-tasks"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="excl-tasks" select="exsl:node-set($excl-tasks-rtf)"/>
		<xsl:call-template name="local:compose-submit-tasks">
			<xsl:with-param name="tasks" select="$form/all-tasks/task"/>
			<xsl:with-param name="excl-tasks" select="$excl-tasks"/>
			<xsl:with-param name="post-tasks" select="$post-tasks"/>
		</xsl:call-template>
	</xsl:template>

	<!-- *********************************************************** -->

	<func:function name="local:processCreateRole">
		<xsl:param name="data"/>
		<xsl:variable name="result" select="securitym:add-role($data/gen/role)"/>
		<xsl:if test="$result[self::error]">
			<xsl:if test="error:put(sw:text('Failed to create the role.'),$result/message)"/>
		</xsl:if>

		<func:result>
			<packet>
				<cookie>
					<msg>
						<set-ok>
							<sw:text>The role has been successfully created.</sw:text>
						</set-ok>
					</msg>
					<operation>create_role</operation>
					<redirect-prev/>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<func:function name="local:processUpdateRole">
		<xsl:param name="data"/>
		<xsl:variable name="result" select="securitym:update-role($data/src/role/name,$data/gen/role)"/>
		<xsl:if test="$result[self::error]">
			<xsl:if test="error:put(sw:text('Failed to update the role.'),$result/message)"/>
		</xsl:if>
		
		<func:result>
			<packet>
				<cookie>
					<msg>
						<set-ok>
							<sw:text>The role has been successfully updated.</sw:text>
						</set-ok>
					</msg>
					<operation>create_role</operation>
					<redirect-prev/>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
