<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:user-profile			="http://www.swsoft.com/xsl/cp/user-profile"	
>
	<sw:include href="/lib/core/check-funcs.xsl"/>	

	<sw:include href="/lib/core/user-profile.xsl"/>			
	<sw:include href="/lib/utils/error.xsl"/>	

	<xsl:output method="xml"/>
	
  <!-- check permissions to show this page -->

	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:param name="wiz_code" select="'settings-panel'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
				<xsl:variable name="new-form-rtf">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()='gen'"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<xsl:if test="$form/def/input-password">
							<password><xsl:value-of select="sw:param('password')"/></password>
							<re-password><xsl:value-of select="sw:param('re_password')"/></re-password>	
						</xsl:if>
						<xsl:if test="$form/def/in-vzcc">
							<home-screen-id>
								<xsl:value-of select="sw:param('home_screen_id')"/>
							</home-screen-id>
							<show-banners><xsl:value-of select="boolean(sw:param('show_banners'))"/></show-banners>		
							<dynamic-updates><xsl:value-of select="boolean(sw:param('dynamic_updates'))"/></dynamic-updates>
							<show-tooltips><xsl:value-of select="boolean(sw:param('show_tooltips'))"/></show-tooltips>														
							<menu-depth><xsl:value-of select="sw:param('menu_depth')"/></menu-depth>																					
						</xsl:if>
						<xsl:if test="$activeMode = 'vzcp'">					
							<refresh-period><xsl:value-of select="sw:param('refresh_period')"/></refresh-period>
						</xsl:if>
						<xsl:if test="$form/def/input-mail">												
							<user-mail><xsl:value-of select="sw:param('user_mail')"/></user-mail>
						</xsl:if>	
						<skin><xsl:value-of select="sw:param('skin')"/></skin>											
						<lang><xsl:value-of select="sw:param('lang')"/></lang>
						<time-zone><xsl:value-of select="sw:param('time_zone')"/></time-zone>						
						<toolbar-mode><xsl:value-of select="sw:param('toolbar_mode')"/></toolbar-mode>										
					</gen>
				</xsl:variable>
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
				
				<xsl:if test="sw:param('next')">
					<!-- check data -->	
					<!-- check mail -->
					<xsl:if test="$new-form/def/input-mail and $new-form/gen/user-mail!='' and not(check:email($new-form/gen/user-mail))">
						<xsl:if test="error:put('Email is invalid','','user_mail')"/>
					</xsl:if>
					<!-- check passwords -->
					<xsl:if test="$new-form/def/input-password and $new-form/gen/password!=$new-form/gen/re-password">
						<xsl:if test="error:put(sw:text('The passwords do not match.'),'','password')"/>
						<xsl:if test="error:add-control('re_password')"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
					    	<xsl:choose>
		    					<xsl:when test="error:is-empty()">
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:choose>
		    							<xsl:when test="error:is-empty()">
												<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>			    							
											</xsl:when>
											<xsl:otherwise>
												<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
											</xsl:otherwise>
										</xsl:choose>
					      	</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<!-- Init form data -->
			<xsl:variable name="user-profile" select="user-profile:get(user-profile:logged-ref())"/>			
			<xsl:variable name="gen-data-rtf">
				<time-zone><xsl:value-of select="sw:sesgetstr('active_tz')"/></time-zone>
				<toolbar-mode><xsl:value-of select="sw:sesgetstr('toolbar-mode')"/></toolbar-mode>
				<lang><xsl:value-of select="$langObj/id"/></lang>
				<skin><xsl:value-of select="$skinObj/id"/></skin>					
				<xsl:if test="$activeMode = 'vzcc'">
					<home-screen-id><xsl:value-of select="$user-profile/homeScreenID"/></home-screen-id>
					<show-banners><xsl:value-of select="sw:if($user-profile/showBanners='false','false','true')"/></show-banners>
					<dynamic-updates><xsl:value-of select="sw:if($user-profile/dynamicUpdates='false','false','true')"/></dynamic-updates>
					<show-tooltips><xsl:value-of select="sw:sesgetstr('vzcc_tooltips')"/></show-tooltips>					
					<menu-depth><xsl:value-of select="sw:sesgetstr('menu-depth')"/></menu-depth>
				</xsl:if>
				<xsl:if test="$activeMode = 'vzcp'">					
					<refresh-period><xsl:value-of select="sw:sesget('refresh_period')"/></refresh-period>
					<user-mail><xsl:value-of select="$user-profile/mail"/></user-mail>
				</xsl:if>
			</xsl:variable>
			<xsl:variable name="new_form">
				<def>	
					<xsl:if test="$activeMode = 'vzcc'">
						<in-vzcc/>
					</xsl:if>
					<xsl:if test="$activeMode = 'vzcp'">
						<input-mail/>
					</xsl:if>
					<xsl:if test="$auth-type='sveuser'">
						<input-password/>
					</xsl:if>
				</def>
				<src>
					<xsl:copy-of select="$gen-data-rtf"/>
				</src>
				<gen>
					<xsl:copy-of select="$gen-data-rtf"/>
				</gen>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<xsl:choose>
					<xsl:when test="$activeMode = 'vzcc'">
						<step id="gen" screen-id="03.00.03.01.01" title="{sw:text('User Profile')}"/>
					</xsl:when>
					<xsl:otherwise>
						<step id="gen" screen-id="03.00.02.02.00" title="{sw:text('Preferences')}"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>	
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		
		<!-- try to update user profile -->
		<xsl:if test="error:is-empty()">	
			<xsl:variable name="attrs-rtf">
				<toolbarMode><xsl:value-of select="$data/gen/toolbar-mode"/></toolbarMode>
				<xsl:if test="($data/def/input-mail and $data/src/user-mail!=$data/gen/user-mail)">				
					<mail><xsl:value-of select="$data/gen/user-mail"/></mail>								
				</xsl:if>
				<xsl:if test="$activeMode = 'vzcc'">
					<menuDepth><xsl:value-of select="$data/gen/menu-depth"/></menuDepth>								
					<tooltipsMode><xsl:value-of select="$data/gen/show-tooltips"/></tooltipsMode>
					<showBanners><xsl:value-of select="$data/gen/show-banners"/></showBanners>					
					<dynamicUpdates><xsl:value-of select="$data/gen/dynamic-updates"/></dynamicUpdates>
					<homeScreenID><xsl:value-of select="$data/gen/home-screen-id"/></homeScreenID>
				</xsl:if>
			</xsl:variable>
			<xsl:variable name="res" select="user-profile:set-attrs(user-profile:logged-ref(),exsl:node-set($attrs-rtf))"/>
			<xsl:if test="$res[self::error]">
				<xsl:if test="error:put('Failed to update user preferences.',$res/message)"/>
			</xsl:if>
		</xsl:if>

		
		<!-- try to update VE root password -->
		<xsl:if test="$data/def/input-password">
			<xsl:variable name="sve-eid" select="vzenv:veid-to-eid(1,sw:local-hn-eid())"/>
			<xsl:variable name="packet">
				<sw:die>TODO: call baza</sw:die>
			</xsl:variable>
			<xsl:variable name="error" select="sw:xchg($packet)//error"/>
			<xsl:if test="$error">
				<xsl:if test="error:put(sw:text('Failed to change the user password.'),$error/message, '')"/>
			</xsl:if>
		</xsl:if>
		
		<!-- complete wizard -->
		<xsl:if test="error:is-empty()">		
			
			<!--************ Update session vars **************-->
			<xsl:if test="sw:sesputstr('active_tz', $data/gen/time-zone)"/>		
			<xsl:if test="sw:sesputstr('toolbar-mode', $data/gen/toolbar-mode)"/>			
			<xsl:if test="$activeMode = 'vzcc'">			
				<xsl:if test="sw:sesputstr('vzcc_tooltips', $data/gen/show-tooltips)"/>	
				<xsl:if test="sw:sesputstr('vzcc_banners', $data/gen/show-banners)"/>	
				<xsl:if test="sw:sesputstr('vzcc_dynamic', $data/gen/dynamic-updates)"/>
				<xsl:if test="$data/gen/menu-depth != $data/src/menu-depth ">
					<xsl:if test="sw:sesputstr('menu-depth',$data/gen/menu-depth)"/>
					<xsl:if test="sw:sesputstr('left-frame-reload','yes')"/>
				</xsl:if>
			</xsl:if>
			<xsl:if test="$activeMode = 'vzcp'">
				<xsl:if test="sw:sesput('refresh_period',$data/gen/refresh-period)"/>
			</xsl:if>
			
			<!-- check if we need frameset redirect (it happens if lang or skin changed) -->
			<xsl:if test="$data/gen/lang != $data/src/lang or $data/gen/skin != $data/src/skin
				or ($activeMode = 'vzcc' and 
						(
							$data/gen/show-banners!=$data/src/show-banners
								or
							$data/gen/menu-depth!=$data/src/menu-depth
								or
							$data/gen/dynamic-updates!=$data/src/dynamic-updates
						)
				)
			">
				<xsl:if test="sw:sesput('frameset_redirect','yes')"/>
				<xsl:if test="sw:sesput('frameset_url','core/settings/panel')"/>
				<xsl:if test="sw:sesput('old_layout',$layout)"/> 

				<xsl:variable name="modeRTF">
					<id><xsl:value-of select="$activeMode"/></id>
					<skin><xsl:value-of select="$data/gen/skin"/></skin>
					<lang><xsl:value-of select="$data/gen/lang"/></lang>
				</xsl:variable>   

				<!-- store mode in session -->
				<xsl:if test="sw:sesput(concat('mode-', $activeMode), $modeRTF)"/>
			</xsl:if>			
			<!--************ /Update session vars **************-->

	
			<!-- Return back -->
			<func:result>
				<packet>
					<cookie>
						<msg>
							<set-ok><sw:text>The settings have been changed.</sw:text></set-ok>
						</msg>
						<set-custom-cookies>
							<cookie name="vzcpRefreshPeriod" Path="/" Expires="never"><xsl:value-of select="$data/gen/refresh-period"/></cookie>
							<cookie name="vzcpTimeZone" Path="/" Expires="never"><xsl:value-of select="$data/gen/time-zone"/></cookie>
							<xsl:variable name="save-lang" select="$global-data/mode[@id = $activeMode]/lang/http[@tag = 'cookies']"/>
							<xsl:if test="count($save-lang)">
								<cookie name="{$save-lang}" Path="/" Expires="never"><xsl:value-of select="$data/gen/lang"/></cookie>
							</xsl:if>		
							<xsl:variable name="save-skin" select="$global-data/mode[@id = $activeMode]/skin/http[@tag = 'cookies']"/>
							<xsl:if test="count($save-skin)">
								<cookie name="{$save-skin}" Path="/" Expires="never"><xsl:value-of select="$data/gen/skin"/></cookie>
							</xsl:if>      
						</set-custom-cookies>     
					</cookie>						
				</packet>		
			</func:result>
		</xsl:if>
	</func:function>

  <!-- credentials -->	
  <sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>				
	
</xsl:stylesheet>
