<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl form func wiz cred check local authm error dirm global"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:authm			="http://www.swsoft.com/xsl/cp/authm"
	xmlns:dirm			="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:func			="http://exslt.org/functions"	
	xmlns:form			="http://www.swsoft.com/xsl/cp/form"  
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:user-profile			="http://www.swsoft.com/xsl/cp/user-profile">

	<sw:include href="/lib/core/user-profile.xsl"/>	
	<sw:include href="/lib/swa/authm.xsl"/>	
	<sw:include href="/lib/swa/dirm.xsl"/>	
	
	<xsl:output method="xml"/>

	<xsl:param name="wiz_code" select="'sm-user'"/>
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>	
	<xsl:variable name="edit-mode" select="$form/user-id"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:when test="name()='user'"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<pwd><xsl:value-of select="sw:param('pwd')"/></pwd>
							<pwd_re><xsl:value-of select="sw:param('pwd_re')"/></pwd_re>
							<xsl:if test="$form/src/mail-editable">
								<mail>
									<xsl:value-of select="normalize-space(sw:param('mail'))"/>
								</mail>
							</xsl:if>							
						</gen>

						<!-- User -->
						<user>
							<xsl:if test="$form/src/mail-editable">
								<mail>
									<xsl:value-of select="normalize-space(sw:param('mail'))"/>
								</mail>
							</xsl:if>
							<displayName>
								<xsl:value-of select="normalize-space(sw:param('displayName'))"/>
							</displayName>
							<description>
								<xsl:value-of select="normalize-space(sw:param('description'))"/>
							</description>
						</user>

					</xsl:variable>
					
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					<xsl:if test="sw:param('next')">
						<!-- Check data -->							
						<!-- check password -->
			      <xsl:choose>
 				      <!-- check password identity -->
				      <xsl:when test="$new_form/gen/pwd!=$new_form/gen/pwd_re">
				      	<xsl:if test="error:put(sw:text('The passwords do not match.'),'','pwd')"/>
				      	<xsl:if test="error:add-control('pwd_re')"/>
				      </xsl:when>
				       <!-- check password presence -->
				      <xsl:when test="$new_form/gen/pwd='' and not($edit-mode)">
				      	<xsl:if test="error:put(sw:text('You should specify a password.'),'','pwd')"/>
				      	<xsl:if test="error:add-control('pwd_re')"/>
				      </xsl:when>				       
						</xsl:choose>
					</xsl:if>
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">

						<!-- Save mail -->
						<xsl:if test="error:is-empty() and $form/src/mail-editable">
							<xsl:variable name="mail-error" select="user-profile:set-attr(
									user-profile:logged-ref(),'mail',$data/gen/mail
							)"/>
							<xsl:if test="$mail-error">
								<xsl:if test="error:put(sw:text('Error saving the email address.'),$mail-error/message)"/>
							</xsl:if>
						</xsl:if>
				
						<!-- Save profile -->
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:choose>
									<xsl:when test="$data/src/is-system-realm='true'">
										<xsl:copy-of select="local:getFinalPacketSystem($data)"/>
									</xsl:when>
									<xsl:when test="$data/src/is-editable-realm='true'">
										<xsl:copy-of select="local:getFinalPacket($data)"/>	
									</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="boolean($activeMode!='vzcc')"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:initEdit">
				<xsl:with-param name="step" select="'gen'"/>
			</xsl:call-template>				
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<xsl:template name="local:initEdit">		
		<xsl:param name="step"/>
		
		<!-- Init steps -->
		<xsl:variable name="all_steps_">
			<step id="gen" screenid="03.00.03.01.00"/>
		</xsl:variable>
		<!-- Init Step -->
		<xsl:variable name="new_step">
			<xsl:choose>
				<xsl:when test="sw:param('tab')"><xsl:value-of select="sw:param('tab')"/></xsl:when>
				<xsl:otherwise>gen</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_steps" select="exsl:node-set($all_steps_)/step[@id=$new_step]"/>
		<!-- Check startup conditions -->
		<xsl:variable name="new_form">
			<xsl:choose>
				<xsl:when test="count($new_steps)=0">
					<xsl:message terminate="yes">
						Requested tab '<xsl:value-of select="$new_step"/>' is unknown for Users Management code.
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initEditData">
						<xsl:with-param name="step" select="$step"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>	
	
	<xsl:template name="local:initEditData">
		<xsl:param name="step"/>
		<!-- Load data -->
		<xsl:variable name="user-auth" select="sw:login()/login"/>	
		<xsl:variable name="user" select="authm:get-user($user-auth,false())"/>
		<xsl:variable name="realms" select="authm:list-realms()"/>
		<xsl:variable name="realm-info"
			select="$realms/realm[string(id)=$user-auth/realm]"/>
		<xsl:variable name="mail-editable" 
			select="$realm-info/id=$global:system-realm-id or $realm-info/id=sw:internal-realm-id()"/>
		<!--|-->
		<gen>
			<xsl:if test="$mail-editable">
				<mail>
					<xsl:variable name="mail-attr" select="user-profile:get-attr(
							user-profile:logged-ref(),'mail'
						)"/>
					<!-- Process result -->
					<xsl:choose> 
						<xsl:when test="$mail-attr[self::error]">
							<xsl:if test="error:put(sw:text('Error retrieving the email address.'),$mail-attr/message)"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="string($mail-attr)"/>
						</xsl:otherwise>
					</xsl:choose>
				</mail>
			</xsl:if>		
		</gen>
		<src>
			<login>
				<xsl:value-of select="authm:user-login($user)"/>
			</login>
			<name><xsl:value-of select="$user-auth/name"/></name>
			<realm><xsl:value-of select="$user-auth/realm"/></realm>
			<xsl:if test="$mail-editable">
				<mail-editable/>
			</xsl:if>
			<is-system-realm>
				<xsl:value-of select="boolean($realm-info/id=$global:system-realm-id)"/>
			</is-system-realm>
			<is-editable-realm>
				<xsl:value-of select="boolean($realm-info/id=sw:internal-realm-id())"/>
			</is-editable-realm>
		</src>
		<user>
			<mail>
				<xsl:value-of 
					select="normalize-space(sw:base64-decode($user/data/attr[name='mail']/value))"/>
			</mail>
			<displayName><xsl:value-of 
				select="normalize-space(sw:base64-decode($user/data/attr[name='displayName']/value))"/>
			</displayName>
			<description>
				<xsl:value-of select="normalize-space(sw:base64-decode($user/data/attr[name='description']/value))"/>
			</description>
		</user>
		<user-id><xsl:value-of select="$user-auth/name"/></user-id>		
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!--|-->		
		<func:result>
			<packet log="on">
				<target>authm</target>
	        <cookie>	        
          	<msg>
	            <ok><sw:text>The personal settings have been successfully updated.</sw:text></ok>
	            <error><sw:text>Failed to update the personal settings.</sw:text></error>
	          </msg>
	          <operation>update_user</operation>	          
	        </cookie>			
				<data>				
					<authm>
						<edit_user>
							<name><xsl:value-of select="$data/src/name"/></name>
							<realm><xsl:value-of select="$data/src/realm"/></realm>
							<!-- Password -->
							<xsl:if test="$data/gen/pwd!=''">
								<password><xsl:value-of select="sw:base64-encode($data/gen/pwd)"/></password>
							</xsl:if>								
							<!-- /Password -->
							<user>																
								<name><xsl:value-of select="$data/src/name"/></name>
								<realm><xsl:value-of select="$data/src/realm"/></realm>
								<data>
									<xsl:copy-of select="dirm:nodes2attrs($data/user/*,'','mod')"/>
								</data>
							</user>
						</edit_user>						
					</authm>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>
	
	<func:function name="local:getFinalPacketSystem">
		<xsl:param name="data"/>
		
		<!--|-->		
		<func:result>
			<xsl:choose>
				<xsl:when test="$data/gen/pwd!=''">
					<packet>
						<target>userm</target>
						<cookie>	        
							<msg>
								<ok><sw:text>The personal settings have been successfully updated.</sw:text></ok>
								<error><sw:text>Failed to update the personal settings.</sw:text></error>
							</msg>
							<operation>update_user</operation>	          
						</cookie>
							<data>				
								<userm>
									<edit_user>
										<name><xsl:value-of select="sw:base64-decode($data/src/name)"/></name>
										<user>
											<name><xsl:value-of select="sw:base64-decode($data/src/name)"/></name>
											<password><xsl:value-of select="sw:base64-encode($data/gen/pwd)"/></password>
										</user>
									</edit_user>						
								</userm>
							</data>
							<vzcpauth/>
					</packet>					
				</xsl:when>
				<xsl:otherwise>
					<xsl:if test="sw:sesput('msg',sw:text('The personal settings have been successfully updated.'))"/>
					<packet/>
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>


  <!-- credentials -->	
  <sw:include href="/lib/cred.xsl"/>
		
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="../../../layout/forms-list.xsl"/>	

	<sw:include href="/lib/vocabulary.xsl"/>					
	
</xsl:stylesheet>
