<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
>
	
	<xsl:output method="xml"/>

	<!-- check permissions to this page -->
	<xsl:variable name="cr-cancel" select="cred:check('vzcp.log.actions_log.cancel')"/>

	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="sw:param('cancel') and not($cr-cancel)">
				<!-- no cancel cred -->
				<packet/>
			</xsl:when>

			<!-- Cancel task -->
			<xsl:when test="sw:param('cancel')">
				<xsl:copy-of
					select="local:packet-cancel(sw:param('id'))"/>
			</xsl:when>

			<!-- Unknown post -->
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>


	<func:function name="local:packet-cancel">
		<xsl:param name="ids"/>
		<func:result>
			<packet log="on">
				<cookie>
					<msg>
						<ok>
							<sw:text>The action(s) has/have been canceled.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to cancel the action(s).</sw:text>
						</error>
					</msg>
					<operation>cancel_action</operation>
					<redirect-last/>
				</cookie>
				<data>
					<xsl:for-each select="$ids">
						<system>
							<cancel>
								<message_id>
									<xsl:value-of select="."/>
								</message_id>
							</cancel>
						</system>
					</xsl:for-each>
				</data>
			</packet>
		</func:result>
	</func:function>


	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
