<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error vt units env request trace"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"	
	xmlns:request		="http://www.swsoft.com/xsl/cp/request"
	xmlns:trace			="http://www.swsoft.com/xsl/cp/trace"
>
	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	

	<xsl:output method="xml"/>  

	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>	

	<xsl:param name="wiz_code" select="'units-move'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='move'">						
				<!-- Restore form's data  -->				
				<xsl:variable name="new-form-rtf">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::dst-dn"></xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>				
					<dst-dn><xsl:value-of select="sw:param('dst_dn')"/></dst-dn>
				</xsl:variable>
				<!-- /Restore form's data  -->
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
				
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<xsl:if test="not($new-form/dst-dn!='')">
						<xsl:if test="error:put(sw:text('You should select the destination folder.'),'','dst_dn')"/>
					</xsl:if>									
					<!-- /Check data -->
				</xsl:if>
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:packet-final($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>				
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-data"/>				
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:init-data">	
		<xsl:variable name="dn-now" select="units:current-dn()"/>		
	
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<dst-dn/>
			<top-dn><xsl:value-of select="units:tree-dn(units:dn2tree($dn-now))"/></top-dn>
			<src-dn><xsl:value-of select="$dn-now"/></src-dn>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="move" screen-id="10.00.00.01.11"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
		
	<!-- *********************************************************** -->
	
	<func:function name="local:packet-final">
		<xsl:param name="data"/>
		<xsl:if test="sw:sesput('frameset_reload_farmdir',$data/top-dn)"/>
		<xsl:if test="units:set-current-dn($data/top-dn)"/>
		<func:result>
			<packet>
				<target>infrastructurem</target>
				<cookie>
	        <msg>
	          <ok><sw:text>The folder has been moved.</sw:text></ok>
	          <error><sw:text>Failed to move the folder.</sw:text></error>
	        </msg>
	        <redirect-prev/>
	      </cookie>	
				<data>
					<infrastructurem>
						<edit>
							<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn($data/src-dn)"/></name>
							<unit>
								<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn(concat( units:dn2name($data/src-dn),',',$data/dst-dn))"/></name>
							</unit>
						</edit>
					</infrastructurem>
				</data>
			</packet>
		</func:result>
		
	</func:function>		

  <!-- credentials -->	
	<sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>					
	
</xsl:stylesheet>
