<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error action units"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action		="http://www.swsoft.com/xsl/cp/action"	
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"
>
	<!-- Import required modules -->
	<sw:include href="/lib/core/units-core.xsl"/>
	<!-- /Import required modules -->

	<xsl:output method="xml"/>
	
	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:param name="wiz_code" select="'cluster_add'"/>


	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "Start" -->
			<xsl:when test="$step='start'">
						
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()='childs-type'"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<childs-type><xsl:value-of select="sw:param('childs_type')"/></childs-type>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- CHECK DATA -->
						<!-- Check childs-type -->
			      <xsl:choose>
 				      <!-- check presence -->
				      <xsl:when test="string($new_form/childs-type)=''">
				      	<xsl:value-of select="error:put(sw:text('Please select the item type.'),'','childs_type')"/>
				      </xsl:when>
						</xsl:choose>
						<!-- /Check childs-type -->
						<!-- /CHECK DATA -->
					</xsl:if>
					
					<xsl:if test="wiz:setStepsEnabledExcept('start',false())"/>
					<xsl:choose>
						<xsl:when test="$new_form/childs-type='hn.core.vt'">
							<xsl:if test="wiz:setStepEnabled('select_hns',true())"/>
						</xsl:when>						
						<xsl:when test="$new_form/childs-type='env.core.vt'">
							<xsl:if test="wiz:setStepEnabled('select_envs',true())"/>
						</xsl:when>						
						<xsl:when test="$new_form/childs-type='unit.farm'">
							<xsl:if test="wiz:setStepEnabled('specify_unit',true())"/>
						</xsl:when>						
					</xsl:choose>
										
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>			
			
			<!-- Step "Select HNs" -->
			<xsl:when test="$step='select_hns'">
					
					<xsl:variable name="chosen" select="sw:param('all_id')"/>
					<xsl:variable name="unchosen" select="sw:param('sel_id')"/>
					
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()='hns'"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<hns>								
							<xsl:for-each select="sw:param('hns')">
								<eid>
									<xsl:value-of select="."/>
								</eid>
							</xsl:for-each>		
						</hns>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- CHECK DATA -->
						<xsl:choose>
							<!-- Check selected for choose items -->
							<xsl:when test="sw:param('choose')">
								<xsl:if test="not($chosen)">
									<xsl:value-of select="error:put(sw:text('You should select at least one Virtuozzo Hardware Node.'),'','')"/>
								</xsl:if>
							</xsl:when>
							<!-- Check selected for unchoose items -->
							<xsl:when test="sw:param('unchoose')">
								<xsl:if test="not($unchosen)">
									<xsl:value-of select="error:put(sw:text('You should select at least one Virtuozzo Hardware Node.'),'','')"/>
								</xsl:if>
							</xsl:when>
							<!-- Check chosen items -->
							<xsl:when test="sw:param('next')">
								<xsl:if test="not($new_form/hns/eid)">
									<xsl:value-of select="error:put(sw:text('You should choose at least one Virtuozzo Hardware Node.'),'','')"/>
								</xsl:if>
							</xsl:when>
						</xsl:choose>							
						<!-- /CHECK DATA -->
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>		
			
			<!-- Step "Select Envs" -->
			<xsl:when test="$step='select_envs'">
					
					<xsl:variable name="chosen" select="sw:param('all_id')"/>
					<xsl:variable name="unchosen" select="sw:param('sel_id')"/>
					
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()='envs'"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<envs>								
							<xsl:for-each select="sw:param('envs')">
								<eid>
									<xsl:value-of select="."/>
								</eid>
							</xsl:for-each>					
						</envs>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- CHECK DATA -->
						<xsl:choose>
							<!-- Check selected for choose items -->
							<xsl:when test="sw:param('choose')">
								<xsl:if test="not($chosen)">
									<xsl:value-of select="error:put(sw:text('You should select at least one Virtuozzo Environment.'),'','')"/>
								</xsl:if>
							</xsl:when>
							<!-- Check selected for unchoose items -->
							<xsl:when test="sw:param('unchoose')">
								<xsl:if test="not($unchosen)">
									<xsl:value-of select="error:put(sw:text('You should select at least one Virtuozzo Environment.'),'','')"/>
								</xsl:if>
							</xsl:when>
							<!-- Check chosen items -->
							<xsl:when test="sw:param('next')">
								<xsl:if test="not($new_form/envs/eid)">
									<xsl:value-of select="error:put(sw:text('You should choose at least one Virtuozzo Environment.'),'','')"/>
								</xsl:if>
							</xsl:when>
						</xsl:choose>							
						<!-- /CHECK DATA -->
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>		
			
			<!-- Step "Specify Unit" -->
			<xsl:when test="$step='specify_unit'">
					
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()='unit'"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>									
								</xsl:otherwise>
							</xsl:choose>							
						</xsl:for-each>
						<unit>					
							<title><xsl:value-of select="sw:param('title')"/></title>
							<type><xsl:value-of select="sw:param('type')"/></type>
						</unit>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- CHECK DATA -->																
						<!-- Check Title-->
						<xsl:if test="not($new_form/unit/title!='')">
							<xsl:value-of select="error:put(sw:text('You should specify the folder name.'),'','title')"/>
						</xsl:if>
						<!-- /Check Title -->
						<!-- Check Type-->
						<xsl:if test="not($new_form/unit/type!='')">
							<xsl:value-of select="error:put(sw:text('You should select the folder icon.'),'','type')"/>
						</xsl:if>
						<!-- /Check Type -->
						<!-- /CHECK DATA -->
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>	
			
			
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:get-final-packet($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:initCreate"/>				
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>	
	
	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="start-type" select="string(sw:param('unit-type'))"/>		
		<xsl:variable name="new_form">
			<def>	
				<xsl:variable name="dn-get" select="sw:base64-decode(string(sw:param('parent')))"/>
				<xsl:choose>
					<xsl:when test="$dn-get!=''">
						<parent-dn><xsl:value-of select="$dn-get"/></parent-dn>
						<parent-title><xsl:value-of select="dirm:dn-first-title($dn-get)"/></parent-title>			
					</xsl:when>
					<xsl:otherwise>
						<parent-dn><xsl:value-of select="units:current-dn()"/></parent-dn>
						<parent-title><xsl:value-of select="sw:sesgetstr('farmdir-parent-title')"/></parent-title>
					</xsl:otherwise>
				</xsl:choose>
			</def>			
			<xsl:if test="$start-type">
				<childs-type>
					<xsl:value-of select="$start-type"/>
				</childs-type>
			</xsl:if>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="start" screen-id="10.00.00.01.00" enabled="{sw:if($start-type='','1','0')}"/>
			<step id="select_hns" screen-id="10.00.00.01.01" enabled="{sw:if($start-type='' or $start-type='hn.core.vt','1','0')}"/>			
			<step id="select_envs" screen-id="10.00.00.01.02"  enabled="{sw:if($start-type='' or $start-type='env.core.vt','1','0')}"/>			
			<step id="specify_unit" screen-id="10.00.00.01.03"  enabled="{sw:if($start-type='' or $start-type='unit.farm','1','0')}"/>			
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[@enabled='1'][1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
		
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:get-final-packet">
		<xsl:param name="data"/>
		<!--|-->		
		<func:result>
			<xsl:choose>
				<!-- Add Unit -->
				<xsl:when test="$data/childs-type='unit.farm'">					
					<packet
						xmlns:xsi ="http://www.w3.org/2001/XMLSchema-instance"	
						xmlns:vzat	="http://www.swsoft.com/webservices/vza/4.0.0/vzatypes"						
					>
						<target>infrastructurem</target>
						<cookie>
			        <msg>
			          <ok><sw:text>The folder has been successfully added.</sw:text></ok>
			          <error><sw:text>Failed to add the folder.</sw:text></error>
			        </msg>
			        <redirect-prev/>       
			      </cookie>		
						<data>
							<infrastructurem>
								<add>
									<unit>
										<xsl:variable name="full-dn-decoded" select="concat(
											'ou=',sw:escape-dn-attribute($data/unit/title),',',units:decode-dn($data/def/parent-dn)
										)"/>
										<xsl:variable name="full-dn-encoded" select="units:encode-dn($full-dn-decoded)"/>
										<xsl:if test="sw:sesput('frameset_reload_farmdir',units:dn2parent($full-dn-encoded))"/>
										<name><xsl:value-of select="$full-dn-decoded"/></name>
										<vzat:attr xsi:type="vzat:modType">
											<name>vzlUnitType</name>
											<value><xsl:value-of select="sw:base64-encode($data/unit/type)"/></value>
										</vzat:attr>
									</unit>
								</add>
							</infrastructurem>
						</data>
					</packet>
				</xsl:when>
				<!-- /Add Unit -->
				<!-- Add Envs -->
				<xsl:when test="$data/childs-type='env.core.vt'">					
					<packet>
						<target>infrastructurem</target>
						<cookie>
			        <msg>
			          <ok><sw:text>The items have been added successfully.</sw:text></ok>
			          <error><sw:text>Failed to add the items.</sw:text></error>
			        </msg>
			        <redirect-prev/>       
			      </cookie>		
						<data>							
							<infrastructurem>
								<add_env>
									<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn($data/def/parent-dn)"/></name>										
									<xsl:for-each select="$data/envs/eid">										
										<xsl:if test="position()=1">									
											<xsl:if test="sw:sesput('frameset_reload_farmdir',$data/def/parent-dn)"/>
										</xsl:if>										
										<eid><xsl:value-of select="."/></eid>
									</xsl:for-each>
								</add_env>
							</infrastructurem>							
						</data>
					</packet>
				</xsl:when>
				<!-- /Add Envs -->
				<!-- Add VZ HNs -->
				<xsl:when test="$data/childs-type='hn.core.vt'">							
					<packet>
						<target>infrastructurem</target>
						<cookie>
			        <msg>
			          <ok><sw:text>The Hardware Node(s) has/have been successfully added.</sw:text></ok>
			          <error><sw:text>Failed to add the Hardware Node(s).</sw:text></error>
			        </msg>
			        <redirect-prev/>       
			      </cookie>		
						<data>							
							<infrastructurem>
								<add_env>
									<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn($data/def/parent-dn)"/></name>
									<xsl:for-each select="$data/hns/eid">										
										<xsl:if test="position()=1">									
											<xsl:if test="sw:sesput('frameset_reload_farmdir',$data/def/parent-dn)"/>
										</xsl:if>										
										<eid><xsl:value-of select="."/></eid>
									</xsl:for-each>
								</add_env>
							</infrastructurem>							
						</data>
					</packet>
				</xsl:when>
				<!-- /Add VZ HNs -->
			</xsl:choose>
		</func:result>
	</func:function>
	
  
	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>				
	
	
</xsl:stylesheet>
