<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error units"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
>
	<sw:include href="/lib/core/units-core.xsl"/>

	<xsl:output method="xml"/>

	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:param name="wiz_code" select="'cluster-unit'"/>
	<xsl:variable name="edit-mode" select="$form/unit-id"/>	

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='unit'">
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()=$step"></xsl:when>
								<xsl:when test="name()='cred'"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<unit>
							<name><xsl:value-of select="sw:param('name')"/></name>							
							<type><xsl:value-of select="sw:param('type')"/></type>							
						</unit>
					</xsl:variable>					
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- Check data -->
						<!-- check name -->
			      <xsl:choose>
 				      <!-- check name presence -->
				      <xsl:when test="string($new_form/unit/name)=''">
				      	<xsl:if test="error:put(sw:text('You should specify a title.'),'','name')"/>
				      </xsl:when>
				      <!-- check name for max.length -->
				      <xsl:when test="string-length($new_form/unit/name)&gt;1000">
				      	<xsl:if test="error:put(sw:text('A title cannot be longer than 1000 characters.'),'','name')"/>
				      </xsl:when>
						</xsl:choose>
						<!-- /check name -->
					</xsl:if>
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:choose>								
									<xsl:when test="$data/unit-id!=''">
									
										<xsl:variable name="new-id" select="concat(
											substring-before($data/unit-id,'='),
											'=',sw:base64-encode(sw:escape-dn-attribute($data/unit/name)),',',
											substring-after($data/unit-id,',')
										)"/>
												
										<!-- Try to update unit -->
										<xsl:variable name="res" select="sw:xchg(local:packet-edit($data,$new-id))/packet/data"/>
										<xsl:variable name="error" select="$res/error|$res/infrastructurem/error"/>										
										<xsl:choose>
											<!-- Eror occured -->
											<xsl:when test="$error">
												<xsl:value-of select="error:put(sw:text('Failed to update the folder.'),$error/message )"/>	
												<xsl:if test="sw:sesputtree($wiz_data,$data)"/>												
											</xsl:when>
											<!-- Updated ok -->
											<xsl:otherwise>
												<xsl:if test="sw:sesput('frameset_reload_farmdir',$new-id)"/>
												<xsl:if test="units:set-current-dn($new-id)"/>
																				
												<packet>
													<cookie>
														<msg>
															<set-ok><sw:text>The folder has been successfully updated.</sw:text></set-ok>
														</msg>
														<redirect-prev/>
													</cookie>
												</packet>
												<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>												
											</xsl:otherwise>
										</xsl:choose>
									</xsl:when>
									<xsl:otherwise>
										<sw:die></sw:die>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check-context('vzcp.units.edit','unit.farm'))"/>
		<xsl:if test="$step = ''">
			<xsl:variable name="act" select="sw:param('act')"/>
			<xsl:choose>
				<xsl:when test="$act='edit'">
					<xsl:variable name="id" select="units:current-dn()"/>					
					<xsl:call-template name="local:initEdit">
						<xsl:with-param name="id" select="$id"/>
						<xsl:with-param name="step" select="'gen'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initCreate"/>
				</xsl:otherwise>
			</xsl:choose>		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>	
	
	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<unit>
				<name/>				
			</unit>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="unit" screenid="10.00.00.01.03"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="local:initEdit">
		<xsl:param name="step"/>
		<xsl:param name="id"/>
		<!-- Init steps -->
		<xsl:variable name="all_steps_">
			<step id="unit" screenid="10.00.00.01.04"/>
		</xsl:variable>
		<!-- Init Step -->
		<xsl:variable name="new_step" select="'unit'"/>
		<xsl:variable name="new_steps" select="exsl:node-set($all_steps_)/step[@id=$new_step]"/>
		<!-- Check startup conditions -->
		<xsl:variable name="new_form">
			<xsl:choose>
				<xsl:when test="count($new_steps)=0">
					<xsl:message terminate="yes">
						Requested tab '<xsl:value-of select="$new_step"/>' is unknown for Unit Management code.
					</xsl:message>
				</xsl:when>
				<xsl:when test="not($id)">
					<xsl:message terminate="yes">
						Unit ID should be specified.
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initEditData">
						<xsl:with-param name="step" select="$step"/>
						<xsl:with-param name="id" select="$id"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>	
	
	<xsl:template name="local:initEditData">
		<xsl:param name="step"/>
		<xsl:param name="id"/>
		<!-- Load data -->	
		<xsl:variable name="unit" select="units:find-unit($id)"/>		
		<!--|-->
		<unit>
			<name><xsl:value-of select="units:dn2title($unit/name)"/></name>			
			<type><xsl:value-of select="sw:base64-decode($unit/attr[name='vzlUnitType']/value)"/></type>			
		</unit>
		<src>
			<name><xsl:value-of select="units:dn2title($unit/name)"/></name>
		</src>
		<unit-id><xsl:value-of select="$id"/></unit-id>		
	</xsl:template>
	
	<!-- *********************************************************** -->
	
	<func:function name="local:packet-edit">
		<xsl:param name="data"/>
		<xsl:param name="new-id"/>		

		<func:result>
			<packet>
				<target>infrastructurem</target>
				<data>
					<infrastructurem>
						<edit>
							<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn($data/unit-id)"/></name>
							<unit>
								<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn($new-id)"/></name>
								<attr>
									<name>vzlUnitType</name>
									<value><xsl:value-of select="sw:base64-encode($data/unit/type)"/></value>
									<op>2</op>
								</attr>
							</unit>
						</edit>
					</infrastructurem>					
				</data>
			</packet>			
		</func:result>
		
	</func:function>		

  <!-- credentials -->	
	<sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>					
	
</xsl:stylesheet>
