<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date env authm global swa-mailer"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:global="http://www.swsoft.com/xsl/cp/global"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:date	="http://exslt.org/dates-and-times"
	xmlns:authm	="http://www.swsoft.com/xsl/cp/authm"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:swa-mailer="http://www.swsoft.com/xsl/cp/swa-mailer"
>
  
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/swa/swa-mailer.xsl"/>

  <xsl:output method="xml"/>

	<xsl:variable name="vps-user" select="$config/vzcpcon/access/auth[sw:lc(type) = 'restorepassword']/user[node() = $login]"/>
	<xsl:variable name="ve-eid-real" select="sw:ve-eid()"/>
	<xsl:variable name="veid-real" select="env:get-env($ve-eid-real)/env/virual_config/veid"/>
	<xsl:variable name="mail-config" select="swa-mailer:get-config(true())"/>

  <xsl:template match="url">
    <xsl:value-of select="concat($baseurl,'/restore-password?LoginTicket=')"/><xsl:value-of select="$ticket"/>
  </xsl:template>

  <xsl:template match="to-email">
    <xsl:value-of select="$request/http_request/post/parameter[name = 'LoginEmail']/value"/>
  </xsl:template>

  <xsl:template match="from-email">
    <xsl:value-of select="$mail-config/accounts/system/email"/>
  </xsl:template>

  <xsl:template match="signature">
    <xsl:value-of select="$config/vzcpcon/defines/restore_password/signature"/>
  </xsl:template>

  <xsl:template match="veid">
    <xsl:value-of select="$veid-real"/>
  </xsl:template>

  <xsl:template match="login">
    <xsl:value-of select="$login"/>
  </xsl:template>

  <!-- send password recovery url to customer by email -->
  <xsl:template name="send-url">
		<xsl:variable name="unixtime" select="date:seconds()"/>
		<xsl:variable name="prefix-date" select="concat(date:day-abbreviation(),' ',date:month-abbreviation())"/>
		<xsl:variable name="sufix-date" select="sw:strftime($unixtime, ' %d %H:%M:%S %Y')"/>
 
    <packet>
      <target>mailer</target>
      <cookie><sent/></cookie>
      <data>
        <mailer>
          <post>
            <xsl:variable name="msgtext">
            	<xsl:if test="vt:is-local-platform-linux()">
            		<!-- #44909 -->
								<xsl:value-of select="concat('From ',$mail-config/accounts/system/email,' ',$prefix-date,$sufix-date,'&#10;')"/>
							</xsl:if>
              <xsl:apply-templates select="sw:document('restore-message.xml')/message/child::node()"/>
            </xsl:variable>	
            <message><xsl:value-of select="sw:base64-encode($msgtext)"/></message>
          </post>
        </mailer>
      </data>
			<vzcpauth/>
    </packet>
    
  </xsl:template>


  <!-- change clusteruser password -->
  <xsl:template name="change-cluster-user-password">
		<xsl:variable name="user-info" select="authm:get-user(sw:login()/login)"/>
		<xsl:choose>
			<xsl:when test="$user-info/realm=$global:system-realm-id">
				<target>userm</target>
				<data>				
					<userm>
						<edit_user>
							<name><xsl:value-of select="sw:base64-decode($user-info/name)"/></name>
							<user>
								<name><xsl:value-of select="sw:base64-decode($user-info/name)"/></name>
								<password><xsl:value-of select="sw:base64-encode(sw:param('passwd','post'))"/></password>
							</user>
						</edit_user>						
					</userm>
				</data>		
			</xsl:when>
			<xsl:otherwise>
				<target>authm</target>
				<data>
					<authm>
						<edit_user>
							<xsl:copy-of select="$user-info/name" />
							<xsl:copy-of select="$user-info/realm" />
							<password>
								<xsl:value-of
									select="sw:base64-encode(/http_request/post/parameter[name = 'passwd']/value)" />
							</password>
							<user>
								<xsl:copy-of select="$user-info/name" />
							</user>
						</edit_user>
					</authm>
				</data>
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>


  <!-- change root password -->
  <xsl:template name="change-vps-user-password">
    <target>vzaenvm</target>    
    <xsl:copy-of select="sw:hn-dst($ve-eid-real)"/>
    <data>
      <vzaenvm>
        <set_user_password>
        	<eid><xsl:value-of select="$ve-eid-real"/></eid>
          <name><xsl:value-of select="$login"/></name>
          <password><xsl:value-of select="sw:base64-encode(/http_request/post/parameter[name = 'passwd']/value)"/></password>
        </set_user_password>
      </vzaenvm>
    </data>
  </xsl:template>

  <!-- change plesk admin password -->
  <xsl:template name="change-psa-admin-password">
    <target>progm</target>      
    <xsl:copy-of select="sw:hn-dst($ve-eid-real)"/>
    <data>
      <progm>
        <exec>
          <veid><xsl:value-of select="$veid-real"/></veid>
          <argv><xsl:value-of select="sw:base64-encode('/usr/local/psa/admin/sbin/ch_admin_passwd')"/></argv>
          <envp><xsl:value-of select="sw:base64-encode(concat('PSA_PASSWORD=', /http_request/post/parameter[name = 'passwd']/value))"/></envp>
          <stdio>
			      <error/>
          </stdio>
        </exec>
      </progm>
    </data>
  </xsl:template>

  <xsl:template name="change-password">
		<xsl:variable name="min-password-length" select="5"/>
    <packet>
  
      <xsl:choose>
        <xsl:when test="not(//http_request/post/parameter[name = '_submit']/value)">
          <!-- no form post - do nothing -->
        </xsl:when>
        
        <xsl:when test="not(string(/http_request/post/parameter[name = 'passwd']/value)) or not(string(/http_request/post/parameter[name = 'retype']/value))">
          <!-- check password presence -->
          <xsl:value-of select="error:put(sw:text('The password was not specified.'))"/>
        </xsl:when>
        
        <xsl:when test="/http_request/post/parameter[name = 'passwd']/value != /http_request/post/parameter[name = 'retype']/value">
          <!-- check passwords match -->
          <xsl:value-of select="error:put(sw:text('The passwords do not match.'))"/>
        </xsl:when>

        <xsl:when test="string-length(/http_request/post/parameter[name = 'passwd']/value) &lt; $min-password-length">
          <!-- check passwords size, for plesk compatible -->
					<xsl:variable name="err-text">
						<sw:text>
			        <xsl:with-param name="min-password-length" select="$min-password-length"/>
							The password length must be at least %{min-password-length} symbols
			      </sw:text>        
					</xsl:variable>
          <xsl:value-of select="error:put($err-text)"/>
        </xsl:when>
        
        <xsl:when test="/http_request/post/parameter[name = 'passwd']/value">
          <cookie>
            <changed/>
          </cookie>

          <xsl:choose>
						<xsl:when test="$auth-type = 'restoreauthmpassword'">
              <xsl:call-template name="change-cluster-user-password"/>
						</xsl:when>
            <xsl:otherwise>
              <xsl:call-template name="change-vps-user-password"/>
            </xsl:otherwise>
          </xsl:choose>
          
        </xsl:when>
      </xsl:choose>
			<vzcpauth/>
    </packet>
  </xsl:template>

  <!-- finish password restore -->
  <xsl:template name="finsh-password-restore">
    <packet>
      <target>ticketm</target>  
      <cookie><redirect/></cookie>
      <data>
        <ticketm>
          <logout>
            <ticket><xsl:value-of select="$ticket"/></ticket>
            <ip><xsl:value-of select="/http_request/env/parameter[name = 'REMOTE_ADDR']/value"/></ip>
          </logout>
        </ticketm>
      </data>
			<vzcpauth/>
    </packet>
  </xsl:template>

  <xsl:template match="/">

    <xsl:choose>
      <!-- we should finish password-recovery session -->
      <xsl:when test="/http_request/post/parameter[name = 'doLogout']/value">
        <xsl:call-template name="finsh-password-restore"/>
      </xsl:when>

      <!-- we already have sent URL and changing password now -->
      <xsl:when test="sw:sesget('password-recovery-url-sent')">
        <xsl:call-template name="change-password"/>
      </xsl:when>

      <!-- we have not sent info - send it now -->
      <xsl:otherwise>
        <xsl:call-template name="send-url"/>
      </xsl:otherwise>

    </xsl:choose>

  </xsl:template>
  
	<sw:include href="../lib/globals.xsl"/>
	<sw:include href="../lib/common.xsl"/>
	<sw:include href="../lib/vt/env-core.xsl"/>
	<sw:include href="../lib/swa/authm.xsl"/>
	
</xsl:stylesheet>
