<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred authm"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:error			="http://www.swsoft.com/xsl/cp/error"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred 		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:authm ="http://www.swsoft.com/xsl/cp/authm"
	xmlns:security="http://www.swsoft.com/xsl/cp/security"
  >
 	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>
  
  <xsl:output method="xml"/>

  <!-- check permissions to this page -->
	<xsl:variable name="cr-group-delete"	select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>
  
	<xsl:template match="/">
		<xsl:choose>

				<xsl:when test="sw:param('delete') and not($cr-group-delete)">	
					<!-- no delete cred -->
					<packet/>
				</xsl:when>
				
        <!-- Check selected templates -->
        <xsl:when test="not(sw:param('id'))">
          <xsl:if test="error:put(sw:text('Please select at least one group.'),'')"/>
          <packet/>
        </xsl:when>

        <!-- Delete template-->
        <xsl:when test="sw:param('delete')">
        	<xsl:copy-of select="local:get-packet-delete(sw:param('id'))"/>
        	<xsl:if test="sw:response('lib/opredirect.xsl')"/>	
        </xsl:when>
        
        <!-- Unknown post -->
        <xsl:otherwise>
          <packet/>
        </xsl:otherwise>

      </xsl:choose>
  </xsl:template>
  

  <func:function name="local:get-packet-delete">
  	<xsl:param name="ids"/>
  	<xsl:variable name="realms-info" select="security:realms-info()"/>
  	
 		<func:result>
 			<packet log="on">
				<target>authm</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>The groups have been deleted.</sw:text></ok>
	            <error><sw:text>Failed to delete the groups.</sw:text></error>
	          </msg>
	          <operation>delete_group</operation>
	          <redirect-last/>
	        </cookie>			
				<data>
					<authm>
						<del_group>
							<xsl:for-each select="$ids">
								<group>
									<name>
										<xsl:value-of select="sw:base64-encode(.)"/>
									</name>
									<realm><xsl:value-of select="$realms-info/current-eid"/></realm>
								</group>
							</xsl:for-each>
						</del_group>
					</authm>
				</data>
			</packet>
 		</func:result>
  </func:function>
 
  <!-- credentials -->
  <sw:include href="/lib/common.xsl"/>
  <sw:include href="/lib/cred.xsl"/>

 
</xsl:stylesheet>
