	<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl form func wiz cred check env local authm error dirm groups vzcpsecuritym perms"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check" xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:func="http://exslt.org/functions" xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:groups="http://www.swsoft.com/xsl/cp/groups" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm" xmlns:perms="http://www.swsoft.com/xsl/cp/perms"
	xmlns:vzcpsecuritym="http://www.swsoft.com/xsl/cp/vzcpsecuritym"
	xmlns:security="http://www.swsoft.com/xsl/cp/security" xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"
>

	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/vzcpsecuritym.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms.xsl"/>
	<sw:include href="/lib/sysdir/securman/groups.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>
	

	<xsl:output method="xml"/>
	<!-- check permissions to show this page -->
	<xsl:variable name="cr-role" select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>

	<!-- calc cred in wizard step case -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'sm-group'"/>
	<xsl:variable name="form" select="local:init-form()"/>
	<xsl:variable name="edit-mode" select="$form/group-id"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- No cred  -->
			<xsl:when test="not($cr-role)">
				<packet/>
			</xsl:when>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:when test="name()='group'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>

					<!-- Group -->
					<gen>
						<name>
							<xsl:choose>
								<xsl:when
									test="$form/src/name and string(authm:vzadmin-group-name()) = $form/src/name">
									<xsl:value-of select="$form/src/name"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="sw:param('name')"/>
								</xsl:otherwise>
							</xsl:choose>
						</name>
						<xsl:for-each select="sw:param('principals')">
							<principal>
								<sid><xsl:value-of select="substring-before(.,'|')"/></sid>
								<src><xsl:value-of select="."/></src>
								<title><xsl:value-of select="substring-after(.,'|')"/></title>								
							</principal>
						</xsl:for-each>
					</gen>
					<group>
						<description>
							<xsl:value-of select="sw:param('description')"/>
						</description>
					</group>
					<!-- /Group -->
				</xsl:variable>

				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- check description -->
					<xsl:choose>
						<!-- check description for max.length -->
						<xsl:when test="string-length($new_form/group/description) &gt; 255">
							<xsl:if
								test="error:put(sw:text('The description cannot be longer than 255 characters.'),'','description')"
							/>
						</xsl:when>
					</xsl:choose>
					<!-- check name -->
					<xsl:if test="string($new_form/gen/name)=''">
						<xsl:if test="error:put(sw:text('You should specify a name.'),'','name')"/>
					</xsl:if>
					<!-- /check name -->
				</xsl:if>
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:getFinalPacket($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:choose>
				<xsl:when test="sw:param('cmd') = 'new'">
					<xsl:call-template name="local:initCreate"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initEdit">
						<xsl:with-param name="id" select="sw:sesgetstr('securman-group-id')"/>
						<xsl:with-param name="step" select="'gen'"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="realms-info" select="security:realms-info()"/>
		
		<xsl:variable name="new_form">
			<src>
				<realm-eid>
					<xsl:value-of select="$realms-info/current-eid"/>
				</realm-eid>
			</src>			
			<gen>
				<!--<enabled>1</enabled>-->
			</gen>
			<group>
				<description/>
				<name/>
			</group>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screenid="03.01.01.04.01"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:initEdit">
		<xsl:param name="id"/>
		<xsl:param name="step"/>
		<!-- Init steps -->

		<xsl:variable name="all_steps_">
			<step id="gen" screenid="03.01.01.04.02"/>
		</xsl:variable>
		<!-- Init Step -->
		<xsl:variable name="new_step">
			<xsl:choose>
				<xsl:when test="string(sw:param('tab')) != ''">
					<xsl:value-of select="string(sw:param('tab'))"/>
				</xsl:when>
				<xsl:otherwise>gen</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_steps" select="exsl:node-set($all_steps_)/step[@id=$new_step]"/>
		<!-- Check startup conditions -->
		<xsl:variable name="new_form">
			<xsl:choose>
				<xsl:when test="count($new_steps)=0">
					<xsl:message terminate="yes">
						Requested tab '<xsl:value-of select="$new_step"
						/>' is unknown for Groups Management code.
					</xsl:message>
				</xsl:when>
				<xsl:when test="not($id)">
					<xsl:message terminate="yes">
						Group ID should be specified.
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initEditData">
						<xsl:with-param name="id" select="$id"/>
						<xsl:with-param name="step" select="$step"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:initEditData">
		<xsl:param name="id"/>
		<xsl:param name="step"/>
		<!-- Load data -->
		<xsl:variable name="realms-info" select="security:realms-info()"/>		
		<xsl:variable name="group" select="authm:get-group($id,$realms-info/current-eid)"/>
		<xsl:variable name="group-users-rtf">
			<xsl:if test="$group/member_user">
				<xsl:copy-of select="authm:get-users-by-authname($group/member_user)/user"/>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="group-users" select="exsl:node-set($group-users-rtf)"/>
		<xsl:variable name="group-groups-rtf">
			<xsl:if test="$group/member_group">
				<xsl:copy-of select="authm:get-groups-by-authname($group/member_group)/group"/>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="group-groups" select="exsl:node-set($group-groups-rtf)"/>
		<!--|-->
		<gen>
			<name>
				<xsl:value-of select="sw:base64-decode($group/name)"/>
			</name>
			<xsl:for-each select="$group/member_user">
				<xsl:variable name="muser" select="$group-users/user[string(name)=current()/name]"/>
				<xsl:if test="$muser">
					<xsl:variable name="muser-sid" select="$muser/data/attr[name='objectSid']/value"/>
					<xsl:variable name="muser-login" select="authm:user-login($muser)"/>
					<principal>
						<sid><xsl:value-of select="$muser-sid"/></sid>
						<title><xsl:value-of select="$muser-login"/></title>
						<src><xsl:value-of
							select="concat($muser-sid,'|',$muser-login)"/></src>
					</principal>
				</xsl:if>
			</xsl:for-each>
			<xsl:for-each select="$group/member_group">
				<xsl:variable name="mgroup" select="$group-groups/group[string(name)=current()/name]"/>
				<xsl:if test="$mgroup">
					<xsl:variable name="mgroup-sid" select="$mgroup/data/attr[name='objectSid']/value"/>
					<xsl:variable name="mgroup-login" select="authm:group-login($mgroup)"/>
					<principal>
						<sid><xsl:value-of select="$mgroup-sid"/></sid>
						<title><xsl:value-of select="$mgroup-login"/></title>
						<src><xsl:value-of 
							select="concat($mgroup-sid,'|',$mgroup-login)"/></src>
					</principal>					
				</xsl:if>
			</xsl:for-each>			
		</gen>

		<src>
			<name>
				<xsl:value-of select="sw:base64-decode($group/name)"/>
			</name>
			<cn>
				<xsl:value-of select="$group/cn"/>
			</cn>
			<sid>
				<xsl:value-of select="$group/objectSid"/>
			</sid>
			<realm-eid>
				<xsl:value-of select="$realms-info/current-eid"/>
			</realm-eid>
		</src>

		<group>
			<xsl:copy-of select="$group/description"/>
		</group>

		<group-id>
			<xsl:value-of select="$id"/>
		</group-id>
	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>

		<xsl:variable name="group-data-rtf">
			<xsl:choose>
				<xsl:when test="not($data/group-id)">
					<xsl:call-template name="local:getFinalPacketCommon">
						<xsl:with-param name="data" select="$data"/>
						<xsl:with-param name="create" select="true()"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:getFinalPacketCommon">
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="group-data" select="exsl:node-set($group-data-rtf)"/>

		<xsl:variable name="error-msg"
			select="sw:if(not($data/group-id),sw:text('Failed to create the group.'),sw:text('Failed to update the group.'))"/>

		<xsl:variable name="group-op-result-rtf">
			<xsl:choose>
				<xsl:when test="not($data/group-id)">
					<xsl:copy-of select="authm:add-group($group-data)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of 
						select="authm:set-group(authm:user-key(
							$data/group-id,$data/src/realm-eid),$group-data)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="group-op-result" select="exsl:node-set($group-op-result-rtf)"/>

		<xsl:choose>
			<xsl:when test="$group-op-result//error">
				<xsl:if test="error:put($error-msg,$group-op-result//error/message)"/>
			</xsl:when>
		</xsl:choose>

		<xsl:variable name="errors" select="error:get()"/>

		<func:result>
			<packet>
				<cookie>
					<xsl:choose>
						<xsl:when test="not($errors)">
							<msg>
								<xsl:choose>
									<xsl:when test="not($data/group-id)">
										<set-ok><sw:text>The group has been created successfully.</sw:text></set-ok>
									</xsl:when>
									<xsl:otherwise>
										<xsl:if test="sw:sesputstr('securman-group-id',$data/gen/name)"/>
										<set-ok><sw:text>The group has been updated successfully.</sw:text></set-ok>
									</xsl:otherwise>
								</xsl:choose>
							</msg>
						</xsl:when>
					</xsl:choose>
					<redirect-prev/>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<xsl:template name="local:getFinalPacketCommon">
		<xsl:param name="data"/>
		<xsl:param name="create" select="false()"/>
		<name>
			<xsl:value-of select="sw:base64-encode($data/gen/name)"/>
		</name>
		<realm>
			<xsl:value-of select="$data/src/realm-eid"/>
		</realm>		
		<xsl:if test="$data/gen/principal">
			<xsl:variable name="auth-names" select="authm:get-auth-names($data/gen/principal/sid)"/>
			<xsl:for-each select="$auth-names[string(type)=$global:auth-name-type-user]">
				<member_user>
					<xsl:copy-of select="auth_name/*"/>
				</member_user>
			</xsl:for-each>
			<xsl:for-each select="$auth-names[string(type)=$global:auth-name-type-group
				or string(type)=$global:auth-name-type-alias
				or string(type)=$global:auth-name-type-wellknown-group]">
				<member_group>
					<xsl:copy-of select="auth_name/*"/>
				</member_group>
			</xsl:for-each>
		</xsl:if>		
		<data>
			<xsl:if test="$create">
				<xsl:copy-of select="dirm:nodes2attrs($data/group/*)"/>
			</xsl:if>
			<xsl:if test="not($create)">
				<xsl:copy-of select="dirm:nodes2mods($data/group/*)"/>
			</xsl:if>
		</data>
	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
