<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred check local error action request perms securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check" xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:perms="http://www.swsoft.com/xsl/cp/perms"
	xmlns:securitym				="http://www.swsoft.com/xsl/cp/securitym"
	xmlns:authm						="http://www.swsoft.com/xsl/cp/authm"	
>

	<!-- Import required modules -->
	<sw:include href="/lib/swa/authm.xsl"/>	
	<sw:include href="/lib/swa/securitym.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms.xsl"/>
	<sw:include href="/lib/sysdir/securman/users.xsl"/>
	<!-- /Import required modules -->

	<xsl:output method="xml"/>

	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:param name="wiz_code" select="'securman-perms-obj-add'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>

			<!-- Step "Start" -->
			<xsl:when test="$step='start'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::roles or self::owners"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<roles>
						<xsl:for-each select="sw:param('roles')">
							<role>
								<name>
									<xsl:value-of select="."/>
								</name>
							</role>
						</xsl:for-each>
					</roles>
					<owners>
						<xsl:for-each select="sw:param('owners')">
							<owner>
								<sid><xsl:value-of select="substring-before(.,'|')"/></sid>
								<src><xsl:value-of select="."/></src>
								<title><xsl:value-of select="substring-after(.,'|')"/></title>
							</owner>
						</xsl:for-each>
					</owners>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA -->
					<!-- Check roles -->
					<xsl:choose>
						<xsl:when test="not($new_form/roles/role)">
							<xsl:value-of
								select="error:put(sw:text('You should select at least one role.'),'','roles')"/>
						</xsl:when>
					</xsl:choose>
					<!-- /Check roles -->
					<!-- Check users/groups -->
					<xsl:if test="not($new_form/owners/owner/sid)">
						<xsl:if test="error:put(sw:text('You should specify at least one user or group.'),'','owners')"/>
					</xsl:if>
					<!-- /Check users-->
					<!-- /CHECK DATA -->
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>

			</xsl:when>

		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:get-final-packet($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.virtuozzo_group.security.roles'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:initCreate"/>				
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="obj-type" select="sw:param('obj-type')"/>
		<xsl:variable name="new_form">
			<def>
				<obj-id>
					<xsl:value-of select="sw:context-object-id($obj-type)"/>
				</obj-id>
				<obj-type>
					<xsl:value-of select="$obj-type"/>
				</obj-type>
			</def>
			<start/>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="screen-id">
			<xsl:choose>
				<xsl:when test="$obj-type = 've.vz.vt'">
					<xsl:value-of select="'03.02.01.01.06'"/>
				</xsl:when>
				<xsl:when test="$obj-type = 'hn.vz.vt'">
					<xsl:value-of select="'03.02.01.32.09'"/>
				</xsl:when>
				<xsl:when test="$obj-type = 'unit.farm'">
					<xsl:value-of select="'10.00.00.01.10'"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'24.00.00.00.04'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_steps_">
			<step id="start" screen-id="{$screen-id}"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>

	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:get-final-packet">
		<xsl:param name="data"/>
		<xsl:variable name="scope" select="securitym:scope($data/def/obj-id,$data/def/obj-type)"/>
		
		<xsl:variable name="role-assignments">
			<xsl:for-each select="$data/roles/role">
				<xsl:copy-of select="securitym:role-assignment(string(name),$data/owners/owner/sid)"/>
			</xsl:for-each>
		</xsl:variable>

		<func:result>
			<xsl:copy-of
				select="securitym:action-add-role-assignments(exsl:node-set($role-assignments)/*,$scope)"/>
		</func:result>
	</func:function>

	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>


</xsl:stylesheet>
