<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred request check local error action dirm perms"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:request		="http://www.swsoft.com/xsl/cp/request"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action		="http://www.swsoft.com/xsl/cp/action"	
	xmlns:dirm			="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:perms			="http://www.swsoft.com/xsl/cp/perms"
>
	<!-- Import required modules -->
	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms.xsl"/>	
	<!-- /Import required modules -->

	<xsl:output method="xml"/>
	
	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:param name="wiz_code" select="'securman-user-perms-add'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			
			<!-- Step "Start" -->
			<xsl:when test="$step='start'">
										
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="self::roles or self::vzhns or self::envs"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<roles>
							<xsl:for-each select="sw:param('roles')">
								<id>
									<xsl:value-of select="."/>
								</id>
							</xsl:for-each>		
						</roles>
						<vzhns>
							<show><xsl:value-of select="sw:param('show_vzhns')"/></show>
							<xsl:for-each select="sw:param('vzhns')">
								<eid>
									<xsl:value-of select="."/>
								</eid>
							</xsl:for-each>		
						</vzhns>
						<envs>
							<show><xsl:value-of select="sw:param('show_envs')"/></show>
							<xsl:for-each select="sw:param('envs')">
								<eid>
									<xsl:value-of select="."/>
								</eid>
							</xsl:for-each>		
						</envs>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- CHECK DATA -->
						<xsl:choose>
							<!-- Check roles -->
							<xsl:when test="not($new_form/roles/id)">
								<xsl:value-of select="error:put(sw:text('You should select at least one role.'),'','roles')"/>
							</xsl:when>														
						</xsl:choose>
						<!-- /CHECK DATA -->
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>		
			
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:get-final-packet($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:initCreate"/>			
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<def>
				<owner-sid>
					<xsl:value-of select="sw:base64-decode(sw:param('owner-sid'))"/>
				</owner-sid>				
			</def>
			<start/>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="start" screen-id="{sw:param('screen-id')}"/>			
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
		
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:get-final-packet">
		<xsl:param name="data"/>
		<xsl:param name="owner-sid" select="$data/def/owner-sid"/>
		<!--|-->		
		<func:result>
			<packet>
				<target>dirm</target>
				<cookie>
	        <msg>
	          <ok><sw:text>The permissions have been added successfully.</sw:text></ok>
	          <error><sw:text>Failed to add the permissions.</sw:text></error>
	        </msg>
	        <redirect-prev/>       
	      </cookie>		
				<data>
					<xsl:for-each select="$data/roles/id">
						<xsl:variable name="role-id" select="."/>
						<xsl:for-each select="$data/envs/eid">
							<xsl:copy-of select="perms:get-packet-add($owner-sid,$role-id,.,'env.core.vt')"/>						
						</xsl:for-each>
						<xsl:for-each select="$data/vzhns/eid">
							<xsl:copy-of select="perms:get-packet-add($owner-sid,$role-id,.,'hn.vz.vt')"/>						
						</xsl:for-each>
						<xsl:if test="not($data/vzenvs/eid) and not($data/vzhns/eid)">
							<xsl:copy-of select="perms:get-packet-add($owner-sid,$role-id,'','vzcp')"/>
						</xsl:if>
					</xsl:for-each>
				</data>
			</packet>
		</func:result>
	</func:function>
		
	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>				
	
	
</xsl:stylesheet>
