<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred dirm request"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:error			="http://www.swsoft.com/xsl/cp/error"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred 		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local		="http://www.swsoft.com/xsl/cp/local"
	xmlns:dirm 		="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:request	="http://www.swsoft.com/xsl/cp/request"
  >
 	<sw:include href="/lib/swa/dirm.xsl"/>	
  
  <xsl:output method="xml"/>

  <!-- check permissions to this page -->
	<xsl:variable name="cr-manage"		select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>
	<xsl:variable name="owner-sid" 		select="sw:base64-decode(sw:param('owner-sid'))"/>
  
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="not($owner-sid!='')">
				<sw:die>
					owner-sid should be specified.
				</sw:die>
			</xsl:when>
			
				<xsl:when test="sw:param('delete') and not($cr-manage)">	
					<!-- no delete cred -->
					<packet/>
				</xsl:when>
				
        <!-- Check selected templates -->
        <xsl:when test="not(sw:param('id'))">
          <xsl:if test="error:put(sw:text('Please select at least one permission.'),'')"/>
          <packet/>
        </xsl:when>

        <!-- Delete -->
        <xsl:when test="sw:param('delete')">
        	<xsl:copy-of select="local:get-packet-delete(sw:param('id'))"/>
        	<xsl:if test="sw:response('lib/opredirect.xsl')"/>	
        </xsl:when>
        
        <!-- Unknown post -->
        <xsl:otherwise>
          <packet/>
        </xsl:otherwise>

      </xsl:choose>
  </xsl:template>
  

  <func:function name="local:get-packet-delete">
  	<xsl:param name="ids"/>
  	
 		<func:result>
 			<packet log="on">
				<target>dirm</target>
	        <cookie>
	          <msg>
	            <ok><sw:text>The permission(s) has/have been deleted.</sw:text></ok>
	            <error><sw:text>Failed to delete the permission(s).</sw:text></error>
	          </msg>
	          <operation>delete_user_perms</operation>
	          <redirect-last/>
	        </cookie>			
				<data>
					<dirm>
						<xsl:for-each select="$ids">
							<remove>
								<id><xsl:value-of select="sw:internal-realm-id()"/></id>
								<dn><xsl:value-of select="concat('permissionId=',.,',',$def-permissions-dn)"/></dn>
							</remove>
						</xsl:for-each>
					</dirm>
				</data>
			</packet>
 		</func:result>
  </func:function>
 
  <!-- credentials -->
  <sw:include href="/lib/common.xsl"/>
  <sw:include href="/lib/cred.xsl"/>

 
</xsl:stylesheet>
