<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred local authm error request"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"
	xmlns:security="http://www.swsoft.com/xsl/cp/security">

	<sw:include href="/lib/core/security/core-ui.xsl"/>

	<xsl:output method="xml"/>

	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>	

	<xsl:param name="wiz_code" select="'sm-realm'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- No cred  -->
			<xsl:when test="not(cred:check('vzcp.virtuozzo_group.security.realms'))">
				<packet/>
			</xsl:when>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<xsl:variable name="base_dn" select="normalize-space(sw:param('base_dn'))"/>
					<xsl:variable name="default_dn" select="normalize-space(sw:param('default_dn'))"/>
					<xsl:variable name="login_domain" select="normalize-space(sw:param('domain'))"/>
					<gen>
						<xsl:call-template name="security:restore-realm">
							<xsl:with-param name="orig-realm" select="$form/gen/realm"/>
						</xsl:call-template>
						<password>
							<xsl:value-of select="sw:base64-encode(sw:param('password'))"/>
						</password>
					</gen>
				</xsl:variable>

				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:param('next')">
					<xsl:call-template name="security:validate-realm">
						<xsl:with-param name="realm" select="$new_form/gen/realm"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:getFinalPacket($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:initCreate"/>				
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="new_form">
			<gen>
				<realm>
					<name/>
					<address/>
					<port>389</port>
					<login>
						<name/>
					</login>
					<type>1</type>
					<base_dn/>
					<default_dn/>
				</realm>
				<password/>
			</gen>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screenid="03.01.01.05.01"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>

		<xsl:variable name="result" select="authm:add-realm($data/gen/realm,$data/gen/password)"/>

		<xsl:if test="$result[self::error]">
			<xsl:if test="error:put(sw:text('Failed to add authentication database.',$result//message))"/>
		</xsl:if>

		<func:result>
			<packet>
				<cookie>
					<xsl:choose>
						<xsl:when test="not($result[self::error])">
							<msg>
								<set-ok>Authentication database have been added successfully.</set-ok>
							</msg>
						</xsl:when>
					</xsl:choose>
					<redirect-prev/>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
