<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred authm request"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:request="http://www.swsoft.com/xsl/cp/request">

	<sw:include href="/lib/swa/authm.xsl"/>

	<xsl:output method="xml"/>

	<xsl:template match="/">
		<xsl:choose>

			<xsl:when
				test="sw:param('delete') and 
				not(cred:check('vzcp.virtuozzo_group.security.realms'))">
				<!-- no delete cred -->
				<packet/>
			</xsl:when>

			<xsl:when test="not(sw:param('realm'))">
				<xsl:if test="error:put(sw:text('Please select at least one authentication database.'),'')"/>
				<packet/>
			</xsl:when>

			<xsl:when test="sw:param('delete')">
				<xsl:copy-of select="local:get-packet-delete(sw:param('realm'))"/>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<!-- Unknown post -->
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>


	<func:function name="local:get-packet-delete">
		<xsl:param name="ids"/>
		<func:result>
			<packet log="on">
				<target>authm</target>
				<cookie>
					<msg>
						<ok>
							<sw:text>The authentication database(s) has/have been deleted.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to delete the authentication database(s).</sw:text>
						</error>
					</msg>
					<operation>delete_realm</operation>
					<redirect-last/>
				</cookie>
				<data>
					<xsl:for-each select="$ids">
						<authm>
							<del_realm>
								<id>
									<xsl:value-of select="."/>
								</id>
							</del_realm>
						</authm>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/cred.xsl"/>


</xsl:stylesheet>
