<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz error local cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:func="http://exslt.org/functions"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:security="http://www.swsoft.com/xsl/cp/security"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>

	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	<xsl:variable name="form" select="local:init-form()"/>
	
	<xsl:param name="wiz_code" select="'sm-realm-manage'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<xsl:when test="not(cred:check('vzcp.virtuozzo_group.security.realms'))">
				<packet/>
			</xsl:when>
			<!-- General step -->
			<xsl:when test="$step='gen'">
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					
					<gen>
						<xsl:call-template name="security:restore-realm">
							<xsl:with-param name="orig-realm" select="$form/gen/realm"/>
						</xsl:call-template>
						<xsl:if test="sw:param('password')!=''">
							<password>
								<xsl:value-of select="sw:base64-encode(sw:param('password'))"/>
							</password>
						</xsl:if>
					</gen>
				</xsl:variable>

				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:param('next')">
					<xsl:call-template name="security:validate-realm">
						<xsl:with-param name="realm" select="$new_form/gen/realm"/>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:getFinalPacket($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:variable name="realms-info" select="security:realms-info()"/>
			<xsl:variable name="realm-info" select="$realms-info/realm[@eid=$realms-info/current-eid]"/>
			<xsl:call-template name="local:initData">
				<xsl:with-param name="realm-info" select="$realm-info"/>
			</xsl:call-template>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>	
	
	<xsl:template name="local:initData">
		<xsl:param name="realm-info"/>
		<xsl:variable name="realm" select="authm:list-realms()/realm[string(id)=$realm-info/@eid]"/>
		<!-- Init data -->
		<xsl:variable name="new_form">
			<gen>
				<realm>
					<xsl:copy-of select="$realm/*"/>
				</realm>
				<password/>
			</gen>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
 
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<xsl:variable name="result" select="authm:set-realm($data/gen/realm,$data/gen/password)"/>

		<xsl:if test="$result[self::error]">
			<xsl:if test="error:put(sw:text('Failed to update the authentication database.'),$result//message)"/>
		</xsl:if>

		<func:result>
			<packet>
				<cookie>
					<xsl:choose>
						<xsl:when test="not($result[self::error])">
							<msg>
								<set-ok><sw:text>The authentication database has been updated successfully.</sw:text></set-ok>
							</msg>
						</xsl:when>
					</xsl:choose>
					<redirect-prev/>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<sw:include href="/lib/wizard.xsl"/>

 </xsl:stylesheet>
