<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local swa-mailer"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:swa-mailer="http://www.swsoft.com/xsl/cp/swa-mailer"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
>

	<xsl:output method="xml"/>
	
	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>	
	<xsl:variable name="form" select="local:init-form()"/>	

	<xsl:param name="wiz_code" select="'config-ordering'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
								
					<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
								<xsl:when test="name()='other'"></xsl:when>
								<xsl:when test="name()='user-registration'"></xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<user-registration>
							<enabled>
								<xsl:value-of select="
									sw:if(sw:param('enabled')='1','true','false')
								"/>
							</enabled>
							<xsl:choose>
								<xsl:when test="sw:param('enabled')='1'">
									<xsl:for-each select="sw:param('role')">
										<user-role>
											<xsl:value-of select="."/>
										</user-role>
									</xsl:for-each>	
									<show-login-register>								
										<xsl:value-of select="
											sw:if(sw:param('login')='1','true','false')
										"/>
									</show-login-register>
								</xsl:when>
								<xsl:otherwise>
									<xsl:copy-of select="$form/user-registration/show-login-register"/>
									<xsl:copy-of select="$form/user-registration/user-role"/>
								</xsl:otherwise>
							</xsl:choose>						
						</user-registration>
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
					
					<xsl:if test="sw:param('next')">
						<!-- check data -->	
					</xsl:if>
					
					<xsl:call-template name="local:completeFormHandling">
						<xsl:with-param name="data" select="$new_form"/>
					</xsl:call-template>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="cred:detail-check('vzcp.virtuozzo_group.security.roles')"/>
					    	<xsl:choose>
		    					<xsl:when test="error:is-empty()">
										<xsl:copy-of select="local:getFinalPacket($data)"/>
										<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
					      	</xsl:when>
									<xsl:otherwise>
										<packet/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>


	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.virtuozzo_group.security.roles'))"/>
		<xsl:if test="$step = ''">
			<!-- Init form data -->
			<xsl:variable name="new_form">
				<xsl:copy-of select="$config/vzcpcon/user-registration"/>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="03.01.01.02.01"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>
	
	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!-- Save new data -->
		<xsl:choose>
			<xsl:when test="sw:update-config('/vzcpcon/user-registration',$data/user-registration)">	
				<!-- Return back -->
				<func:result>
		 			<packet>
		        <cookie>
		          <msg>
		            <set-ok><sw:text>The registration configuration has been changed.</sw:text></set-ok>
		          </msg>
		        </cookie>						
					</packet>
				</func:result>
			</xsl:when>
			<xsl:otherwise>
				<!-- Error occure  -->
				<func:result>
		 			<packet>
		        <cookie>
		          <msg>
		            <set-error>
		            	<short-desc>
		            		<sw:text>Error saving the registration configuration.</sw:text>
		            	</short-desc>
		            </set-error>
		          </msg>
		        </cookie>						
					</packet>		
				</func:result>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
  <!-- credentials -->	
	<sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>				
	<sw:include href="/lib/swa/swa-mailer.xsl"/>
	
</xsl:stylesheet>
