	<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl form func wiz cred check env local authm error dirm perms users vzcpsecuritym user-profile"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check" xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local" xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:func="http://exslt.org/functions" xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:perms="http://www.swsoft.com/xsl/cp/perms" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm" xmlns:users="http://www.swsoft.com/xsl/cp/users"
	xmlns:vzcpsecuritym="http://www.swsoft.com/xsl/cp/vzcpsecuritym"
	xmlns:security="http://www.swsoft.com/xsl/cp/security" xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:user-profile="http://www.swsoft.com/xsl/cp/user-profile"
>

	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/vzcpsecuritym.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms.xsl"/>
	<sw:include href="/lib/sysdir/securman/users.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>
	<sw:include href="/lib/core/check-funcs.xsl"/>
	<sw:include href="/lib/core/user-profile.xsl"/>
	<sw:include href="/lib/core/user-profile/init-settings.xsl"/>
	

	<xsl:output method="xml"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-user-create"
		select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>
	<xsl:variable name="cr-user-edit" select="$cr-user-create"/>

	<!-- RESTORE FORM VALUES -->
	<xsl:variable name="form" select="local:init-form()"/>

	<!-- calc cred in wizard step case -->
	<xsl:variable name="step" select="wiz:processing-step-id()"/>
	
	<xsl:param name="wiz_code" select="'sm-user'"/>
	<xsl:variable name="edit-mode" select="$form/user-id"/>

	<xsl:variable name="local:vzcc-users-group-name" select="'Parallels Infrastructure Manager Users'"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- No cred  -->
			<xsl:when test="not($cr-user-create) and  not($cr-user-edit)">
				<packet/>
			</xsl:when>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='gen'">
				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:when test="name()='user'"/>
							<xsl:when test="name()='groups'"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<gen>
						<username>
							<xsl:value-of select="sw:param('username')"/>
						</username>
						<pwd>
							<xsl:value-of select="sw:param('pwd')"/>
						</pwd>
						<pwd_re>
							<xsl:value-of select="sw:param('pwd_re')"/>
						</pwd_re>
					</gen>

					<!-- User -->
					<user>
						<mail>
							<xsl:value-of select="sw:param('mail')"/>
						</mail>
						<!-- name -->
						<displayName>
							<xsl:value-of
								select="sw:param('displayName')"/>
						</displayName>
						<description>
							<xsl:value-of
								select="sw:param('description')"/>							
						</description>
						<!-- /name -->
					</user>
					<!-- /User -->
					<!-- VE -->

					<!-- Groups -->
					<groups>
						<xsl:for-each select="sw:param('group')">
							<group>
								<id>
									<xsl:value-of select="."/>
								</id>
							</group>
						</xsl:for-each>
					</groups>
					<!-- /Groups -->

					<!-- VEs -->
					<env-access>
						<type>
							<xsl:value-of select="sw:param('env_access_type')"/>
						</type>
						<block_env>
							<xsl:value-of select="sw:param('block_env')"/>
						</block_env>
						<xsl:call-template name="form:restore-list">
							<xsl:with-param name="code" select="'env_ranges'"/>
							<xsl:with-param name="row-node-name" select="'range'"/>
						</xsl:call-template>

						<xsl:variable name="env_add_ids"
							select="sw:param('env_add_ids')"/>
						<xsl:choose>
							<!-- submited from popup -->
							<xsl:when test="$env_add_ids != ''">
								<xsl:copy-of select="$form/env-access/eid"/>
								<xsl:for-each select="sw:split($env_add_ids,',','env')">
									<xsl:variable name="eid" select="."/>
									<xsl:if test="not($form/env-access/eid=$eid)">
										<eid>
											<xsl:value-of select="$eid"/>
										</eid>
									</xsl:if>
								</xsl:for-each>
							</xsl:when>
							<!-- submited from our screen -->
							<xsl:otherwise>
								<xsl:for-each select="$form/env-access/eid">
									<xsl:variable name="eid" select="."/>
									<xsl:if
										test="not(sw:param('remove_env') and sw:param('env_eid')=$eid)">
										<xsl:copy-of select="."/>
									</xsl:if>
								</xsl:for-each>
							</xsl:otherwise>
						</xsl:choose>
					</env-access>
					<!-- VEs -->
				</xsl:variable>

				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- TODO Remove original group checking -->
					<xsl:variable name="new-groups">
						<xsl:if test="$edit-mode">
							<xsl:for-each select="$new_form/groups/group">
								<xsl:variable name="id" select="id"/>
								<xsl:if test="not($new_form/orig-groups/group[id = $id])">
									<xsl:copy-of select="."/>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					</xsl:variable>
					<!-- check password -->
					<xsl:choose>
						<!-- check password identity -->
						<xsl:when test="$new_form/gen/pwd!=$new_form/gen/pwd_re">
							<xsl:if test="error:put(sw:text('The passwords do not match.'),'','pwd')"/>
							<xsl:if test="error:add-control('pwd_re')"/>
						</xsl:when>
						<!-- check password presence -->
						<xsl:when test="$new_form/gen/pwd='' and not($edit-mode)">
							<xsl:if test="error:put(sw:text('You should specify a password.'),'','pwd')"/>
							<xsl:if test="error:add-control('pwd_re')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check login -->
					<xsl:if test="string($new_form/gen/username)=''">
							<xsl:if test="error:put(sw:text('You should specify a login.'),'','username')"/>
					</xsl:if>
					<xsl:choose>
						<!-- check email -->
						<xsl:when test="$edit-mode"> </xsl:when>
						<!-- check email presence -->
						<xsl:when test="string($new_form/user/mail)=''"> </xsl:when>
						<!-- check email for valid -->
						<xsl:when test="not(check:email($new_form/user/mail))">
							<xsl:if
								test="error:put(sw:text('You should specify a valid email address.'),'','mail')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:getFinalPacket($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:choose>
				<xsl:when test="sw:param('cmd') = 'new'">
					<xsl:call-template name="local:initCreate"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initEdit">
						<xsl:with-param name="id" select="sw:sesgetstr('securman-user-id')"/>
						<xsl:with-param name="step" select="'gen'"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:initCreate">
		<!-- Init default data -->
		<xsl:variable name="realms-info" select="security:realms-info()"/>
		
		<xsl:variable name="new_form">
			<src>
				<realm-eid>
					<xsl:value-of select="$realms-info/current-eid"/>
				</realm-eid>
			</src>		
			<gen>
				<!--<enabled>1</enabled>-->
				<username/>
				<pwd/>
				<pwd_re/>
			</gen>
			<user>
				<mail/>
				<displayName/>
				<description/>
			</user>
			<!-- /User -->
			<groups>
				<xsl:if test="$realms-info/current-eid=sw:internal-realm-id()">
					<xsl:variable name="vzcc-users-group" 
						select="authm:get-group($local:vzcc-users-group-name,$realms-info/current-eid,false())"/>
					<xsl:if test="$vzcc-users-group/name">
						<group>
							<id><xsl:value-of select="$local:vzcc-users-group-name"/></id>
						</group>
					</xsl:if>
				</xsl:if>
			</groups>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="gen" screenid="03.01.01.01.01"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:initEdit">
		<xsl:param name="id"/>
		<xsl:param name="step"/>
		<!-- Init steps -->
		<xsl:variable name="all_steps_">
			<step id="gen" screenid="03.01.01.01.02"/>
		</xsl:variable>
		<!-- Init Step -->
		<xsl:variable name="new_step">
			<xsl:choose>
				<xsl:when test="string(sw:param('tab')) != ''">
					<xsl:value-of select="string(sw:param('tab'))"/>
				</xsl:when>
				<xsl:otherwise>gen</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_steps" select="exsl:node-set($all_steps_)/step[@id=$new_step]"/>
		<!-- Check startup conditions -->
		<xsl:variable name="new_form">
			<xsl:choose>
				<xsl:when test="count($new_steps)=0">
					<xsl:message terminate="yes">
						Requested tab '<xsl:value-of select="$new_step"
						/>' is unknown for Users Management code.
					</xsl:message>
				</xsl:when>
				<xsl:when test="not($id)">
					<xsl:message terminate="yes">
						User ID should be specified.
					</xsl:message>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:initEditData">
						<xsl:with-param name="id" select="$id"/>
						<xsl:with-param name="step" select="$step"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>

	<xsl:template name="local:initEditData">
		<xsl:param name="id"/>
		<xsl:param name="step"/>
		<!-- Load data -->
		<xsl:variable name="realms-info" select="security:realms-info()"/>
		<xsl:variable name="user" select="authm:get-user(authm:user-key($id,$realms-info/current-eid))"/>
		<xsl:variable name="user-attrs" select="$user/data"/>
	
		<!--|-->
		<gen>
			<username>
				<xsl:copy-of select="sw:base64-decode($user/name)"/>				
			</username>
		</gen>

		<src>
			<realm-eid>
				<xsl:value-of select="$realms-info/current-eid"/>
			</realm-eid>
			<sid>
				<xsl:value-of select="$user-attrs/objectSid"/>
			</sid>
		</src>

		<user>
			<xsl:copy-of select="$user-attrs/*[self::mail or self::displayName or self::description]"/>
		</user>

		<groups>
			<xsl:for-each select="$user/group">
				<group>
					<id>
						<xsl:value-of select="sw:base64-decode(name)"/>
					</id>
				</group>
			</xsl:for-each>
		</groups>

		<!-- TODO remove check of original group in form handling -->
		<orig-groups>
			<xsl:for-each select="$user/group">
				<group>
					<id>
						<xsl:value-of select="sw:base64-decode(name)"/>
					</id>
				</group>
			</xsl:for-each>
		</orig-groups>

		<user-id>
			<xsl:value-of select="$id"/>
		</user-id>
	</xsl:template>

	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>

		<xsl:variable name="user-data">
			<xsl:choose>
				<xsl:when test="not($data/user-id)">
					<xsl:call-template name="local:getFinalPacketCommon">
						<xsl:with-param name="data" select="$data"/>
						<xsl:with-param name="create" select="true()"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:getFinalPacketCommon">
						<xsl:with-param name="data" select="$data"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:for-each select="$data/groups/group">
				<group>
					<name>
						<xsl:value-of select="sw:base64-encode(id)"/>
					</name>
					<realm><xsl:value-of select="$data/src/realm-eid"/></realm>
				</group>
			</xsl:for-each>
		</xsl:variable>

		<xsl:variable name="error-msg"
			select="sw:if(not($data/user-id),sw:text('Failed to create the user.'),sw:text('Failed to update the user.'))"/>

		<xsl:variable name="user-op-result-rtf">
			<xsl:choose>
				<xsl:when test="not($data/user-id)">
					<xsl:copy-of select="authm:add-user($user-data,sw:base64-encode($data/gen/pwd))"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:copy-of select="authm:set-user($data/user-id,$user-data,$data/gen/pwd)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="user-op-result" select="exsl:node-set($user-op-result-rtf)"/>

		<xsl:choose>
			<xsl:when test="$user-op-result//error">
				<xsl:if test="error:put($error-msg,$user-op-result//error/message)"/>
			</xsl:when>
		</xsl:choose>

		<xsl:if test="not(error:get()) 
			and $data/src/realm-eid=sw:internal-realm-id()">
			<xsl:variable name="profile-ref" 
				select="user-profile:construct-ref('clusteruser',$data/gen/username,$data/src/realm-eid)"/>
			<xsl:variable name="profile-create-res" select="user-profile:init-settings($profile-ref)"/>
			<xsl:choose>
				<xsl:when test="$profile-create-res[self::error]">
					<xsl:if test="error:put(sw:text('Error modifying the user profile.'),$profile-create-res/message)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="mail-error"
						select="user-profile:set-attr($profile-ref,'mail',$data/user/mail)" />
					<xsl:if test="$mail-error">
						<xsl:if
							test="error:put(sw:text('Error saving the email address.'),$mail-error/message)" />
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>

		<xsl:variable name="errors" select="error:get()"/>

		<func:result>
			<packet>
				<cookie>
					<xsl:choose>
						<xsl:when test="not($errors)">
							<msg>
								<xsl:choose>
									<xsl:when test="not($data/user-id)">
										<set-ok><sw:text>The user has been created successfully.</sw:text></set-ok>
									</xsl:when>
									<xsl:otherwise>
										<set-ok><sw:text>The user has been updated successfully.</sw:text></set-ok>
									</xsl:otherwise>
								</xsl:choose>
							</msg>
						</xsl:when>
					</xsl:choose>
					<redirect><xsl:value-of select="concat($baseurl,'/sysdir/securman/users/index')"/></redirect>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<xsl:template name="local:getFinalPacketCommon">
		<xsl:param name="data"/>
		<xsl:param name="create" select="false()"/>
		<!--/-->
		<name>
			<xsl:value-of select="sw:base64-encode($data/gen/username)"/>
		</name>
		<realm>
			<xsl:value-of select="$data/src/realm-eid"/>
		</realm>
		<data>
			<!-- Define our own classes -->
			<xsl:if test="$create">
				<attr>
					<name>objectClass</name>
					<value>
						<xsl:value-of select="sw:base64-encode('VZCPUser')"/>
					</value>
				</attr>
			</xsl:if>
			<!-- /Define our own classes -->
			<xsl:copy-of select="dirm:nodes2attrs($data/user/*,'',sw:if($create,'attr','mod'))"/>
		</data>
	</xsl:template>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="../../../../layout/forms-list.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
