<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->
<!--
API
GET PARAMETERS:

Backup VE
	cmd = backup
	env-set = selected-multi / current / select-multi
	
Renew Backup	
	cmd = renew
	backup-set = selected-multi
							
-->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func voc cred local check wiz vzenv backups request env form"  
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:error	="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
  xmlns:func	="http://exslt.org/functions"	
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"
	xmlns:check	="http://www.swsoft.com/xsl/cp/check"
	xmlns:env	="http://www.swsoft.com/xsl/cp/env"
	xmlns:ve	="http://www.swsoft.com/xsl/cp/ve"	
	xmlns:vzenv	="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"
	xmlns:backups	="http://www.swsoft.com/xsl/cp/backups"
	xmlns:form	="http://www.swsoft.com/xsl/cp/form"
	xmlns:jobs				="http://www.swsoft.com/xsl/cp/jobs"	
>
	
	<sw:include href="/lib/core/jobs/core.xsl"/>	
	<sw:include href="/lib/vt/backups-core.xsl"/>
	<sw:include href="/lib/vt/backups-forms.xsl"/>	
	<sw:include	href="/lib/vt/ve-core.xsl"/>	
	<sw:include href="/layout/forms-list.xsl"/>	

	<xsl:output method="xml"/>
	<xsl:param 		name="wiz_code"			select="'ve-new-backups'"/>
	
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>	


	<xsl:template match="node()|@*">
	
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">
				<xsl:variable name="timer-type"	select="sw:param('timer')"/>
				<xsl:variable name="new_form_">
						<xsl:for-each select="$form/*">
							<xsl:choose>
                <xsl:when test="self::gen or self::timer or self::exclude or self::include"></xsl:when>																
                <xsl:when test="$form/def/env-set='select-multi' and  self::backup"></xsl:when>								
								<xsl:otherwise>
									<xsl:copy-of select="."/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
						<gen>
							<description><xsl:value-of select="sw:param('description')"/></description>
							<xsl:if test="$form/def/vzcc">
								<xsl:call-template name="backups:restore-backup-options"/>
							</xsl:if>
						</gen>
						
						<exclude>
							<xsl:call-template name="backups:restore-backup-paths">
								<xsl:with-param name="list-type" select="'exclude'"/>								
							</xsl:call-template>
							<show><xsl:value-of select="sw:param('show_excl')"/></show>
						</exclude>

						<include>
							<xsl:call-template name="backups:restore-backup-paths">
								<xsl:with-param name="list-type" select="'include'"/>								
							</xsl:call-template>
							<show><xsl:value-of select="sw:param('show_incl')"/></show>
						</include>
						
						<xsl:if test="$form/def/vzcc and $form/def/env-set='select-multi'">	
							<xsl:for-each select="sw:param('envs')">
								<backup>				
									<ve-eid>
										<xsl:value-of select="."/>
									</ve-eid>
								</backup>
							</xsl:for-each>
						</xsl:if>
						
						<timer>
							<xsl:choose>
								<xsl:when test="string($timer-type) = ''"> 
									<type>now</type>
								</xsl:when>
								<xsl:otherwise>
									<xsl:call-template name="jobs:restore-timer-time"/>
									<type><xsl:value-of select="$timer-type"/></type>									
								</xsl:otherwise>
							</xsl:choose>
							<show><xsl:value-of select="sw:param('show_timer')"/></show>
						</timer>
						
					</xsl:variable>
					<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
										
					<xsl:if test="sw:param('back')">
						 <!-- Move to back -->
						<xsl:if test="wiz:goBack()"/>
					</xsl:if>
					<xsl:if test="sw:param('next')">
						<!-- Check data -->
						<xsl:choose>
							<xsl:when test="not($new_form/backup/ve-eid)">
								<xsl:if test="error:put(sw:text('Please select at least one Container.'),'','envs')"/>
							</xsl:when>
							<xsl:when test="cred:filter-valid-env('vzcp.env.backups.backup',$new_form/backup/ve-eid)"/>
						</xsl:choose>
			      <!-- Check time  and date -->
			      <xsl:choose>
			      	<xsl:when test="string($new_form/timer/type)=''">
				      	<xsl:if test="error:put(sw:text('Please specify the backup time.'),'','')"/>
			      	</xsl:when>
			      	<xsl:when test="$new_form/timer/type='time'">
								<xsl:call-template name="jobs:check-timer-time">
									<xsl:with-param name="timer" select="$new_form/timer"/>
								</xsl:call-template>
							</xsl:when>
						</xsl:choose>
						
				  	<!-- Move to next step -->
			      <xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:call-template name="local:final-packet">
									<xsl:with-param name="data" select="$new_form"/>
								</xsl:call-template>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>		
							</xsl:when>
						</xsl:choose>
					</xsl:if>
					
					<!-- Store form values-->
					<xsl:variable name="res">
						<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
					</xsl:variable>
					
			</xsl:when>
				
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			
			<!-- Read GET parameters -->
			<xsl:variable name="cmd-get" select="sw:param('cmd')"/>
			<xsl:variable name="cmd" select="sw:if($cmd-get!='',$cmd-get,'backup')"/>
			<xsl:variable name="env-set" select="string(sw:param('env-set'))"/>		
      <xsl:variable name="backup-set" select="string(sw:param('backup-set'))"/>
			
			<!-- Validate parameters -->
			<sw:die test="$cmd='renew' and $backup-set=''">
        'backup-set' GET param is empty.
      </sw:die>
			<sw:die test="$cmd='backup' and $env-set=''">
				'env-set' GET param is empty.
			</sw:die>

			<!-- Init Data -->
			<xsl:variable name="backups-rtf">
				<xsl:choose>
					<!-- Renew -->
					<xsl:when test="$cmd='renew'">
						<xsl:variable name="backups" select="sw:param('id')"/>
           	<xsl:variable name="backup-info" select="backups:find-backup($backups)"/>
					  <xsl:for-each select="$backup-info">
            	<backup>
              	<backup-id><xsl:value-of select="id"/></backup-id>
                <ve-eid><xsl:value-of select="eid"/></ve-eid>
                <hn-storage-eid><xsl:value-of select="storage_eid"/></hn-storage-eid>
              </backup>
          	</xsl:for-each>
					</xsl:when>
					<!-- Backup -->
				  <xsl:when test="$cmd='backup'">
						<xsl:choose>
							<xsl:when test="$env-set='selected-multi'">
								<xsl:for-each select="ve:post2eids()">
									<backup><ve-eid><xsl:value-of select="."/></ve-eid></backup>
								</xsl:for-each>
							</xsl:when>
							<xsl:when test="$env-set='current'">
								<backup><ve-eid><xsl:value-of select="sw:ve-eid()"/></ve-eid></backup>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
				</xsl:choose>
			</xsl:variable>
			<xsl:variable name="backups" select="exsl:node-set($backups-rtf)/backup"/>
			<xsl:variable name="envs" select="env:get-env($backups/ve-eid)/env"/>
			<xsl:variable name="platforms" select="ve:envs2platforms($envs)"/>
			
			<xsl:variable name="new_form">
				<!-- Check limits in VZPP/Plesk mode -->
				<xsl:if test="$activeMode!='vzcc' and $cmd='backup'">
					<xsl:variable name="backups-limit"	select="backups:find-actual-ve-limit(sw:ve-parent($backups/ve-eid[1]))"/>		
					<xsl:variable name="error" select="backups:get-vzpp-limits-warning($backups-limit,'',true(),false())"/>
					<xsl:if test="$error!=''">
						<error type="limits">
							<xsl:copy-of select="$error"/>
						</error>
					</xsl:if>
				</xsl:if>
				<def>
					<xsl:if test="$activeMode='vzcc'">
						<vzcc/>
					</xsl:if>
					<cmd><xsl:value-of select="$cmd"/></cmd>
					<backup-set><xsl:value-of select="$backup-set"/></backup-set>
					<env-set><xsl:value-of select="$env-set"/></env-set>
					<xsl:for-each select="$platforms">
						<xsl:variable name="ve" select="$envs[ve:ve2platform(.)=current()][1]"/>					
						<xsl:variable name="ref" select="env:make-platform-ref($ve/parent_eid)"/>
						<platform>
							<value><xsl:value-of select="."/></value>
							<ref>
								<xsl:copy-of select="$ref"/>
							</ref>
							<features>
								<xsl:if test="voc:check-feature('backup.exclude.system',$ref)">
									<exclude-system/>
								</xsl:if>
							</features>
						</platform>
					</xsl:for-each>
				</def>
				<xsl:copy-of select="$backups"/>
				<gen>
					<compression-level/>
					<backup-type/>
					<storage-server-eid/>
				</gen>
				<timer>
					<type>now</type>
				</timer>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<xsl:choose>
					<xsl:when test="$cmd='renew'">
          	<step id="gen" screen-id="23.00.00.01.03"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="$env-set='select-multi'">
							<step id="gen" screen-id="23.00.00.01.00"/>
						</xsl:if>
						<xsl:if test="$env-set='current'">
							<step id="gen" screen-id="23.00.00.01.01"/>
						</xsl:if>
						<xsl:if test="$env-set='selected-multi'">
							<step id="gen" screen-id="23.00.00.01.02"/>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>				
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps_filtered">
					<xsl:copy-of	select="exsl:node-set($new_steps_)/step"/>
				</xsl:variable>
				<xsl:variable name="new_steps"	select="exsl:node-set($new_steps_filtered)"/>
				<xsl:variable name="new_step"		select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		
		<func:result select="wiz:init-data()"/>
		
	</func:function>
	
	<xsl:template name="local:final-packet">
		<xsl:param name="data"/>
		
		<xsl:choose>
			<xsl:when test="$data/timer/type='now'">
				<xsl:copy-of select="backups:new-action(
					$data/backup,$data/gen/*|$data/exclude|$data/include,/..,$data/def/cmd
				)"/>
			</xsl:when>
			<xsl:when test="$data/timer/type='time'">
				<xsl:variable name="job-rtf">
					<job>
						<category>vz.backup.ves</category>
						<enabled>true</enabled>
						<title><_>Back Up Containers</_></title>
						<timer>
							<xsl:copy-of select="$data/timer/*[self::time or self::start-date]"/>
							<recurrence-type>none</recurrence-type>
						</timer>
						<ves>
							<xsl:for-each select="$data/backup/ve-eid">
								<eid><xsl:value-of select="."/></eid>
							</xsl:for-each>
						</ves>
						<specific>
							<backup-options>
								<xsl:copy-of select="$data/gen/*[not(self::description)]"/>
							</backup-options>
							<backup-excludes>
								<xsl:copy-of select="$data/exclude/*[not(self::show)]"/>								
							</backup-excludes>
							<backup-includes>
								<xsl:copy-of select="$data/include/*[not(self::show)]"/>								
							</backup-includes>
						</specific>
					</job>
				</xsl:variable>
				<xsl:call-template name="jobs:construct-update-packet">
					<xsl:with-param name="job" select="exsl:node-set($job-rtf)/job"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<sw:die>
					Uknown timer type "<xsl:value-of select='$data/timer/type'/>"
				</sw:die>
			</xsl:otherwise>
		</xsl:choose>
	
	</xsl:template>
	
	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>		
	
</xsl:stylesheet>
