<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<!-- 
	
	GET params:
	
		backup-id-src  - backups ID specificaton method
			possible values:
				get
				session
				post
			
-->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error action env vzenv backups"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"
	xmlns:action		="http://www.swsoft.com/xsl/cp/action"	
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"	
	xmlns:backups		="http://www.swsoft.com/xsl/cp/backups"	
	xmlns:request   ="http://www.swsoft.com/xsl/cp/request"
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"	
>

	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>				
	
	<!-- Import required modules -->
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vt/backups-core.xsl"/>
	<!-- Import required modules -->

	<xsl:output method="xml"/>

  <xsl:param name="wiz_code" select="'ves_restore_backup'"/>
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>	

	<xsl:template match="node()|@*">
		<xsl:choose>
			
			<!-- Step "Confirm" -->
			<xsl:when test="$step='confirm'">
						
				<xsl:variable name="new_form_">
					<xsl:copy-of select="$form/*[not(self::def)]"/>
					<def>
						<xsl:copy-of select="$form/def/*[not(self::backup)]"/>					
						<xsl:for-each select="$form/def/backup">
							<xsl:if test="sw:param(concat('backup_',index))='true'">
								<backup>
									<xsl:copy-of select="*[not(self::dst-eid)]"/>
									<xsl:choose>
										<xsl:when test="ve/exists">
											<xsl:copy-of select="dst-eid"/>
										</xsl:when>
										<xsl:otherwise>
											<dst-eid><xsl:value-of select="sw:param(concat('dst_eid_',index))"/></dst-eid>
										</xsl:otherwise>
									</xsl:choose>
								</backup>
							</xsl:if>
						</xsl:for-each>
					</def>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>
				
				<xsl:if test="sw:param('next')">
					<!-- CHECK DATA -->				
					<xsl:for-each select="$form/def/backup[not(ve/exists) and not(dst-eid!='')]">
						<xsl:if test="error:put(sw:text('Please select the Hardware Node where the Containers are to be restored.'),'',concat('dst_eid_',index) )"/>
					</xsl:for-each>
					<!-- /CHECK DATA -->
				</xsl:if>
				
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>
					
			</xsl:when>		
			
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
								<xsl:copy-of select="local:get-final-packet($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-form-create"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>		
	</func:function>
	
	<xsl:template name="local:init-form-create">
		<!-- Init default data -->

		<xsl:variable name="backup-id-src" select="sw:param('id-src')"/>
		<xsl:variable name="backup-ids-rtf">
			<xsl:choose>
				<xsl:when test="$backup-id-src='post'">
					<xsl:for-each select="sw:param('id')">
						<backup-id><xsl:value-of select="."/></backup-id>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$backup-id-src='get'">
					<xsl:for-each select="sw:param('id')">
						<backup-id><xsl:value-of select="."/></backup-id>
					</xsl:for-each>
				</xsl:when>
				<xsl:when test="$backup-id-src='session'">
					<backup-id><xsl:value-of select="sw:sesgetstr('vz-backup-id')"/></backup-id>
				</xsl:when>
				<xsl:otherwise>
					<sw:die>
						Unknown or unspecified "id-src" get parameter.
					</sw:die>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="backup-ids" select="exsl:node-set($backup-ids-rtf)/backup-id"/>
		
		<sw:die test="not($backup-ids)">
			Unspecified value for backup id-src=<xsl:value-of select="$backup-id-src"/>
		</sw:die>
		
		<!-- Init form nodeset-->
		<xsl:variable name="form-inited-rtf">						
			<def>
				<xsl:for-each select="$backup-ids">
					<xsl:variable name="backup-id" select="."/>
					<xsl:variable name="backup" select="backups:find-backup($backup-id)"/>			
					<xsl:variable name="backup-ve" select="backups:find-env-info($backup)/env"/>

					<xsl:variable name="ve-eid" select="$backup-ve/eid"/>

			  	<xsl:variable name="ve" select="env:get-env($ve-eid)/env"/>
			  	<xsl:variable name="ve-exists" select="$ve/status/state and $ve/status/state!=$env-state/unexist"/>
			  	<xsl:variable name="ve-info" select="env:env2info($backup-ve)"/>
			  				  	
					<backup>
						<id><xsl:value-of select="$backup-id"/></id>
						<index><xsl:value-of select="position()"/></index>
						<xsl:choose>
							<xsl:when test="not($backup)">
								<oper-problem>
									<ui:type>custom</ui:type>
									<ui:reason>             
										<sw:text>You are not allowed to access this backup.</sw:text>
									</ui:reason>   
									<ui:reason>             
										<sw:text>The backup has already been removed.</sw:text>
									</ui:reason>  
									<ui:solution>             
										<sw:text>Try to restore the Container from another backup.</sw:text>
									</ui:solution>             
                </oper-problem>                                     
							</xsl:when>
							<xsl:when test="$backup[self::error]">
								<oper-problem>
									<ui:type>vza-error</ui:type>
									<ui:reason>             
										<sw:text>You are not allowed to access this backup.</sw:text>
									</ui:reason>   
									<ui:reason>             
										<sw:text>The backup has already been removed.</sw:text>
									</ui:reason>  
									<ui:solution>             
										<sw:text>Try to restore the Container from another backup.</sw:text>
									</ui:solution>             
									<ui:vza-error>                                                                          
										<xsl:copy-of select="$backup/*"/>
									</ui:vza-error>         
                </oper-problem>                                     
							</xsl:when>
							<xsl:when test="$ve-exists">
								<ve>
									<exists/>
									<xsl:copy-of select="env:env2info($ve)"/>
								</ve>
								<xsl:variable name="oper-problem" select="voc:check-operation('vzabackupm','restore_env','',$ve-eid)"/>
								<xsl:if test="$oper-problem!=''">
									<oper-problem>
										<xsl:copy-of select="$oper-problem"/>
									</oper-problem>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<ve>
									<xsl:if test="string($backup-ve/virtual_config/architecture)=''">
										<ignore-arch/>										
									</xsl:if>
									<xsl:copy-of select="$ve-info"/>
								</ve>
							</xsl:otherwise>
						</xsl:choose>
						<dst-eid>
							<xsl:value-of select="$ve-info/hn-eid"/>
						</dst-eid>
					</backup>
				</xsl:for-each>
			</def>				
		</xsl:variable>
		
		<!-- Init steps -->
		<xsl:variable name="new-steps-rtf">
			<step id="confirm" screen-id="23.00.00.02.00"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new-steps" select="exsl:node-set($new-steps-rtf)"/>
			<xsl:variable name="new-step" select="string($new-steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,$form-inited-rtf)"/>
			<xsl:if test="sw:sesput($wiz_steps,$new-steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new-step)"/>
		</xsl:if>
	</xsl:template>
	
	<!-- *********************************************************** -->
	<func:function name="local:get-final-packet">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<xsl:variable name="cookies">
				<redirect-prev/>
			</xsl:variable>
			<xsl:copy-of select="backups:get-packet-restore($data/def/backup,$cookies)"/>
			<xsl:if test="sw:response('lib/opredirect.xsl')"/>
		</func:result>
	</func:function>
	  	
</xsl:stylesheet>
