<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred requests"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:local="http://www.swsoft.com/xsl/cp/local/vt/envrequests/list-control"
	xmlns:requests="http://www.swsoft.com/xsl/cp/requests"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>

	<sw:include href="/lib/swa/swa-mailer.xsl"/>

	<xsl:output method="xml"/>

	<!-- check permissions to this page -->
	<xsl:variable name="cr-delete" select="cred:check('vzcp.env.ordering.admin')"/>

	<xsl:template match="/">

		<xsl:choose>

			<!-- no delete cred -->
			<xsl:when test="sw:param('delete') and not($cr-delete)">
				<packet/>
			</xsl:when>

			<!-- Check selected orders-->
			<xsl:when test="not(sw:param('id'))">
				<xsl:if test="error:put(sw:text('Please select at least one request.'),'')"/>
				<packet/>
			</xsl:when>

			<!-- Delete template-->
			<xsl:when test="sw:param('delete')">
				<xsl:copy-of select="local:delete(sw:param('id'))"/>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<!-- Unknown post -->
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>


	<func:function name="local:delete">
		<xsl:param name="order-ids"/>
		<xsl:variable name="op-error" select="requests:cancel-requests($order-ids)"/>
		<xsl:choose>
			<xsl:when test="$op-error!=''">
				<func:result>
					<packet log="on">
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<sw:text>Error rejecting the request.</sw:text>
									</short-desc>
									<detail>
										<xsl:value-of select="$op-error"/>
									</detail>
								</set-error>
							</msg>
							<operation>cancel_orders</operation>
							<redirect-last/>
						</cookie>
					</packet>
				</func:result>					
			</xsl:when>
			<xsl:otherwise>
				<func:result>			
					<packet log="on">
						<cookie>
							<msg>
								<set-ok>
									<sw:text>The Container requests have been rejected.</sw:text>
								</set-ok>
							</msg>
							<operation>cancel_orders</operation>
							<redirect-last/>
						</cookie>
					</packet>
				</func:result>					
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- credentials -->

	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vt/envrequests.xsl"/>

</xsl:stylesheet>
