<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func date voc cred local check wiz form requests vzenv vz"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"	
	xmlns:env="http://www.swsoft.com/xsl/cp/env"	
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:requests="http://www.swsoft.com/xsl/cp/requests"
	xmlns:vz="http://www.swsoft.com/xsl/cp/vz"
>

	<sw:include href="/lib/core/check-funcs.xsl"/>
	
	<!-- SWA functionality module -->
	<sw:include href="/lib/swa/swa-mailer.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>	

	<!-- VZCP functionality modules -->
	<sw:include href="/lib/vt/envrequests.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<!-- VZ functionality modules -->
	<sw:include href="/lib/vz/core.xsl"/>
	<sw:include href="/lib/vz/vzenv-net.xsl"/>

	<xsl:output method="xml"/>
	<xsl:param name="wiz_code" select="'ve-order'"/>
	<xsl:variable name="admin-mode" select="cred:check('vzcp.env.ordering.admin')"/>
	
  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>		

	<xsl:template match="node()|@*">

		<xsl:variable name="ordering" select="requests:get-config()"/>

		<xsl:choose>
		
		
			<!-- Step "General Settings" -->
			<xsl:when test="$step='gen'">

				<xsl:variable name="select-user" select="$admin-mode"/>
				<xsl:variable name="new_form_">
					<xsl:copy-of select="$form/*[not(self::data or self::other)]"/>
					<data>
						<xsl:choose>
							<xsl:when test="$select-user">
								<ownerSid>
									<xsl:value-of select="sw:param('user')"/>
								</ownerSid>
							</xsl:when>
							<xsl:otherwise>
								<xsl:copy-of select="$form/data/ownerSid"/>
							</xsl:otherwise>
						</xsl:choose>
						<description>
							<xsl:value-of select="sw:param('description')"/>
						</description>
						<!-- VE -->
						<requestEnvHostname>
							<xsl:value-of select="sw:param('hostname')"/>
						</requestEnvHostname>
						<requestEnvName>
							<xsl:value-of select="sw:param('name')"/>
						</requestEnvName>
						<xsl:variable name="sample" select="sw:split( sw:param('sample'),'|' )"/>
						<requestSampleId>
							<xsl:value-of select="$sample[1]"/>
						</requestSampleId>
						<requestSampleName>
							<xsl:value-of select="sw:base64-decode($sample[2])"/>
						</requestSampleName>
						<requestEnvPassword>
							<xsl:value-of
								select="sw:param('root_password')"/>
						</requestEnvPassword>
						<!-- /VE -->
					</data>
					<other>
						<root-password-re>
							<xsl:value-of	select="sw:param('root_password_re')"/>
						</root-password-re>
					</other>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('back')">
					<!-- Move to back -->
					<xsl:if test="wiz:goBack()"/>
				</xsl:if>
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<!-- Check user -->
					<xsl:if test="$select-user and $new_form/data/ownerSid=''">
						<xsl:value-of select="error:put(sw:text('A Container owner should be selected.'),'','user')"/>
					</xsl:if>
					<!-- Check password -->
					<xsl:choose>
						<xsl:when test="string($new_form/data/requestEnvPassword)='' and string($new_form/other/root-password-re)=''">
							<!-- check password presence -->
							<xsl:value-of select="error:put(sw:text('The password field must not be empty.'),'','root_password')"/>
						</xsl:when>
						<xsl:when test="$new_form/data/requestEnvPassword != $new_form/other/root-password-re">
							<!-- check password matching -->
							<xsl:if test="error:put(sw:text('The passwords do not match.'),'','root_password')"/>
							<xsl:if test="error:add-control('root_password_re')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check sample -->
					<xsl:choose>
						<!-- check template presence -->
						<xsl:when test="string($new_form/data/requestSampleId)=''">
							<xsl:if test="error:put(sw:text('You should select some Container sample.'),'','sample')"/>
						</xsl:when>
					</xsl:choose>
					<!-- check hostname -->
					<xsl:variable name="hostname-rule" select="$ordering/hostname-rule"/>
					<xsl:choose>
						<!-- check hostname presence -->
						<xsl:when test="$hostname-rule='' or $hostname-rule='hidden' or 
							($hostname-rule='optional' and string($new_form/data/requestEnvHostname)='')
						"> 
						</xsl:when>
						<!-- check hostname -->
						<xsl:when test="$new_form/data/requestEnvHostname=''">
							<xsl:if test="error:put(sw:text('You should specify a hostname.'),'','hostname')"/>
						</xsl:when>
						<!-- check hostname for valid -->
						<!-- Disabled due to #79796, TODO: uncomment after 4.0 review 
						<xsl:when test="not(check:hostname(
							env:make-platform-ref('',$new_form/hn/platform),$new_form/data/requestEnvHostname
						))">
							<xsl:if test="error:put(sw:text('You should specify a valid hostname.'),'','hostname')"/>
						</xsl:when>
						-->
					</xsl:choose>
					<!-- check name -->
					<xsl:variable name="name-rule" select="$ordering/ve-name-rule"/>
					<xsl:choose>
						<!-- check name presence -->
						<xsl:when test="$name-rule='' or $name-rule='hidden' or 
							($name-rule='optional' and string($new_form/data/requestEnvName)='')
						"> 
						</xsl:when>
						<!-- check name -->
						<xsl:when test="$new_form/data/requestEnvName=''">
							<xsl:if test="error:put(sw:text('You should specify a name.'),'','name')"/>
						</xsl:when>
						<!-- check name for valid -->
						<!-- Disabled due to #79796, TODO: uncomment after 4.0 review 
						<xsl:when test="not(check:hostname(
							env:make-platform-ref('',$new_form/hn/platform),$new_form/data/requestEnvHostname
						))">
							<xsl:if test="error:put(sw:text('You should specify a valid hostname.'),'','hostname')"/>
						</xsl:when>
						-->
					</xsl:choose>					
					<!-- Move to next step -->
					<xsl:choose>
						<xsl:when test="error:is-empty()">
							<xsl:copy-of select="local:final($new_form/data)"/>
							<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
						</xsl:when>
					</xsl:choose>
				</xsl:if>

				<!-- Store form values-->
				<xsl:variable name="res">
					<xsl:value-of select="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				</xsl:variable>

			</xsl:when>

		</xsl:choose>

	
		<xsl:copy/>
	
	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.env.ordering.user'))"/>
		<xsl:if test="$step = ''">

			<!-- Show welcome message after new user registration -->
			<xsl:variable name="msg" select="sw:sesgetstr('env-request-message')"/>
			<xsl:if test="$msg!=''">
				<xsl:if test="sw:sesputstr('msg',$msg)"/>
				<xsl:if test="sw:sesputstr('env-request-message','')"/>
			</xsl:if>
			<!-- /Show welcome message after new user registration -->

			<xsl:variable name="new_form">
				<def> </def>
				<data>
					<requestSampleId> </requestSampleId>
					<ownerSid>
						<xsl:if test="$auth-type = 'clusteruser'">
							<xsl:value-of select="authm:get-user(sw:login()/login)/data/objectSid"/>
						</xsl:if>
					</ownerSid>
				</data>
			</xsl:variable>
			<!-- Init steps -->
			<xsl:variable name="new_steps_">
				<step id="gen" screen-id="22.00.00.01.00"/>
			</xsl:variable>
			<!-- Save wizard initial settings -->
			<xsl:if test="error:is-empty()">
				<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
				<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
				<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
				<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
				<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
			</xsl:if>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<!-- *********************************************************** -->
	<func:function name="local:final">
		<xsl:param name="data"/>

		<!-- Post Request  -->
		<xsl:variable name="posted-error" select="requests:new-order($data)"/>

		<!-- Return back -->
		<func:result>
			<xsl:choose>
				<xsl:when test="$posted-error!=''">
					<!-- error -->
					<packet>
						<cookie>
							<msg>
								<set-error>
									<short-desc>
										<xsl:value-of select="$posted-error"/>
									</short-desc>
								</set-error>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
					<!-- /error -->
				</xsl:when>
				<xsl:otherwise>
					<!-- ok -->
					<packet>
						<cookie>
							<msg>
								<set-ok>
									<sw:text>Your request was submitted successfully.</sw:text>
								</set-ok>
							</msg>
							<redirect-prev/>
						</cookie>
					</packet>
					<!-- /ok -->
				</xsl:otherwise>
			</xsl:choose>
		</func:result>
	</func:function>

	<!-- Includes -->
	<!-- UI modules -->
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

	<!-- /Includes -->

</xsl:stylesheet>
