<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func env cred action"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm" 
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
	xmlns:func="http://exslt.org/functions" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:action="http://www.swsoft.com/xsl/cp/action"
	xmlns:request="http://www.swsoft.com/xsl/cp/request">

	<sw:include href="/lib/cred-filter.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>
	<sw:include href="/lib/vt/env-control.xsl"/>
	<sw:include href="/lib/utils/action.xsl"/>

	<xsl:output method="xml"/>

	<!-- check permissions to this page -->
	<xsl:variable name="cr-backup" select="true()"/>

	<!-- eid can be sent via GET or POST, do not put here 'true()' -->
	<xsl:variable name="selected-eids" select="ve:post2eids(0 != count(sw:param('env-src')))"/>

	<xsl:template match="/">
		<xsl:choose>
			<!-- Check selected VE -->
			<xsl:when test="not($selected-eids)">
				<xsl:if test="error:put(sw:text('Please select at least one Container.'),'')"/>
				<packet/>
			</xsl:when>

			<!-- Start VE -->
			<xsl:when test="sw:param('start')">
				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<packet/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="cred-valid-eids"
							select="cred:filter-valid-env('vzcp.env.manage.start_stop',$selected-eids)"/>
						<xsl:choose>
							<xsl:when test="count($cred-valid-eids) > 0">
								<xsl:copy-of select="env:action-start($cred-valid-eids)"/>
								<xsl:if test="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Restart VE -->
			<xsl:when test="sw:param('restart')">
				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<packet/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="cred-valid-eids"
							select="cred:filter-valid-env('vzcp.env.manage.start_stop',$selected-eids)"/>
						<xsl:choose>
							<xsl:when test="count($cred-valid-eids) > 0">
								<xsl:copy-of select="env:action-restart($cred-valid-eids)"/>
								<xsl:if test="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Stop VE -->
			<xsl:when test="sw:param('stop')">
				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<packet/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="cred-valid-eids"
							select="cred:filter-valid-env('vzcp.env.manage.start_stop',$selected-eids)"/>
						<xsl:choose>
							<xsl:when test="count($cred-valid-eids) > 0">
								<xsl:copy-of select="env:action-stop($cred-valid-eids)"/>
								<xsl:if test="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Fast Stop VE -->
			<xsl:when test="sw:param('fast_stop')">
				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<packet/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="cred-valid-eids"
							select="cred:filter-valid-env('vzcp.env.manage.start_stop',$selected-eids)"/>
						<xsl:choose>
							<xsl:when test="count($cred-valid-eids) > 0">
								<xsl:copy-of select="env:action-stop($cred-valid-eids,true())"/>
								<xsl:if test="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Suspend VE -->
			<xsl:when test="sw:param('suspend')">
				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<packet/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="cred-valid-eids"
							select="cred:filter-valid-env('vzcp.env.manage.start_stop',$selected-eids)"/>
						<xsl:choose>
							<xsl:when test="count($cred-valid-eids) > 0">
								<xsl:copy-of select="env:action-suspend($cred-valid-eids)"/>
								<xsl:if test="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Backup VE -->
			<xsl:when test="sw:param('backup')">
				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<packet/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="cred-valid-eids"
							select="cred:filter-valid-env('vzcp.env.backups.backup',$selected-eids)"/>
						<xsl:choose>
							<xsl:when test="count($cred-valid-eids) > 0">
								<xsl:copy-of select="env:action-backup($cred-valid-eids)"/>
								<xsl:if test="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Stop&Delete the VE -->
			<xsl:when test="sw:param('stop_destroy_ve')">
				<xsl:choose>
					<xsl:when test="error:has-errors()">
						<packet/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="cred-valid-eids"
							select="cred:filter-valid-env('vzcp.env.destroy',$selected-eids)"/>
						<xsl:choose>
							<xsl:when test="count($cred-valid-eids) > 0">
								<xsl:copy-of select="env:getPacketDestroyVE($cred-valid-eids)"/>
								<xsl:if test="sw:response('lib/opredirect.xsl')"/>
							</xsl:when>
							<xsl:otherwise>
								<packet/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			
			<!-- Delete the VE -->
			<xsl:when test="sw:param('destroy')">
				<xsl:call-template name="env:destroyVE"/>
			</xsl:when>

			<!-- Unknown post -->
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>



	<xsl:template name="env:destroyVE">
		<xsl:variable name="eids" select="$selected-eids"/>

		<!-- Get VE Info -->
		<xsl:variable name="env-list" select="env:get-env($eids)/env"/>
		<packet>
			<xsl:choose>
				<xsl:when test="not($env-list)">
					<xsl:if
						test="error:put('This VE(s) was(were) already deleted. See action log for the details.','')"/>
					<xsl:if test="sw:response('lib/opredirect.xsl')"/>
					<cookie>
						<redirect-prev/>
					</cookie>					
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="security-enabled-eids" select="cred:filter-valid-env(
						'vzcp.env.destroy',
						$env-list/eid,
						false())"/>
					<xsl:choose>
						<xsl:when test="not($security-enabled-eids)">
							<xsl:if
								test="error:put('You are not authorized to delete the selected VE(s).','')"/>
							<xsl:if test="sw:response('lib/opredirect.xsl')"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$env-list[string(eid)=$security-enabled-eids]"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</packet>

	</xsl:template>

	<func:function name="env:getPacketDestroyVE">
		<xsl:param name="eids"/>

		<func:result>

			<xsl:call-template name="action:make-packet">
				<xsl:with-param name="path" select="'actions/vt/envs/destroy.xsl'"/>
				<xsl:with-param name="cookie">
					<msg>
						<sched>
							<sw:text>The Containers have been scheduled for deleting.</sw:text>
						</sched>
						<error>
							<sw:text>Failed to delete the Containers.</sw:text>
						</error>
					</msg>
					<operation>destroy_ve</operation>
					<redirect-prev/>
				</xsl:with-param>
				<xsl:with-param name="input">
					<data>
						<xsl:copy-of select="ve:eids2nodes($eids)"/>
					</data>
				</xsl:with-param>
			</xsl:call-template>

		</func:result>

	</func:function>


	<!-- credentials -->
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
