<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local error vt units env hn request trace"
	xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl			="http://exslt.org/common"
	xmlns:sw				="http://www.swsoft.com/xsl/cp"
	xmlns:error			="http://www.swsoft.com/xsl/cp/error"
	xmlns:check			="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz				="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"
  xmlns:func			="http://exslt.org/functions"	
	xmlns:cred			="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:sample 		="http://www.swsoft.com/xsl/cp/sample"		
	xmlns:env-samplem 		="http://www.swsoft.com/xsl/cp/env-samplem"	
	xmlns:hn				="http://www.swsoft.com/xsl/cp/hn"
	xmlns:request		="http://www.swsoft.com/xsl/cp/request"
	xmlns:requests  ="http://www.swsoft.com/xsl/cp/requests"	
	xmlns:trace			="http://www.swsoft.com/xsl/cp/trace"
>
<!--
	Input GET Params:
		request-id: VE Request ID
		context: 'default_unit'
-->
	<sw:include href="/lib/trace.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/swa/env-samplem.xsl"/>	
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/envrequests.xsl"/>  		
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vt/hn-select.xsl"/>

	<xsl:output method="xml"/>  

	<xsl:param name="wiz_code" select="'envs-new'"/>

  <xsl:variable name="step" select="wiz:processing-step-id()"/>	
  <xsl:variable name="form" select="local:init-form()"/>	

	<xsl:variable name="local:max-number-of-ve-for-multicreate" select="100"/>
	
	<xsl:variable name="edit-mode" select="$form/unit-id"/>	

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when test="$step='start'">
			
				<xsl:variable name="envs-count-src" select="sw:param('envs_count')"/>
				<xsl:variable name="envs-count" select="sw:if($form/envrequest-id,$form/envs-count,$envs-count-src)"/>
				
				<xsl:variable name="method" select="sw:param('method')"/>
				<xsl:variable name="auto-platform" select="string(sw:param('auto_platform'))"/>
				<xsl:variable name="auto-tech" select="sw:param('auto_tech')"/>
		
				<!-- Select HN  -->
				<xsl:variable name="hn-eid">
					<xsl:choose>
						<xsl:when test="$method='auto'">
							<xsl:if test="$auto-platform!=''">
								<xsl:value-of select="hn:autoselect-for-create-ve($auto-platform)"/>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="sw:param('hn')"/>
						</xsl:otherwise>	
					</xsl:choose>
				</xsl:variable>
				<!-- /Select HN  -->
		
				<!-- Restore form's data  -->				
				<xsl:variable name="new-form-rtf">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="self::hn or self::hn-select"></xsl:when>
							<xsl:when test="self::envs-count"></xsl:when>							
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>				
					<hn-select>
						<eid><xsl:value-of select="sw:param('hn')"/></eid>
						<method><xsl:value-of select="$method"/></method>
						<auto-platform><xsl:value-of select="$auto-platform"/></auto-platform>
						<tech><xsl:value-of select="$auto-tech"/></tech>
					</hn-select>
					<hn>
						<xsl:if test="$hn-eid!=''">
							<xsl:copy-of select="env:eid2info($hn-eid)"/>
							<tech>vz.vt</tech>
						</xsl:if>
					</hn>
					<envs-count>
						<xsl:value-of select="$envs-count"/>
					</envs-count>
				</xsl:variable>
				<!-- /Restore form's data  -->
				<xsl:variable name="new-form" select="exsl:node-set($new-form-rtf)"/>
				
				<xsl:if test="sw:param('next')">
					<!-- Check data -->
					<xsl:choose>
						<xsl:when test="$method='select'">
							<xsl:choose>
								<xsl:when test="not($new-form/hn/eid!='')">
									<xsl:if test="error:put(sw:text('You should either select a Hardware Node yourself or have it selected automatically.'),'','hn')"/>
								</xsl:when>
								<xsl:when test="not(env:get-env($new-form/hn/eid)/env/status/state=$env-state/running)">
									<xsl:if test="error:put(sw:text('The selected Hardware Node is not online. Please select another Node.'),'','hn')"/>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
						<xsl:when test="$method='auto'">
							<xsl:choose>
								<xsl:when test="$auto-platform=''">
									<xsl:if test="error:put(sw:text('You should select the platform.'))"/>
								</xsl:when>
								<xsl:when test="not($new-form/hn/eid!='')">
									<xsl:if test="error:put(sw:text('No Hardware Node can be selected automatically.'))"/>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<sw:die>
								Uknown method '<xsl:value-of select="$method"/>'
							</sw:die>
						</xsl:otherwise>
					</xsl:choose>
					<!-- check VE count -->						
					<xsl:choose>
			      <xsl:when test="string($envs-count)=''">
			      	<xsl:if test="error:put(sw:text('You should specify the number of Containers to create.'),'','envs_count')"/>
			      </xsl:when>
			      <xsl:when test="not(check:num($envs-count)) or number($envs-count)=0">
			      	<xsl:if test="error:put(sw:text('The number of Containers is invalid.'),'','envs_count')"/>
			      </xsl:when>
			      <xsl:when test="$envs-count &gt; $local:max-number-of-ve-for-multicreate">
			      	<xsl:variable name="error-max-multicreate">
			      		<sw:text>
			      			<xsl:with-param name="max-number" select="$local:max-number-of-ve-for-multicreate"/>
									The number of Containers should be less than or equal to %{max-number}.
			      		</sw:text>
			      	</xsl:variable>
			      	<xsl:if test="error:put($error-max-multicreate,'','envs_count')"/>
			      </xsl:when>
					</xsl:choose>
					<!-- /check VE count -->
					<!-- /Check data -->
				</xsl:if>
				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new-form"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
		
		<xsl:copy/>
	</xsl:template>
	
	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->		
		<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
		<!--|-->		
		<xsl:choose>
			<xsl:when test="sw:param('next') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
    				<xsl:choose>
							<xsl:when test="error:is-empty()">
								<xsl:copy-of select="local:packet-new($data)"/>
								<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>	
							</xsl:when>
		          <xsl:otherwise>
              	<packet/>
            	</xsl:otherwise>
          	</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>				
			</xsl:otherwise>
		</xsl:choose>
					
	</xsl:template>
	
	<func:function name="local:init-form">
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-new"/>				
		</xsl:if>
		<xsl:choose>	
			<!-- Handle return from New VE platform-specific wizard -->
			<xsl:when test="$step='restart'">
				<func:result select="wiz:init-data('start')"/>
			</xsl:when>
			<!-- Normal situation -->
			<xsl:otherwise>
				<func:result select="wiz:init-data()"/>				
			</xsl:otherwise>
		</xsl:choose>
	</func:function>
	
	<xsl:template name="local:init-new">
	
		<!-- Set new context -->
		<xsl:variable name="context" select="sw:param('context')"/>
		<xsl:choose>
			<!-- Now we will be in Infrasctructure/VEs -->
			<xsl:when test="$context='default_unit'">
				<xsl:if test="units:set-current-dn(units:infra-top-dn())"/>	
				<xsl:if test="trace:set-branch('env-home','unit')"/>
			</xsl:when>
		</xsl:choose>
		
	
		<!-- Prepare current DN -->				 		
		<xsl:variable name="dn-now" select="units:current-dn()"/>		
		<xsl:variable name="unit-branch" select="trace:check-branch('env-home','unit')"/>
		<xsl:variable name="in-dn" select="$dn-now!='' and (($unit-branch or trace:screens()[last()]/@id='10.00.00.01.07')
			and ( not(units:is-dn-top($dn-now)) or units:is-tree-logical($dn-now) )
		)"/>		
		<!-- Do we inside Folder/Envs? -->
		<xsl:variable name="dn">		
			<xsl:choose>
				<xsl:when test="$in-dn">
					<xsl:value-of select="$dn-now"/>
				</xsl:when>
				<xsl:when test="true()">
					<xsl:variable name="dn-infra" select="units:infra-top-dn()"/>							
					<xsl:if test="sw:sesputstr('farmdir-parent-dn',$dn-infra)"/>
					<xsl:value-of select="$dn-infra"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<!-- /Prepare current DN -->
		
		<!-- Prepare current HN -->		
		<xsl:variable name="hn-branch" select="trace:check-branch('env-home','hn')"/>		
		<xsl:variable name="in-hn" select="$hn-branch or trace:find-screen('03.02.01.27.08') or trace:find-screen('03.02.01.27.01')"/>		<!-- Do we inside HN/Envs? -->
		<xsl:variable name="hn-eid" select="sw:if($in-hn,sw:hn-eid(),'')"/>
		<!-- /Prepare current HN -->				
	
		<!-- Prepare VE Request  -->		
		<xsl:variable name="envrequest-id" select="sw:base64-decode(sw:param('request-id'))"/>
		<!-- /Prepare VE Request  -->		
	
		<!-- Init default data -->
		<xsl:variable name="def-platform">
			<xsl:choose>
				<xsl:when test="$envrequest-id!=''">
					<!-- Get platform from VE Request/Sample -->
					<xsl:variable name="verequest" select="requests:find-request($envrequest-id)"/>
					<xsl:variable name="sample" select="env-samplem:get-sample($verequest/requestSampleId)"/>
					<xsl:value-of select="sample:sample2platform($sample)"/>
				</xsl:when>
				<xsl:otherwise>
					<!-- commented as the workaround for #92150 
						<xsl:value-of select="vt:local-platform()"/>
					-->
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="new_form">
			<wizard-id><xsl:value-of select="sw:generate-id()"/></wizard-id>
			<xsl:if test="$envrequest-id!=''">
				<envrequest-id><xsl:value-of select="$envrequest-id"/></envrequest-id>
			</xsl:if>
			<envs-count>1</envs-count>						
			<hn>
				<eid></eid>
				<name></name>
				<platform></platform>
				<tech></tech>
			</hn>	
			<xsl:if test="$in-dn and units:is-tree-logical($dn)">
				<parent-folder>
					<dn><xsl:value-of select="$dn"/></dn>
				</parent-folder>
			</xsl:if>
			<hn-select>
				<xsl:choose>
					<xsl:when test="$hn-eid!=''">					
						<eid><xsl:value-of select="$hn-eid"/></eid>
						<method>select</method>
						<tech>vz.vt</tech>
					</xsl:when>
					<xsl:otherwise>
						<!-- post default platform -->
						<xsl:choose>
							<xsl:when test="$def-platform!=''">
								<method>auto</method>
								<auto-platform><xsl:value-of select="$def-platform"/></auto-platform>	
							</xsl:when>
							<xsl:otherwise>	
								<!-- workaround for #92150 -->
								<method>auto</method>
								<auto-platform><xsl:value-of select="env:eid2info(sw:master-eid())/platform"/></auto-platform>	
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</hn-select>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="start" screen-id="11.00.00.00.00"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,$new_form)"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>
		
	<!-- *********************************************************** -->
	
	<func:function name="local:packet-new">
		<xsl:param name="data"/>
						
		<func:result>
			<packet>
				<cookie>	        
	        <redirect> 
	        	<xsl:choose>
	        		<xsl:when test="$data/hn-select/tech='vz.vt'">
	        			<xsl:value-of select="concat($baseurl,'/vzdir/infrman/envs/create')"/>
	        		</xsl:when>
	        		<xsl:when test="$data/hn-select/tech='vmware.vt'">
	        			<xsl:value-of select="concat($baseurl,'/vmwaredir/infrman/envs/create')"/>
	        		</xsl:when>
	        		<xsl:otherwise>
	        			<sw:die>Unknown VT '<xsl:value-of select="$data/hn-select/tech"/></sw:die>
	        		</xsl:otherwise>
	        	</xsl:choose>   
	        </redirect>
	      </cookie>					
			</packet>			
		</func:result>
		
	</func:function>		

  <!-- credentials -->	
	<sw:include href="/lib/cred.xsl"/>
	
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>					
	
</xsl:stylesheet>
