<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func cred local authm dirm units"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:authm		="http://www.swsoft.com/xsl/cp/authm"
  xmlns:dirm			="http://www.swsoft.com/xsl/cp/dirm"
  xmlns:error			="http://www.swsoft.com/xsl/cp/error"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred 		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"
>
	<sw:include href="/lib/swa/dirm.xsl"/>	
	<sw:include href="/lib/core/units-core.xsl"/>

  <xsl:output method="xml"/>

  <!-- check permissions to this page -->
	<xsl:variable name="cr-delete"	select="cred:check-context('vzcp.unit.subunits.manage','unit.farm')"/>
	<xsl:variable name="parent-dn">
		<xsl:choose>
			<xsl:when test="sw:param('dn')">
				<xsl:value-of select="sw:param('dn')"/>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="units:current-dn()"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="eids" select="sw:param('id')"/>	
  
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when
				test="not($cr-delete)">
				<!-- no delete cred -->
				<packet />
			</xsl:when>			

			<!-- Check ENV I -->
			<xsl:when test="not($eids)">
				<xsl:if test="error:put(sw:text('Please select some Container.'),'')" />
				<packet />
			</xsl:when>

			<!-- Delete many Units -->
			<xsl:when test="$eids">
				<xsl:copy-of select="local:get-packet-delete-many()" />
				<xsl:if test="sw:response('lib/opredirect.xsl')" />
			</xsl:when>	
			<xsl:otherwise>
				<sw:die>No one Container was specified</sw:die>
			</xsl:otherwise>
			
		</xsl:choose>
	</xsl:template>
   
	<func:function name="local:get-packet-delete-many">  	  	
 		<xsl:if test="sw:sesput('frameset_reload_farmdir',$parent-dn)"/>
		<xsl:variable name="units" select="units:list($parent-dn,$def-scope-tree)"/> 		
		<func:result>
			<packet>
				<target>infrastructurem</target>
				<cookie>
					<msg>
						<ok><sw:text>The Container(s) has/have been removed.</sw:text></ok>
						<error><sw:text>Failed to remove the Container(s).</sw:text></error>
					</msg>
					<redirect-last/>
				</cookie>	
				<data>
					<xsl:for-each select="$eids">
						<xsl:variable name="eid" select="."/>
						<xsl:variable name="names" select="$units//unit[eid = $eid]/name"/>
						<xsl:for-each select="$names">							
							<infrastructurem>
								<del_env>
									<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn(.)"/></name>
									<eid><xsl:value-of select="$eid"/></eid>											
								</del_env>
							</infrastructurem>
						</xsl:for-each>							
					</xsl:for-each>
				</data>
			</packet>
		</func:result>
	</func:function> 
  
  
  <!-- credentials -->
  <sw:include href="/lib/common.xsl"/>
  <sw:include href="/lib/cred.xsl"/>  
 
</xsl:stylesheet>
