<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl sw func local cred envm vt units"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:envm="http://www.swsoft.com/xsl/cp/envm"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
	xmlns:units	="http://www.swsoft.com/xsl/cp/units"
>

	<sw:include href="/lib/cred-filter.xsl"/>
	<sw:include href="/lib/swa/envm.xsl"/>

	<xsl:output method="xml"/>

	<xsl:template match="/">
		<xsl:choose>

			<!-- Check selected nodes -->
			<xsl:when test="not(sw:param('id'))">
				<xsl:if test="error:put(sw:text('Please select at least one Hardware Node.'),'')"/>
				<packet/>
			</xsl:when>

			<!-- Delete template-->
			<xsl:when test="sw:param('unregister')">
				<xsl:variable name="cred-valid-eids"
					select="cred:filter-valid-hw('vzcp.virtuozzo_group.manage',sw:param('id'))"/>
				<xsl:choose>
					<xsl:when test="count($cred-valid-eids) > 0">
						<xsl:copy-of select="local:unregister($cred-valid-eids)"/>
						<xsl:if test="sw:sesput('frameset_reload_farmdir',units:infra-top-dn())"/>
						<xsl:if test="sw:sesput('frameset_reload_farmdir_logical',units:logical-top-dn())"/>
					</xsl:when>
					<xsl:otherwise>
						<packet/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:if test="sw:response('lib/opredirect.xsl')"/>
			</xsl:when>

			<!-- Unknown post -->
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>


	<func:function name="local:unregister">
		<xsl:param name="ids"/>
		<func:result>
			<packet log="on" progress="on">
				<target>server_group</target>
				<cookie>
					<msg>
						<ok>
							<sw:text>The Hardware Node(s) has/have been unregistered.</sw:text>
						</ok>
						<error>
							<sw:text>Failed to unregister the Hardware Node(s).</sw:text>
						</error>
					</msg>
					<operation>unregister_hn</operation>
					<redirect-last/>
				</cookie>
				<data>
					<xsl:for-each select="$ids">
						<server_group>
							<del>
								<eid>
									<xsl:value-of select="."/>
								</eid>
								<force/>
							</del>
						</server_group>
					</xsl:for-each>
				</data>
				<vzcpauth/>
			</packet>
		</func:result>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/common.xsl"/>

</xsl:stylesheet>
