<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred check local units"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"	
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:check="http://www.swsoft.com/xsl/cp/check"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:units	="http://www.swsoft.com/xsl/cp/units" 	
	xmlns:trace			="http://www.swsoft.com/xsl/cp/trace"	
>
	<sw:include href="/lib/trace.xsl"/>

	<xsl:output method="xml"/>

	<xsl:variable name="step" select="wiz:processing-step-id()"/>

	<xsl:param name="wiz_code" select="'cluster-node'"/>
	<xsl:variable name="form" select="local:init-form()"/>

	<xsl:template match="node()|@*">
		<xsl:choose>
			<!-- Step "General Settings" -->
			<xsl:when
				test="$step='reg'">

				<xsl:variable name="new_form_">
					<xsl:for-each select="$form/*">
						<xsl:choose>
							<xsl:when test="name()=$step"/>
							<xsl:otherwise>
								<xsl:copy-of select="."/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:for-each>
					<reg>
						<ip>
							<xsl:value-of
								select="normalize-space(sw:param('ip'))"/>
						</ip>
						<user>
							<xsl:value-of
								select="normalize-space(sw:param('user'))"/>
						</user>
						<password>
							<xsl:value-of
								select="normalize-space(sw:param('password'))"/>
						</password>
						<force>
							<xsl:value-of select="sw:param('force')"/>
						</force>
						<user>
							<xsl:value-of
								select="normalize-space(sw:param('user'))"/>
						</user>
					</reg>
				</xsl:variable>
				<xsl:variable name="new_form" select="exsl:node-set($new_form_)"/>

				<xsl:if test="sw:param('submit')">
					<!-- Check data -->
					<!--+ Check Name -->
					<xsl:choose>
						<!--+++ Check value presence -->
						<xsl:when test="string($new_form/reg/user)=''">
							<xsl:if
								test="error:put(sw:text('You should specify a Service Container user name.'),'','user')"/>
						</xsl:when>
					</xsl:choose>
					<!--+ Check password -->
					<xsl:choose>
						<xsl:when test="string($new_form/reg/password) = ''">
							<!-- check password presence -->
							<xsl:if test="error:put(sw:text('You should specify a password.'),'','password')"/>
						</xsl:when>
					</xsl:choose>
					<!--+ Check IP -->
					<xsl:choose>
						<!--+++ Check value presence -->
						<xsl:when test="string($new_form/reg/ip)=''">
							<xsl:value-of
								select="error:put(sw:text('You should specify the Hardware Node IP address.'),'','ip')"
							/>
						</xsl:when>
						<!--+++ Check name for valid chars -->
						<!--<xsl:when test="not(check:ip($new_form/reg/ip))">
				      	<xsl:value-of select="error:put('Specified Hardware Node IP contains invalid characters.','','ip')"/>
				      </xsl:when>-->
					</xsl:choose>
				</xsl:if>

				<xsl:call-template name="local:completeFormHandling">
					<xsl:with-param name="data" select="$new_form"/>
				</xsl:call-template>

			</xsl:when>
			
			<!-- Step "Progress" -->
			<xsl:when
				test="$step='progress'">
				
				<xsl:variable name="result-code" select="sw:param('result_code')"/>
				<xsl:variable name="result-message" select="sw:param('result_message')"/>				

				<xsl:choose>
					<!-- RECEIVED OK -->
					<xsl:when test="$result-code='ok'">
						<xsl:if test="sw:sesput('frameset_reload_farmdir',units:current-dn())"/>
						<packet>
							<cookie>
								<redirect-prev/>
						          <msg>
									<set-ok>
										<sw:text>
											The Hardware Node was successfully registered.
										</sw:text>
									</set-ok>
								</msg>
							</cookie>
						</packet>
						<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
					<!-- RECEIVED ERROR -->
					<xsl:when test="$result-code='error'">
						<xsl:if test="error:put(sw:text('An error occurred during the registration. Please verify the server address and user credentials.'),$result-message)"/>
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
					<!-- CALL DEFAULT WIZARD HANDLER -->
					<xsl:otherwise>
						<xsl:call-template name="local:completeFormHandling">
							<xsl:with-param name="data" select="$form"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
				
			</xsl:when>

		</xsl:choose>

		<xsl:copy/>
	</xsl:template>

	<xsl:template name="local:completeFormHandling">
		<xsl:param name="data"/>
		<!--|-->
		<xsl:choose>
			<xsl:when test="sw:param('next') or sw:param('submit') and error:is-empty()">
				<!-- Handle "Next" Button -->
				<xsl:choose>
					<xsl:when test="wiz:isLastStep()">
						<xsl:copy-of select="local:getFinalPacket($data)"/>
						<xsl:value-of select="sw:response('lib/opredirect.xsl')"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="wiz:goNext()"/>
						<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
					</xsl:otherwise>
				</xsl:choose>
				<!-- /Handle "Next" Button -->
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="sw:param('back')">
						<xsl:if test="wiz:goBack()"/>
					</xsl:when>
				</xsl:choose>
				<xsl:if test="sw:sesputtree($wiz_data,$data)"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<func:function name="local:init-form">
		<sw:noauth-redirect select="not(cred:check('vzcp.virtuozzo_group.manage'))"/>
		<xsl:if test="$step = ''">
			<xsl:call-template name="local:init-register"/>
		</xsl:if>
		<func:result select="wiz:init-data()"/>
	</func:function>

	<xsl:template name="local:init-register">
		<!-- Init default data -->
		
		<!-- Prepare current DN -->				 		
		<xsl:variable name="dn-now" select="units:current-dn()"/>		
		<xsl:variable name="trace" select="trace:screens()"/>			
		<!-- in folder and not in HN and in logical tree -->
		<xsl:variable name="in-unit" select="$trace[@units-path='unit'] and not($trace[@id='03.02.01.27.08'])
		"/>		
		<!-- /Prepare current DN -->	
		
		<xsl:variable name="new_form">
			<reg>
				<user></user>
			</reg>
			<xsl:if test="$dn-now!='' and $in-unit">
				<parent-folder>
					<dn><xsl:value-of select="$dn-now"/></dn>
				</parent-folder>
			</xsl:if>
		</xsl:variable>
		<!-- Init steps -->
		<xsl:variable name="new_steps_">
			<step id="reg" screen-id="11.01.00.02.00"/>
			<step id="progress" screen-id="11.01.00.02.01"/>
		</xsl:variable>
		<!-- Save wizard initial settings -->
		<xsl:if test="error:is-empty()">
			<xsl:variable name="new_steps" select="exsl:node-set($new_steps_)"/>
			<xsl:variable name="new_step" select="string($new_steps/step[1]/@id)"/>
			<xsl:if test="sw:sesput($wiz_data,exsl:node-set($new_form))"/>
			<xsl:if test="sw:sesput($wiz_steps,$new_steps)"/>
			<xsl:if test="sw:sesput($wiz_step,$new_step)"/>
		</xsl:if>
	</xsl:template>


	<!-- *********************************************************** -->
	<func:function name="local:getFinalPacket">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet>
				<cookie>
					<redirect-prev/>
				</cookie>
			</packet>
		</func:result>
	</func:function>

	<!-- credentials -->
	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>	

</xsl:stylesheet>
