<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw cred trace voc"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:trace="http://www.swsoft.com/xsl/cp/trace" xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
>

	<sw:include href="/lib/vt/env-core.xsl"/>


	<xsl:param name="single-ve"
		select="not(trace:check-branch('env-home','management')) or $activeMode = 'vzcp' or $activeMode = 'plesk'"/>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied"
		select="not(cred:check-context('vzcp.log.list',sw:if($single-ve,'env.core.vt','vzcp')))"/>

	<xsl:template mode="screen" match="/">

		<xsl:variable name="voc-hn-eid">
			<xsl:choose>
				<xsl:when test="$single-ve or $activeMode != 'vzcc'">
					<xsl:value-of select="sw:ve-parent(sw:ve-eid())"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="sw:master-eid()"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="platform-ref" select="env:make-platform-ref($voc-hn-eid)"/>
		<xsl:variable name="voc-qos" select="voc:get('qos', $platform-ref )"/>

		<!-- agent provide alert type not supported by vzcp voc:* functions -->
		<xsl:variable name="voc-alert-category-rtf">
			<category>
				<id>resource_alert</id>
				<short-desc>
					<sw:text>Resource</sw:text>
				</short-desc>
			</category>
			<category>
				<id>server_group_alert</id>
				<short-desc>
					<sw:text>Group</sw:text>
				</short-desc>
			</category>				
		</xsl:variable>
		<xsl:variable name="voc-alert-category" select="exsl:node-set($voc-alert-category-rtf)"/>		
		
		<xsl:variable name="log-management" select="$single-ve or $activeMode != 'vzcc'"/>
		
		<xsl:variable name="filter_init_">
		
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="vz-logs-alerts{sw:if($log-management, '-management', '')}" item-url="/vzdir/infrman/envs/env"
						url="/core/alerts" items-title="{sw:text('Alerts')}"/>
					<ui:cols sorting-col="time" sorting-direction="desc">
						<ui:column id="time" vza-id="event_log.time" data-type="datetime"
							title="{sw:text('Time')}" filter-from-title="{sw:text('Occurred From')}"
							filter-to-title="{sw:text('Occurred To')}" filter-from-tip="alert_from_filter"
							filter-to-tip="alert_to_filter" filter="interval"/>
						<xsl:choose>
							<xsl:when test="$log-management">
								<ui:column id="id" vza-id="event_log.parameter.env.eid" filter="equal" hidden="yes"
									value="{sw:ve-eid()}"/>
							</xsl:when>
							<xsl:otherwise>
								<ui:column id="alert-category" vza-id="event_log.category" 
									title="{sw:text('Category')}" filter="select"  apply-templates="yes">
									<xsl:for-each select="$voc-alert-category/category">
										<xsl:sort select="id"/>
											<ui:filter-option value="{id}" title="{short-desc}"/>
										</xsl:for-each>
								</ui:column>
								<ui:column id="alert-info" vza-id="event_log.info" 
									title="{sw:text('Details')}" sorting="no"/>
								
								<ui:column id="env-title-link" title="{sw:text('Hardware Node')}" filter="auto" vza-id="event_log.origin.title" apply-templates="yes">
									<ui:column-layout-options eid-node="hn-eid" vza-type-node="hn-type"/>
								</ui:column>
								<ui:column id="hn-eid" vza-id="event_log.origin.eid" hidden="yes"/>	
								<ui:column id="hn-type" vza-id="event_log.origin.type" hidden="yes"/>
																
								<ui:column id="alert-ve-title" vza-id="event_log.parameter.env.title" apply-templates="yes"
									title="{sw:text('Container')}" filter="auto"
								>
								</ui:column>
								<ui:column id="ve-eid" vza-id="event_log.parameter.env.eid" hidden="yes"/>
							</xsl:otherwise>
						</xsl:choose>
						<ui:column id="alert-type" vza-id="event_log.parameter.type" apply-templates="yes" sorting="no"
							title="{sw:text('Type')}"/>						
						<ui:column id="qos-help-id" vza-id="event_log.parameter.id" apply-templates="yes"
							title="{sw:text('Parameter')}" filter="select">
							<xsl:for-each select="$voc-qos">
								<xsl:sort select="id"/>
								<ui:filter-option value="{id}" title="{id}"/>
							</xsl:for-each>
						</ui:column>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-from-vza">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="sql-where">
					<xsl:choose>
						<xsl:when test="$single-ve or $activeMode != 'vzcc'">
							pager.event_log.category='resource_alert'
						</xsl:when>
						<xsl:otherwise>
						  (
							(pager.event_log.category='resource_alert') or 
							(pager.event_log.category='server_group_alert') or
							(pager.event_log.category='license_alert')
							)
						</xsl:otherwise>
					</xsl:choose>     
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		
		<ui:screen id="19.00.00.00.00">
			<xsl:choose>
				<xsl:when test="$single-ve">
					<ui:tab-bar id="vzve" current-tab="logs" current-subtab="alerts"/>
				</xsl:when>
				<xsl:otherwise>
					<ui:tab-bar id="alerts-events" current-tab="alerts"/>  
				</xsl:otherwise>
			</xsl:choose>
			<ui:properties>
				<ui:form-get/>
				<ui:contains-date-control/>
				<ui:description width="full">
					<sw:text>On this screen you can see the log of resource alerts. These are the events that occur when the Container resource usage hits a certain limit. <br/>Use the filter to select the relevant records by their date/time.</sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:block width="full">
					<ui:browse title="{sw:text('Alerts')}">

						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>

						<ui:browse-empty-msg>
							<sw:text>There have been no alerts so far.</sw:text>
						</ui:browse-empty-msg>

					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/trace.xsl"/>
	<sw:include href="/lib/core/browse-filter-vza.xsl"/>

	<sw:include href="/lib/common.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
