<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred desktop env"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:local		="http://www.swsoft.com/xsl/cp/local"
  xmlns:func		="http://exslt.org/functions"
  xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:desktop	="http://www.swsoft.com/xsl/cp/desktop"
  xmlns:env			="http://www.swsoft.com/xsl/cp/env"
>
	<!-- Imports -->
	<sw:include	href="/lib/vzcc/desktop.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<!-- /Imports -->

	<xsl:variable name="fav-ids" select="local:fav-unpack(sw:param('ids'))"/>
	<xsl:variable name="fav-comments" select="local:fav-unpack(string(sw:param('comments')))"/>
	<xsl:variable name="cmd" select="sw:param('cmd')"/>
	<xsl:variable name="fav-type" select="sw:param('fav-type')"/>
	<xsl:variable name="old-desktop" select="desktop:load()"/>


	<xsl:template mode="screen" match="/">
		<ui:body-screen>
			<ui:content>											
				<xsl:variable name="new-desktop">
					<desktop>
						<xsl:copy-of select="$old-desktop/*[not(self::favorites)]"/>
						<favorites>
							<xsl:if test="$cmd = 'add'">
								<xsl:copy-of select="$old-desktop/favorites/item[
									@type!=$fav-type or not(id=$fav-ids)
								]"/>
							</xsl:if>
							<xsl:if test="$cmd = 'edit'">
								<xsl:copy-of select="$old-desktop/favorites/item[@type!=$fav-type]"/>
							</xsl:if>
							
							<xsl:for-each select="$fav-ids">
								<item type="{$fav-type}">
									<xsl:variable name="index" select="position()"/>
									<id>
										<xsl:value-of select="."/>
									</id>
									<comment>
										<xsl:message>[<sw:text select="$fav-comments"/>]</xsl:message>
										<xsl:value-of select="$fav-comments[position() = $index]"/>
									</comment>
								</item>
							</xsl:for-each>							
						</favorites>
					</desktop>
				</xsl:variable>
				<xsl:if test="desktop:save($new-desktop)"/>	
				<xsl:variable name="my-new-desktop" select="desktop:load()"/>
				<xsl:variable name="envs" select="env:get-env($my-new-desktop/favorites/item[@type=$fav-type]/id)"/>

				<ui:favorites id="{$fav-type}">
					<xsl:for-each select="$envs/env">
						<xsl:variable name="eid" select="eid"/>
						<ui:favorite-item disable-edit="'false'" id="{$eid}">
							<xsl:choose>
								<xsl:when test="$fav-type = 've.vz.vt'">
									<ui:fav-link href="/vz/cp/vzdir/infrman/envs/env?id={sw:base64-encode($eid)}">
										<xsl:value-of select="env:env2title(.)"/>
									</ui:fav-link>	
								</xsl:when>
								<xsl:when test="$fav-type = 'hn.vz.vt'">
									<ui:fav-link href="/vz/cp/vzdir/infrman/envs/env?id={sw:base64-encode($eid)}">
										<xsl:value-of select="env:env2title(.)"/>
									</ui:fav-link>										
								</xsl:when>
							</xsl:choose>
							<ui:fav-note><xsl:value-of select="$my-new-desktop/favorites/item[id=$eid]/comment"/></ui:fav-note>
						</ui:favorite-item>
					</xsl:for-each>
				</ui:favorites>
				<ui:raw><xsl:comment><![CDATA[<<<<<]]><xsl:value-of select="$fav-type"/><![CDATA[>>>>>]]></xsl:comment></ui:raw>
			</ui:content>
		</ui:body-screen>
  </xsl:template>
  
	<func:function name="local:fav-unpack">
		<xsl:param name="data"/>
		<xsl:choose>
			<xsl:when test="$data = 'false' or $data=''">
				<func:result>
				</func:result>				
			</xsl:when>
			<xsl:otherwise>
				<func:result select="sw:split($data,',')"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<!-- includes -->
  <sw:include href="/layout/ext-favorites.xsl" />	
  <sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
