<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred auth local"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:auth="http://www.swsoft.com/xsl/cp/auth"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
>

	<xsl:param name="wiz_code" select="'desktop-setup'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- Wizard, General Step  -->
	<xsl:template name="step_gen">

		<ui:screen id="03.00.00.05.01" icon="setup">

			<ui:properties>
				<ui:form-post/>
				<ui:refresh-type>none</ui:refresh-type>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit" width="full">

					<xsl:call-template name="local:setup-sections"/>
					<xsl:call-template name="local:setup-memo"/>
					<xsl:call-template name="local:setup-actions"/>
					<xsl:if test="cred:check('vzcp.hn') and $activeMode='vzcc'">
						<xsl:call-template name="local:setup-vz-hn"/>
					</xsl:if>
					<xsl:if test="cred:check('vzcp.license') and $activeMode='vzcc'">
						<xsl:call-template name="local:setup-vz-licenses"/>
					</xsl:if>
					<xsl:if test="$activeMode='vzcp'">
						<xsl:call-template name="local:setup-vzpp-env"/>
					</xsl:if>
					<xsl:if test="$activeMode='vzcp'">
						<xsl:call-template name="local:setup-vzpp-download"/>
					</xsl:if>

					<xsl:if test="$activeMode='vzcc'">
						<ui:rows title="{sw:text('Desktop Settings')}">
							<ui:row>
								<ui:cell-check id="vzcc_home" checked="{$form/desktop/vzcc-home}">
									<sw:text>Set Desktop to be displayed as the first page after logging in to Parallels Infrastructure Manager.</sw:text>
								</ui:cell-check>
							</ui:row>
							<ui:row>
								<ui:cell-check id="desktop_default">
									<sw:text>Save this Desktop configuration as default for all Parallels Infrastructure Manager users.</sw:text>
								</ui:cell-check>
							</ui:row>
						</ui:rows>
					</xsl:if>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<xsl:template name="local:setup-memo">
		<ui:rows>
			<ui:rows-title>
				<input type="checkbox" name="memo_show" value="1">
					<xsl:if test="$form/desktop/memo/show='true'">
						<xsl:attribute name="checked"/>
					</xsl:if>
				</input>
				<span>
					<sw:text>Show 'Memo' Section</sw:text>
				</span>
			</ui:rows-title>
			<ui:row>
				<ui:cell-text colspan="2">
					<sw:text>Memo Contents</sw:text>
				</ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-inputblock id="memo_text" rows="10" width="100">
					<xsl:value-of select="sw:html-unescape($form/desktop/memo/text)"/>
				</ui:cell-inputblock>
			</ui:row>
		</ui:rows>
	</xsl:template>

	<xsl:template name="local:setup-vzpp-env">
		<ui:rows>
			<ui:rows-title>
				<input type="checkbox" name="vzpp_env_show" value="1">
					<xsl:if test="$form/desktop/vzpp-env/show='true'">
						<xsl:attribute name="checked"/>
					</xsl:if>
				</input>
				<span>
					<sw:text>Show 'Container Summary' Section</sw:text>
				</span>
			</ui:rows-title>
		</ui:rows>
	</xsl:template>

	<xsl:template name="local:setup-vzpp-download">
		<ui:rows>
			<ui:rows-title>
				<input type="checkbox" name="vzpp_download_show" value="1">
					<xsl:if test="$form/desktop/vzpp-download/show='true'">
						<xsl:attribute name="checked"/>
					</xsl:if>
				</input>
				<span>
					<sw:text>Show 'Download' Section</sw:text>
				</span>
			</ui:rows-title>
		</ui:rows>
	</xsl:template>


	<xsl:template name="local:setup-vz-hn">
		<ui:rows>
			<ui:rows-title>
				<input type="checkbox" name="vz_hn_show" value="1">
					<xsl:if test="$form/desktop/vz-hn/show='true'">
						<xsl:attribute name="checked"/>
					</xsl:if>
				</input>
				<span>
					<sw:text>Show 'Virtuozzo Hardware Node' Section</sw:text>
				</span>
			</ui:rows-title>
			<ui:row>
				<ui:cell-check id="vz_hn_links" checked="{$form/desktop/vz-hn/show-links}" offset="2">
					<sw:text>Show links to appropriate sections</sw:text>
				</ui:cell-check>
			</ui:row>
		</ui:rows>
	</xsl:template>

	<xsl:template name="local:setup-vz-licenses">
		<ui:rows>
			<ui:rows-title>
				<input type="checkbox" name="vz_lics_show" value="1">
					<xsl:if test="$form/desktop/vz-lics/show='true'">
						<xsl:attribute name="checked"/>
					</xsl:if>
				</input>
				<span>
					<sw:text>Show 'Virtuozzo Licenses' Section</sw:text>
				</span>
			</ui:rows-title>
			<ui:row>
				<ui:cell-text>
					<sw:text>Show the following additional links on Desktop:</sw:text>
				</ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-check id="vz_lics_install" checked="{$form/desktop/vz-lics/show-install}"
					offset="2">
					<sw:text>Install New License</sw:text>
				</ui:cell-check>
			</ui:row>
			<ui:row>
				<ui:cell-check id="vz_lics_request" checked="{$form/desktop/vz-lics/show-request}"
					offset="2">
					<sw:text>Request New License</sw:text>
				</ui:cell-check>
			</ui:row>
		</ui:rows>
	</xsl:template>

	<xsl:template name="local:setup-sections">
		<ui:rows>
			<ui:rows-title>
				<span>
					<sw:text>Desktop Layout</sw:text>
				</span>
			</ui:rows-title>

			<xsl:variable name="customized" select="$form/desktop/sections/section"/>
			<xsl:variable name="sections-rtf">
				<section id="memo" title="{sw:text('Memo')}" default-pos="left"/>
				<section id="actions" title="{sw:text('Actions')}" default-pos="left"/>
				<section id="vz-hn" title="{sw:text('Virtuozzo Hardware Node')}" default-pos="right"
					panel="vzcc"/>
				<section id="vz-lics" title="{sw:text('Virtuozzo Licenses')}" default-pos="right"
					panel="vzcc"/>
				<section id="vzpp-env" title="{sw:text('Container Summary')}" default-pos="right" panel="vzcp"/>
				<section id="vzpp-download" title="{sw:text('Download')}" default-pos="right" panel="vzcp"/>
				<section id="favorites" title="{sw:text('Favorites')}" default-pos="right" panel="vzcc"/>
			</xsl:variable>
			<xsl:variable name="sections"
				select="exsl:node-set($sections-rtf)/section[
				(not(@panel) or @panel=$activeMode)
			]"/>
			<ui:row>
				<ui:cell-list-selector id="sections" size="10" colspan="2" updown-left="true"
					updown-right="true" header-left="{sw:text('Left Column')}"
					header-right="{sw:text('Right Column')}">
					<xsl:choose>
						<!-- Show customized layout -->
						<xsl:when test="$customized">
							<xsl:for-each select="$customized[@pos='right']">
								<ui:item-select value="{@id}"/>
							</xsl:for-each>
							<xsl:for-each select="$customized[@pos='left']">
								<xsl:variable name="id" select="@id"/>
								<ui:item value="{@id}">
									<xsl:value-of select="$sections[@id=$id]/@title"/>
								</ui:item>
							</xsl:for-each>
							<xsl:for-each select="$sections[not(@id=$customized[@pos='left']/@id)]">
								<ui:item value="{@id}">
									<xsl:value-of select="@title"/>
								</ui:item>
							</xsl:for-each>
						</xsl:when>
						<!-- /Show customized layout -->
						<!-- Show default layout -->
						<xsl:otherwise>
							<xsl:for-each select="$sections[@default-pos='left']">
								<ui:item-select value="{@id}"/>
							</xsl:for-each>
							<xsl:for-each select="$sections">
								<ui:item value="{@id}">
									<xsl:value-of select="@title"/>
								</ui:item>
							</xsl:for-each>
						</xsl:otherwise>
						<!-- /Show default layout -->
					</xsl:choose>
				</ui:cell-list-selector>
			</ui:row>
		</ui:rows>
	</xsl:template>


	<xsl:template name="local:setup-actions">
		<ui:rows>
			<ui:rows-title>
				<input type="checkbox" name="actions_show" value="1">
					<xsl:if test="$form/desktop/actions/show='true'">
						<xsl:attribute name="checked"/>
					</xsl:if>
				</input>
				<span>
					<sw:text>Show 'Actions' Section</sw:text>
				</span>
			</ui:rows-title>
			<xsl:variable name="screens-repository" select="sw:document('screens.xml')"/>

			<ui:row>
				<ui:cell-list-selector id="actions" size="20" colspan="2" sort-logic="true">
					<xsl:for-each select="$form/desktop/actions/screen-id">
						<ui:item-select value="{.}"/>
					</xsl:for-each>
					
					<xsl:for-each
						select="cred:filter-items($screens-repository//screen[
							link and (not(link/@panel) or link/@panel = $activeMode)
						])[link]
					">
						<xsl:sort select="sw:if(link/@title,link/@title,@title)"/>
						<xsl:variable name="screen-id" select="@id"/>
						<ui:item value="{$screen-id}" selected="false">
							<xsl:value-of select="sw:if(link/@title,link/@title,@title)"/>
						</ui:item>
					</xsl:for-each>
				</ui:cell-list-selector>
			</ui:row>
		</ui:rows>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<!-- Includes -->
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/cred-filter.xsl"/>	
	<sw:include href="/lib/vocabulary.xsl"/>

	<!-- /Includes -->

</xsl:stylesheet>
