<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred auth local html"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:auth  ="http://www.swsoft.com/xsl/cp/auth"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:html="http://www.swsoft.com/xsl/cp/html"
 >

	<sw:include href="/layout/lib/html.xsl"/>

	<xsl:param name="access-denied" select="not(  cred:check('vzcp.support.troubleshooting')   )"/>

  <xsl:template mode="screen" match="/">
  	<xsl:variable name="error-code" select="sw:param('error_code')"/>

		<ui:screen id="16.00.00.00.00">

	    <ui:properties>
	      <ui:refresh-type>none</ui:refresh-type>
	      <ui:description width="full">
	      	<sw:text>
	      		On this screen you can find detailed information on a particular Parallels Infrastructure Manager error by its code.
	      	</sw:text>
	      </ui:description>
	      <ui:form-get/>
	    </ui:properties>

	  	<ui:tab-bar id="support" current-tab="error-codes"/>
	    <ui:content>
	      <ui:block mode="edit">

					<ui:rows title="{sw:text('Enter Error Code')}">
						<ui:row>
							<ui:cell-label><sw:text>Error Code</sw:text></ui:cell-label>
							<ui:cell-input value="{$error-code}" id="error_code" required="true" maxlength="20"/>
						</ui:row>
					</ui:rows>

	        <ui:buttons>
	        	<ui:button id="ok" type="ok" tip="wizard_finish" name="submit_">
	      			<sw:text>Submit</sw:text>
	      		</ui:button>
	        </ui:buttons>

	        <!-- Show error -->
	        <xsl:if test="$error-code!=''">
		        <xsl:variable name="errors" select="sw:document('error-codes.xml')"/>
		        <xsl:variable name="error" select="$errors/errors/error[@code=$error-code]"/>

		     		<ui:rows title="{sw:text('Error Details')}">
			     		<xsl:choose>
			     			<xsl:when test="$error">
			     				<xsl:call-template name="local:show-error">
			     					<xsl:with-param name="error" select="$error"/>
			     				</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<ui:row>
										<ui:cell-text colspan="2">
											<sw:text>
												<xsl:with-param name="code" select="$error-code"/>
												Error #%code is unknown. It might have occurred in low-level Virtuozzo tools. Please refer to the Virtuozzo documentation for details.
											</sw:text>
										</ui:cell-text>
									</ui:row>
								</xsl:otherwise>
							</xsl:choose>
						</ui:rows>
					</xsl:if>
					<!-- /Show error -->

	     	</ui:block>
	    </ui:content>
    </ui:screen>
  </xsl:template>

  <xsl:template name="local:show-error">
  	<xsl:param name="error"/>

  	<ui:row>
			<ui:cell-text colspan="2"><b><sw:text>Error #</sw:text></b></ui:cell-text>
		</ui:row>
		<ui:row>
			<ui:cell-text/>
			<ui:cell-text><xsl:value-of select="$error/@code"/></ui:cell-text>
		</ui:row>
		<ui:row>
			<ui:cell-text colspan="2"><b><sw:text>Problem</sw:text></b></ui:cell-text>
		</ui:row>
		<ui:row>
			<ui:cell-text/>
			<ui:cell-text><xsl:value-of select="$error/problem"/></ui:cell-text>
		</ui:row>
		<xsl:for-each select="$error/reason">
			<ui:row>
				<ui:cell-text colspan="2"><b><sw:text>Reason</sw:text></b></ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-text/>
				<ui:cell-text><xsl:value-of select="."/></ui:cell-text>
			</ui:row>
		</xsl:for-each>
		<xsl:for-each select="$error/resolution">
			<ui:row>
				<ui:cell-text colspan="2"><b><sw:text>Resolution</sw:text>
					<xsl:if test="@num">&#160;#<xsl:value-of select="@num"/></xsl:if>
				</b></ui:cell-text>
			</ui:row>
			<ui:row>
				<ui:cell-text/>
				<ui:cell-text>
					<sw:text select="substring-after(html:plain2html(.),'&lt;br/&gt;')"/>
				</ui:cell-text>
			</ui:row>
		</xsl:for-each>

  </xsl:template>


	<!-- Includes -->
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl"/>

	<!-- /Includes -->

</xsl:stylesheet>
