<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl date cred trace vzenv"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:date="http://exslt.org/dates-and-times"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:trace="http://www.swsoft.com/xsl/cp/trace"
>

	<!-- search vzenv screen in path -->
	<xsl:param name="single-ve"
		select="not(trace:check-branch('env-home','management')) or $activeMode = 'vzcp'  or $activeMode = 'plesk'"/>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied"
		select="not(cred:check-context('vzcp.log.list',sw:if($single-ve,'env.core.vt','vzcp')))"/>

	<xsl:template mode="screen" match="/">

		<xsl:variable name="log-management" select="$single-ve or $activeMode != 'vzcc'"/>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="logs-status{sw:if($log-management, '-management', '')}" item-url="/vzdir/infrman/envs/env"
						url="/core/events"
						items-title="{sw:text('Status Changes')}"/>
					<ui:cols sorting-col="time" sorting-direction="desc">
						<ui:column id="time" vza-id="event_log.time" data-type="datetime"
							title="{sw:text('Time')}" filter-from-title="{sw:text('Changed From')}"
							filter-to-title="{sw:text('Changed To')}" filter-from-tip="status_from_filter"
							filter-to-tip="status_to_filter" filter="interval"/>
						<xsl:choose>
							<xsl:when test="$log-management">
								<ui:column id="id" vza-id="event_log.parameter.env.eid" filter="equal" hidden="yes"
									value="{sw:ve-eid()}"/>
							</xsl:when>
							<xsl:otherwise>
								<ui:column id="event-obj-title" vza-id="event_log.parameter.env.title" apply-templates="yes"
									title="{sw:text('Object')}" filter="auto" for-url="yes" show-url="no"/>
								<ui:column id="obj-id"	vza-id="event_log.parameter.env.eid" hidden="yes"/>
								<ui:column id="obj-type"	vza-id="event_log.parameter.env.type" hidden="yes"/> 
							</xsl:otherwise>
						</xsl:choose>
						<ui:column id="old-env-status" vza-id="event_log.parameter.old_status"
							apply-templates="yes" title="{sw:text('Old Status')}"/>
						<ui:column id="old-env-transition" vza-id="event_log.parameter.old_transition" hidden="yes"
							vza-sort-with="old-env-status" vza-sort-ord="1"/>
						<ui:column id="env-status" vza-id="event_log.parameter.new_status" apply-templates="yes"
							title="{sw:text('Status Obtained')}"/>
						<ui:column id="env-transition" vza-id="event_log.parameter.new_transition" hidden="yes"
							vza-sort-with="env-status" vza-sort-ord="1"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-from-vza">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="sql-where"> 
					pager.event_log.category='env_status'
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="20.00.00.00.00">
			<xsl:choose>
				<xsl:when test="$single-ve">
					<ui:tab-bar id="vzve" current-tab="logs" current-subtab="status"/>
					<ui:properties>
						<ui:form-get/>
						<ui:contains-date-control/>
						<ui:description width="full">
							<sw:text> On this screen you can see how the Container status has been changing. <br/>Use the search to filter the relevant records by their date. <br/>Clicking on the Container name displays the Container summary information.
							</sw:text>
						</ui:description>
					</ui:properties>
				</xsl:when>
				<xsl:otherwise>
					<ui:tab-bar id="alerts-events" current-tab="events"/>
					<ui:properties>
						<ui:contains-date-control/>
						<ui:description width="full">
							<sw:text> On this screen you can view the information on status changes for all the Containers. <br/>Use the search to filter the relevant records by their date/Container/HN. <br/>Click on a Container or HN name to view the properties of this Container or HN.
							</sw:text>
						</ui:description>
					</ui:properties>
				</xsl:otherwise>
			</xsl:choose>

			<ui:content>
				<ui:block width="full">
					<ui:browse item-name="{sw:text('records')}" title="{sw:text('Status Changes')}">
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						<ui:browse-empty-msg>
							<xsl:choose>
								<xsl:when test="$single-ve">
									<sw:text>No registered status changes.</sw:text>
								</xsl:when>
								<xsl:otherwise>
									<sw:text>No registered status changes.</sw:text>
								</xsl:otherwise>
							</xsl:choose>
						</ui:browse-empty-msg>
					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/trace.xsl"/>
	<sw:include href="/lib/core/browse-filter-vza.xsl"/>


</xsl:stylesheet>
