<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred global"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:global="http://www.swsoft.com/xsl/cp/global" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:authm="http://www.swsoft.com/xsl/cp/authm">

	<sw:include href="/lib/swa/authm.xsl"/>

	<xsl:template mode="screen" match="/">
		<ui:body-screen>
			<ui:content>
				<xsl:variable name="realm-eid"
					select="sw:base64-decode(sw:param('realm_eid'))"/>
				<ui:raw>|<xsl:for-each select="sw:param('login')"
							><xsl:value-of
							select="local:seek-group(.,$realm-eid)"/>|</xsl:for-each></ui:raw>
			</ui:content>
		</ui:body-screen>
	</xsl:template>

	<!-- Find group by name and realm and return SID or empty string -->
	<func:function name="local:seek-group">
		<xsl:param name="group-name"/>
		<xsl:param name="realm-eid"/>

		<xsl:variable name="result-attrs-rtf">
			<name>objectSid</name>
		</xsl:variable>
		<xsl:variable name="result-attrs" select="exsl:node-set($result-attrs-rtf)"/>
		<xsl:variable name="vz-realm-id" select="sw:internal-realm-id()"/>
		
		<xsl:variable name="groups-rtf">
			<xsl:choose>
				<xsl:when test="$realm-eid=$global:system-realm-id 
					or $realm-eid=$vz-realm-id">
					<xsl:variable name="sys-group" select="authm:get-group(sw:base64-decode($group-name),$realm-eid,false())"/>
					<xsl:if test="not($sys-group[self::error])">
						<group>
							<xsl:copy-of select="$sys-group/*"/>
						</group>
					</xsl:if>
				</xsl:when>
				<xsl:otherwise>
					<xsl:variable name="sa-filter-rtf">
						<attr>
							<name>sAMAccountName</name>
							<value><xsl:value-of select="$group-name"/></value>
							<realm><xsl:value-of select="$realm-eid"/></realm>
						</attr>
					</xsl:variable>
					<xsl:variable name="cn-filter-rtf">
						<attr>
							<name>CN</name>
							<value><xsl:value-of select="$group-name"/></value>
							<realm><xsl:value-of select="$realm-eid"/></realm>
						</attr>
					</xsl:variable>
					<xsl:variable name="sa-groups"
						select="authm:get-groups('',exsl:node-set($sa-filter-rtf),$result-attrs)"/>
					<xsl:choose>
						<xsl:when test="count($sa-groups/authm/group)=0">
							<xsl:copy-of 
								select="authm:get-groups('',exsl:node-set($cn-filter-rtf),$result-attrs)/authm/group"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="$sa-groups/authm/group"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="groups" select="exsl:node-set($groups-rtf)"/>

		<xsl:choose>
			<xsl:when test="count($groups/group)=1">
				<func:result select="$groups/group[1]/data/attr[name='objectSid']/value"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
</xsl:stylesheet>
