<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred jobs date show format"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:date			="http://exslt.org/dates-and-times"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
  xmlns:browse		="http://www.swsoft.com/xsl/cp/browse" 
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:cred 			="http://www.swsoft.com/xsl/cp/cred"
  xmlns:jobs  		="http://www.swsoft.com/xsl/cp/jobs"  
  xmlns:show			="http://www.swsoft.com/xsl/cp/show"
  xmlns:env				="http://www.swsoft.com/xsl/cp/env"
  xmlns:format="http://www.swsoft.com/xsl/cp/format"
>
	<sw:include href="/lib/vt/env-core.xsl"/>		
	<sw:include href="/lib/core/jobs/core.xsl"/>
	<sw:include href="/lib/utils/format-datetime.xsl"/>	

	<xsl:param name="access-denied" select="not(cred:check('vzcp.full_control'))"/>

  <!-- check permissions to show this page -->
	<xsl:template mode="screen" match="/">	
	
	
		<xsl:variable name="cr-jobs" select="cred:check('vzcp.full_control')"/>
						
	  <xsl:variable name="filter-inited-rtf">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="jobs" url="/core/jobs/index" 
						item-url="/core/jobs/job"
					/>
	        <ui:cols sorting-col="title">
	        	<ui:column id="id" nav-type="id" hidden="yes">	
							<xsl:attribute name="for-select"><xsl:value-of select="sw:if($cr-jobs,'yes','no')"/></xsl:attribute>							
						</ui:column>
						<ui:column id="job-category-icon" title="" width="20" apply-templates="yes"
							filter-title="{sw:text('Action Icon')}"
						/>
	        	<ui:column id="title" nav-type="title" title="{sw:text('Title')}" filter="auto">
							<xsl:attribute name="show-url"><xsl:value-of select="sw:if($cr-jobs,'yes','no')"/></xsl:attribute>
						</ui:column>	
						<ui:column id="description" title="{sw:text('Description')}" filter="auto"
							custom-hidden="yes"
							custom-filter-hidden="yes"
	        	>
						</ui:column>
						<ui:column id="job-category" title="{sw:text('Action')}" apply-templates="yes"
							 custom-hidden="yes"
						> <!-- filter="select"  -->
							<xsl:copy-of select="jobs:categories()"/>
						</ui:column>
						<ui:column id="env-list" title="{sw:text('Container(s)')}" filter="auto" apply-templates="yes">
						</ui:column>

						<ui:column id="job-next-start" data-type="datetime"  title="{sw:text('Next Start')}" 
							filter="interval" apply-templates="yes"
	        		filter-from-title="{sw:text('From')}" filter-to-title="{sw:text('To')}" 
	        		filter-from-tip="next_from_filter" filter-to-tip="next_to_filter"	        		
	        	>	        	
	        	</ui:column>
	        	<ui:column id="job-enabled" data-type="bool" align="center" title="{sw:text('Enabled')}" apply-templates="yes" width="20" filter="auto"/>
	        </ui:cols>
				</xsl:with-param>
			</xsl:call-template>
    </xsl:variable>
    
    <!-- Load all jobs -->
		<xsl:variable name="jobs" select="jobs:list()"/>    
    <!-- 
    	Force VZCP core to preload all affected VEs.
    	It can speed up VEs title seeking during ui:env-eid-link processing in browse rendering.
    -->
    <xsl:variable name="affected-ves" select="env:get-env($jobs/ves/eid)/env"/>    
    
    <!-- Fill browser manually -->
    <xsl:variable name="filter-filled-rtf">
    	<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter-inited-rtf)"/>
				<xsl:with-param name="rows">					
	        <ui:browse-rows>
	        	<xsl:for-each select="$jobs">
	            <ui:row>
	            	<id>								
									<xsl:value-of select="id"/>
								</id>					
								<job-category-icon>
									<xsl:value-of select="category"/>
								</job-category-icon>
								<job-category>
									<xsl:value-of select="category"/>
								</job-category>
								<title>
									<xsl:value-of select="title"/>
								</title> 			
								<description>
									<xsl:value-of select="description"/>
								</description> 	
								<env-list>
									<xsl:for-each select="ves/eid">
										<ui:env-eid-link>
											<xsl:value-of select="."/>
										</ui:env-eid-link>
									</xsl:for-each>
								</env-list>
								<job-next-start>
									<xsl:if test="next-start!=''">
										<xsl:value-of select="sw:time2vzatime(next-start)"/>
									</xsl:if>
								</job-next-start>						
								<job-enabled>
									<xsl:value-of select="sw:if(enabled='false','0','1')"/>
								</job-enabled>
	            </ui:row>
	          </xsl:for-each> 
        	</ui:browse-rows>
        </xsl:with-param>    
			</xsl:call-template>
    </xsl:variable>

		<ui:screen id="14.00.00.00.00">
			
			<ui:properties>
				<ui:no-default-form/>	
				<ui:form-get/>
				<ui:contains-date-control/>
				<ui:description>
					<sw:text>
						<xsl:with-param name="time" select="format:date-time(date:seconds())"/>
						This screen helps automate such a routine maintenance operation as backing up Containers.
						<br/>Here you can create a new backup task or review the tasks you have already scheduled.
						<br/><br/>Now is %{time}.
					</sw:text>
				</ui:description>
			</ui:properties>
			<ui:tab-bar id="jobs" current-tab="index"/>	    
    	<ui:content>    	    	
    
    		<ui:block width="full">														
					<ui:browse>
						<xsl:attribute name="title"><sw:text>Scheduled Tasks</sw:text></xsl:attribute>
						
						<ui:browse-js-many>
							<ui:warn><sw:text>Select at least one task!</sw:text></ui:warn>
						</ui:browse-js-many>
						<ui:browse-js-one>
							<ui:warn><sw:text>Select only one task!</sw:text></ui:warn>
						</ui:browse-js-one>
						
						<ui:filter>
							<xsl:copy-of select="$filter-filled-rtf"/>
						</ui:filter>

						<ui:browse-buttons type="list-selection">							

							<xsl:if test="$cr-jobs">
								<ui:button icon="scheduler_task_new" submit-href="manage?mode=new&amp;unit-type=vz.backup.ves" 
									require-items="false" sandclock="false" tip="new_job"
									new-obj-title="{sw:text('Task')}"  
								>
				          <sw:text>New Task</sw:text>
				        </ui:button>
			        	<ui:button type="list-selection" tip="run_jobs_now" icon="service_start" 
			        		script="if (!onlyOne()) return false;" name="run"
			        		submit-href="{$baseurl}/core/jobs/run?id-from=selected-one"
			        	>			        		
									<sw:text>Run Now</sw:text>
								</ui:button>
								<ui:button type="list-selection" tip="enable_job" icon="enable" script="if (!atLeastOne()) return false;" name="enable">
									<sw:text>Enable</sw:text>
								</ui:button>
								<ui:button type="list-selection" tip="disable_job" icon="disable" script="if (!atLeastOne()) return false;" name="disable">
									<sw:text>Disable</sw:text>
								</ui:button>
								<ui:button type="list-selection" tip="delete_job" icon="delete" confirmation="{sw:text('Are you sure you want to delete the selected task(s)?')}" script="if (!atLeastOne()) return false;" name="remove" width="150">
									<sw:text>Delete</sw:text>
								</ui:button>
							</xsl:if>
						</ui:browse-buttons>

						<!-- form definition for other controls -->
			      <ui:form action="list-control"/>
			
			      <ui:browse-empty-msg>
			        <sw:text>No tasks.</sw:text>
			      </ui:browse-empty-msg>
	
	      	</ui:browse>
      	</ui:block>
    	</ui:content>          
		</ui:screen>
	
  </xsl:template>  

	<sw:include href="/lib/screen.xsl"/>

	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	  
</xsl:stylesheet>
