<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred local op_log browse show"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"  
	xmlns:cred  		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:jobs			="http://www.swsoft.com/xsl/cp/jobs"
	xmlns:op_log			="http://www.swsoft.com/xsl/cp/op_log"
	xmlns:browse		="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:show			="http://www.swsoft.com/xsl/cp/show"   
	xmlns:env			="http://www.swsoft.com/xsl/cp/env"   
  xmlns:tasks  ="http://www.swsoft.com/xsl/cp/tasks"     	
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/core/browse-filter-vza.xsl"/>
	<sw:include href="/lib/swa/op_log.xsl"/>   
	<sw:include href="/lib/core/jobs/core.xsl"/>		
	<sw:include href="/lib/vt/env-select.xsl"/>

	<xsl:param name="access-denied" select="not(cred:check('vzcp.full_control'))"/>	

	<!-- Init data -->
	<xsl:variable name="job-get-id" select="sw:base64-decode(string($request/http_request/get/parameter[name = 'id']/value))"/>
	<xsl:variable name="job-session-id" select="sw:sesgetstr('job-id')"/>
	<xsl:variable name="job-id">
		<xsl:choose>
			<xsl:when test="$job-get-id!=''">
				<xsl:if test="sw:sesputstr('job-id',$job-get-id)"/>
				<xsl:value-of select="$job-get-id"/>
			</xsl:when>
			<xsl:when test="$job-session-id!=''">
				<xsl:value-of select="$job-session-id"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="job" select="jobs:find-by-id($job-id)"/>  	
 	<!-- /Init data -->

  <xsl:template mode="screen" match="/">    	  


    <ui:screen id="14.00.00.02.00">
    	<xsl:if test="sw:sesputstr('job-title',$job/title)"/>
    	
      <ui:properties>
				<ui:contains-date-control/>      
      </ui:properties>

			<xsl:choose>	  	
				<!-- No task  ID -->
	  		<xsl:when test="not($job-id!='')">
	  			<sw:die>
	  				No Task ID in session and/or get data.
	  			</sw:die>
	  		</xsl:when>
	  		<!-- /No task-->	
		  	<!-- Error occurred -->
	  		<xsl:when test="name($job)='error'">
	  			<xsl:call-template name="local:show-error">
	  				<xsl:with-param name="error" select="$job"/>
	  			</xsl:call-template>
	  		</xsl:when>
	  		<!-- /Error occurred -->
		 		<!-- Received data  -->
	  		<xsl:otherwise>
	  			<xsl:call-template name="local:show-data"/>	  				
	  		</xsl:otherwise>
	  		<!-- /Received data-->
			</xsl:choose>
			
    </ui:screen>    
  </xsl:template>
  
  <!-- Show data -->
	<xsl:template name="local:show-data">
	
		<ui:data-options id="job-category">
			<xsl:copy-of select="jobs:categories()"/>
		</ui:data-options>
		
		<ui:content>
			<ui:block width="max">
				
				<!-- Show Info -->			
				<ui:rows title="{sw:text('Task Details')}">								
					<ui:row>
						<ui:cell-label>
							<sw:text>Title</sw:text>
						</ui:cell-label>
						<ui:cell-text>
							<xsl:value-of select="$job/title"/>
						</ui:cell-text>
					</ui:row>	
					<ui:row>
						<ui:cell-label>
							<sw:text>Enabled</sw:text>
						</ui:cell-label>
						<ui:cell-text>
							<xsl:value-of select="sw:if($job/enabled='true',sw:text('Yes'),sw:text('No'))"/>
						</ui:cell-text>
					</ui:row>	
					<ui:row>
						<ui:cell-label>
							<sw:text>Next start</sw:text>
						</ui:cell-label>
						<ui:cell-text>
							<ui:job-next-start>
								<xsl:value-of select="$job/next-start"/>								
							</ui:job-next-start>
						</ui:cell-text>
					</ui:row>
					<ui:row>
						<ui:cell-label>
							<sw:text>Action</sw:text>
						</ui:cell-label>
						<ui:cell-text>
							<ui:job-category-icon>
								<xsl:value-of select="$job/category"/>
							</ui:job-category-icon>
							<ui:text>&#160;</ui:text>
							<ui:job-category>
								<xsl:value-of select="$job/category"/>
							</ui:job-category>
						</ui:cell-text>
					</ui:row>
					<xsl:if test="$job/ves/eid">
						<ui:row>
							<ui:cell-label>
								<sw:text>Containers to process</sw:text>
							</ui:cell-label>
							<ui:cell-text>
								<xsl:call-template name="env:show-links">
									<xsl:with-param name="eids" select="$job/ves/eid"/>
								</xsl:call-template>
							</ui:cell-text>
						</ui:row>
					</xsl:if>
				</ui:rows>
				<!-- /Show Info -->
				
				<xsl:if test="$job/description!=''">
					<ui:rows title="{sw:text('Description')}">			
						<ui:row>
							<ui:cell-text>
								<xsl:value-of select="$job/description"/>
							</ui:cell-text>
						</ui:row>	
					</ui:rows>
				</xsl:if>
				
				<!-- Show Log -->				
				<xsl:call-template name="local:show-log"/>								
				<!-- /Show Log -->
				
			</ui:block>
		</ui:content>
		
	</xsl:template>
  
  
  <!-- Show Log -->
	<xsl:template name="local:show-log">
	
		<!-- Init Filter -->
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="job-log" url="/core/jobs/job"/>
	        <ui:cols sorting-col="time" sorting-direction="desc">
						<ui:column id="time" vza-id="op_log.time" data-type="datetime"
							title="{sw:text('Time')}" filter-from-title="{sw:text('Time From')}"
							filter-to-title="{sw:text('Time to')}" filter-from-tip="action_from_filter"
							filter-to-tip="action_to_filter" filter="interval"/>
						<ui:column id="id" vza-id="op_log.id" hidden="yes"
							for-select-condition="task-status=1 or task-status=2"
						>
						</ui:column>
						<ui:column id="task-op" vza-id="op_log.op" apply-templates="yes"
							title="{sw:text('Operation')}"/>
						<ui:column id="task-status" vza-id="op_log.status" apply-templates="yes"
							title="{sw:text('Status')}" filter="select">
							<ui:filter-option value="1" title="{sw:text('Started')}"/>
							<ui:filter-option value="2" title="{sw:text('In Progress')}"/>
							<ui:filter-option value="3" title="{sw:text('Completed')}"/>
							<ui:filter-option value="4" title="{sw:text('Failed')}"/>
							<ui:filter-option value="0" title="{sw:text('Other')}"/>
						</ui:column>
						<ui:column id="taskid" vza-id="op_log.task_id" hidden="yes"/>						
						<ui:column id="task-details" apply-templates="yes" title=""/>
	        </ui:cols>
				</xsl:with-param>
			</xsl:call-template>
    </xsl:variable>		
		<!-- /Init Filter -->
		
		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-from-vza">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="sql-where">
					pager.op_log.task_id='<xsl:value-of select="sw:sql-escape($job-id)"/>'
					and pager.op_log.latest=true
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		
		<ui:rows>
			<xsl:attribute name="title">
  			<sw:text>Logged Operations</sw:text>  			
  		</xsl:attribute>  
  		
		<ui:browse>
			<xsl:attribute name="title">
  			<sw:text>Operations</sw:text>  			
  		</xsl:attribute>  
			<ui:filter>
      	<xsl:copy-of select="$filter"/>
      </ui:filter>		
      		
      <ui:browse-empty-msg stop-sign="no">
        <sw:text>No log records for this task.</sw:text>
      </ui:browse-empty-msg> 
    </ui:browse>-->
		<!-- /Show Log -->
		</ui:rows>
	</xsl:template>
  
  <!-- Show some VZA error -->
	<xsl:template name="local:show-error">
		<xsl:param name="error" select="/.."/>
		<ui:content>
			<ui:block>
				<ui:operation-problem>
					<ui:type>vza-error</ui:type>
					<ui:descr>
						<sw:text>Error reading the operation information.</sw:text>
					</ui:descr>
					<xsl:if test="$error">
						<ui:vza-error>
							<xsl:copy-of select="$error/*"/>
						</ui:vza-error>
					</xsl:if>
					<ui:reason>
						<sw:text>The requested operation has been removed from the Virtuozzo database.</sw:text>
					</ui:reason>
					<ui:solution>
						<sw:text>Return to the task list and select another task.</sw:text>
					</ui:solution>
				</ui:operation-problem>
			</ui:block>
		</ui:content>
	</xsl:template>
	<!-- /Show some VZA error -->

  <sw:include href="/lib/screen.xsl"/>  

</xsl:stylesheet>
