<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local show voc env hn"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:show	="http://www.swsoft.com/xsl/cp/show"   
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"   		
	xmlns:env	="http://www.swsoft.com/xsl/cp/env"   	
	xmlns:hn	="http://www.swsoft.com/xsl/cp/hn"   	
	xmlns:licenses="http://www.swsoft.com/xsl/cp/licenses"  	
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"  
 >
 
 	<!-- Import required modules -->
	<sw:include href="/lib/swa/licensem.xsl"/>	
	<sw:include href="/lib/core/licenses/core-ui.xsl"/>	

 	<sw:include href="/lib/vt/env-core.xsl"/>
 	<sw:include href="/lib/vt/env-select.xsl"/>
 	<sw:include href="/lib/vt/hn-core.xsl"/>
 	<sw:include href="/lib/vt/hn-select.xsl"/>
 	<!-- /Import required modules -->

  <xsl:param name="wiz_code" 					select="'add_license_core'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="step-cred" 			select="$step_data/@cred"/>
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>
  <xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>

	<!-- check detail permissions to req -->
	<xsl:param name="access-denied" select="$step-cred!='' and not(cred:check($step-cred))"/>
  
	<!-- Step "Input Key" -->
  <xsl:template name="step_input_key">
  
  	<ui:screen id="{$screen-id}">
  	
	    <ui:properties>
	      <ui:refresh-type>none</ui:refresh-type>
	      <ui:form-get/>    
	    </ui:properties>
	    
	    <ui:content>
	      <ui:hidden name="step" value="input_key"/>    
	      <ui:block mode="edit">
					
	      	<ui:rows title="{sw:text('Product Key')}">	   			      	
						<ui:row>
							<ui:cell-input close="false" id="key_content" required="true" maxlength="1000" width="60"
								value="{$form/key/content}"
							/>
							<ui:cell-text show-asterisk="true" open="false">&#160;</ui:cell-text>
						</ui:row>						
					</ui:rows>
	      
	        <ui:buttons>
	        	<xsl:call-template name="wiz:showButtons">
	        		<xsl:with-param name="submit-sandclock" select="false()"/>	        		
	        	</xsl:call-template>
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template> 
  
  
	<!-- Step "Upload file" -->
  <xsl:template name="step_upload_file">
  
  	<ui:screen id="{$screen-id}">
  	
	    <ui:properties>
	      <ui:refresh-type>none</ui:refresh-type>    
	    </ui:properties>
	    
	    <ui:content>
	      <ui:hidden name="step" value="upload_file"/>    
	      <ui:block mode="edit">
					
	      	<ui:rows>
						<ui:row>
							<ui:cell colspan="2" label="filefile">
								<sw:text>Either specify the path to the license file in the field below:</sw:text>
							</ui:cell>
						</ui:row>
						<ui:row>
							<ui:cell-file id="file" />
						</ui:row>
						<ui:row>
							<ui:cell colspan="2" label="text">
								<sw:text>or paste the license file contents in the area below:</sw:text>
							</ui:cell>
						</ui:row>
						<ui:row>
							<ui:cell-inputblock id="text" maxlength="10000" rows="25" width="80"
								style="font-family: Courier New">
								<xsl:value-of select="$form/file/text" />
							</ui:cell-inputblock>
						</ui:row>
					</ui:rows>
	      
	        <ui:buttons>
	        	<xsl:call-template name="wiz:showButtons">
	        		<xsl:with-param name="submit-sandclock" select="false()"/>	        		
	        	</xsl:call-template>
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template> 
  
  
  <!-- Step "Review -->
  <xsl:template name="step_review">
  	
		<xsl:variable name="lic" select="$form/parsed/license"/>
  
  	<ui:screen id="{$screen-id}">
  	
	    <ui:properties>
	      <ui:refresh-type>none</ui:refresh-type>    
	    </ui:properties>
	    
	    <ui:content>
	      <ui:hidden name="step" value="review"/>    
	      <ui:block>

					<xsl:call-template name="local:show-hn-selector"/>
				
					<xsl:call-template name="licenses:view-license">
						<xsl:with-param name="lic" select="$lic"/>
						<xsl:with-param name="show-status" select="false()"/>			
						<xsl:with-param name="show-hw" select="false()"/>			
					</xsl:call-template>
					
	        <ui:buttons>
	        	<xsl:call-template name="wiz:showButtons">
	 						<xsl:with-param name="submit-title" select="sw:text('Install')" />
  						<xsl:with-param name="submit-tip" select="'license_install_submit'" />
	        	</xsl:call-template>
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>  
  
  <!-- Show HN selector -->
  <xsl:template name="local:show-hn-selector">
  
  	<xsl:variable name="hn-eid" select="$form/target/hn-eid"/>
  	
  	<!-- Preload HN title -->
  	<xsl:variable name="hn-title">
  		<xsl:if test="$hn-eid!=''">
				<xsl:value-of select="env:env2title(env:get-env($hn-eid)/env)"/>
			</xsl:if>
  	</xsl:variable>  	
  	<!-- /Preload some data -->  
  	
		<ui:rows title="{sw:text('Install License to')}">
			<ui:row>
				<ui:cell-label>
					<sw:text>Hardware Node</sw:text>
				</ui:cell-label>
				<xsl:choose>
					<xsl:when test="$form/target/license-hwid!='' or $form/def/no-local-license">
						<ui:cell-text>
							<ui:text>
								<xsl:value-of select="$hn-title"/>
							</ui:text>
							<xsl:if test="$form/def/no-local-license">
								<!--<ui:text-disabled>
									<br/>
									<sw:text>
										No Hardware Node can be selected because no Parallels Infrastructure Manager license is installed.
									</sw:text>
								</ui:text-disabled>-->
							</xsl:if>
						</ui:cell-text>
					</xsl:when>
					<xsl:otherwise>
						<ui:cell-selector id="hn" align="left" value="{$hn-title}" required="true"
							code-value="{$hn-eid}"
							link-tip="select_hn" 
							link-onclick="open_details('{$baseurl}/vt/hns/select-one-popup?id=hn');return false;"
							link-caption="{sw:text('Select...')}"				      
						/>
					</xsl:otherwise>
				</xsl:choose>
			</ui:row>
		</ui:rows>
		
  </xsl:template>
  <!-- /Show HN selector -->
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
			<xsl:choose>
				<xsl:when test="$step = 'review'">
					<xsl:call-template name="step_review"/>
				</xsl:when>
				<xsl:when test="$step = 'input_key'">
					<xsl:call-template name="step_input_key"/>
				</xsl:when>
				<xsl:when test="$step = 'upload_file'">
					<xsl:call-template name="step_upload_file"/>
				</xsl:when>
				<xsl:otherwise>
					<sw:die>
						Uknown step id
					</sw:die>
				</xsl:otherwise>
			</xsl:choose>
	</xsl:template>			
	
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/common.xsl"/>			

		
</xsl:stylesheet>
