<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred  show local"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
  xmlns:browse		="http://www.swsoft.com/xsl/cp/browse"
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"
  xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:cred  		="http://www.swsoft.com/xsl/cp/cred"
  xmlns:error			="http://www.swsoft.com/xsl/cp/error"
  xmlns:show			="http://www.swsoft.com/xsl/cp/show"
 	xmlns:licenses	="http://www.swsoft.com/xsl/cp/licenses"
	xmlns:licensem	="http://www.swsoft.com/xsl/cp/licensem"
>

	<sw:include href="/lib/core/browse-filter-vza.xsl"/>
	<sw:include href="/lib/core/licenses/core-ui.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>

	<xsl:param name="access-denied" select="not(cred:check('vzcp.license'))"/>
	<xsl:variable name="warning" select="sw:param('warning')"/>

	<xsl:template mode="screen" match="/">

		<!-- Process defined screen arguments, show the special warnings, errors and so on -->
		<xsl:call-template name="local:process-screen-arguments"/>

		<!-- Make screen content -->
		<ui:screen id="25.00.00.00.00">

	    <ui:properties>
	      <ui:no-default-form/>
	      <ui:form-get/>
	      <ui:contains-date-control/>
	      <xsl:call-template name="local:show-description"/>
	    </ui:properties>

			<ui:tab-bar id="licenses" current-tab="index"/>
			<ui:content>
				<ui:block>
					<xsl:call-template name="local:show-list"/>
				</ui:block>
			</ui:content>
		</ui:screen>

  </xsl:template>

	<!-- Show some VZA error -->
	<xsl:template name="local:show-list">
		<xsl:variable name="classes" select="licensem:classes()"/>
		<xsl:variable name="statuses" select="licensem:statuses()"/>

	  <xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="all-license-core" url="/core/licenses/index"
						item-url="/core/licenses/license"
					/>
	        <ui:cols sorting-col="key-number">
	        	<ui:column id="id" title="{sw:text('Serial Number')}" custom-hidden="yes" custom-filter-hidden="yes"
	        		filter="auto"  vza-id="license.serial"
	        	>
							<xsl:attribute name="for-url">yes</xsl:attribute>
							<xsl:attribute name="for-select">yes</xsl:attribute>
							<xsl:attribute name="show-url">yes</xsl:attribute>
						</ui:column>
						<ui:column id="key-number" show-url="yes" filter="auto" title="{sw:text('Key Number')}"
							 vza-id="license.key_number"/>
<!--	        	<ui:column id="license-class" nav-type="title" title="{sw:text('Class')}" filter="select" show-url="no"
	        		vza-id="license.class" apply-templates="yes"
	        	>
	        		<xsl:copy-of select="$classes[not(@hidden = 'yes')]"/>
						</ui:column>
-->						
						<ui:column id="env-title-link" title="{sw:text('Hardware Node')}" filter="auto" vza-id="env.config.hostname" apply-templates="yes">
							<ui:column-layout-options eid-node="hn-eid" vza-type-node="hn-type"/>
						</ui:column>
						<ui:column id="hn-eid" vza-id="env.eid" hidden="yes" for-url="yes" for-select="yes"/>
						<ui:column id="hn-type" vza-id="env.config.type" hidden="yes"/>
						<ui:column id="envelope-type" vza-id="license.envelope_type" hidden="yes"/>
						<!-- Post status -->
						<ui:column id="license-status" title="{sw:text('Status')}" filter="select"
							vza-id="license.status" apply-templates="yes"
						>
	        		<xsl:copy-of select="$statuses"/>
						</ui:column>
						<!--
						<ui:column id="status-src" title="{sw:text('Status')}" filter="select" hidden="yes">
	        		<xsl:copy-of select="$statuses"/>
						</ui:column>
						<ui:column id="license-status-icon" hidden="yes"/>
						<ui:column id="license-status" title="{sw:text('Status')}" apply-templates="yes">
						</ui:column>
						-->
						<!-- Post exprired -->
						<ui:column id="license-expiration" data-type="datetime" custom-filter-hidden="yes"
							vza-id="license.expiration"  apply-templates="yes"
							title="{sw:text('Expiration')}" filter-from-title="{sw:text('Expired From')}"
							filter-to-title="{sw:text('Expired To')}" filter-from-tip="expired_from_filter"
							filter-to-tip="expired_to_filter" filter="interval"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
    </xsl:variable>

    <xsl:variable name="filter-rtf">
    	<xsl:call-template name="browse:fill-from-vza">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
			</xsl:call-template>
    </xsl:variable>
    <xsl:variable name="filter" select="exsl:node-set($filter-rtf)"/>

		<ui:browse width="full">
			<xsl:attribute name="title"><sw:text>Licenses</sw:text></xsl:attribute>

			<ui:browse-js-array name="refresh">
				<ui:warn>
					<sw:text>You cannot refresh the selected licenses.</sw:text>
				</ui:warn>
				<xsl:for-each select="$filter/ui:browse-rows/ui:row[envelope-type=$licenses:def-envelop-key]/id">
					<ui:value>
						<xsl:value-of select="."/>
					</ui:value>
				</xsl:for-each>
			</ui:browse-js-array>

			<ui:browse-js-many>
				<ui:warn>
					<sw:text>Please select at least one license.</sw:text>
				</ui:warn>
			</ui:browse-js-many>

			<ui:browse-empty-msg>
				<sw:text>No installed licenses.</sw:text>
			</ui:browse-empty-msg>


			<ui:filter>
				<xsl:copy-of select="$filter"/>
			</ui:filter>

			<ui:browse-buttons type="list-selection">

				<ui:button tip="lic_install_key" icon="license_key"
					new-obj-title="{sw:text('License Key')}"
					submit-href="add?license-type=key" require-items="false"
				>
					<sw:text>Install License Key</sw:text>
				</ui:button>

				<ui:button tip="lic_install_file" icon="key"
					new-obj-title="{sw:text('License File')}"
					submit-href="add?license-type=file" require-items="false"
				>
					<sw:text>Install License File</sw:text>
				</ui:button>

				<ui:button type="list-selection" name="refresh" tip="refresh_licenses"
					icon="license_update"
					script="if(!atLeastOne() || !check_refresh_array()) return false;"
				>
					<sw:text>Refresh</sw:text>
				</ui:button>
			</ui:browse-buttons>

			<!-- form definition for other controls -->
			<ui:form action="list-control"/>

		</ui:browse>

	</xsl:template>

	<!-- Process screen arguments -->
	<xsl:template name="local:process-screen-arguments">
		<xsl:choose>
			<xsl:when test="$warning='newhn'">
				<xsl:if
					test="error:put(sw:text('Additional Hardware Nodes cannot be registered because no Virtuozzo Group license is installed.'))"
				/>
			</xsl:when>
			<xsl:when test="$warning='unlicensed'">
				<xsl:if
					test="error:put(sw:text('You have no valid Parallels Infrastructure Manager license installed. Please install a license to proceed.'))"
				/>
			</xsl:when>
		</xsl:choose>

	</xsl:template>
	<!-- /Process screen arguments -->


	<xsl:template name="local:show-description">
		<xsl:choose>
			<!-- No VZCC license, show special warning.
					 Skip description if warning was already shown on screen
			-->
			<xsl:when test="$warning!='' and not(licensem:get-active('VZSRV'))">
				<ui:description show-alert="true" mandatory="true">
					<sw:text>
						You have no valid Parallels Infrastructure Manager license installed. <br/> Only License Management is now available. Please install a valid license to have a full access to Parallels Infrastructure Manager.
					</sw:text>
				</ui:description>
			</xsl:when>
			<xsl:otherwise>
				<ui:description mandatory="true">
					<sw:text>
						On this screen you can see information on the available Virtuozzo Server licenses and manage them.
					</sw:text>
				</ui:description>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
