<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl  cred  func"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:func			="http://exslt.org/functions"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred  		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local  		="http://www.swsoft.com/xsl/cp/local"
  xmlns:show 			="http://www.swsoft.com/xsl/cp/show"
 	xmlns:licenses	="http://www.swsoft.com/xsl/cp/licenses"
 	xmlns:licensem	="http://www.swsoft.com/xsl/cp/licensem"
>
  <sw:include	href="/lib/common.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>
	<sw:include href="/lib/core/licenses/core-ui.xsl"/>

	<xsl:param name="access-denied" select="not(cred:check('vzcp.license'))"/>

  <!-- show backup details -->
  <xsl:template mode="screen" match="/">

    <!-- set new ID from GET -->
		<xsl:variable name="get-id" select="/http_request/get/parameter[name = 'id']/value"/>
		<xsl:variable name="get-hn-eid" select="/http_request/get/parameter[name = 'hn-eid']/value"/>
		<xsl:if test="$get-id">
			<xsl:if test="sw:sesputstr('license-id',sw:base64-decode($get-id))"/>
			<sw:die test="$get-hn-eid=''">
				hn-eid GET parameter should be specified
			</sw:die>
			<xsl:if test="sw:sesputstr('license-hn-eid',sw:base64-decode($get-hn-eid))"/>
		</xsl:if>
		<!-- /set new ID from GET -->

		<!-- Init data -->
		<xsl:variable name="license-id" select="sw:sesgetstr('license-id')"/>
		<xsl:variable name="license-hn-eid" select="sw:sesgetstr('license-hn-eid')"/>
		<xsl:variable name="license" select="licensem:get($license-hn-eid,true(),$license-id)"/>

    <ui:screen id="25.00.00.00.01">


      <ui:properties>
      </ui:properties>

      <xsl:choose>
      	<!-- Error occurred -->
	  		<xsl:when test="$license-id='' or not($license)">
	  			<xsl:if test="sw:sesputstr('license-title',sw:text('Unknown'))"/>
	  			<xsl:call-template name="local:show-error">
	  				<xsl:with-param name="error" select="$license"/>
	  			</xsl:call-template>
	  		</xsl:when>
	  		<!-- /Error occurred -->
      	<!-- Error occurred -->
	  		<xsl:when test="$license/error">
	  			<xsl:if test="sw:sesputstr('license-title',sw:text('Unknown'))"/>
	  			<xsl:call-template name="local:show-vza-error">
	  				<xsl:with-param name="error" select="$license/error"/>
	  			</xsl:call-template>
	  		</xsl:when>
	  		<!-- /Error occurred -->

	  		<!-- Show loaded backup -->
      	<xsl:otherwise>
      		<xsl:if test="sw:sesputstr('license-title',$license/param[id='key_number']/value)"/>
		      <ui:content>
		        <ui:block>
							 <xsl:call-template name="licenses:view-license">
								<xsl:with-param name="lic" select="$license"/>
								<xsl:with-param name="hn-eid" select="$license-hn-eid"/>
							</xsl:call-template>
						</ui:block>
					</ui:content>
				</xsl:otherwise>
			</xsl:choose>
    </ui:screen>
  </xsl:template>

  <!-- Show error -->
	<xsl:template name="local:show-error">
		<ui:content>
			<ui:block>
				<ui:operation-problem>
					<ui:type>custom</ui:type>
					<ui:descr>
						<sw:text>The specified license has not been found.</sw:text>
					</ui:descr>
					<ui:reason>
						<sw:text>The specified license has been removed.</sw:text>
					</ui:reason>
					<ui:solution>
						<sw:text>Return to the license list and select another license.</sw:text>
					</ui:solution>
				</ui:operation-problem>
			</ui:block>
		</ui:content>

	</xsl:template>

  <!-- Show some VZA error -->
	<xsl:template name="local:show-vza-error">
		<xsl:param name="error"/>
		<ui:content>
			<ui:block>
				<ui:operation-problem>
					<ui:type>vza-error</ui:type>
					<ui:descr>
						<sw:text>Error reading the license details.</sw:text>
					</ui:descr>
					<ui:vza-error>
						<xsl:copy-of select="$error/*"/>
					</ui:vza-error>
					<ui:reason>
						<sw:text>The specified license has been removed.</sw:text>
					</ui:reason>
					<ui:solution>
						<sw:text>Return to the backup list and select another license backup.</sw:text>
					</ui:solution>
				</ui:operation-problem>
			</ui:block>
		</ui:content>
	</xsl:template>

  <sw:include href="/lib/screen.xsl"/>
  <sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
