<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred vzenv"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
  xmlns:hn="http://www.swsoft.com/xsl/cp/hn"  
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
>
 
	<sw:include href="/lib/vt/hn-select.xsl"/>		

  <!-- check permissions to show this page -->
	<xsl:variable name="cr-problem-report" select="cred:check('vzcp.support.troubleshooting')"/>

  <xsl:param name="wiz_code" select="'problem_report'"/>
  
	<xsl:variable name="step_data"	select="wiz:getStep()"/>
	<xsl:variable name="step"		select="$step_data/@id"/>
	<xsl:variable name="screen-id"	select="$step_data/@screenid"/>

  <xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<xsl:param name="access-denied" select="not($cr-problem-report)"/>

  
  <!-- Wizard, Step 'Submit' -->
  <xsl:template name="step_submit">
  	<ui:screen id="{$screen-id}">
  	
		<ui:properties>
			<ui:refresh-type>none</ui:refresh-type>
			<ui:description  mandatory="yes" width="600">
				<sw:text>
					Please specify your contact information, the problem details and press the "Report" button. <br/> The wizard will generate a problem report and send it to the Parallels support team. On the next screen you will be informed if the report has been sent and receive the unique ID of the problem.
				</sw:text>
			</ui:description>
			<ui:form-get/>
		</ui:properties>
    
    <ui:tab-bar id="support" current-tab="report-problem"/>
    <ui:content>
      <ui:hidden name="step" value="submit"/>    
      <ui:block mode="edit" width="600">
      	
   			<ui:rows title="{sw:text('Your Contact Information')}">
					<ui:row>
   					<ui:cell-label>
	        		<sw:text>Person Name</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="name" maxlength="256" required="true">
							<xsl:attribute name="value"><xsl:value-of select="$form/contact/name"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
					<ui:row>
   					<ui:cell-label>
	        		<sw:text>Company Name</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="company" maxlength="256" required="true">
							<xsl:attribute name="value"><xsl:value-of select="$form/contact/company"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
					<ui:row>
   					<ui:cell-label>
	        		<sw:text>E-mail</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="email" maxlength="256" required="true">
							<xsl:attribute name="value"><xsl:value-of select="$form/contact/email"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>
				</ui:rows>
					
				<ui:rows title="{sw:text('Problem Details')}">
	      	<xsl:variable name="hns" select="hn:list()/hn"/>
	      	<xsl:choose>
	      		<xsl:when test="count($hns)=1">
      				<ui:hidden id="hn_eid" value="{sw:master-eid()}"/>
	      		</xsl:when>
	      		<xsl:otherwise>
	      			<ui:row>
	      				<ui:cell-label>
	      					<sw:text>Hardware Node</sw:text>
	      				</ui:cell-label>
								<ui:cell-list id="hn_eid" value="{$form/problem/hn-eid}" required="true">
									<ui:list-item id="" title="{sw:text('-- Select --')}"/>
									<xsl:for-each select="$hns">
										<ui:list-item id="{eid}" title="{hostname}"/>
									</xsl:for-each>
								</ui:cell-list>	   
							</ui:row>
	      		</xsl:otherwise>
	      	</xsl:choose>
					<ui:row>
   					<ui:cell-label>
	        		<sw:text>Subject</sw:text>
	        	</ui:cell-label>
						<ui:cell-input id="subject" maxlength="256" required="true">
							<xsl:attribute name="value"><xsl:value-of select="$form/problem/subject"/></xsl:attribute>
						</ui:cell-input>
					</ui:row>	
					<ui:row>
   					<ui:cell-label label="descr" show-aster="true" valign="top">
	        		<sw:text>Problem Description</sw:text>
	        		</ui:cell-label>
					<ui:cell-inputblock required="true" id="descr" maxlength="65545" rows="10">
							<xsl:value-of select="$form/problem/descr"/>
						</ui:cell-inputblock>
					</ui:row>
				</ui:rows>
				
				<ui:rows title="{sw:text('Existing Problem Report')}">
					<ui:row>
						<ui:cell-label>
							<sw:text>Ticket ID</sw:text>
						</ui:cell-label>
						<ui:cell-input id="ticket_id" maxlength="256" value="{$form/problem/ticket-id}"/>
					</ui:row>			
				</ui:rows>
	
        <ui:buttons>
        	<xsl:call-template name="wiz:showButtons">
        		<xsl:with-param name="next-title" select="sw:text('Report')"/>
        		<xsl:with-param name="next-tip" select="'click_report_problem'"/>
        		<xsl:with-param name="next-sandclock" select="true()"/>
        	</xsl:call-template>
        </ui:buttons>
        
     	</ui:block>
    </ui:content>   
    </ui:screen>
  </xsl:template>
  
  
  <!-- Wizard, Step 'Final' -->
  <xsl:template name="step_final">
  	<ui:screen id="{$screen-id}">
  	
		<ui:properties>
			<ui:refresh-type>none</ui:refresh-type>
			<ui:description  mandatory="yes" width="600">
				<sw:text>
					Your problem report was sent to the Parallels support team.
				</sw:text>
			</ui:description>
			<ui:form-get/>
		</ui:properties>
    
    <ui:tab-bar id="support" current-tab="report-problem"/>
    <ui:content>
      <ui:hidden name="step" value="final"/>    
      <ui:block width="600">
      
      	<ui:rows title="{sw:text('Problem Information')}">
      		<ui:row>
      			<ui:cell-label>Your Problem ID</ui:cell-label>
      			<ui:cell><b><xsl:value-of select="$form/report/ticket-id"/></b></ui:cell>
      		</ui:row>
      	</ui:rows>
    		
        <ui:buttons>
        	<xsl:call-template name="wiz:showButtons">
        		<xsl:with-param name="submit-title" select="sw:text('Close')"/>
        		<xsl:with-param name="show-back" select="false()"/>
        		<xsl:with-param name="show-cancel" select="false()"/>
        	</xsl:call-template>
        </ui:buttons>
        
     	</ui:block>
    </ui:content>   
    </ui:screen>
  </xsl:template>  
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
			<xsl:choose>
			
				<xsl:when test="$step = 'intro'">
					<xsl:call-template name="step_intro"/>
				</xsl:when>
				<xsl:when test="$step = 'submit'">
					<xsl:call-template name="step_submit"/>
				</xsl:when>
				<xsl:when test="$step = 'final'">
					<xsl:call-template name="step_final"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="step_intro"/>
				</xsl:otherwise>
				
			</xsl:choose>
		
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>			
	
</xsl:stylesheet>
