<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz form auth local browse"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:auth="http://www.swsoft.com/xsl/cp/auth"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:func="http://exslt.org/functions"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" xmlns:form="http://www.swsoft.com/xsl/cp/form">

	<!-- show page everytime -->
	<xsl:param name="wiz_code" select="'registration-user'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="screenid" select="$step_data/@screenid"/>
	<xsl:variable name="cred" select="$step_data/@cred"/>
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[@id = 'gen']/@screenid)"/>

	<xsl:param name="access-denied" select="$cred and not(cred:check($cred))"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="create" select="not($form/user_id!='')"/>

	<xsl:variable name="screen-title" select="$step_data/@title"/>
	<xsl:variable name="screen-icon" select="'user_new'"/>

	<!-- Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">
		<ui:screen path-id="{$path-id}" id="{$screenid}" title="{$screen-title}" icon="{$screen-icon}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:no-active-task/>
				<ui:description>
					<sw:text>
        	On this screen you can register yourself as a new Parallels Infrastructure Manager user. After the registration you will get access to other Parallels Infrastructure Manager functionality. If you do not want to register now, click on the 'Cancel Registration' menu item on the left.
        </sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="js_mode" value="0"/>

				<ui:java-script language="JavaScript"
					>
      document.forms[0].js_mode.value = 'JavaScript';	
    </ui:java-script>
				<ui:java-script language="JavaScript1.1"
					>
      document.forms[0].js_mode.value = '1.1';    
    </ui:java-script>
				<ui:java-script language="JavaScript1.2"
					>
      document.forms[0].js_mode.value = '1.2';    
    </ui:java-script>
				<ui:java-script language="JavaScript1.3"
					>
      document.forms[0].js_mode.value = '1.3';    
    </ui:java-script>
				<ui:java-script language="JavaScript1.4"
					>
      document.forms[0].js_mode.value = '1.4';
    </ui:java-script>

				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit">
					<ui:rows title="{sw:text('Security Data')}">

						<ui:row>
							<ui:cell-label>
								<sw:text>Login</sw:text>
							</ui:cell-label>
							<ui:cell-input id="username" required="true" value="{$form/gen/username}"/>
						</ui:row>

						<ui:row>
							<ui:cell-label>
								<sw:text>Password</sw:text>
							</ui:cell-label>
							<ui:cell-input mode-password="true" id="pwd" maxlength="64">
								<xsl:attribute name="value">
									<xsl:value-of select="$form/gen/pwd"/>
								</xsl:attribute>
								<xsl:if test="$create">
									<xsl:attribute name="required">true</xsl:attribute>
								</xsl:if>
							</ui:cell-input>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Retype the password</sw:text>
							</ui:cell-label>
							<ui:cell-input mode-password="true" id="pwd_re" maxlength="64">
								<xsl:attribute name="value">
									<xsl:value-of select="$form/gen/pwd_re"/>
								</xsl:attribute>
								<xsl:if test="$create">
									<xsl:attribute name="required">true</xsl:attribute>
								</xsl:if>
							</ui:cell-input>
						</ui:row>
					</ui:rows>

					<ui:rows title="{sw:text('Personal Data')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>Name</sw:text>
							</ui:cell-label>
							<ui:cell-input id="displayName" value="{$form/user/displayName}"/>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Email</sw:text>
							</ui:cell-label>
							<ui:cell-input id="mail" maxlength="255" value="{$form/user/mail}"> </ui:cell-input>
						</ui:row>
					</ui:rows>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="submit-title" select="sw:text('Register')"/>
							<xsl:with-param name="show-cancel" select="false()"/>
						</xsl:call-template>
					</ui:buttons>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="../../../layout/forms-list.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>


</xsl:stylesheet>
