<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl browse cred vzcpsecuritym securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vzcpsecuritym="http://www.swsoft.com/xsl/cp/vzcpsecuritym"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym">

	<sw:include href="/lib/swa/vzcpsecuritym.xsl"/>
	<sw:include href="/lib/swa/securitym.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-role" select="cred:check('vzcp.virtuozzo_group.security.roles')"/>

	<xsl:param name="access-denied" select="not($cr-role)"/>

	<xsl:template mode="screen" match="/">

		<xsl:variable name="builtin-roles" select="sw:get-builtin-roles()"/>

		<xsl:variable name="filter-cols-rtf">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="roles" url="/core/roles/index" item-url="/core/roles/manage?mode=edit"/>
					<ui:cols sorting-col="name">
						<ui:column id="id" nav-type="id" hidden="yes" for-select="yes"/>
						<ui:column id="name" nav-type="q" title="{sw:text('Name')}" filter="auto" show-url="yes"/>
						<ui:column id="description" title="{sw:text('Description')}" filter="auto"/>
						<ui:column id="builtin" title="{sw:text('Built-in')}" filter="auto" data-type="bool" align="center"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="roles" select="securitym:list-roles()"/>
		<xsl:if test="$roles[self::error]">
			<xsl:if test="error:put(sw:text('Failed to get a list of roles.'),$roles/message)"/>
		</xsl:if>

		<xsl:variable name="filter-rtf">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter-cols-rtf)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:if test="not($roles[self::error])">
							<xsl:for-each select="$roles">
								<xsl:variable name="is-builtin" 
									select="$builtin-roles/roles/role[string(name)=current()/name]"/>
								<ui:row>
									<id>
										<xsl:value-of select="name"/>
									</id>
									<name>
										<xsl:value-of select="sw:if($is-builtin,sw:text(string(current()/name)),current()/name)"/>
									</name>
									<description>
										<xsl:value-of select="sw:base64-decode(description)"/>
									</description>
									<builtin>
										<xsl:value-of select="sw:if($is-builtin,'1','0')"/>
									</builtin>
								</ui:row>
							</xsl:for-each>
						</xsl:if>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="filter" select="exsl:node-set($filter-rtf)"/>

		<ui:screen id="24.00.00.00.00" icon="role">

			<ui:properties>
				<ui:form-get/>
				<ui:no-default-form/>
				<ui:description width="full">
					<sw:text>
					On this screen you can view a list of roles, create a new role, clone an existing role, configure the role parameters, and remove a role that you do not need any more. Roles are sets of abstract privileges a user or a group of users will have in respect of Parallels Infrastructure Manager Hardware Nodes and Containers. For a user to receive a real permission to perform the operations defined by the role privileges in the context of a particular Hardware Node, Container, group of these objects, or globally in Parallels Infrastructure Manager, this permission must be created on the Security tab of the corresponding object or on the Global Permissions tab of the Setup | Security screen.
				</sw:text>
				</ui:description>
			</ui:properties>

			<ui:tab-bar id="security" current-tab="roles"/>
			<ui:content>
				<ui:block width="full">

					<ui:browse>
						<xsl:attribute name="title">
							<sw:text>Roles</sw:text>
						</xsl:attribute>

						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Please select at least one role.</sw:text>
							</ui:warn>
						</ui:browse-js-many>

						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
						
						<ui:browse-buttons type="list-selection">
							<ui:button icon="role_new" new-obj-title="{sw:text('Role')}" 
								submit-href="manage?cmd=new"
								sandclock="false" tip="create_role" require-items="false"
							>
								<sw:text>New Role</sw:text>
							</ui:button>		
							<ui:button type="list-selection" tip="clone_role" icon="role_clone"
								script="if (!atLeastOne()) return false;" name="clone" width="150">
								<sw:text>Clone</sw:text>
							</ui:button>
							<ui:button type="list-selection" tip="delete_role" icon="delete"
								confirmation="{sw:text('Are you sure you want to delete the selected role(s)?')}"
								script="if (!atLeastOne()) return false;"
								name="delete" width="150">
								<sw:text>Delete</sw:text>
							</ui:button>
						</ui:browse-buttons>

						<!-- form definition for other controls -->
						<ui:form action="list-control"/>

						<ui:browse-empty-msg>
							<sw:text>No roles could be found. </sw:text>
						</ui:browse-empty-msg>

					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
