<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred auth local voc env"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:auth="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym" xmlns:set="http://exslt.org/sets"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" xmlns:env="http://www.swsoft.com/xsl/cp/env">

	<sw:include href="/lib/swa/securitym.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-role" select="cred:check('vzcp.virtuozzo_group.security.roles')"/>

	<xsl:param name="wiz_code" select="'sm-role'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="screenid" select="$step_data/@screenid"/>
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[@id = 'gen']/@screenid)"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="create" select="not($form/src/role)"/>

	<xsl:param name="access-denied" select="not($cr-role)"/>

	<xsl:variable name="screen-icon" select="sw:if($create,'role_new','role')"/>

	<!-- Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">
		<ui:screen path-id="{$path-id}" id="{$screenid}" icon="{$screen-icon}">
			<xsl:if test="sw:sesput('securman-role-name',$form/src/role/name)"/>

			<ui:properties>
				<ui:form-post/>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>
    			A user role is a fixed set of rights the users have when working in Parallels Infrastructure Manager or Parallels Power Panel. A role must have a unique name and description.
    		</sw:text>
					<xsl:if test="$form/src/role/read-only">
						<br/><br/>
						<img src="/{$theme}/icons/small_yellow.gif" border="0"
								/>&#160;
    			<sw:text>This is a <b>built-in</b> role which cannot be edited. You may clone the role to create its custom version to be edited.</sw:text>
					</xsl:if>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit">

					<ui:rows title="{sw:text('General Parameters')}">

						<ui:row>
							<ui:cell-label>
								<sw:text>Name</sw:text>
							</ui:cell-label>
							<xsl:choose>
								<xsl:when test="$create or $form/src/role/assignable='true'">
									<xsl:variable name="role-name-pattern" 
										select="voc:get-pattern(env:make-platform-ref(sw:master-eid()),'pattern.role_name')"/>
									<ui:cell-input id="name" 
										maxlength="{sw:if($role-name-pattern and $role-name-pattern/max,$role-name-pattern/max,25)}"
										required="true" value="{$form/gen/role/name}"/>
								</xsl:when>
								<xsl:otherwise>
									<ui:cell-text>
										<xsl:value-of select="$form/src/role/name"/>
									</ui:cell-text>
								</xsl:otherwise>
							</xsl:choose>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Description</sw:text>
							</ui:cell-label>
							<ui:cell-input id="description" maxlength="256" 
								width="50" value="{sw:base64-decode($form/gen/role/description)}"/>
						</ui:row>
					</ui:rows>
					
					<xsl:call-template name="local:edit-creds"/>					

					<ui:rows title="{sw:text('Included Roles')}" id="show_roles" 
						status-def="0" status="{$form/gen/show-roles}" 
						closed-text="{sw:text('Click to manage the included subroles.')}"
					>
						<xsl:variable name="all-roles" select="securitym:list-roles()"/>
						<ui:row>
							<ui:cell-list-selector id="sub_roles" size="6" colspan="2">
								<xsl:for-each select="$all-roles[string(name) != string($form/src/role/name)]">
									<xsl:sort select="name"/>
									<xsl:variable name="role-id" select="name"/>
									<ui:item value="{$role-id}"
										selected="{sw:if($form/gen/role[role = string($role-id)],true(),false())}">
										<xsl:value-of select="name"/>
									</ui:item>
								</xsl:for-each>
							</ui:cell-list-selector>
						</ui:row>
					</ui:rows>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- Show Creds Management Control -->
	<xsl:template name="local:edit-creds">
		<xsl:variable name="creds" select="sw:document('credentials.xml')"/>
		<xsl:variable name="selected-tasks-rtf">
			<xsl:call-template name="local:compose-selected-tasks">
				<xsl:with-param name="all-tasks" select="$form/all-tasks/task"/>
				<xsl:with-param name="full-parent-id" select="'/|'"/>
			</xsl:call-template>
		</xsl:variable>
		<ui:rows title="{sw:text('Privileges')}" separate-tables="true">
			<ui:tree-selector id="cred" open-depth="0">
				<ui:nodes-selected>
					<xsl:for-each select="set:distinct(exsl:node-set($selected-tasks-rtf)/node/@id)">
						<ui:node>
							<ui:id>
								<xsl:value-of select="."/>
							</ui:id>
						</ui:node>
					</xsl:for-each>
				</ui:nodes-selected>
				<ui:nodes>
					<xsl:call-template name="local:tasks-tree">
						<xsl:with-param name="tasks" select="$form/all-tasks/task"/>
					</xsl:call-template>
				</ui:nodes>
			</ui:tree-selector>

		</ui:rows>
	</xsl:template>

	<xsl:template name="local:copy-tasks-with-childs">
		<xsl:param name="task"/>
		<xsl:param name="full-parent-id"/>
		
		<node id="{$task/@full-task-id}"/>
		<xsl:for-each select="$task/task">
			<xsl:call-template name="local:copy-tasks-with-childs">
				<xsl:with-param name="task" select="."/>
				<xsl:with-param name="full-parent-id" select="concat($task/@full-task-id,'/','|')"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="local:compose-selected-tasks">
		<xsl:param name="all-tasks"/>
		<xsl:param name="full-parent-id"/>
		<xsl:for-each select="$all-tasks">
			<xsl:choose>
				<xsl:when test="count($form/gen/role/task[string(.)=current()/name]) &gt; 0">
					<xsl:for-each select="sw:split($full-parent-id,'/|')[string(.) != '']">
						<node id="{.}"/>
					</xsl:for-each>
					<xsl:call-template name="local:copy-tasks-with-childs">
						<xsl:with-param name="task" select="."/>
						<xsl:with-param name="full-parent-id" select="$full-parent-id"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="local:compose-selected-tasks">
						<xsl:with-param name="all-tasks" select="task"/>
						<xsl:with-param name="full-parent-id" 
							select="concat(current()/@full-task-id,'/','|',$full-parent-id)"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name="local:tasks-tree">
		<xsl:param name="tasks"/>
		
		<xsl:for-each select="$tasks">
			<xsl:sort select="@order" data-type="number"/>
			<ui:node>
				<ui:id>
					<xsl:value-of select="@id"/>
				</ui:id>
				<ui:title>
					<sw:text select="name/text()" />
				</ui:title>
				<ui:tip-text>
				<sw:text select="name/text()" />
				</ui:tip-text>

				<xsl:call-template name="local:tasks-tree">
					<xsl:with-param name="tasks" select="task"/>
				</xsl:call-template>
				
			</ui:node>
		</xsl:for-each>

	</xsl:template>


	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>

			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>

</xsl:stylesheet>
