<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:search="http://www.swsoft.com/xsl/cp/search"
	xmlns:html	="http://www.swsoft.com/xsl/cp/html"
>

	<sw:include href="/lib/core/search.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<!-- it's size of showed page.
	     Global search can showed only first 20 objects even if found more 
	-->
	<xsl:variable name="showed-objects" select="20"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="search-string-get" select="sw:param('global_search')"/>	
		<xsl:variable name="search-string-post" select="sw:param('global_search')"/>
		<xsl:variable name="search-string">
			<xsl:choose>
				<xsl:when test="$search-string-get"><xsl:value-of select="$search-string-get"/><xsl:if test="sw:sesputstr('search-string',$search-string-get)"/></xsl:when>
				<xsl:when test="$search-string-post"><xsl:value-of select="$search-string-post"/><xsl:if test="sw:sesputstr('search-string',$search-string-post)"/></xsl:when>				
				<xsl:otherwise><xsl:value-of select="sw:sesgetstr('search-string')"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:variable name="new-current-tab" select="sw:param('tab')"/>
		<xsl:variable name="old-current-tab" select="sw:sesgetstr('global-search-tab')"/>		
		<xsl:variable name="current-tab">
			<xsl:choose>
				<xsl:when test="$new-current-tab">
					<!-- direct set tab from interface, use it -->
					<xsl:value-of select="$new-current-tab"/>
				</xsl:when>
				<xsl:when test="$old-current-tab">
          <!-- tab already selected, use old tab -->
          <xsl:value-of select="$old-current-tab"/>
        </xsl:when>
        <xsl:otherwise>
        	<!-- default tab set here: VE -->
        	<xsl:value-of select="'ve'"/>
        </xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="sw:sesputstr('global-search-tab',$current-tab)"/>

		<ui:screen id="21.00.00.00.00">
			<xsl:variable name="all-section-commmon-result-rtf">
				<xsl:call-template name="search:in-ves">
					<xsl:with-param name="search-pattern" select="$search-string"/>
				</xsl:call-template>
				<xsl:call-template name="search:in-hns">
					<xsl:with-param name="search-pattern" select="$search-string"/>
				</xsl:call-template>
				<xsl:call-template name="search:in-templates">
					<xsl:with-param name="search-pattern" select="$search-string"/>
				</xsl:call-template>
				<xsl:call-template name="search:in-backups">
					<xsl:with-param name="search-pattern" select="$search-string"/>
				</xsl:call-template>
				<xsl:call-template name="search:in-screens">
					<xsl:with-param name="search-pattern" select="$search-string"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="all-section-commmon-result" select="exsl:node-set($all-section-commmon-result-rtf)"/>

			<!-- for dynamic counter in tabs -->
			<xsl:for-each select="$all-section-commmon-result/common-result">
				<xsl:if test="sw:sesputstr(concat('search-count-',id),concat('(',count,')'))"/>
			</xsl:for-each>

			<xsl:variable name="cur-section" select="$all-section-commmon-result/common-result[id = $current-tab]"/>
			<ui:tab-bar id="global.search" current-tab="{sw:if($current-tab,$current-tab,'ve')}"/>
			<ui:properties>
				<ui:form-get/>
				<ui:description>
					<xsl:choose>
						<xsl:when test="($cur-section/count &gt; $showed-objects) and ($current-tab != 'screen')">
							<sw:text>
								<xsl:with-param name="query" select="$search-string"/>
								<xsl:with-param name="found" select="$cur-section/count"/>
								<xsl:with-param name="shown" select="$showed-objects"/>	
								On this screen you can see the search results for %{query}. %{found} objects have been found. The first %{shown} objects are shown.
							</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>
								<xsl:with-param name="query" select="$search-string"/>
								<xsl:with-param name="found" select="$cur-section/count"/>
								On this screen you can see the search results for %{query}. %{found} objects have been found.
							</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:description>
			</ui:properties>
			<ui:content>
				<xsl:variable name="common-result" select="$all-section-commmon-result/common-result[id = $current-tab]/raw"/>
				<xsl:choose>
					<xsl:when test="$current-tab = 'screen'">
						<xsl:copy-of select="$common-result"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="search:show-result">
							<xsl:with-param name="common-result"	select="$common-result"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</ui:content>
		</ui:screen>
	</xsl:template>
</xsl:stylesheet>
