<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz		="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func	="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"	
 >
 
	<sw:include href="/lib/cred-filter.xsl"/>

  <!-- check permissions to show this page -->

	<xsl:param name="wiz_code" 					select="'settings-panel'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>

	<xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>
  
  <!-- Wizard, General Step  -->
  <xsl:template name="step_gen">
  	<ui:screen  id="{$step_data/@screen-id}" title="{$step_data/@title}">
  	
		<ui:properties>
		<ui:refresh-type>none</ui:refresh-type>
		<ui:form-get/>
			<ui:description mandatory="yes" width="full">
		 		<sw:text>
		  		On this screen you can view and modify your preferences for working with the system.
		 		</sw:text>
			</ui:description>
		</ui:properties>

		<xsl:if test="$form/def/in-vzcc and ($auth-type='clusteruser' or $auth-type='veuser')">
			<ui:tab-bar id="user.profile" current-tab="interface"/>
		</xsl:if>
		
		<ui:content>
      <ui:hidden name="step" value="gen"/>    
      <ui:block mode="edit">
      	
					<xsl:if test="$form/def/in-vzcc">
						<ui:rows title="{sw:text('Navigation Settings')}">
							<!-- Home Page -->
							<xsl:variable name="screens-repository" select="sw:document('screens.xml')"/>
							<xsl:variable name="home-screens" select="cred:filter-items($screens-repository//screen[
								link and (not(link/@panel) or link/@panel=$activeMode)
							])"/>
							<ui:row>
								<ui:cell-label>
									<sw:text>Home Page</sw:text>
								</ui:cell-label>
								<ui:cell-list id="home_screen_id" class=" " value="{$form/gen/home-screen-id}"
								>
									<ui:list-item id="" title="{sw:text('System Default')}"/>
									<xsl:call-template name="local:home-items">
										<xsl:with-param name="category-id" select="'main'"/>
										<xsl:with-param name="category-title" select="sw:text('-- Main Screens --')"/>
										<xsl:with-param name="all-screens" select="$home-screens"/>
									</xsl:call-template>
									<xsl:call-template name="local:home-items">
										<xsl:with-param name="category-id" select="''"/>
										<xsl:with-param name="category-title" select="sw:text('-- Other Screens --')"/>
										<xsl:with-param name="all-screens" select="$home-screens"/>
									</xsl:call-template>
								</ui:cell-list>
							</ui:row>
							<!-- /Home Page -->
						</ui:rows>
					</xsl:if>   		
				
					<ui:rows title="{sw:text('Regional Settings')}">
						<xsl:variable name="langs" select="sw:document('languages.xml')/languages/language[active]"/>
						<xsl:if test="count($langs) &gt; 1">
							<ui:row>
								<ui:cell-label>
									<sw:text>Interface Language</sw:text>
								</ui:cell-label>
								<ui:cell-list id="lang" value="{$form/gen/lang}">
									<xsl:for-each select="$langs">
										<ui:list-item id="{id}" title="{name}"/>
									</xsl:for-each>
								</ui:cell-list>
							</ui:row>
						</xsl:if>
						<ui:row>
							<ui:cell-label>
								<sw:text>Local Time Zone</sw:text>
							</ui:cell-label>
							<ui:cell-list id="time_zone" class=" " value="{$form/gen/time-zone}">
								<ui:list-item id="" title="{sw:text('Server Default')}"/>
								<xsl:for-each select="sw:document('zones.xml')/time-zones/time-zone">
									<ui:list-item id="{@id}" title="{.}"/>
								</xsl:for-each>
							</ui:cell-list>
						</ui:row>
					</ui:rows>
					
					<ui:rows title="{sw:text('Visual Settings')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>GUI Elements Style</sw:text>
							</ui:cell-label>
							<ui:cell-list id="toolbar_mode" value="{$form/gen/toolbar-mode}">
								<ui:list-item id="icontext" title="{sw:text('Icons and text')}"/>							
								<ui:list-item id="text" title="{sw:text('Text only')}"/>
								<ui:list-item id="icons" title="{sw:text('Icons only')}"/>										
							</ui:cell-list>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Interface Skin</sw:text>
							</ui:cell-label>
							<ui:cell-list id="skin" value="{$form/gen/skin}">
								<xsl:variable name="skin-list" select="sw:document('skins.xml')"/>
								<xsl:variable name="skins" select="$skin-list/skins/mode[@id = $activeMode]/skin"/>
								<xsl:for-each select="$skins">
									<ui:list-item id="{id}" title="{sw:text(string(name))}"/>
								</xsl:for-each>
							</ui:cell-list>
						</ui:row>
						<xsl:if test="$activeMode = 'vzcp'">
							<ui:row>
								<ui:cell-label>
									<sw:text>Status Bar Refresh</sw:text>
								</ui:cell-label>
								<ui:cell-list id="refresh_period" value="{$form/gen/refresh-period}">
									<xsl:for-each select="$config/vzcpcon/timeout/status_bar_refresh/custom/period">
										<ui:list-item id="{@value}" title="{sw:text(string(.))}"/>
									</xsl:for-each>
								</ui:cell-list>
							</ui:row>
						</xsl:if>
						<xsl:if test="$form/def/in-vzcc">
							<ui:row>						
								<ui:cell-label id="menu_depth">
									<sw:text>Menu Details Level</sw:text>
								</ui:cell-label>
								<ui:cell-list class=" " id="menu_depth" value="{$form/gen/menu-depth}">
									<ui:list-item id="ves" title="{sw:text('Folders, Hardware Nodes, and Containers')}"/>	
									<ui:list-item id="nodes" title="{sw:text('Folders and Hardware Nodes')}"/>
									<ui:list-item id="folders" title="{sw:text('Folders only')}"/>							
								</ui:cell-list>
							</ui:row>							
							<ui:row>
								<ui:cell-label>
									<sw:text>Enable Tooltips</sw:text>
								</ui:cell-label>
								<ui:cell-check id="show_tooltips" checked="{$form/gen/show-tooltips}" close="false"/>
							</ui:row>
							<ui:row>
								<ui:cell-label>
									<sw:text>Show Top Right Buttons Pane</sw:text>
								</ui:cell-label>
								<ui:cell-check id="show_banners" checked="{$form/gen/show-banners}" close="false"/>
							</ui:row>
							<ui:row>
								<ui:cell-label>
									<sw:text>Allow Dynamic Status Updates</sw:text>
								</ui:cell-label>
								<ui:cell-check id="dynamic_updates" checked="{$form/gen/dynamic-updates}" close="false"/>
							</ui:row>
						</xsl:if>
					</ui:rows>
					
					<xsl:if test="$form/def/input-password or $form/def/input-mail">
						<ui:rows title="{sw:text('Personal Settings')}">
							<xsl:if test="$form/def/input-password">
								<ui:row>
									<ui:cell-label>
										<sw:text>Password</sw:text>
									</ui:cell-label>
									<ui:cell-input mode-password="true" id="password" maxlength="64"/>
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Retype the password</sw:text>
									</ui:cell-label>
									<ui:cell-input mode-password="true" id="re_password" maxlength="64"/>
								</ui:row>
							</xsl:if>
							<xsl:if test="$form/def/input-mail">
								<ui:row>
									<ui:cell-label>
										<sw:text>Contact Email</sw:text>
									</ui:cell-label>
									<ui:cell-input id="user_mail" maxlength="256" alone-in-form="yes" value="{$form/gen/user-mail}"/>
								</ui:row>
							</xsl:if>
						</ui:rows>
					</xsl:if>
				
					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="show-cancel" select="false()"/>
						</xsl:call-template>
					</ui:buttons>
        
	     	</ui:block>
  	  </ui:content>   
    </ui:screen>
  </xsl:template>
  

	<xsl:template name="local:home-items">
		<xsl:param name="category-id"/>
		<xsl:param name="category-title"/>
		<xsl:param name="all-screens"/>
		
		<xsl:variable name="filtered" select="$all-screens[
			($category-id!=''  and link/@home-category=$category-id)
			or 
			($category-id=''  and not(link/@home-category))
		]"/>
		<ui:list-item id="" title="{$category-title}" disabled="true"/>
		<xsl:for-each select="$filtered">
			<xsl:sort select="sw:if(link/@title,link/@title,@title)"/>
			<ui:list-item id="{@id}" title="{sw:text(sw:if(link/@title,link/@title,@title))}"/>
		</xsl:for-each>
	</xsl:template>  
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
		<xsl:choose>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>
			
		</xsl:choose>
	
	</xsl:template>
	
	<!-- Includes -->	
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl"/>			
		
	<!-- /Includes -->	
	
</xsl:stylesheet>
