<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"  
  xmlns:browse="http://www.swsoft.com/xsl/cp/browse"     
  xmlns:env="http://www.swsoft.com/xsl/cp/env"     
 
>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
  
  <xsl:template mode="screen" match="/">
		<!-- Prepare Filter -->
 		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="tasks_popup" url="/core/tasks/active-popup" items-title="{sw:text('Actions')}"/>
	        <ui:cols sorting-direction="desc">
	        	<ui:column id="started" data-type="datetime"  title="{sw:text('Started')}"/>
	        	<xsl:if test="$activeMode = 'vzcc'">
	        		<ui:column id="env-list" apply-templates="yes" title="{sw:text('Container')}" filter="auto"/>
	        	</xsl:if>
	        	<ui:column id="task-op" apply-templates="yes" title="{sw:text('Operation')}"/>
	        	<ui:column id="task-status" apply-templates="yes" title="{sw:text('Status')}" filter="select">
	        		<ui:filter-option value="1" title="{sw:text('Started')}"/>
	          	<ui:filter-option value="2" title="{sw:text('In Progress')}"/>
	          	<ui:filter-option value="3" title="{sw:text('Completed')}"/>
	          	<ui:filter-option value="4" title="{sw:text('Failed')}"/>
	          	<ui:filter-option value="0" title="{sw:text('Other')}"/>
	        	</ui:column>
	        	<ui:column id="task-details" apply-templates="yes" title=""/>
	        </ui:cols>
				</xsl:with-param>
			</xsl:call-template>
    </xsl:variable>
    
    <xsl:variable name="browse_request">
	    <packet>
	      <target>op_log</target>
	      <data>
	        <op_log>
	          <get_ops>
	          	<xsl:if test="$activeMode != 'vzcc'">
	              <eid><xsl:value-of select="sw:ve-eid()"/></eid>
	            </xsl:if>
	            <current/>
	            <status/>
							<!--<directly />-->
	          </get_ops>
	        </op_log>
	      </data>
	    </packet>    
		</xsl:variable>
			
    <xsl:variable name="browse_result" select="sw:xchg($browse_request)"/>
    
    <xsl:variable name="filter">
    	<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">					
	        <ui:browse-rows>
	        	<xsl:variable name="tasks" select="$browse_result/packet/data/op_log/progress[not(parent_id)]" />
	        	<xsl:variable name="continued" select="contains($tasks[1]/op, 'vzaup2date')" />
	        	
	          <xsl:for-each select="sw:if($continued, $tasks[not(contains(sw:base64-decode(progress/message), 'dbm operator restart'))], $tasks)">
	            <ui:row>
	            	<started><xsl:value-of select="time"/></started>
	              <xsl:copy-of select="id"/>
								<task-status><xsl:copy-of select="status/node()"/></task-status>
								<task-op><xsl:copy-of select="op/node()"/></task-op>
	              <xsl:if test="$activeMode = 'vzcc'">
	              	<env-list>
	              		<xsl:if test="eid_list/eid">
											<xsl:for-each select="eid_list/eid">
												<ui:env-eid-link>
													<xsl:value-of select="."/>
												</ui:env-eid-link>
											</xsl:for-each>
	              		</xsl:if>
									</env-list>
	              </xsl:if>
	              <task-details/>
	      	    </ui:row> 
	      	  </xsl:for-each>      
        	</ui:browse-rows>
        </xsl:with-param>        					
			</xsl:call-template>
    </xsl:variable>
    <!-- /Prepare Filter -->
  
    <ui:popup-screen id="03.00.02.01.03" title="{sw:text('Active Tasks')}" icon="maintenance">
      <ui:properties>
		<ui:form-get/>
      	<ui:contains-date-control/>
        <ui:refresh timeout="{$config/vzcpcon/timeout/task_list_refresh}"/>
        <ui:refresh-type>POST</ui:refresh-type>
      </ui:properties>
	    <ui:content>
	    	<ui:block width="full">
		      <ui:browse title="{sw:text('Action Log')}">
			
						<ui:filter>
		        	<xsl:copy-of select="$filter"/>
		        </ui:filter>
		
		        <ui:browse-empty-msg>
		        	<sw:text>
			        	No active tasks at the moment.							
			        </sw:text>
		        </ui:browse-empty-msg>
		      </ui:browse>    
		     </ui:block>
	    </ui:content>     
    </ui:popup-screen>    
  </xsl:template>
  
</xsl:stylesheet>
