<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl local func op_log env"
	xmlns:xsl	="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw	="http://www.swsoft.com/xsl/cp"
	xmlns:ui	="http://www.swsoft.com/xsl/cp/ui"  
	xmlns:voc	="http://www.swsoft.com/xsl/cp/voc"
	xmlns:env	="http://www.swsoft.com/xsl/cp/env"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:op_log	="http://www.swsoft.com/xsl/cp/op_log"
	xmlns:global	="http://www.swsoft.com/xsl/cp/global"	
	xmlns:func	="http://exslt.org/functions"
>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/swa/op_log.xsl"/>
	<sw:include href="/lib/screen.xsl"/>

<xsl:template mode="screen" match="/">
	<xsl:variable name="task_progress"
		select="sw:if(
			contains(/packet/data/op_log/progress[1]/op,'vzaup2date')
			,/packet/data/op_log/progress[
				not(contains(sw:base64-decode(message/message),'op_log operator restart'))
			],/packet/data/op_log/progress
		)" 
	/>
	<xsl:variable name="total-status" select="$task_progress[last()]/status"/>
	<xsl:variable name="in-progress" select="($task_progress[last()]/status = 1) or ($task_progress[last()]/status = 2)"/>
	<xsl:variable name="percent" select="$task_progress[last()]/percent"/>

	<xsl:variable name="url_wp">
		<xsl:value-of select="concat($requesturl,'?')"/>
		<xsl:for-each select="$request/http_request/*[self::get]/parameter">
			<xsl:choose>
				<xsl:when test="name='open_rft'"></xsl:when>
				<xsl:when test="name='close_rft'"></xsl:when>
				<xsl:otherwise><xsl:value-of select="name"/>=<xsl:value-of select="value"/>&amp;</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:variable>
	
	<ui:popup-screen id="03.00.02.01.02" title="{sw:text('Task Details')}" icon="task">
		<ui:properties>
			<ui:form-get/>
			<ui:refresh>
				<xsl:attribute name="href"><xsl:value-of select="$url_wp"/></xsl:attribute>
				<xsl:attribute name="href_ref">javascript:customRefresh('<xsl:value-of select="$url_wp"/>');</xsl:attribute>
			<xsl:if test="$in-progress">
				<xsl:attribute name="timeout">
					<xsl:value-of select="$config/vzcpcon/timeout/task_details_refresh"/>
				</xsl:attribute>
			</xsl:if>
			</ui:refresh>

			<ui:js-tail>
				<script language="JavaScript">

	//---init open/close menus;
	var openRTF='<xsl:value-of select="sw:param('open_rft')"/>';
	var closeRTF='<xsl:value-of select="sw:param('close_rft')"/>';
	var el='';

<![CDATA[

	function switchChildById(id){
		el=document.getElementById(id);
		if(el) {
			var idNum=id.split('_');
			if (idNum[1]!='') {switchChild(idNum[1]);}
		}
	}

	//---dynamic open;
	if (openRTF!='') {
		var tmp=openRTF.split('|');
		for(var i=0;i<tmp.length;i++) {
			if (tmp[i]!='') {
				el=document.getElementById(tmp[i]);
				if (el) { if (el.src.indexOf('open_tree')!=-1) {switchChildById(tmp[i]);}	}
			}
		}
	}
	//---dynamic close;
	if (closeRTF!='') {
		var tmp=closeRTF.split('|');
		for(var i=0;i<tmp.length;i++) {
			if (tmp[i]!='') {
				el=document.getElementById(tmp[i]);
				if (el) { if (el.src.indexOf('close_tree')!=-1) {switchChildById(tmp[i]);}	}
			}
		}
	}
]]>
				function switchChild(id){
					s = document.getElementById('child_'+id+'_1');
					o = document.getElementById('arr_'+id);
					var display;
					if(s.style.display=='none'){
						display='';
						o.src="<xsl:value-of select="concat('/',$theme,'/images/close_tree.gif')"/>";
					} else{
						display='none';
						o.src="<xsl:value-of select="concat('/',$theme,'/images/open_tree.gif')"/>";
					}
					var i = 1;
					do 
					{ 
						s = document.getElementById('child_'+id+'_'+i);
						if(s) s.style.display = display;
 						i++;
					} 
					while(s);
					
					
					return false;
				}
				</script>
			</ui:js-tail>
		</ui:properties>

	<ui:content>
		<xsl:choose>
			<!-- have some data -->
			<xsl:when test="$task_progress">
				<ui:block>
					<ui:summary-block>
						<ui:summary-generic label-width="33%" value-width="67%">
							<item label="{sw:text('Task')}">
								<value>
									<b>
										<xsl:for-each select="$task_progress[1]/op">
											<xsl:call-template name="task-op"/>
										</xsl:for-each>
									</b>
								</value>							
							</item>
							<xsl:if test="$activeMode='vzcc'">
								<xsl:variable name="envs" select="$task_progress[position() = last()]/message/parameter[name = 'env']"/>
								<xsl:variable name="ves" select="$envs[parameter[name='type']/message != sw:base64-encode('generic')]"/>
								<xsl:variable name="hns" select="$envs[parameter[name='type']/message  = sw:base64-encode('generic')]"/>
								<xsl:if test="$ves">
									<item label="{sw:text('Containers')}" wrap="{true()}">
										<value>
											<ui:envs-by-message>
												<xsl:copy-of select="$ves"/>
											</ui:envs-by-message>
										</value>
									</item>
								</xsl:if>						
								<xsl:if test="$hns">
									<item label="{sw:text('Hardware Nodes')}" wrap="{true()}">
										<value>
											<ui:envs-by-message>
												<xsl:copy-of select="$hns"/>
											</ui:envs-by-message>
										</value>
									</item>
								</xsl:if>						
							</xsl:if>
							<item label="{sw:text('Status')}">
								<value>
									<xsl:call-template name="local:show-status">
										<xsl:with-param name="status-src" select="$total-status"/>
									</xsl:call-template>
								</value>
							</item>
						</ui:summary-generic>
					</ui:summary-block>
				
				</ui:block>
				<ui:raw>
					<div id="scrollArea" class="scrollableArea" style="height:230px;">
					<!-- Show Browse -->
					<!-- Show Browse Header -->
					<table border="0" cellpadding="3" cellspacing="0" width="100%" class="sTable" style="border-collapse: collapse">
						<thead>
							<th class="taskDet" align="left" width="30%"><span class="label"><sw:text>Time</sw:text></span></th>
							<th class="taskDet" align="left" width="50%"><span class="label"><sw:text>Operation</sw:text></span></th>
							<th class="taskDet" align="left" width="20%"><span class="label"><sw:text>Status</sw:text></span></th>
						</thead>

					<!-- Show Browse Rows -->
					<xsl:for-each select="$task_progress">
						<xsl:variable name="id" select="position()"/>
						<xsl:variable name="is-last" select="position()=last()"/>
						<xsl:variable name="is-completed" select="not($is-last) or not($in-progress)"/>
						<!-- Prepare message to display -->
						<xsl:variable name="msg-src" select="op_log:parse-message(message)"/>
						<xsl:variable name="info-child-id" select="sw:base64-decode(message/parameter[name = 'child_id']/message)"/>
						
						<!-- detect children by complex packet-id -->
						<xsl:variable name="is-child" select="contains($msg-src,'/')"/>
						
						<!-- get IP of child packtes - standard and legacy ways -->
						<xsl:variable name="child-id" select="sw:if($info-child-id, $info-child-id, substring-after($msg-src,'|'))"/>
						
						<!-- check, do we have actual records in DB -->
						<xsl:variable name="child-recs" select="local:load-child($child-id,$total-status)"/>
						
						<!-- final conclusion about children -->
						<xsl:variable name="has-child" select="$child-id and $child-recs"/>

						<!-- cut legacy child-id from message -->
						<xsl:variable name="msg" select="
								sw:if(contains($msg-src,'|'),
										substring-before($msg-src,'|'),
										$msg-src)  
							"/>

						<xsl:choose>
							<!-- Show basic record -->
							<xsl:when test="not($has-child)">
								<xsl:if test="string($msg) or ($is-last and number($percent) &gt; 0)">
									<!-- Prepare status display -->
									<xsl:variable name="status">
										<xsl:choose>
											<!-- completed OK or not last in PROGRESS-->
											<xsl:when test="status=3 or (status=1 and not($is-last)) or (status=2 and not ($is-last))">
												<xsl:value-of select="3"/>
											</xsl:when>
											<!-- completed with errors -->
											<xsl:when test="status=4">
												<xsl:value-of select="4"/>
											</xsl:when>
											<!-- in progress -->
											<xsl:when test="$is-last and number($percent) &gt; 0"><xsl:value-of select="$percent" />%</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="2"/>
											</xsl:otherwise>
										</xsl:choose>
									</xsl:variable>
									<!-- / -->
									<tr class="{sw:if(position() mod 2,'sEvenRow','sOddRow')}">
										<td align="left" width="30%" nowrap="1" class="taskDet"><xsl:apply-templates select="time"/></td>
										<td width="50%" align="left" class="taskDet"><xsl:value-of select="$msg"/></td>
										<td align="left" width="20%" class="taskDet">
											<xsl:call-template name="local:show-status">
												<xsl:with-param name="status-src" select="string($status)"/>
											</xsl:call-template>
										</td>									
									</tr>
								</xsl:if>
							</xsl:when>
							<!-- Show complex record (with child )-->
							<xsl:otherwise>
								<!-- Prepare status display -->
								<xsl:variable name="status">
									<xsl:choose>
										<!-- completed OK -->
										<xsl:when test="not($is-last) and not($child-recs[last()][status=4])">3</xsl:when>
										<!-- completed with errors -->
										<xsl:when test="not($is-last) and $child-recs[last()][status=4]">4</xsl:when>
										<!-- in progress -->
										<xsl:otherwise>2</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="open" select="$is-last or $status=4"/>
								<!--/-->
								<xsl:variable name="row-class" select="sw:if(position() mod 2,'sEvenRow','sOddRow')"/>
								<tr class="{$row-class}">
									<td align="left" nowrap="1" width="30%" class="taskDet"><xsl:apply-templates select="time"/></td>
									<td  width="50%" class="taskDet">
										<a onclick="switchChild('{$id}')" style="cursor:hand; cursor:pointer;text-decoration: none;color:#000000;">
											<img id="arr_{$id}" src="/{$theme}/images/{sw:if($open,'close_tree','open_tree')}.gif" 
												width="16" height="16" style="vertical-align:middle; margin-right: 2px; margin-bottom:2px" 
													alt="{sw:text('Click here to open/close the operation details.')}"/>
											<xsl:value-of select="$msg"/>
										</a>
									</td>
									<td align="left" width="20%" class="taskDet">
										<xsl:call-template name="local:show-status">
											<xsl:with-param name="status-src" select="$status"/>
										</xsl:call-template>
									</td>								
								</tr>
								<xsl:call-template name="local:show-child">
									<xsl:with-param name="child-recs" select="$child-recs"/>
									<xsl:with-param name="open" select="$open"/>
									<xsl:with-param name="id" select="concat('child_',$id)"/>
									<xsl:with-param name="is-parent-completed" select="$is-completed"/>
									<xsl:with-param name="row-class" select="$row-class"/>
								</xsl:call-template>
							</xsl:otherwise>
							<!--/-->
						</xsl:choose>
					</xsl:for-each>
					</table>
					</div>
				</ui:raw>
			</xsl:when>
			<xsl:otherwise>
				<ui:stop-sign>
					<sw:text>No data available</sw:text>
				</ui:stop-sign>
			</xsl:otherwise>
		</xsl:choose>
		</ui:content>
</ui:popup-screen>
</xsl:template>

<func:function name="local:translate-msg">
	<xsl:param name="message"/>
	<xsl:param name="text"/>
	<func:result select="$text"/>
</func:function>

<!--
 child-op-id may be empty
-->
	<func:function name="local:load-child">
		<xsl:param name="child-op-id"/>
		<xsl:param name="total-status"/>		
		<xsl:param name="eid"/>
		<xsl:choose>
			<xsl:when test="$child-op-id=''">
				<func:result/>
			</xsl:when>
			<xsl:otherwise>
				<!-- Prepare Packet to Get Child Operation Details -->
				<xsl:variable name="vza-request">
					<packet>
					<target>op_log</target>
					<data>
						<op_log>
							<get_ops>
								<!--<directly/>-->
								<id><xsl:value-of select="$child-op-id"/></id>
							</get_ops>
						</op_log>
					</data>
					</packet>
				</xsl:variable>
	
				<!-- Send Packet -->
				<xsl:variable name="response" select="sw:xchg($vza-request)"/>
	
				<!-- Return data -->
				<xsl:choose>
					<!-- Return loaded info -->
					<xsl:when test="$response/packet/data/op_log/progress">
						<func:result select="$response/packet/data/op_log/progress"/>
					</xsl:when>
					<!-- VZA does not log child execution -->
					<!-- Show the fake message to prevent bugs similar to #82058 -->					
					<xsl:when test="$total-status=global:task-failed">
						<xsl:variable name="error-rtf">
							<progress>
								<message>
									<message>
										<xsl:value-of select="sw:base64-encode(
												sw:text('Failed to complete the task, see the Parallels Infrastructure Manager logs for details.')
												)"/>
									</message>
								</message>
								<id><xsl:value-of select="$child-op-id"/></id>
								<status><xsl:value-of select="$global:task-failed"/></status><!-- erorr -->
								<time/>
							</progress>
						</xsl:variable>
						<func:result select="exsl:node-set($error-rtf)/progress"/>
					</xsl:when>
					<!-- No details -->										
					<xsl:otherwise>
						<func:result select="/.."/>					
					</xsl:otherwise>					
				</xsl:choose>
		
			</xsl:otherwise>
		</xsl:choose>
	</func:function>

<xsl:template name="local:show-child">
	<xsl:param name="child-recs"/>
	<xsl:param name="open"/>
	<xsl:param name="id"/>
	<xsl:param name="is-parent-completed"/>
	<xsl:param name="row-class"/>
	<!-- Show Child Details-->
	<xsl:for-each select="$child-recs">

		<xsl:variable name="msg-src" select="op_log:parse-message(message)"/>
		
		<xsl:variable name="info-child-id" select="sw:base64-decode(message/parameter[name = 'child_id']/message)"/>
		
		<!-- detect children by complex packet-id -->
		<xsl:variable name="complex" select="sw:split($id,'/') &gt; 2"/>
		
		<!-- get IP of child packtes - standard and legacy ways -->
		<xsl:variable name="child-id" select="sw:if($info-child-id, $info-child-id, string(sw:split($msg-src,'|')[2]))"/>
		
		<!-- cut legacy child-id from message -->
		<xsl:variable name="msg" select="
			sw:if(contains($msg-src,'|'),
			substring-before($msg-src,'|'),
			$msg-src)  
			"/>
		
		<xsl:if test="string($msg) or (not($is-parent-completed) and position() = last() and number(percent) &gt; 0)">
			<tr class="{$row-class}"  id="{$id}_{position()}">
				<xsl:if test="not($open)">
					<xsl:attribute name="style">display:none;</xsl:attribute>
				</xsl:if>						
				<td align="left" nowrap="1" width="30%" class="taskDet"><xsl:apply-templates select="time"/></td>
				<td width="50%" class="taskDet" style="padding-left:25px">
					<xsl:value-of select="$msg"/>
				</td>
				<td align="left" width="20%"  class="taskDet" >
					<xsl:call-template name="local:show-status">
						<xsl:with-param name="packet-id" select="$child-id"/>
						<xsl:with-param name="status-src">
							<xsl:choose>
								<!-- error -->
								<xsl:when test="status=4"><xsl:value-of select="'4'"/></xsl:when>
								<!-- completed -->
								<xsl:when test="$is-parent-completed or position()!=last()"><xsl:value-of select="''"/></xsl:when>
								<!-- In progress -->
								<xsl:when test="not($is-parent-completed) and position() = last() and number(percent) &gt; 0">
									<xsl:value-of select="concat(percent, '%')" />
								</xsl:when>
								<xsl:otherwise><xsl:value-of select="'2'"/></xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</td>
			</tr>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

<xsl:template name="local:show-status">
	<xsl:param name="status-src"/>
	<xsl:param name="packet-id" select="''"/>
	<xsl:variable name="status">
		<!-- check sub childs -->
		<xsl:choose>
			<xsl:when test="$packet-id!='' and ($status-src='' or $status-src='3')">
				<xsl:variable name="child-recs" select="local:load-child($packet-id,$status-src)"/>
				<xsl:choose>
					<!-- at least one childs was failed -->
					<xsl:when test="$child-recs[status='4']">
						<xsl:value-of select="'4'"/>
					</xsl:when>
					<!-- /at least one childs was failed -->
					<xsl:otherwise><xsl:value-of select="$status-src"/></xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="$status-src"/></xsl:otherwise>
		</xsl:choose>
		<!-- /check sub childs -->
	</xsl:variable>

	<xsl:variable name="text">
		<xsl:choose>
			<xsl:when test="$status = '' and $packet-id!=''"><sw:text>details</sw:text></xsl:when>
			<xsl:when test="$status = ''">&#160;</xsl:when>
			<xsl:when test="$status = 1"><sw:text>Started</sw:text></xsl:when>
			<xsl:when test="$status = 2"><sw:text>In progress</sw:text></xsl:when>
			<xsl:when test="$status = 3"><span class="green"><sw:text>Completed</sw:text></span></xsl:when>
			<xsl:when test="$status = 4"><span class="red"><sw:text>Failed</sw:text></span></xsl:when>
			<xsl:when test="contains($status, '%') and string(number(substring-before($status, '%'))) != 'NaN'">
				<xsl:value-of select="$status" />
			</xsl:when>
			<xsl:otherwise><span class="red"><sw:text>Unknown</sw:text>(<xsl:value-of select="$status"/>)</span></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="icon">
		<xsl:choose>
			<xsl:when test="$status = '' and $packet-id!=''">images/1x1</xsl:when>
			<xsl:when test="$status = ''">images/1x1</xsl:when>		
			<xsl:when test="$status = 1">icons/indicator</xsl:when>
			<xsl:when test="$status = 2">icons/indicator</xsl:when>
			<xsl:when test="$status = 3">icons/green_16</xsl:when>
			<xsl:when test="$status = 4">icons/red_16</xsl:when>
			<xsl:when test="contains($status, '%') and string(number(substring-before($status, '%'))) != 'NaN'">icons/indicator</xsl:when>
			<xsl:otherwise>red_16</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<nobr>
		<xsl:if test="$icon">
			<img src="/{$theme}/{$icon}.gif" width="16" height="16" style="padding-right:4px;"/>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="$packet-id=''">
				<xsl:copy-of select="$text"/>
			</xsl:when>
				<!--
				<xsl:when test="$packet-id='' or $status = ''">
					<xsl:copy-of select="$text"/>
				</xsl:when>
				-->
			<xsl:otherwise>
				<a href="#" 
					onmouseover="callTip('active_tasks',event)" onmouseout="callTip()" onclick="open_details('{$baseurl}/core/tasks/details-popup?id={$packet-id}','tasks_list_{sw:base64-encode($packet-id)}');return false">
					<img src="/{$theme}/icons/move_16.gif" width="16" height="16" border="0"/></a>
			</xsl:otherwise>
		</xsl:choose>
	</nobr>
</xsl:template>

<sw:include href="../../../layout/ext-tasks.xsl"/>

</xsl:stylesheet>
