<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred trace"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" 
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:trace="http://www.swsoft.com/xsl/cp/trace"
>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/trace.xsl"/>
	<sw:include href="/lib/core/browse-filter-vza.xsl"/>

	<!-- search vzenv screen in path -->
	<xsl:param name="log-road" select="trace:find-road('env-home')"/>
	<xsl:param name="log-management" select="$log-road='management'"/>

	<!-- check permissions to show this page -->
	<xsl:param name="access-denied"
		select="not(cred:check-context('vzcp.log.list',sw:if(not($log-management),'ve.vz.vt','vzcp')))"/>

	<xsl:variable name="allow-cancel"
		select="$activeMode = 'vzcc' and cred:check-context('vzcp.log.actions_log.cancel',sw:if(not($log-management),'ve.vz.vt','vzcp'))"/>
		
	<xsl:template mode="screen" match="/">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<ui:screen
			id="{
    		sw:if(not($log-management), '03.00.02.01.00', '03.00.02.01.01')
    	}">
			<xsl:choose>								
				<xsl:when test="$log-management">
					<ui:tab-bar id="tasks" current-tab="index"/>
				</xsl:when>
				<xsl:when test="not($log-management)">
					<ui:tab-bar id="vzve" current-tab="logs" current-subtab="tasks"/>
				</xsl:when>
			</xsl:choose>
			<ui:properties>
				<ui:form-get/>
				<ui:contains-date-control/>
				<ui:no-default-form/>
				<ui:description width="full">
					<sw:text>On this screen you can see a list of Container-related tasks, both running and already finished. Use the filter to display the relevant records only. <br/>Clicking on "Details" will open a popup window with additional information about the task.
					</sw:text>
				</ui:description>
			</ui:properties>

			<xsl:variable name="filter_init_">
				<xsl:call-template name="browse:init-filter">
					<xsl:with-param name="browse">
						<ui:browse-setup id="tasks{sw:if($log-management, '-management', '')}" item-url="/vzdir/infrman/envs/env" url="/core/tasks/index"
							items-title="{sw:text('Tasks')}"/>
						<ui:cols sorting-direction="desc">
							<ui:column id="time" vza-id="op_log.time" data-type="datetime"
								title="{sw:text('Time')}" filter-from-title="{sw:text('Time From')}"
								filter-to-title="{sw:text('Time to')}" filter-from-tip="action_from_filter"
								filter-to-tip="action_to_filter" filter="interval"/>
							<xsl:if test="$log-management">
								<ui:column id="task-info-xml" vza-id="op_log.messagexml" hidden="yes"/>
								
								<!-- HN column -->
								<ui:column id="task-hn" vza-id="op_log.origin.title" apply-templates="yes"
									title="{sw:text('Hardware Node')}" filter="auto"/>
								
								<!-- show VEs list XXX: to be hidden in VZPP -->
								<ui:column id="task-ve" apply-templates="yes" sorting="no"
									title="{sw:text('Container')}"/>
							</xsl:if>
														
							<!-- in case of selection by VE - require VE column -->							
							<xsl:if test="not($log-management)">
								<ui:column id="task-ve" vza-id="op_log.parameter.env.eid" hidden="yes"/>								
							</xsl:if>
							
							<ui:column id="id" vza-id="op_log.id" hidden="yes"
								for-select-condition="task-status=1 or task-status=2"
							>
								<xsl:if test="$allow-cancel">
									<xsl:attribute name="for-select">yes</xsl:attribute>
								</xsl:if>
							</ui:column>							
							<ui:column id="task-op" vza-id="op_log.op" apply-templates="yes" sorting="no"
								title="{sw:text('Task')}"/>
							<ui:column id="task-status" vza-id="op_log.status" apply-templates="yes"
								title="{sw:text('Status')}" filter="select">
								<ui:filter-option value="1" title="{sw:text('Started')}"/>
								<ui:filter-option value="2" title="{sw:text('In Progress')}"/>
								<ui:filter-option value="3" title="{sw:text('Completed')}"/>
								<ui:filter-option value="4" title="{sw:text('Failed')}"/>
								<ui:filter-option value="0" title="{sw:text('Other')}"/>
							</ui:column>
							<ui:column id="task-details" apply-templates="yes" title=""/>

							<!-- filter by VE only -->
							<ui:column id="ve-title" vza-id="op_log.parameter.env.title" title="{sw:text('Container')}" 
								hidden="yes" select-only-filtered="true"
							>
								<xsl:if test="$log-management">
									<xsl:attribute name="filter">auto</xsl:attribute>
								</xsl:if>
								<ui:cond vza-id="op_log.parameter.env.type" expr="!=">generic</ui:cond>
							</ui:column>
							
						</ui:cols>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>

			<xsl:variable name="env-where">
				<xsl:if test="not($log-management)">
					<xsl:value-of select="concat('(pager.op_log.origin.eid = ',&#x22;&#x27;&#x22;,$eid,&#x22;&#x27;&#x22;,' OR pager.op_log_eid.eid = ',&#x22;&#x27;&#x22;,$eid,&#x22;&#x27;&#x22;,') AND ')" disable-output-escaping="yes"/>
				</xsl:if>
			</xsl:variable>

			<xsl:variable name="filter">
				<xsl:call-template name="browse:fill-from-vza">
					<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
					<xsl:with-param name="sql-where"><xsl:value-of select="$env-where"/>
						<xsl:if test="not(sw:param('filter_ve-title') != '')">
							(pager.op_log.parent_id = '') and	
						</xsl:if>
						pager.op_log.latest=true
					</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>

			<ui:content>
				<ui:block width="full">
					<ui:browse title="{sw:text('Tasks Log')}">
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>

						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Select at least one task!</sw:text>
							</ui:warn>
						</ui:browse-js-many>

						<xsl:if test="$allow-cancel">
							<ui:browse-buttons>
								<ui:button type="list-selection" tip="cancel_tasks" icon="cancel" confirmation="{sw:text('Are you sure you want to cancel the selected tasks?')}" script="if (!atLeastOne()) return false;" name="cancel">
									<sw:text>Cancel Tasks</sw:text>
								</ui:button>
							</ui:browse-buttons>
						</xsl:if>

						<!-- form definition for other controls -->
						<ui:form action="list-control"/>

						<ui:browse-empty-msg>
							<sw:text>No tasks have been performed.</sw:text>
						</ui:browse-empty-msg>
					</ui:browse>
				</ui:block>
			</ui:content>

		</ui:screen>
	</xsl:template>


</xsl:stylesheet>
