<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred show server_group units"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:local		="http://www.swsoft.com/xsl/cp/local"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:show		="http://www.swsoft.com/xsl/cp/show"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"
>

	<xsl:variable name="src-dn" select="units:decode-dn(sw:param('src_dn'))"/>
	<xsl:variable name="dst-dn" select="units:decode-dn(sw:param('dst_dn'))"/>
	<xsl:variable name="remove-dn" select="units:decode-dn(sw:param('dn'))"/>
	<xsl:variable name="src-id" select="sw:base64-decode(sw:param('id'))"/>
	
	<xsl:variable name="type-dnd" select="sw:param('type_dnd')"/>

	<xsl:template match="node()|@*">
				
		<xsl:variable name="packet-rtf" select="local:make-packet()"/>
		<xsl:variable name="res" select="sw:xchg($packet-rtf)/packet/data"/>
		<xsl:variable name="res-error" select="$res/error|$res/server_group/error"/>

		<xsl:variable name="reload-dn">
			<xsl:choose>
				<xsl:when test="$type-dnd='move_ve' or $type-dnd='add_ve' or $type-dnd='add_hn' or $type-dnd='remove_ve' or $type-dnd='remove_hn'">
					<xsl:value-of disable-output-escaping="yes" select="units:logical-top-dn()"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="units:is-tree-logical(units:encode-dn($dst-dn))"><xsl:value-of disable-output-escaping="yes" select="units:logical-top-dn()"/></xsl:when>
						<xsl:otherwise><xsl:value-of disable-output-escaping="yes" select="units:infra-top-dn()"/></xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$res-error">
					<xsl:value-of select="$res-error/message"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$reload-dn!=''">
					<refresh_id>
					[refresh_id]
						parent.menu.reloadGroup(
							'<xsl:value-of select="$reload-dn"/>',
							'<xsl:value-of select="sw:base64-encode($reload-dn)"/>',
							'<xsl:value-of select="units:tree-dn(units:dn2tree($reload-dn))"/>');
					[/refresh_id]
					</refresh_id>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>
  
	<func:function name="local:make-packet">
		<func:result>
			<xsl:choose>

			<!--remove VE from Logical-->
			<xsl:when test="$type-dnd='remove_ve'">
				<packet>
				<target>infrastructurem</target>
				<cookie>
					<msg>
						<ok><sw:text>The Container(s) has/have been removed.</sw:text></ok>
						<error><sw:text>Failed to remove the Container(s).</sw:text></error>
					</msg>
				</cookie>	
				<data>
					<infrastructurem>
						<del_env>
							<name><xsl:value-of disable-output-escaping="yes" select="$remove-dn"/></name>
							<eid><xsl:value-of select="$src-id"/></eid>
						</del_env>
					</infrastructurem>
				</data>
			</packet>
			</xsl:when>

			<!--remove HN from Logical-->
			<xsl:when test="$type-dnd='remove_hn'">
				<packet>
				<target>infrastructurem</target>
				<cookie>
					<msg>
						<ok><sw:text>The HN(s) has/have been removed.</sw:text></ok>
						<error><sw:text>Failed to remove the HN(s).</sw:text></error>
					</msg>
				</cookie>	
				<data>
					<infrastructurem>
						<del_env>
							<name><xsl:value-of disable-output-escaping="yes" select="$remove-dn"/></name>
							<eid><xsl:value-of select="$src-id"/></eid>
						</del_env>
					</infrastructurem>
				</data>
			</packet>
			</xsl:when>

			<!--add HN to Logical-->
			<xsl:when test="$type-dnd='add_ve'">
				<packet>
				<target>infrastructurem</target>
				<cookie>
					<msg>
						<ok>The items have been added successfully.</ok>
						<error>Failed to add the items.</error>
					</msg>
				</cookie>	
				<data>
					<infrastructurem>
						<add_env>
							<name><xsl:value-of disable-output-escaping="yes" select="$dst-dn"/></name>
							<eid><xsl:value-of select="$src-id"/></eid>
						</add_env>
					</infrastructurem>
				</data>
			</packet>
			</xsl:when>

			<!--add HN to Logical-->
			<xsl:when test="$type-dnd='add_hn'">
				<packet>
				<target>infrastructurem</target>
				<cookie>
					<msg>
						<ok>The Hardware Node(s) has/have been successfully added.</ok>
						<error>Failed to add the Hardware Node(s).</error>
					</msg>
				</cookie>	
				<data>
					<infrastructurem>
						<add_env>
							<name><xsl:value-of disable-output-escaping="yes" select="$dst-dn"/></name>
							<eid><xsl:value-of select="$src-id"/></eid>
						</add_env>
					</infrastructurem>
				</data>
			</packet>
			</xsl:when>

			<!--move VE in Logical-->
			<xsl:when test="$type-dnd='move_ve'">
				<packet>
				<target>infrastructurem</target>
				<cookie>
					<msg>
						<ok><sw:text>The Container shortcut(s) has/have been moved.</sw:text></ok>
						<error><sw:text>Failed to move the Container shortcut(s).</sw:text></error>
					</msg>
				</cookie>	
				<data>
					<infrastructurem>
						<move_env>
							<src><xsl:value-of disable-output-escaping="yes" select="$src-dn"/></src>
							<dst><xsl:value-of disable-output-escaping="yes" select="$dst-dn"/></dst>
							<eid><xsl:value-of select="$src-id"/></eid>
						</move_env>
						<xsl:if test="not($src-dn=$dst-dn)">
							<del_env>
								<name><xsl:value-of disable-output-escaping="yes" select="$src-dn"/></name>
								<eid><xsl:value-of select="$src-id"/></eid>
							</del_env>
						</xsl:if>
					</infrastructurem>
				</data>
			</packet>
			</xsl:when>

			<!--move HN in Infrastructure-->
			<xsl:when test="$type-dnd='move_hn'">
				<packet>
				<target>infrastructurem</target>
				<cookie>
					<msg>
						<ok><sw:text>The HN(s) has/have been moved.</sw:text></ok>
						<error><sw:text>Failed to move the HN(s).</sw:text></error>
					</msg>
				</cookie>	
				<data>
					<infrastructurem>
						<move_env>
							<src><xsl:value-of disable-output-escaping="yes" select="$src-dn"/></src>
							<dst><xsl:value-of disable-output-escaping="yes" select="$dst-dn"/></dst>
							<eid><xsl:value-of select="$src-id"/></eid>
						</move_env>
					</infrastructurem>
				</data>
			</packet>
			</xsl:when>
			
			<!--move HN in logical -->
			<xsl:when test="$type-dnd='logical_move_hn'">
				<packet>
				<target>infrastructurem</target>
				<cookie>
					<msg>
						<ok><sw:text>The HN(s) has/have been moved.</sw:text></ok>
						<error><sw:text>Failed to move the HN(s).</sw:text></error>
					</msg>
				</cookie>	
				<data>
					<infrastructurem>
						<move_env>
							<src><xsl:value-of disable-output-escaping="yes" select="$src-dn"/></src>
							<dst><xsl:value-of disable-output-escaping="yes" select="$dst-dn"/></dst>
							<eid><xsl:value-of select="$src-id"/></eid>
						</move_env>
						<xsl:if test="not($src-dn=$dst-dn)">
							<del_env>
								<name><xsl:value-of disable-output-escaping="yes" select="$src-dn"/></name>
								<eid><xsl:value-of select="$src-id"/></eid>
							</del_env>
						</xsl:if>
					</infrastructurem>
				</data>
			</packet>
			</xsl:when>

			<!--move Units in Infrastructure and Logical-->
			<xsl:otherwise>
			<packet>
				<target>infrastructurem</target>
				<data>
					<infrastructurem>
						<edit>
							<name><xsl:value-of disable-output-escaping="yes" select="$src-dn"/></name>
							<unit>
								<name><xsl:value-of disable-output-escaping="yes" select="concat( units:dn2name($src-dn),',', $dst-dn )"/></name>
							</unit>
						</edit>
					</infrastructurem>
				</data>
			</packet>
			</xsl:otherwise>
		</xsl:choose>
		</func:result>
		
	</func:function>
  
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/swa/server-group.xsl"/>

</xsl:stylesheet>
