<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred global"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:global="http://www.swsoft.com/xsl/cp/global"  
  xmlns:local		="http://www.swsoft.com/xsl/cp/local"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:ui			="http://www.swsoft.com/xsl/cp/ui"
	xmlns:authm		="http://www.swsoft.com/xsl/cp/authm">

	<sw:include href="/lib/swa/authm.xsl"/>	

	<xsl:template mode="screen" match="/">
		<ui:body-screen>
			<ui:content>			
				<xsl:variable name="realm-eid" select="sw:base64-decode(sw:param('realm_eid'))"/>
				<ui:raw>|<xsl:for-each select="sw:param('login')"
				><xsl:variable name="login" select="sw:base64-decode(.)"/><xsl:value-of select="local:seek-user($login,$realm-eid)"
				/>|</xsl:for-each></ui:raw>					
			</ui:content>
		</ui:body-screen>
										
  </xsl:template>
  
  <!-- Find user by login and realm and return SID or empty string -->
  <func:function name="local:seek-user">
  	<xsl:param name="login"/>
  	<xsl:param name="realm-eid"/>  	
  	
  	<xsl:variable name="result-attrs-rtf">
  		<name>objectSid</name>
  	</xsl:variable>
  	<xsl:variable name="result-attrs" select="exsl:node-set($result-attrs-rtf)"/>
  	<xsl:variable name="vz-realm-id" select="sw:internal-realm-id()"/>
  	
  	<xsl:variable name="users-rtf">
  		<xsl:choose>
  			<xsl:when test="$realm-eid=$global:system-realm-id 
  				or $realm-eid=$vz-realm-id">
  				<xsl:variable name="sys-user" select="authm:get-user(authm:user-key($login,$realm-eid),false())"/>
  				<xsl:if test="not($sys-user[self::error])">
  					<user>
  						<xsl:copy-of select="$sys-user/*"/>
  					</user>
  				</xsl:if>
  			</xsl:when>
  			<xsl:otherwise>
  				<xsl:variable name="sa-filter-rtf">
  					<attr>
  						<name>sAMAccountName</name>
  						<value><xsl:value-of select="sw:base64-encode($login)"/></value>
  						<realm><xsl:value-of select="$realm-eid"/></realm>
  					</attr>
  				</xsl:variable>
  				<xsl:variable name="cn-filter-rtf">
  					<attr>
  						<name>CN</name>
  						<value><xsl:value-of select="sw:base64-encode($login)"/></value>
  						<realm><xsl:value-of select="$realm-eid"/></realm>
  					</attr>
  				</xsl:variable>
  				<xsl:variable name="sa-users"
  					select="authm:get-users('',exsl:node-set($sa-filter-rtf),$result-attrs)"/>
  				<xsl:choose>
  					<xsl:when test="count($sa-users/authm/user)=0">
  						<xsl:copy-of 
  							select="authm:get-users('',exsl:node-set($cn-filter-rtf),$result-attrs)/authm/user"/>
  					</xsl:when>
  					<xsl:otherwise>
  						<xsl:copy-of select="$sa-users/authm/user"/>
  					</xsl:otherwise>
  				</xsl:choose>
  			</xsl:otherwise>
  		</xsl:choose>
  	</xsl:variable>

  	<xsl:variable name="users" select="exsl:node-set($users-rtf)"/>
		<xsl:choose>
			<xsl:when test="count($users/user)=1">
				<func:result select="$users/user[1]/data/attr[name='objectSid']/value"/>
			</xsl:when>
			<xsl:otherwise>
				<func:result select="''"/>
			</xsl:otherwise>
		</xsl:choose>
  </func:function>
  
	<!-- includes -->
	<sw:include href="/lib/vza/filem.xsl"/>		
	
  <sw:include href="/lib/screen.xsl"/>
  <sw:include href="/lib/vocabulary.xsl"/>  


</xsl:stylesheet>
