	<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred units env vzaconfig local func check format"
exclude-result-prefixes="exsl browse ui cred units env vzaconfig local licensem vzcpsummary func check show format"
  xmlns:xsl		  ="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	  ="http://exslt.org/common"
  xmlns:sw		  ="http://www.swsoft.com/xsl/cp"
  xmlns:browse  = "http://www.swsoft.com/xsl/cp/browse" 
  xmlns:ui  		="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:cred    ="http://www.swsoft.com/xsl/cp/cred"
  xmlns:units   ="http://www.swsoft.com/xsl/cp/units"
  xmlns:env     ="http://www.swsoft.com/xsl/cp/env"
  xmlns:vzaconfig  	="http://www.swsoft.com/xsl/cp/vzaconfig"
  xmlns:local      	="http://www.swsoft.com/xsl/cp/local"
  xmlns:licensem   	="http://www.swsoft.com/xsl/cp/licensem"	  
  xmlns:vzcpsummary ="http://www.swsoft.com/xsl/cp/vzcpsummary"
	xmlns:func  			="http://exslt.org/functions"
	xmlns:check				="http://www.swsoft.com/xsl/cp/check"
	xmlns:show				="http://www.swsoft.com/xsl/cp/show"
	xmlns:format			="http://www.swsoft.com/xsl/cp/format"
>
	
	<sw:include href="/lib/utils/format-number.xsl"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="parent-dn" select="units:current-dn()"/>
		<xsl:variable name="unit" select="units:find-unit($parent-dn)"/>
		<xsl:variable name="unit-type" select="sw:base64-decode($unit/attr[name='vzlUnitType']/value)"/>
		<ui:screen id="10.00.00.01.05" icon="{units:folder-types()[@type = $unit-type]/@icon}">
			<ui:properties>
				<ui:form-get/>
				<ui:description width="full">
					<sw:text>An overview of Hardware Nodes and Containers in your datacenter. You can click the hyperlinked numbers below to see the corresponding lists of objects or launch common tasks from the Tasks group.</sw:text>
				</ui:description>
			</ui:properties>
			<xsl:call-template name="units:define-unit-toolbars"/>
			
			<ui:tab-bar id="unit" current-tab="summary"/>
		
			<ui:content>    	    	    
				<ui:block width="full">
					<xsl:call-template name="local:infrastructure-summary">
						<xsl:with-param name="parent-dn" select="$parent-dn"/>
					</xsl:call-template>
				</ui:block>      	
			</ui:content>          
		</ui:screen>
	</xsl:template>  

	<xsl:template name="local:infrastructure-summary">
		<xsl:param name="parent-dn"/>
		<xsl:variable name="unit-summary" select="vzcpsummary:get-unit-summary($parent-dn)"/>

		<xsl:variable name="ve-status-total" 				select="format:normalize-number($unit-summary/ve_summary/total)"/>
		<xsl:variable name="ve-status-running" 			select="format:normalize-number($unit-summary/ve_summary/group[name = 'running']/count)"/>
		<xsl:variable name="ve-status-stopped" 			select="$ve-status-total - $ve-status-running"/>
		<xsl:variable name="ve-status-attention" 		select="format:normalize-number($unit-summary/ve_summary/group[name = 'alerted']/count)"/>

		<xsl:variable name="ve-os-total"						select="$ve-status-total"/>
		<xsl:variable name="ve-os-windows"					select="format:normalize-number($unit-summary/ve_summary/group[name = 'windows']/count)"/>
		<xsl:variable name="ve-os-linux"						select="format:normalize-number($unit-summary/ve_summary/group[name = 'linux']/count)"/>
		<xsl:variable name="ve-os-other"						select="$ve-os-total - $ve-os-windows - $ve-os-linux"/>

		<xsl:variable name="ve-platform-total" 			select="$ve-status-total"/>
		<xsl:variable name="ve-platform-virtuozzo"	select="format:normalize-number($unit-summary/ve_summary/group[name = 'virtuozzo']/count)"/>
		<xsl:variable name="ve-platform-vmware" 		select="format:normalize-number($unit-summary/ve_summary/group[name = 'vmware']/count)"/>
		<xsl:variable name="ve-platform-xen"				select="format:normalize-number($unit-summary/ve_summary/group[name = 'xen']/count)"/>


		<xsl:variable name="hn-status-total" 				select="format:normalize-number($unit-summary/hn_summary/total)"/>
		<xsl:variable name="hn-status-running" 			select="format:normalize-number($unit-summary/hn_summary/group[name = 'running']/count)"/>
		<xsl:variable name="hn-status-stopped" 			select="$hn-status-total - $hn-status-running"/>
		<xsl:variable name="hn-status-attention" 		select="format:normalize-number($unit-summary/hn_summary/group[name = 'alerted']/count)"/>

		<xsl:variable name="hn-os-total"						select="$hn-status-total"/>
		<xsl:variable name="hn-os-windows"					select="format:normalize-number($unit-summary/hn_summary/group[name = 'windows']/count)"/>
		<xsl:variable name="hn-os-linux"						select="format:normalize-number($unit-summary/hn_summary/group[name = 'linux']/count)"/>
		<xsl:variable name="hn-os-other"						select="$hn-os-total - $hn-os-windows - $hn-os-linux"/>

		<xsl:variable name="hn-platform-total" 			select="$hn-status-total"/>
		<xsl:variable name="hn-platform-virtuozzo"	select="format:normalize-number($unit-summary/hn_summary/group[name = 'virtuozzo']/count)"/>
		<xsl:variable name="hn-platform-vmware" 		select="format:normalize-number($unit-summary/hn_summary/group[name = 'vmware']/count)"/>
		<xsl:variable name="hn-platform-xen"				select="format:normalize-number($unit-summary/hn_summary/group[name = 'xen']/count)"/>

		<xsl:variable name="access-map-rtf">
			<xsl:call-template name="cred:access-map">
				<xsl:with-param name="creds-rtf">
					<cred id="vzcp.env.create" security-obj-type="vzcp"/>
					<cred id="vzcp.env.import" security-obj-type="vzcp"/>
					<cred id="vzcp.virtuozzo_group.manage" security-obj-type="vzcp"/>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="access-map" select="exsl:node-set($access-map-rtf)/cred"/>
	
		<ui:summary-cols>
			<ui:summary-col>
				<ui:summary-block title="{sw:text('Containers')}">
					<ui:tally title="{sw:text('Status')}">
						<ui:tally-sum href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_ve-status=">
							<xsl:value-of select="$ve-status-total"/>
						</ui:tally-sum>
						<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_ve-status=ve-status_running" title="{sw:text	('Running')}" 	icon="green">
							<xsl:value-of select="$ve-status-running"/>
						</ui:tally-row>
						<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_ve-status=ve-status_not_running" title="{sw:text		('Stopped')}" icon="grey">
							<xsl:value-of select="$ve-status-stopped"/>
						</ui:tally-row>
						<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_ve-status=alert-type-icon_ra" title="{sw:text('Require attention')}" icon="yellow">
							<xsl:value-of select="$ve-status-attention"/>
						</ui:tally-row>
					</ui:tally>
	
					<ui:tally title="{sw:text('OS')}">
						<ui:tally-sum href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_platform-os=">
							<xsl:value-of select="$ve-os-total"/>
						</ui:tally-sum>
						<xsl:if test="$ve-os-windows">
							<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_platform-os=Windows" title="{sw:text	('Windows')}" 	icon="os_win">
								<xsl:value-of select="$ve-os-windows"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$ve-os-linux">
							<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_platform-os=Linux" title="{sw:text('Linux')}" 		icon="os_lin">
								<xsl:value-of select="$ve-os-linux"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$ve-os-other">
							<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_platform-os=Other" title="{sw:text('Other')}">
								<xsl:value-of select="$ve-os-other"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$ve-os-total=0">
							<ui:tally-row href=""/>
						</xsl:if>
					</ui:tally>
				
					<ui:tally title="{sw:text('Technology')}">
						<ui:tally-sum href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_vt-type=">
							<xsl:value-of select="$ve-platform-total"/>
						</ui:tally-sum>
						<xsl:if test="$ve-platform-virtuozzo">
							<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_vt-type=virtuozzo" title="{sw:text('Virtuozzo')}" 		icon="platform_vz">
								<xsl:value-of select="$ve-platform-virtuozzo"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$ve-platform-vmware">
							<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_vt-type=vmware" title="{sw:text('VMWare')}" 		icon="platform_vmware">
								<xsl:value-of select="$ve-platform-vmware"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$ve-platform-xen">
							<ui:tally-row href="{$baseurl}/vt/envs/index?tab-force=default&amp;filter_action=force_search&amp;filter_vt-type=xen" title="{sw:text('Xen')}" 		icon="platform_xen">
								<xsl:value-of select="$ve-platform-xen"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$ve-platform-total=0">
							<ui:tally-row href=""/>
						</xsl:if>
					</ui:tally>
				</ui:summary-block>
	
				<ui:summary-block title="{sw:text('Hardware Nodes')}">
					<ui:tally title="{sw:text('Status')}">
						<ui:tally-sum href="{$baseurl}/vt/hns/index?tab-force=default&amp;filter_action=force_search&amp;filter_hn-status=">
							<xsl:value-of select="$hn-status-total"/>
						</ui:tally-sum>
						<ui:tally-row href="{$baseurl}/vt/hns/index?tab-force=default&amp;filter_action=force_search&amp;filter_hn-status=hn-status_online" title="{sw:text('Online')}" 	icon="green">
							<xsl:value-of select="$hn-status-running"/>
						</ui:tally-row>
						<ui:tally-row href="{$baseurl}/vt/hns/index?tab-force=default&amp;filter_action=force_search&amp;filter_hn-status=hn-status_offline" title="{sw:text('Offline')}" 	icon="grey">
							<xsl:value-of select="$hn-status-stopped"/>
						</ui:tally-row>
						<ui:tally-row href="{$baseurl}/vt/hns/index?tab-force=default&amp;filter_action=force_search&amp;filter_hn-status=hn-alert-type-icon_ra" title="{sw:text('Require attention')}" icon="yellow">
							<xsl:value-of select="$hn-status-attention"/>
						</ui:tally-row>
					</ui:tally>
					<ui:tally title="{sw:text('OS')}">
						<ui:tally-sum href="{$baseurl}/vt/hns/index?tab-force=default&amp;filter_action=force_search&amp;filter_hn-status=">
							<xsl:value-of select="$hn-os-total"/>
						</ui:tally-sum>
						<xsl:if test="$hn-os-windows">
							<ui:tally-row href="{$baseurl}/vt/hns/index?tab-force=default&amp;filter_action=force_search&amp;filter_hn-status=platform-os_Windows" title="{sw:text('Windows')}" 		icon="os_win">
								<xsl:value-of select="$hn-os-windows"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$hn-os-linux">
							<ui:tally-row href="{$baseurl}/vt/hns/index?tab-force=default&amp;filter_action=force_search&amp;filter_hn-status=platform-os_Linux" title="{sw:text('Linux')}" 		icon="os_lin">
								<xsl:value-of select="$hn-os-linux"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$hn-os-other">
							<ui:tally-row href="{$baseurl}/vt/hns/index?tab-force=default&amp;filter_action=force_search&amp;filter_hn-status=platform-os_Other" title="{sw:text('Other')}">
								<xsl:value-of select="$hn-os-other"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$hn-os-total=0">
							<ui:tally-row href=""/>
						</xsl:if>
					</ui:tally>
					<ui:tally title="{sw:text('Technology')}">
						<ui:tally-sum href="{$baseurl}/vt/hns/index?tab-force=default">
							<xsl:value-of select="$hn-platform-total"/>
						</ui:tally-sum>
						<xsl:if test="$hn-platform-virtuozzo">
							<ui:tally-row href="{$baseurl}/vt/hns/index?tab-force=default" title="{sw:text('Virtuozzo')}" icon="platform_vz">
								<xsl:value-of select="$hn-platform-virtuozzo"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$hn-platform-vmware">
							<ui:tally-row href="{$baseurl}/vt/hns/index" title="{sw:text('VMWare')}" icon="platform_vmware">
								<xsl:value-of select="$hn-platform-vmware"/>
							</ui:tally-row>
						</xsl:if>
						<xsl:if test="$hn-platform-xen">
							<ui:tally-row href="{$baseurl}/vt/hns/index" title="{sw:text('Xen')}" icon="platform_xen">
								<xsl:value-of select="$hn-platform-xen"/>
							</ui:tally-row>
						</xsl:if>    					
						<xsl:if test="$hn-platform-total=0">
							<ui:tally-row href=""/>
						</xsl:if>
					</ui:tally>
				</ui:summary-block>
			</ui:summary-col>
			<ui:summary-col>
				<ui:summary-block title="{sw:text('Overall Status')}">
					<ui:simple-table>
						<row>
							<xsl:choose>
								<xsl:when test="$ve-status-attention = 0">
									<col valign="middle">
										<img src="/{$theme}/icons/green_16.gif" width="16" height="16"/>
									</col>
									<col width="100%" valign="middle">
										<sw:text>All Containers are operating normally.</sw:text>
									</col>
								</xsl:when>
								<xsl:otherwise>
									<col valign="middle">
										<img src="/{$theme}/icons/red_16.gif" width="16" height="16"/>
									</col>
									<col width="100%" valign="middle">
										<sw:text-plural>
											<sw:text-zero />
											<xsl:with-param name="num" select="$ve-status-attention"/>
											<xsl:with-param name="aopen">&lt;a href="<xsl:value-of select="concat($baseurl,'/vt/envs/index')"/>?tab-		force=default&amp;filter_action=force_search&amp;filter_ve-status=alert-type-icon_ra"&gt;</xsl:with-param>
											<xsl:with-param name="aclose">&lt;/a&gt;</xsl:with-param>
											<sw:text-single>%{aopen}1%{aclose} Container requires the administrator's attention.</sw:text-single>
											<sw:text-multiple>%{aopen}%{num}%{aclose} Containers require the administrator's attention.</sw:text-multiple>
										</sw:text-plural>
									</col>
								</xsl:otherwise>
							</xsl:choose>
						</row>
						<row>
							<xsl:choose>
								<xsl:when test="$hn-status-attention = 0">
									<col valign="middle">
										<img src="/{$theme}/icons/green_16.gif" width="16" height="16"/>
									</col>
									<col width="50%" valign="middle">
										<sw:text>All Hardware Nodes are operating normally.</sw:text>
									</col>
								</xsl:when>
								<xsl:otherwise>
									<col valign="middle">
										<img src="/{$theme}/icons/red_16.gif" width="16" height="16"/>
									</col>
									<col width="50%" valign="middle">
										<sw:text-plural>
											<sw:text-zero />
											<xsl:with-param name="num" select="$hn-status-attention"/>
											<xsl:with-param name="aopen">&lt;a href="<xsl:value-of select="concat($baseurl,'/vt/hns/index')"/>?tab-		force=default&amp;filter_action=force_search&amp;filter_hn-status=hn-alert-type-icon_ra"&gt;</xsl:with-param>
											<xsl:with-param name="aclose">&lt;/a&gt;</xsl:with-param>
											<sw:text-single>%{aopen}1%{aclose} Hardware Node requires the administrator's attention.</sw:text-single>
											<sw:text-multiple>%{aopen}%{num}%{aclose} Hardware Nodes require the administrator's attention.</sw:text-multiple>
										</sw:text-plural>
									</col>
								</xsl:otherwise>
							</xsl:choose>
						</row>
					</ui:simple-table>
				</ui:summary-block>			
				
				<ui:summary-block title="{sw:text('Tasks')}">
					<ui:summary-tasks folder-type="{sw:if(units:is-dn-top($parent-dn),'top','child')}-{sw:if(units:is-tree-logical($parent-dn),'logical','infrastructure')}"/>
				</ui:summary-block>
			</ui:summary-col>
		</ui:summary-cols>
	
	</xsl:template>


  <sw:include href="/lib/swa/licensem.xsl"/>

	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	<sw:include href="/lib/vzaconfig.xsl"/>	
	<sw:include href="/lib/swa/vzcpsummary.xsl"/>		
	  
</xsl:stylesheet>
