<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local units"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:units			="http://www.swsoft.com/xsl/cp/units"
>

	<sw:include href="/lib/core/units-core.xsl"/>

  <!-- check permissions to show this page -->
	<xsl:variable name="cr-manage"								select="cred:check-context('vzcp.units.edit','unit.farm')"/>

  <xsl:param name="wiz_code" select="'cluster-unit'"/>
  
	<xsl:variable name="step_data"	select="wiz:getStep()"/>
	<xsl:variable name="step"				select="$step_data/@id"/>
	<xsl:variable name="screen-id"		select="$step_data/@screenid"/>

	<xsl:variable name="access-denied" select="not($cr-manage)"/>
  <xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="create" select="not($form/unit-id!='')"/>  
    
  <!-- Wizard, Step 'Unit Settings' -->
  <xsl:template name="step_unit">
  	
  	<xsl:variable name="current-tree" select="units:dn2tree($form/unit-id)"/>  	
  	<xsl:variable name="folder-types" select="units:folder-types()[not(@tree) or @tree=$current-tree]"/>  	
  	
  	<xsl:if test="sw:sesput('cluster-unit-title',$form/src/name)"/>
  	
  	<ui:screen id="{$screen-id}">  	
  	
	    <ui:properties>
	      <ui:form-get/>
	    	<ui:refresh-type>none</ui:refresh-type>    	
	    </ui:properties>
	
	    <ui:content>
	      <ui:hidden name="step" value="unit"/>    
	      <ui:block mode="edit">
	      	
	   			<ui:rows title="{sw:text('Title')}">	   			
	   				<ui:row>
							<ui:cell-input id="name" required="true" maxlength="1000"> 
								<xsl:attribute name="value"><xsl:value-of select="$form/unit/name"/></xsl:attribute>
							</ui:cell-input>
						</ui:row>																							
					</ui:rows>
					
					<xsl:choose>
	      		<xsl:when test="count($folder-types)=1">
	      			<ui:hidden name="type" value="{$folder-types[1]/@type}" />
	      		</xsl:when>
	      		<xsl:when test="count($folder-types) &gt; 1">
			      	<ui:rows title="{sw:text('Folder Type')}">	   			      	
			      		<xsl:for-each select="$folder-types">
				      		<ui:row>
					 					<ui:cell-radio name="type" id="type_{position()}" value="{@type}" checked="{$form/unit/type=@type}"/>
										<ui:cell cell-width="100%" align="left">
											<img src="/{$theme}/icons/{@icon}_16.gif" border="0" width="16" height="16"/>
											&#160;<xsl:value-of select="@title"/>
										</ui:cell>
									</ui:row>
								</xsl:for-each>
			      	</ui:rows>
			      </xsl:when>
			      <xsl:otherwise>
			      	<sw:die>
			      		No any avaiable folder types for tree <xsl:value-of select="$current-tree"/>
			      	</sw:die>
			      </xsl:otherwise>
			   	</xsl:choose>
					
	        <ui:buttons>
	        	<xsl:call-template name="wiz:showButtons" />        	
	        </ui:buttons>
	        
	     	</ui:block>
	    </ui:content>   
    </ui:screen>
  </xsl:template>
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
			<xsl:choose>
			
				<xsl:when test="$step = 'unit'">
					<xsl:call-template name="step_unit"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="step_unit"/>
				</xsl:otherwise>
				
			</xsl:choose>
		
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>			
	
</xsl:stylesheet>
