<!--
	Copyright (c) SWsoft, 1999-2007
	All rights reserved.
-->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred trace func units local env vzaconfig"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:func			="http://exslt.org/functions"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" 
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred" 
	xmlns:trace="http://www.swsoft.com/xsl/cp/trace"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:units="http://www.swsoft.com/xsl/cp/units"
	xmlns:env     ="http://www.swsoft.com/xsl/cp/env"	
	xmlns:ve					="http://www.swsoft.com/xsl/cp/ve"	
	xmlns:hn	="http://www.swsoft.com/xsl/cp/hn"
	xmlns:vzaconfig	  ="http://www.swsoft.com/xsl/cp/vzaconfig"
		
>

	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/vt/ve-core.xsl"/>	
	<sw:include href="/lib/core/units-tree.xsl"/>
	<sw:include href="/lib/vzaconfig.xsl"/>		
	
	<xsl:variable name="level" select="sw:param('level')"/>
	<xsl:variable name="eid" select="sw:base64-decode(sw:param('eid'))"/>
	<xsl:variable name="tree-id" select="sw:base64-decode(sw:param('tree-id'))"/>
	<xsl:variable name="base-item-id" select="concat('eid=',sw:base64-encode($eid),',',$tree-id)"/>

	<xsl:variable name="envs-req">
		<fields>
			<env.eid/>
			<env.vconfig.veid/>
			<env.parent_eid	/>			
			<env.title/>
			<env.state/>
			<env.alert_type/>
		</fields>
		<where>
			<xsl:choose>
				<xsl:when test="not(vzaconfig:show-sve())">
					<xsl:copy-of select="ve:get-veid-range-filter()"/>			
				</xsl:when>
				<xsl:otherwise test="vzaconfig:show-sve()">
					pager.env.eid != ''	
				</xsl:otherwise>
			</xsl:choose>
			 	AND (pager.env.parent_eid='<xsl:value-of select="$eid"/>' )
		</where>
	</xsl:variable>
	<xsl:variable name="envs-all" select="sw:xchg-sql($envs-req)/pager/row_set"/>	

	<!-- search vzenv screen in path -->
	<xsl:template mode="screen" match="/">
		<ui:body-screen>			
			<ui:content>
				<ui:raw>
					<xsl:call-template name="local:show-ves">
						<xsl:with-param name="level" select="$level"/>
					</xsl:call-template>
					<xsl:comment><![CDATA[<<<<<]]><xsl:value-of select="sw:base64-encode($base-item-id)"/><![CDATA[>>>>>]]></xsl:comment>					
				</ui:raw>
			</ui:content>
		</ui:body-screen>			
	</xsl:template>	
	
	<xsl:template name="local:show-ves">
		<xsl:variable name="display-mode" select="'menu'"/><!-- leftover from the Farm Director Tree View screen -->
		<div>
			<xsl:for-each select="$envs-all/row/env">
				<xsl:sort select="title"/>

				<xsl:variable name="plat2" select="hn:hn2platform(env:get-env(parent_eid)/env)"/>
				<xsl:variable name="menu-id">
					<xsl:choose>
						<xsl:when test="contains( $plat2, 'linux' )">linux.ve.vz.vt</xsl:when>
						<xsl:when test="contains( $plat2, 'windows' )">windows.ve.vz.vt</xsl:when>
						<xsl:otherwise>0</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				<xsl:variable name="ve-pref">
					<xsl:choose>
						<xsl:when test="units:is-tree-logical($base-item-id)"><xsl:value-of select="sw:base64-encode($base-item-id)"/></xsl:when>
						<xsl:otherwise>INF_</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>

				<xsl:variable name="item-id" select="concat($base-item-id,'_',eid)"/>
				<xsl:variable name="href"><xsl:value-of select="$baseurl"/>/vzdir/infrman/envs/env?id=<xsl:value-of select="sw:base64-encode(eid)"/>&amp;context=hn&amp;parent-dn=<xsl:value-of select="sw:base64-encode($tree-id)"/></xsl:variable>
				<xsl:variable name="env-state" select="state"/>
				<xsl:variable name="left-icon" select="$ve:state[vza-value=$env-state]/left-icon"/>
				<table cellpadding="0" cellspacing="0" border="0" width="100%" id="item_{$item-id}" class="{sw:if($display-mode = 'menu', 'MenuItem', 'TreeItem')}">
					<tr>
						<xsl:if test="$level &gt; 1">
							<td style="width:{$level * 14}px"><img src="/{$theme}/images/1x1.gif" border="0" width="{$level * 14}" height="16"/></td>
						</xsl:if>
						<td  style="width:16px;" align="right" class="{sw:if($display-mode = 'menu', 'MenuTreeNode', 'TreeNode')}">
							<img src="/{$theme}/images/1x1.gif" border="0" width="16" height="16"/>
						</td>
						<td class="{sw:if($display-mode = 'menu', 'MenuItemImage', 'TreeItemImage')}">
							<!--onclick="showSelectedItem('item_{$tree-id}_{eid}')"-->
							<a href="{$href}" target="main" 
								onmouseover="mRM=1"
								onmouseout="mRM=0"
								oncontextmenu="rML('{$menu-id}','{eid}','{title}')"
								onmousedown="moveDIV('{$ve-pref}obj_lid_','{$ve-pref}img_lid_','{eid}',event,'item_{$item-id}','@::ve.vz.vt@::{hn:hn2platform( env:get-env(parent_eid)/env )}')"
							>
								<img id="{$ve-pref}img_lid_{eid}" src="/{$theme}/icons/{$left-icon}" border="0" width="16" height="16"/>
							</a>
						</td>
						<!-- Show Title -->
						<td nowrap="nowrap" class="{sw:if($display-mode = 'menu', 'MenuItemText', 'TreeItemText')}">
							<!--onclick="showSelectedItem('item_{$tree-id}_{eid}')"-->
							<a href="{$href}" target="main" id="{$ve-pref}obj_lid_{eid}"
								onmouseover="mRM=1"
								onmouseout="mRM=0"
								oncontextmenu="rML('{$menu-id}','{eid}','{title}')"
								onmousedown="moveDIV('{$ve-pref}obj_lid_','{$ve-pref}img_lid_','{eid}',event,'item_{$item-id}','@::ve.vz.vt@::{hn:hn2platform( env:get-env(parent_eid)/env )}')"
							>
								<xsl:value-of select="title"/>
							</a>
							<xsl:variable name="alert_icon" select="alert_type"/>
							<span id="{$ve-pref}_alert_{eid}">
								<span>
								<xsl:if test="eid">
									<xsl:choose>
										<xsl:when test="$alert_icon = 3"><img src="/{$theme}/icons/alert_red_left_16.gif" border="0" width="16" height="16"/></xsl:when>
										<xsl:when test="$alert_icon = 2"><img src="/{$theme}/icons/alert_red_left_16.gif" border="0" width="16" height="16"/></xsl:when>
										<xsl:when test="$alert_icon = 1"><img src="/{$theme}/icons/alert_yellow_left_16.gif" border="0" width="16" height="16"/></xsl:when>
									</xsl:choose>
								</xsl:if>
								</span>
								<div class="hidden"><xsl:value-of select="$env-state"/></div>
							</span>
						</td>
						<!-- /Show Title -->
					</tr>
				</table>					
			</xsl:for-each>
			<xsl:if test="count($envs-all/row/env) = 0">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<xsl:if test="$level &gt; 1">
							<td style="width:{($level - 1) * 14 + 32}px"><img src="/{$theme}/images/1x1.gif" border="0" width="{($level - 1) * 14 + 32}" height="16"/></td>
						</xsl:if>					
						<td nowrap="nowrap" class="{sw:if($display-mode = 'menu', 'MenuItemText', 'TreeItemText')}" style="color:#444444; padding-left:4px">													<sw:text>Empty</sw:text>
						</td>
					</tr>			
				</table>
			</xsl:if>
		</div>
	</xsl:template>		
	
	<sw:include href="/lib/screen.xsl"/>
</xsl:stylesheet>
