<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:help="http://www.swsoft.com/xsl/cp/help">

	<xsl:variable name="topic">
		<xsl:choose>
			<xsl:when test="/http_request/get/parameter[name = 'topic']/value">
				<xsl:value-of select="/http_request/get/parameter[name = 'topic']/value"/>
			</xsl:when>
			<xsl:when test="$activeMode = 'vzcc'">5170</xsl:when>
			<xsl:otherwise>728</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="a" select="/http_request/get/parameter[name = 'a']/value"/>
	<xsl:variable name="p" select="/http_request/get/parameter[name = 'p']/value"/>

	<!-- load help page for specific topic and locale -->
	<func:function name="help:load">
		<xsl:param name="topic"/>
		<xsl:param name="lang" select="'en'"/>

		<xsl:variable name="tool" select="sw:if($activeMode = 'vzcc', 'cc', 'pp')"/>
		<xsl:variable name="file" select="concat($tool, '/', $lang,'/', $topic, '.html')"/>
		<func:result select="sw:document($file, 'help', 'noerror')"/>
	</func:function>

	<xsl:template match="/">
		<xsl:variable name="title">
			<xsl:choose>
				<xsl:when test="$activeMode = 'vzcc'">
					<sw:text>Parallels Infrastructure Manager Help</sw:text>
				</xsl:when>
				<xsl:otherwise>
					<sw:text>Parallels Power Panel Help</sw:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<ui:raw>

			<xsl:choose>

				<!-- download single page -->

				<xsl:when
					test="/http_request/get/parameter[name = 'p']/value and not(contains(/http_request/get/parameter[name = 'p']/value, '..'))">

					<!-- first try help for specific locale -->
					<xsl:variable name="c1"
						select="help:load(/http_request/get/parameter[name = 'p']/value, $active_lang_id)"/>

					<xsl:choose>
						<xsl:when test="not($c1)">
							<!-- try to load help for default locale -->
							<xsl:variable name="deflang"
								select="sw:document('languages.xml')/languages/language[default]/id"/>
							<xsl:if test="$deflang != $active_lang_id">
								<xsl:variable name="c2"
									select="help:load(/http_request/get/parameter[name = 'p']/value, $deflang)"/>
								<xsl:choose>
									<xsl:when test="not($c2)">
										<!-- try to load help for predefined 'en' locale -->
										<xsl:apply-templates mode="filter"
											select="help:load(/http_request/get/parameter[name = 'p']/value)/*"
										/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:apply-templates mode="filter" select="$c2/*"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates mode="filter" select="$c1/*"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>

				<!-- show frameset -->
				<xsl:otherwise>
					<xsl:variable name="topic-href" select="concat('?p=', $topic, sw:if($a, concat('#',$a), ''))"/>
					<html>
						<head>
							<title><sw:text>Parallels Infrastructure Manager</sw:text></title>
							<meta name="SuperTitle" content="{sw:text('Administrator&quot;s Guide')}" />
						</head>
						
						<frameset rows="23,*" framespacing="0" frameborder="0" border="0">
							<frame name="TITL" SRC="?p=title" frameborder="no" border="0" scrolling="no" marginwidth="0" marginheight="0" noresize="noresize"/>
							<frameset cols="30%,70%" framespacing="1" border="1" frameborder="yes">
								
								<frameset rows="24,*" frameborder="0" border="0">	
									<frame name="TAB" SRC="?p=tab_toc" frameborder="0" scrolling="no"  marginwidth="0" marginheight="0"/>
									<frame name="TOC" src="?p=toc" frameborder="1" scrolling="auto" marginheight="0" marginwidth="0"/>
								</frameset>
								
								<frameset rows="24,*" frameborder="0" border="0">
									<frame name="NAV" SRC="?p=navigation" frameborder="0" scrolling="no" marginheight="0" marginwidth="0"/>
									<frame name="BODY" src="{$topic-href}" frameborder="1" scrolling="auto"/>
								</frameset>								
							</frameset>
						</frameset>
						
					</html>
					
				</xsl:otherwise>

			</xsl:choose>
		</ui:raw>
	</xsl:template>

	<xsl:template match="text()|comment()" mode="filter">
		<xsl:copy-of select="."/>
	</xsl:template>

	<xsl:template match="*" mode="filter">
		<xsl:copy>
			<xsl:copy-of select="@*"/>
			<xsl:apply-templates select="node()" mode="filter"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="help:vzcp" mode="filter"/>

	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/cred.xsl"/>

</xsl:stylesheet>
