<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->
<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred env vzenv"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:html="http://www.swsoft.com/xsl/cp/html"
	xmlns:ve="http://www.swsoft.com/xsl/cp/ve"
>


	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="../lib/vz/vzenv-apps.xsl"/>

	<xsl:output method="xml" encoding="utf-8"/>

	<xsl:variable name="mail-allowed-user"
		select="not($auth-type = 'clusteruser' or $auth-type = 'pleskadmin')"/>

	<!-- save one request to agent, we already know VE status, update cache -->
	<xsl:variable name="setStatus">
		<xsl:for-each select="/packet/data/envm/env/status">
			<xsl:if test="sw:envsetstate(state)"/>
			<xsl:if test="sw:envsettransition(transition)"/>
		</xsl:for-each>
	</xsl:variable>

	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="$activeMode = 'vzcp'">
				<xsl:call-template name="body"/>
			</xsl:when>
			<xsl:otherwise>
				<packet/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="body" name="body">
		<xsl:variable name="eid" select="sw:ve-eid()"/>
		<xsl:variable name="env" select="env:get-env($eid)/env"/>

		<ui:screen id="03.00.00.00.06" title="{sw:text('Container')}" icon="top">
			<ui:properties>
				<ui:width value="fixed"/>
				<ui:description>
					<sw:text>
            You are logged into <b>Parallels Power Panel</b>. <br/> This powerful and easy-to-use tool allows you to manage your Container.
          </sw:text>
				</ui:description>
			</ui:properties>

			<ui:content>
				<xsl:if test="cred:check-env('vzcp.env.manage.resources',$eid) and /packet/cookie/alerts">
					<!-- show warning in case of alerts -->
					<ui:stop-sign>
						<sw:text>
							<xsl:with-param name="aopen">&lt;a href="<xsl:value-of select="$baseurl"
								/>/vzdir/infrman/envs/resources"&gt;</xsl:with-param>
							<xsl:with-param name="aclose">&lt;/a&gt;</xsl:with-param>
							<xsl:with-param name="br"
							>&lt;/br&gt;</xsl:with-param>
              Your Container experienced a shortage of some resources.%br Please check the Container %{aopen}resources%{aclose} for details.
            </sw:text>
					</ui:stop-sign>
				</xsl:if>

				<xsl:if test="ve:context-state() = $env-state/repairing and not(ve:context-transition())">
					<!-- show warning in case of repair mode -->
					<ui:stop-sign head="{sw:text('The Container is in the repair mode.')}">
						<sw:text>
							<xsl:with-param name="aopen">&lt;a href="<xsl:value-of select="$baseurl"
								/>/vzdir/infrman/envs/repair"&gt;</xsl:with-param>
							<xsl:with-param name="aclose">&lt;/a&gt;</xsl:with-param>
							<xsl:with-param name="br"
								>&lt;/br&gt;</xsl:with-param>
				Your Container is in the repair mode now.%br Please exit the %{aopen}repair mode%{aclose}<span > </span> and start the Container to continue working in the normal way.
            </sw:text>
					</ui:stop-sign>
				</xsl:if>
				<ui:block>
					<xsl:if
						test="$mail-allowed-user and string(exsl:node-set(sw:get-private()/vzcp/admin-emails/email[login = $login]/mail)) = ''">
						<!-- show warning in case of empty contact email -->
						<ui:alert>
							<sw:text>
								<xsl:with-param name="aopen">&lt;a href="<xsl:value-of select="$baseurl"
									/>/config"&gt;</xsl:with-param>
								<xsl:with-param name="aclose"
								>&lt;/a&gt;</xsl:with-param>
								Your contact email for this Container is not configured.<br/> Please enter the contact email %{aopen}here%{aclose} to be able to recover your password.
							</sw:text>
						</ui:alert>
					</xsl:if>

					<ui:dashboard/>
				</ui:block>

				<ui:block>
					<ui:rows title="{sw:text('Container Summary')}" class="Summary">
						<ui:row>
							<ui:cell-label>
								<sw:text>ID</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<xsl:value-of select="$env/virtual_config/veid"/>
							</ui:cell-value>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Hostname</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<xsl:choose>
									<xsl:when test="sw:sesget('hostname')">
										<xsl:value-of select="sw:sesget('hostname')"/>
									</xsl:when>
									<xsl:otherwise>
										<span class="inactive">
											<sw:text>Not Assigned</sw:text>
										</span>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell-value>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>The current status</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<ui:current-ve-status/>
							</ui:cell-value>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>IP Address(es)</sw:text>
							</ui:cell-label>
							<ui:cell-value>
								<xsl:choose>
									<xsl:when test="sw:sesget('iplist')">
										<xsl:value-of select="sw:sesget('iplist')"/>
									</xsl:when>
									<xsl:otherwise>
										<span class="inactive">
											<sw:text>Not Assigned</sw:text>
										</span>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell-value>
						</ui:row>
						<xsl:call-template name="vzenv:show-os-apps">
							<xsl:with-param name="env" select="$env"/>
						</xsl:call-template>
					</ui:rows>
					<ui:download-box/>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="../lib/globals.xsl"/>
	<sw:include href="../lib/cred.xsl"/>
	<sw:include href="../lib/common.xsl"/>
	<sw:include href="../lib/dashboard.xsl"/>
	<sw:include href="../lib/vt/env-private.xsl"/>
	<sw:include href="../lib/vza/tem.xsl"/>

</xsl:stylesheet>
