<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl swa-mailer func local"
	xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl	="http://exslt.org/common"
	xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui" 
	xmlns:swa-mailer="http://www.swsoft.com/xsl/cp/swa-mailer"    
	xmlns:plesk			="http://www.swsoft.com/xsl/cp/plesk"
	xmlns:local			="http://www.swsoft.com/xsl/cp/local"
	xmlns:func			="http://exslt.org/functions"
	xmlns:env				="http://www.swsoft.com/xsl/cp/env"
	xmlns:ve				="http://www.swsoft.com/xsl/cp/ve"
	xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"
	xmlns:vzenv			="http://www.swsoft.com/xsl/cp/vzenv"
	>

	<!-- detect plesk presenece -->
	<xsl:variable name="psa-mode" select="string($request/http_request/env/parameter[name = 'VZCP_MODE_PLESK']/value)"/>
	<xsl:variable name="psa-setup-rtf">
		<xsl:choose>
			<xsl:when test="$psa-mode != ''">
				<xsl:copy-of select="plesk:getPsaSetup()"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="/.."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="psa-setup" select="exsl:node-set($psa-setup-rtf)"/>
	<xsl:variable name="psa-run"  select="count($psa-setup/*) &gt; 1"/>
	
	<!--  hints for login page only -->
	<xsl:param name="psa-skin-on-login-page" select="string($psa-setup/default/skin)"/>
	<xsl:param name="psa-lang-on-login-page" select="string($psa-setup/default/lang)"/>
	<xsl:param name="psa-locale-mode-on-login-page" select="string($psa-setup/mode/locale)"/>
	<xsl:variable name="psa-admin-lang" select="string($psa-setup/admin/lang)"/>
	<xsl:variable name="psa-admin-skin" select="string($psa-setup/admin/skin)"/>

	<sw:include href="../lib/progm.xsl"/> 
	<sw:include href="../lib/psa_auth.xsl"/>
	<sw:include href="../lib/globals.xsl"/>
	<sw:include href="../lib/swa/swa-mailer.xsl"/>                                    
  <sw:include href="../lib/sso.xsl"/>

	<!-- handle post/get param -->
	<xsl:variable name="login-user">
		<xsl:choose>
			<xsl:when test="/http_request/post/parameter[name = 'LoginUser']/value">
				<xsl:value-of select="/http_request/post/parameter[name = 'LoginUser']/value"/>
			</xsl:when>
			<xsl:when test="/http_request/get/parameter[name = 'LoginUser']/value">
				<xsl:value-of select="/http_request/get/parameter[name = 'LoginUser']/value"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<!-- check that user try logged by vzcp handled user name -->
	<xsl:variable name="user-present-in-ve">
		<!-- speedup here. Don't use sw:if() insteed ! -->
		<xsl:choose>
			<xsl:when test="$psa-run">
				<xsl:value-of select="local:user-present-in-ve($login-user)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="1"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<!-- on login operation, vzcp ALWAYS handle user with name admin, root and other user in ve  -->				
	<xsl:variable name="login-as-vzcp-handled-user" select="($login-user = 'admin') or ($user-present-in-ve = 1)"/>

	<xsl:variable name="email-user">
		<xsl:choose>
			<xsl:when test="/http_request/post/parameter[name = 'LoginEmail']/value">
				<xsl:value-of select="/http_request/post/parameter[name = 'LoginEmail']/value"/>
			</xsl:when>
			<xsl:when test="/http_request/get/parameter[name = 'LoginEmail']/value">
				<xsl:value-of select="/http_request/get/parameter[name = 'LoginEmail']/value"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable	name="passwd"			select="string(/http_request/*[name() = 'post' or name() = 'get']/parameter[name = 'LoginPass']/value)"/>
	<xsl:variable name="psa-selected-locale" select="string(/http_request/post/parameter[name = 'psa_active_lang']/value)"/>
	<xsl:variable name="ticket-set" 		select="string(/http_request/get/parameter[name = 'ticket']/value)"/>
	<xsl:variable name="restore-allowed-in-vzcp"	select="$config/vzcpcon/defines/restore_password"/>
	<xsl:variable name="mode-restore-detector" select="$requesturl = concat($baseurl,'/restore-password')"/>

  <!-- SSO support -->

  <xsl:variable name="mode-sso-detector">
    <xsl:if test="$sso-sp-config/enabled">
      <xsl:choose>
        <xsl:when test="/http_request/*[name() = 'post' or name() = 'get']/parameter[name = 'sso-no-autologin']">
          <xsl:value-of select="'sso-no-autologin'"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="'sso-autologin'"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:variable>

	<!-- old plesk return from failed login such -->
	<xsl:variable name="return-from-plesk-login" select="string(/http_request/get/parameter[name = 'doLogin']/value)"/>
	<!-- old plesk return from failed restore such -->
	<xsl:variable name="return-from-plesk-restore" select="string(/http_request/get/parameter[name = 'doRestore']/value)"/>
	<!-- only modern plesk has correct error handling in login and restore -->
	<xsl:variable name="psa-new-error-handling-in-login" select="plesk:check-plesk-version-for('new-login',$psa-setup/version/detail)"/>
	<xsl:variable name="psa-new-error-handling-in-restore" select="plesk:check-plesk-version-for('new-restore',$psa-setup/version/detail)"/>

	<!-- define mode -->
	<xsl:variable name="mode">
		<xsl:choose>
			<xsl:when test="$mode-restore-detector">
				<xsl:choose>
					<xsl:when test="not(string(/http_request/post/parameter[name = 'doRestore']/value) = '') or not(string(/http_request/post/parameter[name = 'doRestorePSA']/value) = '')">
						<xsl:choose>
							<xsl:when test="$psa-mode != ''">
								<xsl:value-of select="'restore-action-plesk'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'restore-action-vzcp'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="$psa-mode != ''">
								<xsl:value-of select="'restore-show-plesk'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'restore-show-vzcp'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

      <!-- Enabled SSO affects logins both to VZCP and Plesk -->
      <xsl:when test="$mode-sso-detector != ''">
        <xsl:value-of select="'login-sso'"/>
      </xsl:when>

			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="not(string(/http_request/post/parameter[name = 'doLogin']/value) = '')">
						<xsl:choose>
							<xsl:when test="$psa-mode != ''">
								<xsl:value-of select="'login-action-plesk'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'login-action-vzcp'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="$psa-mode != ''">
								<xsl:value-of select="'login-show-plesk'"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="'login-show-vzcp'"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<!-- select do redirect to main url or show login page -->
	<xsl:template match="/">
		<xsl:choose>
			<!-- first check: if port is plesk related - 8443, and ve-eid is empty  - redirect to same IP but with port 4643 
			 		 empty veid present only for hnode or for sve.
			 -->
			<xsl:when test="(sw:ve-eid() = $env:empty-eid) and ($request/http_request/env/parameter[name = 'SERVER_PORT']/value = $config/vzcpcon/defines/standalone-plesk-port)">
				<xsl:variable name="redirect-url" select="concat('https://',$request/http_request/env/parameter[name = 'SERVER_NAME']/value,':4643/')"/>
				<ui:redirect type="javascript" location="{$redirect-url}"/> -->
			</xsl:when>

			<!-- check if unauthorized user gets not base url, redirect it to base -->
			<xsl:when test="($psa-mode = '') and (($baseurl != $requesturl) and  ($requesturl != concat($baseurl,'/login-wrapper')))  and not($mode-restore-detector)">
				<ui:redirect/>
			</xsl:when>
			<xsl:when test="($psa-mode != '') and (($requesturl != concat($baseurl,'/panel/plesk/frameset')) and ($requesturl != concat($baseurl,'/login-wrapper')))  and not($mode-restore-detector)">
				<ui:redirect/>
			</xsl:when>

 			<xsl:when test="$ticket-set != ''">
				<ui:redirect location="{$requesturl}">
					<ui:cookie name="vzcpSession" Path="/"><xsl:value-of select="$ticket-set"/></ui:cookie>
				</ui:redirect>
			</xsl:when>

			<xsl:when test="($mode = 'login-action-plesk') and $psa-run and not($login-as-vzcp-handled-user) and ($login-user != '') and ($passwd != '')">
				<ui:redirect type="javascript" location="/login_up.php3">
					<ui:arg name="login_name"><xsl:value-of select="$login-user"/></ui:arg>
					<ui:arg name="passwd"><xsl:value-of select="$passwd"/></ui:arg>
					<ui:arg name="locale"><xsl:value-of select="$psa-selected-locale"/></ui:arg>
				</ui:redirect>
			</xsl:when>
			<xsl:when test="($mode = 'restore-action-plesk') and $psa-run and ($login-user != '') and ($email-user != '')">
				<ui:redirect type="javascript" location="/get_password.php">
					<ui:arg name="login_name"><xsl:value-of select="$login-user"/></ui:arg>
					<ui:arg name="email"><xsl:value-of select="$email-user"/></ui:arg>
					<ui:arg name="cmd"><xsl:value-of select="'get_password'"/></ui:arg>
				</ui:redirect>
			</xsl:when>

			<!-- cancel button present only on screen restore password -->
			<xsl:when test="/http_request/post/parameter[name = 'doReturn']/value">
				<ui:redirect/>
			</xsl:when>

			<!-- process with front-screen -->
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="($mode = 'restore-show-vzcp') or  ($mode = 'restore-action-vzcp')">
						<xsl:variable name="mail-config" select="swa-mailer:get-config(true())"/>
						<xsl:variable name="is-messaging-enabled" select="string($mail-config/notify) = 'true'"/>
						<xsl:variable name="is-mailer-enabled" select="swa-mailer:email-enabled()"/>
						<xsl:choose>
							<xsl:when test="not($is-messaging-enabled)">
								<xsl:call-template name="screen-restore-vzcp-off">
									<xsl:with-param name="error-code" select="'cp1002'"/>
								</xsl:call-template>
							</xsl:when>							
							<xsl:when test="not($is-mailer-enabled)">
								<xsl:call-template name="screen-restore-vzcp-off">
									<xsl:with-param name="error-code" select="'cp1001'"/>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="screen-restore-vzcp"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="($mode = 'restore-show-plesk') or ($mode = 'restore-action-plesk')">
						<xsl:choose>
							<xsl:when test="not($psa-run)">
								<xsl:call-template name="screen-restore-plesk-off">
									<xsl:with-param name="error-code" select="'cp1005'"/>
								</xsl:call-template>
							</xsl:when>							
							<xsl:otherwise>
								<xsl:call-template name="screen-restore-plesk"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
          <xsl:when test="$mode = 'login-sso'">
            <xsl:call-template name="screen-login-sso"/>
          </xsl:when>
					<xsl:when test="($mode = 'login-show-plesk') or ($mode = 'login-action-plesk')">
						<xsl:call-template name="screen-login-plesk"/>
					</xsl:when>
					<xsl:otherwise>
						<!-- mode login-show-vzcp assumed by default -->
						<xsl:call-template name="screen-login-vzcp"/>						
					</xsl:otherwise>					
				</xsl:choose>
			</xsl:otherwise>      
		</xsl:choose>
	</xsl:template>

	<!-- show password recovery disabled form for vzcp -->
	<xsl:template name="screen-restore-vzcp-off">
		<xsl:param name="error-code"/>
		<ui:front-screen id="03.00.00.00.05" title="{sw:text('Recover Password')}">
			<ui:error>
						<sw:text>
							<xsl:with-param name="error-code" select="$error-code"/>
							The password recovery is unavailable due to system error #%{error-code}. Please contact your service provider.
						</sw:text>
			</ui:error>
			<ui:bottom>
				<ui:oldtext/>
				<ui:button name="doReturn"><sw:text>Return</sw:text></ui:button>
			</ui:bottom>  
		</ui:front-screen>
	</xsl:template>

	<!-- show password recovery disabled form for plesk -->
	<xsl:template name="screen-restore-plesk-off">
		<xsl:param name="error-code"/>
		<ui:front-screen id="03.00.00.00.05" title="{sw:text('Get Password')}">
			<ui:error>
				<sw:text>
					<xsl:with-param name="error-code" select="$error-code"/>
					The password recovery is unavailable due to system error #%{error-code}. Please contact your service provider.
				</sw:text>
			</ui:error>
			<ui:bottom>
				<ui:oldtext/>
				<ui:button name="doReturn"><sw:text>Return</sw:text></ui:button>
			</ui:bottom>  
		</ui:front-screen>
	</xsl:template>

	<!-- show password recovery form vzcp -->
	<xsl:template name="screen-restore-vzcp">
		<ui:front-screen id="03.00.00.00.05" title="{sw:text('Recover Password')}" action="{concat($baseurl,'/restore-password')}">
			<xsl:if test="$mode = 'restore-action-vzcp'">
				<!-- need handle error here -->
				<ui:error>
					<xsl:choose>
						<xsl:when test="$auth-result = -5">
							<sw:text>You are not authorized to log in. Please contact your service provider for support.</sw:text>							
						</xsl:when>
						<xsl:when test="$auth-result = -3">
							<sw:text>The password recovery has failed due to system error #cp1003. Please contact your service provider for support.</sw:text>
						</xsl:when>
						<xsl:when test="$auth-result = -2">
							<sw:text>The account is disabled by the administrator.</sw:text>
						</xsl:when>
						<xsl:when test="$auth-result = 0">
							<sw:text>Password recovery is not allowed.</sw:text>
						</xsl:when>
						<xsl:when test="$auth-result = 1">
							<sw:text>An invalid e-mail or username. Please try again.</sw:text>
						</xsl:when>							
					</xsl:choose>
				</ui:error>
			</xsl:if>
			<ui:oldtext align="left" valign="top">
				<sw:text>
					Please enter your e-mail address (and your login if you have one)<br/> for the password recovery. <br/> The instructions will be emailed to you.
				</sw:text>        
			</ui:oldtext>
			<ui:input type="text" name="LoginEmail" title="{sw:text('E-mail')}" value="{$email-user}"/>
			<ui:input type="text" name="LoginUser" title="{sw:text('Username')}" value="{$login-user}"/>
			<ui:bottom>
				<ui:oldtext/>
				<ui:button name="doRestore" type="ok"><sw:text>Ok</sw:text></ui:button>
				<ui:button name="doReturn"><sw:text>Cancel</sw:text></ui:button>
			</ui:bottom> 
		</ui:front-screen>
	</xsl:template>

	<!-- show password recovery form plesk -->
	<xsl:template name="screen-restore-plesk">
		<ui:front-screen id="03.00.00.00.05" title="{sw:text('Get Password')}" action="{concat($baseurl,'/restore-password')}">
			<xsl:variable name="auth-result-rc" select="string(/http_request/get/parameter[name = 'rc']/value)"/>
			<xsl:variable name="auth-result-message" select="sw:base64-decode(string(/http_request/get/parameter[name = 'rc_mess']/value))"/>
			<xsl:if test="$mode = 'restore-show-plesk'">
				<xsl:choose>
					<xsl:when test="($auth-result-rc != '') and ($auth-result-rc != 0) and $psa-new-error-handling-in-restore">
						<!-- realy error happens, modern plesk -->
						<ui:error>
							<xsl:value-of select="$auth-result-message"/>
						</ui:error>
					</xsl:when>
					<xsl:when test="not($ticket) and ($return-from-plesk-restore != '') and not($psa-new-error-handling-in-restore)">
						<!-- old plesk not return auth-result-rc and auth-result-message -->
						<ui:error>
							<sw:text>An invalid username or e-mail. Please try again.</sw:text>
						</ui:error>
					</xsl:when>
					<xsl:otherwise>
						<!-- it's not error, rc = 0: restore over plesk finished -->
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			<xsl:if test="$mode = 'restore-action-plesk' and not($psa-new-error-handling-in-restore) and (not($email-user != '') or not($login-user != ''))">
				<!-- vzcp handle empty login and/or email -->
				<ui:error>
					<sw:text>Empty login or e-mail address specified.</sw:text>
				</ui:error>
			</xsl:if>
			
			<xsl:choose>
				<xsl:when test="$auth-result-rc = 0">
					<ui:oldtext align="center" valign="top">
						<sw:text>
							The password recovery instructions have been emailed to you.<br/>
							Please read and follow them.
						</sw:text>        
					</ui:oldtext>
					<ui:bottom>
						<ui:oldtext/>
						<ui:button name="doReturn" type="ok"><sw:text>Ok</sw:text></ui:button>
					</ui:bottom> 
				</xsl:when>
				<xsl:otherwise>
					<ui:oldtext align="left" valign="top">
						<sw:text>
							Please enter your username and e-mail address<br/> for the password recovery.
						</sw:text>        
					</ui:oldtext>
					<ui:input type="text" name="LoginUser" title="{sw:text('Username')}" value="{$login-user}"/>
					<ui:input type="text" name="LoginEmail" title="{sw:text('E-mail')}" value="{$email-user}"/>
					<ui:bottom>
						<ui:oldtext/>
						<ui:button name="doRestorePSA" type="ok"><sw:text>Ok</sw:text></ui:button>
						<ui:button name="doReturn"><sw:text>Cancel</sw:text></ui:button>
					</ui:bottom>
				</xsl:otherwise>
			</xsl:choose>			
		</ui:front-screen>
	</xsl:template>
	
	<!-- SSO is enabled - attempt to authenticate user in it. SAML POST binding. -->
  <xsl:template name="screen-login-sso">

    <!-- required parameters -->
    <xsl:variable name="request-url" select="/http_request/env/parameter[name = 'SCRIPT_URI']/value"/>
    <xsl:variable name="idp-url" select="concat($sso-sp-config/idp_api_base_url, 'relay')"/>
    <xsl:variable name="saml-authn-request">
      <xsl:choose>
        <xsl:when test="$mode-sso-detector = 'sso-autologin'">
          <xsl:value-of select="sw:sso-get-authn-request($sso-sp-config/sp_id)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="sw:sso-get-authn-request($sso-sp-config/sp_id, 1)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <!-- TODO: Endless loop prevention: add cookie and if it's found in request - remove and stop attempts to redirect to SSO -->
    <xsl:choose>
      <xsl:when test="$saml-authn-request">
        <ui:redirect type="javascript" location="{$idp-url}">
          <ui:arg name="SAMLRequest"><xsl:value-of select="$saml-authn-request"/></ui:arg>
          <ui:arg name="response_url"><xsl:value-of select="$request-url"/></ui:arg>
        </ui:redirect>
      </xsl:when>
      <xsl:otherwise>
        <ui:error>
          <!-- TODO: display a local login screen -->
          <xsl:text>Can not create authentication request</xsl:text>
        </ui:error>
      </xsl:otherwise>
    </xsl:choose>

    </xsl:template>

	<!-- show login form vzcp -->
	<xsl:template name="screen-login-vzcp">
		<xsl:variable name="product-name" select="local:product-name()"/>
		<ui:front-screen id="03.00.00.00.03" title-long="{$product-name/long}" title="{$product-name/short}">
			<xsl:choose>
				<xsl:when test="not($ticket) and ($mode = 'login-action-vzcp')">
					<ui:error>
						<xsl:choose>
							<xsl:when test="$auth-result = -6">
								<sw:text>You have reached the maximum number of Parallels Infrastructure Manager connections allowed by the license installed.</sw:text>							
							</xsl:when>							
							<xsl:when test="$auth-result = -5">
								<sw:text>You are not authorized to log in. Please contact your service provider for support.</sw:text>							
							</xsl:when>							
							<xsl:when test="$auth-result = -4">
								<sw:text>The Node you are trying to log in to is a Slave Node of a Virtuozzo Group. Only the address of the Master Node of this Group can be used for logging in.</sw:text>
							</xsl:when>
							<xsl:when test="$auth-result = -3">
							  <sw:text>The attempt to log in failed due to system error #cp1003. Please contact your service provider for support.</sw:text>
							</xsl:when>
							<xsl:when test="$auth-result = -2">
							  <sw:text>The account is disabled by the administrator.</sw:text>
							</xsl:when>
							<xsl:when test="$auth-result = 0">
							  <sw:text>The attempt to log in failed due to system error #cp1006. Please contact your service provider for support.</sw:text>
							</xsl:when>
							<xsl:when test="$auth-result = 1">
								<sw:text>An invalid username or password. Please try again.</sw:text>
							</xsl:when>
							<xsl:when test="$auth-result = 6">
								<sw:text>You are not authorized to log in. Please contact your service provider for support.</sw:text>
							</xsl:when>
						</xsl:choose>
					</ui:error>
				</xsl:when>      
			</xsl:choose>
			<ui:oldtext align="left" valign="top">
				<sw:text>Please enter your login information.</sw:text>
			</ui:oldtext>
			<ui:input type="text" name="LoginUser" title="{sw:text('Username')}" value="{$login-user}"/>
			<ui:input type="password" name="LoginPass" title="{sw:text('Password')}"/>

			<xsl:variable name="langs" select="sw:document('languages.xml')/languages/language[active]"/>
			<xsl:variable name="lang-default" select="$langs[default]/id"/>

			<xsl:choose>
				<xsl:when test="count($langs) &gt; 1">
					<ui:input type="combo" title="{sw:text('Interface Language')}" name="active_lang"
						onchange="var n=this.options[this.selectedIndex].value;eatCookie('vzcpLang');setCookie('vzcpLang',n);window.location.reload();" 
					>
						<option value="$lang-default"><sw:text>User Default</sw:text></option>
						<xsl:for-each select="$langs">
							<option value="{id}">
								<xsl:if test="$langObj/id = string(id)">
									<xsl:attribute name="selected">1</xsl:attribute>
								</xsl:if>
							<sw:text select="name/text()"/></option>
						</xsl:for-each>
					</ui:input>      
				</xsl:when>
				<xsl:otherwise>   
					<!-- one lang allowed -->
					<ui:hidden name="active_lang" value="{$lang-default}"/>
				</xsl:otherwise>
			</xsl:choose>

			<ui:bottom>
				<ui:oldtext>
					<xsl:if test="$restore-allowed-in-vzcp">
						<a href="{$baseurl}/restore-password"><sw:text>Forgot your password?</sw:text></a>
					</xsl:if>
					<xsl:variable name="registration"				select="$config/vzcpcon/access/auth[type = 'registration']"/>
					<xsl:variable name="registration-link"	select="$config/vzcpcon/user-registration/enabled='true' and $config/vzcpcon/user-registration/show-login-register='true'"/>
					
					<xsl:if test="not($registration = '') and $registration-link">
						&#160;|&#160;
						<a href="{$baseurl}/core/register/index"><sw:text>Register</sw:text></a>
					</xsl:if>					
				</ui:oldtext>
				<ui:button name="doLogin"><sw:text>Login_button</sw:text></ui:button>
			</ui:bottom>
		</ui:front-screen>
	</xsl:template>

	<!-- show login form plesk -->
	<xsl:template name="screen-login-plesk">
		<xsl:variable name="title-plesk-login">
			<sw:text>
				<xsl:with-param name="version" select="sw:split($psa-setup/version/raw,' ')[1]"/>
				Log in to Plesk %{version}
			</sw:text>
		</xsl:variable>
		<ui:front-screen id="03.00.00.00.03" title="{$title-plesk-login}">
			<xsl:variable name="auth-result-rc" select="string(/http_request/get/parameter[name = 'rc']/value)"/>
			<xsl:variable name="auth-result-message" select="sw:base64-decode(string(/http_request/get/parameter[name = 'rc_mess']/value))"/>
			<xsl:choose>
				<xsl:when test="not($ticket) and ($mode = 'login-action-plesk') and $login-as-vzcp-handled-user">
					<ui:error>
						<xsl:choose>
							<xsl:when test="$auth-result = -3">
							  <sw:text>The attempt to log in failed due to system error #cp1003. Please contact your service provider for support.</sw:text>
							</xsl:when>
							<xsl:when test="$auth-result = -2">
							  <sw:text>The account is disabled by the administrator.</sw:text>
							</xsl:when>
							<xsl:when test="$auth-result = 0">
							  <sw:text>The attempt to log in failed due to system error #cp1006. Please contact your service provider for support.</sw:text>
							</xsl:when>
							<xsl:when test="$auth-result = 1">
								<sw:text>An invalid username or password. Please try again.</sw:text>
							</xsl:when>
						</xsl:choose>
					</ui:error>
				</xsl:when>
				<xsl:when test="not($ticket) and ($auth-result-rc != '') and ($auth-result-rc != 0) and $psa-new-error-handling-in-login">
					<ui:error>
						<xsl:value-of select="$auth-result-message"/>
					</ui:error>
				</xsl:when>
				<xsl:when test="not($ticket) and ($return-from-plesk-login != '') and not($psa-new-error-handling-in-login)">
					<!-- plesk not return auth-result-rc and auth-result-message -->
					<ui:error>
						<sw:text>An invalid username or password. Please try again.</sw:text>
					</ui:error>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="$mode = 'login-action-plesk' and (not($login-user != '') or not($passwd != ''))">
				<!-- vzcp handle empty login and/or passwd -->
				<ui:error>
					<sw:text>An invalid username or password. Please try again.</sw:text>
				</ui:error>
			</xsl:if>
			
			<ui:oldtext align="left" valign="top">
				<sw:text>Please enter your login information.</sw:text>
			</ui:oldtext>
			<ui:input type="text" name="LoginUser" title="{sw:text('Username')}" value="{$login-user}"/>
			<ui:input type="password" name="LoginPass" title="{sw:text('Password')}"/>

			<!-- empty for not psa mode, used while submit -->
			<ui:hidden name="admin_default_lang" value="{$psa-admin-lang}"/>
			<ui:hidden name="psa-locale-mode" value="{$psa-locale-mode-on-login-page}"/>
			<ui:hidden name="psa_active_skin" value="{$psa-admin-skin}"/>

			<xsl:variable name="langs" select="$psa-setup/languages/language"/>
			<xsl:choose>
				<xsl:when test="count($langs) &gt; 1">
					<ui:input type="combo" title="{sw:text('Interface Language')}" name="psa_active_lang">
						<option value="default"><sw:text>User Default</sw:text></option>
						<xsl:for-each select="$langs">
							<option value="{id}">
								<xsl:if test="$langObj/id = string(id)">
									<xsl:attribute name="selected">1</xsl:attribute>
								</xsl:if>
							<sw:text select="name/text()"/></option>
						</xsl:for-each>
					</ui:input>      
				</xsl:when>
				<xsl:otherwise>   
					<!-- one lang allowed -->
					<ui:hidden name="psa_active_lang" value="default"/>
				</xsl:otherwise>
			</xsl:choose>
			<ui:bottom>
				<ui:oldtext>
					<a href="{$baseurl}/restore-password"><sw:text>Forgot your password?</sw:text></a>
				</ui:oldtext>
				<ui:button name="doLogin"><sw:text>Login_button</sw:text></ui:button>
			</ui:bottom>
		</ui:front-screen>
	</xsl:template>

	<!--
		check that user-name defined as user inside VE
		return 0 if not, 1 if yes.
	-->
	<func:function name="local:user-present-in-ve">
		<xsl:param name="user-name"/>
		<xsl:variable name="req">
			<packet>
				<target>userm</target>
				<xsl:copy-of select="sw:env-dst(sw:ve-eid())"/>
				<data>
					<userm>
						<get_user>
							<user>
								<name>
									<xsl:value-of select="$user-name"/>
								</name>
							</user>
						</get_user>
					</userm>
				</data>
			</packet>
		</xsl:variable>
		<xsl:variable name="user-info" select="sw:xchg($req)/packet/data/userm"/>
		<func:result select="sw:if($user-info/error/code != '' 
							   or (vt:is-platform-linux(ve:ve2platform(env:get-env(sw:ve-eid())/env)) 
										and not($user-info/user/initial_group/name='root')
										and not($user-info/user/group/name='root')
										),0,1)"/>

	</func:function>

	<!-- Product name (VZCC/VZPP) -->
	<func:function name="local:product-name">
		<xsl:variable name="name">
			<xsl:choose>
				<xsl:when test="sw:ve-eid() = $env:empty-eid">
					<long>
						<sw:text>Parallels Infrastructure Manager</sw:text>
					</long>
					<short>
						<sw:text>PIM</sw:text>
					</short>
				</xsl:when>
				<xsl:otherwise>
					<long>
						<sw:text>Parallels Power Panel</sw:text>
					</long>
					<short>
						<sw:text>PPP</sw:text>	
					</short>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<func:result select="exsl:node-set($name)"/>
	</func:function>

	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="../lib/common.xsl"/>
	
</xsl:stylesheet>
