<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func env vzenv vzhn units hn error"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:units="http://www.swsoft.com/xsl/cp/units"
	xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/> 
	<sw:include href="/lib/vz/vzenv-core.xsl"/> 
	<sw:include href="/lib/vt/hn-core.xsl"/>	
	<sw:include href="/lib/vz/vzhn-core.xsl"/>
	<sw:include href="/lib/core/units-core.xsl"/>
  
	<xsl:output method="xml"/>

	<!-- Request parameters -->
	<xsl:variable name="type" select="$request/http_request/get/parameter[name = 'type']/value"/>
	<xsl:variable name="get-eid" select="$request/http_request/get/parameter[name = 'id']/value"/>
	<xsl:variable name="base-dec" select="$request/http_request/get/parameter[name = 'base64']/value"/>
	<xsl:variable name="url" select="sw:base64-decode(string($request/http_request/get/parameter[name = 'url']/value))"/>
	<xsl:variable name="oper" select="$request/http_request/get/parameter[name = 'oper']/value"/>
	<xsl:variable name="proxy-url" select="sw:document('cc/menu.xml')/menu/context-menu/item[@label-id=$oper]/@proxy-url"/>
	<xsl:variable name="op-url">
		<xsl:value-of select="sw:if(starts-with($proxy-url,'$baseurl'), concat($baseurl,substring-after(string($proxy-url),'$baseurl')), $proxy-url)"/>
	</xsl:variable>

	<xsl:template match="/">

		<xsl:choose>
			<!-- VE actions -->
			<xsl:when test="$type='ve.vz.vt'">

				<xsl:variable name="current-eid">
					<xsl:choose>
						<xsl:when test="$base-dec='1'">
							<xsl:variable name="current-dec-ve" select="vzenv:set-current(sw:base64-decode($get-eid),true())"/>
							<xsl:value-of select="$current-dec-ve/eid"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="current-ve" select="vzenv:set-current($get-eid,true())"/>
							<xsl:value-of select="$current-ve/eid"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>

				<xsl:choose>

					<xsl:when test="$current-eid!=''">
						<ui:redirect location="{concat($op-url,$url)}"/>
					</xsl:when>

					<xsl:otherwise>
						<xsl:if test="error:put(sw:text('The requested Container could not be found. It might have been deleted or moved.'))"/>
						<ui:redirect location="{concat($baseurl,'/vt/envs/index')}"/>
					</xsl:otherwise>

				</xsl:choose>

			</xsl:when>

			<!-- HN actions -->
			<xsl:when test="$type='hn.vz.vt'">

				<xsl:variable name="current-hid">
					<xsl:choose>
						<xsl:when test="$base-dec='1'">
							<xsl:variable name="current-dec-hn" select="vzhn:set-current(sw:base64-decode($get-eid))"/>
							<xsl:value-of select="$current-dec-hn/eid"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:variable name="current-hn" select="vzhn:set-current($get-eid)"/>
							<xsl:value-of select="$current-hn/eid"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>

				<xsl:choose>

					<xsl:when test="$current-hid!=''">
						<ui:redirect location="{concat($op-url,$url)}"/>
					</xsl:when>

					<xsl:otherwise>
						<xsl:if test="error:put(sw:text('The Hardware Node is unavailable for management.'))"/>
						<ui:redirect location="{concat($baseurl,'/vt/hns/index?tab-force=default')}"/>
					</xsl:otherwise>

				</xsl:choose>

			</xsl:when>

			<!-- UNIT actions -->
			<xsl:when test="$type='unit.vz.vt'">

				<xsl:choose>
					<xsl:when test="units:find-unit($get-eid)">
						<xsl:if test="units:set-current-dn($get-eid)"/>
						<ui:redirect location="{concat($op-url,$url)}"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="error:put(sw:text('The requested folder could not be found. It might have been deleted or moved.'))"/>
						<ui:redirect location="{concat($baseurl,'/farmdir/unitman/units/index?tree-id=infrastructure&amp;tab-force=default')}"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

		</xsl:choose>

	</xsl:template>

	<!--sw:include href="/lib/screen.xsl"/--> 
	<sw:include href="/lib/common.xsl"/> 
	<sw:include href="/lib/cred.xsl"/> 
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
