<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" extension-element-prefixes="sw format func env"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:local="http://www.swsoft.com/xsl/local"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
	xmlns:func="http://exslt.org/functions"
  	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	>

	<xsl:output method="xml"/>

 	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/layout/external.xsl"/>
	<sw:include href="/lib/utils/format-datetime.xsl"/>

	<xsl:template name="local:get-tasks">

		<xsl:variable name="counter_request">
		<packet>
			<target>op_log</target>
			<data>
				<op_log>
					<get_ops>
						<current/>
						<status/>
					</get_ops>
				</op_log>
			</data>
		</packet>    
		</xsl:variable>
			
		<xsl:variable name="counter_result" select="sw:xchg($counter_request)"/>
		<xsl:variable name="counter" select="count($counter_result/packet/data/op_log/progress[not(parent_id)])"/>
		Dyn_counter="<xsl:value-of select="$counter"/>";
		<xsl:variable name="req">
			<packet>
				<target>vzcpwatcher</target>
				<data>
					<vzcpwatcher>
						<get>
							<session><xsl:value-of select="$ticket"/></session>
						</get>
					</vzcpwatcher>
				</data>
			</packet>
		</xsl:variable>

		<xsl:variable name="delimiter" select="'/@|'"/>
		<xsl:variable name="packet" select="sw:xchg($req)"/>
		<xsl:for-each select="$packet/packet/data/vzcpwatcher/events/event">
			<xsl:variable name="data">
				<!--Important! index= +1 from js_format-->
				<xsl:variable name="base" select="sw:split(data,',')"/>
				<xsl:choose>

					<!--task format-->
					<xsl:when test="$base[2]='task' or $base[2]='newtask'">
						<xsl:variable name="envs" select="local:make-ve-list($base[10])"/>
						<xsl:variable name="mess" select="local:localize-message(data)"/>
						<xsl:for-each select="$base">
							<xsl:variable name="p" select="position()"/>
							<xsl:choose>
								<xsl:when test="$p=3"><xsl:value-of select="format:date-time( sw:vzatime2utime( sw:base64-decode(.) ) )"/><xsl:value-of select="$delimiter"/></xsl:when>
								<xsl:when test="$p=4"><xsl:value-of select="sw:base64-decode(.)"/><xsl:value-of select="$delimiter"/></xsl:when>
								<xsl:when test="$p=5"><xsl:value-of select="$mess"/><xsl:value-of select="$delimiter"/></xsl:when>
								<xsl:when test="$p=6"><xsl:value-of select="sw:text( $envs )"/><xsl:value-of select="$delimiter"/></xsl:when>
								<xsl:when test="$p=9 or $p=10 or $p>16"><xsl:value-of select="concat(sw:base64-decode(.), $delimiter)"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="concat(., $delimiter)"/></xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:when>

					<!--eid format-->
					<xsl:when test="$base[2]='eid'">
						<xsl:for-each select="$base">
							<xsl:variable name="p" select="position()"/>
							<xsl:choose>
								<xsl:when test="$p=3 or $p=4 or $p=11 or $p>12"><xsl:value-of select="concat(sw:base64-decode(.), $delimiter)"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="concat(., $delimiter)"/></xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:when>

					<!--hn format-->
					<xsl:when test="$base[2]='hid'">
						<xsl:for-each select="$base">
							<xsl:variable name="p" select="position()"/>
							<xsl:choose>
								<xsl:when test="$p=3"><xsl:value-of select="concat(sw:base64-decode(.), $delimiter)"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="concat(., $delimiter)"/></xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:when>
					
					<!--other format-->
					<xsl:otherwise>
						<xsl:for-each select="$base"><xsl:value-of select="concat(., $delimiter)"/></xsl:for-each>
					</xsl:otherwise>

				</xsl:choose>
			</xsl:variable>
			<xsl:if test="index!=''">Dyn[<xsl:value-of select="index"/>]='<xsl:value-of select="sw:html-escape(normalize-space($data),'escape-quote')"/>';</xsl:if>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="/">
		<data>
		//@allow-dyn@//
		[script]
		<xsl:call-template name="local:get-tasks"/>
		[/script]
		</data>
	</xsl:template>

	<func:function name="local:make-ve-list">
		<xsl:param name="envs"/>
		<xsl:variable name="base" select="sw:split(sw:base64-decode($envs),',')"/>
		<func:result>
			<xsl:for-each select="$base">
				<xsl:if test="not(.='') and not(position()=1)">, </xsl:if>
				<xsl:if test="not(.='')"><xsl:call-template name="env-link"><xsl:with-param name="content-type" select="'eid'"/></xsl:call-template></xsl:if>
			</xsl:for-each>
		</func:result>
	</func:function>

	<func:function name="local:localize-message">
		<xsl:param name="data"/>
		<xsl:variable name="base" select="sw:split($data,',')"/>
		<xsl:variable name="mess" select="sw:text( sw:base64-decode( $base[5] ) )"/>
		<xsl:variable name="mess-base" select="sw:split($mess,'%')"/>
		<func:result>
			<xsl:for-each select="$mess-base">
				<xsl:variable name="cur" select="."/>
				<xsl:choose>
					<xsl:when test="not(position() mod 2)">
						<xsl:variable name="num" select="(position() div 2)+16"/>
						<xsl:variable name="cont" select="sw:base64-decode( $base[$num] )"/>
						<xsl:variable name="eid-list" select="sw:split($cont,'|')"/>
						<xsl:choose>
							<xsl:when test="$eid-list[1]='env' and not($eid-list[2]='')">
								<xsl:for-each select="$eid-list">
									<xsl:if test="not(.='') and not(position()=1)"><xsl:if test="position()>2">, </xsl:if><xsl:value-of select="env:env2title(env:get-env(.)/env)"/></xsl:if>
								</xsl:for-each>
							</xsl:when>
							<xsl:otherwise><xsl:value-of select="sw:text( $cont )"/></xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise><xsl:value-of select="$cur"/></xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</func:result>
	</func:function>


</xsl:stylesheet>