<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sb func units"
exclude-result-prefixes="func ui cred sb units local licensem"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:func	="http://exslt.org/functions"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred	="http://www.swsoft.com/xsl/cp/cred"
	xmlns:sb		="http://www.swsoft.com/xsl/cp/sb"
	xmlns:units	="http://www.swsoft.com/xsl/cp/units"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"	
  xmlns:licensem	="http://www.swsoft.com/xsl/cp/licensem"
  >
  
	<sw:include href="/lib/core/units-core.xsl"/>
	<sw:include href="/lib/sitebuilder.xsl"/>

	<xsl:variable name="all-screens" select="sw:document('screens.xml')"/>

	<!--
		Main local template in 'menu-cred-transform'. Get 'screen'
		elements from menu 'item's and add corresponding 'cred' child element(s)
		with attributes from screens.xml
	-->
	<xsl:template match="item" mode="menu-cred-transform">
		<xsl:variable name="hide-item" 
			select="string(@id)='logical' 
				and string(item/@type)='units' 
				and not(units:list(units:logical-top-dn(),$def-scope-tree)/unit)"/>
		<xsl:if test="not($hide-item)">
			<xsl:copy>
				<xsl:copy-of select="@*[name() != 'cred']"/>
				<xsl:copy-of select="*[name() != 'item']"/>
				<xsl:if test="@cred">
					<security cred="{@cred}" 
						security-obj-type="{sw:if(@security-obj-type,string(@security-obj-type),'vzcp')}"
						security-obj-id="{sw:if(@security-obj-id,string(@security-obj-id),'default')}"
					/>
				</xsl:if>
				<xsl:for-each select="screen">
					<xsl:variable name="mscr" 
						select="$all-screens//screen[string(@id)=current()/@id]"/>
					<xsl:if test="$mscr/@cred">
						<security cred="{$mscr/@cred}"
							security-obj-type="{sw:if($mscr/@security-obj-type,string($mscr/@security-obj-type),'vzcp')}"
							security-obj-id="{sw:if($mscr/@security-obj-id,string($mscr/@security-obj-id),'default')}"
						/>
					</xsl:if>
				</xsl:for-each>				
				<xsl:if test="@target-tab-id">
					<xsl:variable name="tab" select="
							sw:document('tabs.xml',sw:if($activeMode = 'vzcc', 'vzcc', 'vzpp'))/tab-bars/tab-bar[@id = current()/@target-tab-id]
					"/>
					<sw:die test="not($tab)">
						Can not find tab bar ID "<xsl:value-of select='current()/@target-tab-id'/>"
					</sw:die>
					<xsl:for-each select="$tab/descendant-or-self::tab[@href]">
						<xsl:variable name="cred-item" select="sw:if(@cred,.,..)"/>
						<href href="{@href}">
							<xsl:if test="$cred-item/@cred">
								<xsl:attribute name="cred"><xsl:value-of select="$cred-item/@cred"/></xsl:attribute>
								<xsl:attribute name="security-obj-type">
									<xsl:value-of select="sw:if($cred-item/@security-obj-type,string($cred-item/@security-obj-type),'vzcp')"/>
								</xsl:attribute>
								<xsl:attribute name="security-obj-id">
									<xsl:value-of select="sw:if($cred-item/@security-obj-id,string($cred-item/@security-obj-id),'default')"/>								
								</xsl:attribute>
							</xsl:if>
						</href>
					</xsl:for-each>
				</xsl:if>
				<xsl:apply-templates mode="menu-cred-transform" select="item"/>
			</xsl:copy>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="/" mode="menu-cred-transform">
		<xsl:apply-templates mode="menu-cred-transform" select="menu"/>
	</xsl:template>
	
	<xsl:template match="menu" mode="menu-cred-transform">
		<xsl:copy>
			<xsl:apply-templates select="item" mode="menu-cred-transform"/>
		</xsl:copy>
	</xsl:template>

	<xsl:template match="/">
		<xsl:variable name="menu-data-rtf">
			<xsl:apply-templates mode="menu-cred-transform" select="sw:document($menu-file, $menu-source)"/>
		</xsl:variable>
		<xsl:variable name="menu-data" select="exsl:node-set($menu-data-rtf)"/>
		<xsl:variable name="validItems" select="cred:filter-items($menu-data/menu/item)[item]"/>
		<xsl:variable name="default-mode" select="'all'"/>	
		<xsl:variable name="init-first" select="sw:if($request/http_request/get/parameter[name = 'mode']/value != 'all' and $request/http_request/get/parameter[name = 'init']/value ='first', 'true', 'false')"/>
		<xsl:variable name="mode">
			<xsl:choose>
				<xsl:when test="not($request/http_request/get/parameter[name = 'mode']/value != '')">
					<xsl:value-of select="sw:if(not($request/http_request/cookies/parameter[name = 'vzcc-menu-mode']/value != ''), $default-mode, $request/http_request/cookies/parameter[name = 'vzcc-menu-mode']/value)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$request/http_request/get/parameter[name = 'mode']/value"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>				
		
		<xsl:variable name="button-height" select="'32'"/>
		<xsl:variable name="bar-height" select="'32'"/>
		<xsl:variable name="selector-height" select="sw:if($mode = 'all', $bar-height, $button-height * (count($validItems)+1))"/>
		<ui:raw>
			<!-- xsl:text disable-output-escaping="yes">&lt;!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd"&gt;&#10;</xsl:text -->
			<html>
				<head>

					<link rel="stylesheet" type="text/css" href="/{$theme}/left-cc.css"/>
					<link rel="stylesheet" type="text/css" href="/{$theme}/common.css"/>        
					<link rel="stylesheet" type="text/css" href="/{$theme}/css_expand.css"/>
					<script type="text/javascript" src="/vz/js/browser.js"></script>					
					<script type="text/javascript" src="/vz/js/common_script.js"></script>
					<script type="text/javascript" src="/vz/js/right_click.js"></script>
					<script type="text/javascript" src="/vz/js/dnd.js"></script>
					<script type="text/javascript">
							var selector_height = <xsl:value-of select="$selector-height"/>;
							var border_offset = <xsl:value-of select="sw:if($mode = 'all',2,count($validItems)+1)"/>;
						<![CDATA[
							function _callNavigate(){
								if (top.main && top.main.callNavigate)
									top.main.callNavigate()
							}
						
							function callScroll(){
								var frame_height = 0;

								if( typeof( window.innerWidth ) == 'number' ) {
								    //Non-IE
									frame_height = window.innerHeight -10;
									frame_width =  window.innerWidth - 10;
								} else if( document.documentElement && ( document.documentElement.clientWidth || document.documentElement.clientHeight ) ) {
									//IE 6+ in 'standards compliant mode'
									frame_height = document.documentElement.clientHeight - 10 - border_offset;
									frame_width = document.documentElement.clientWidth;
								} else if( document.body && ( document.body.clientWidth || document.body.clientHeight ) ) {
									//IE 4 compatible
									frame_height = document.body.clientHeight;
									frame_width = document.body.clientWidth
								}							
								na = document.getElementById('navArea');
								h = parseInt(frame_height - selector_height);
								w = parseInt(frame_width);
								na.style.height = h+'px';
								na.style.width = w+'px';
							}
						]]>
						setCookie("vzcc-menu-mode", "<xsl:value-of select="$mode"/>", 2E12);
					</script>
	
				</head>
				<body marginheight="0" marginwidth="0" topmargin="0" leftmargin="0" rightmargin="0" onresize="callScroll()" onload="callScroll();{sw:if($init-first = 'true','initFirst();','')};_callNavigate()" class="leftFrame">
					<div style="margin: auto; padding:0; padding-top:10px; padding-left:10px; overflow:auto; display:block; width: 100%;" id="navArea">
					<div id="rightMenu"></div>
					<div id="moveTip"></div>
						<xsl:call-template name="vzcc_menu">
							<xsl:with-param name="validItems" select="$validItems"/>
							<xsl:with-param name="mode" select="$mode"/>
						</xsl:call-template>
					</div>
					<div style=" margin: 0; clear: both; height: {$selector-height}px;" id="menu_selector">
						<xsl:call-template name="local:show-menu-switch">
							<xsl:with-param name="items" select="$validItems"/>
							<xsl:with-param name="mode" select="$mode"/>		
							<xsl:with-param name="button-height" select="$button-height"/>	
							<xsl:with-param name="bar-height" select="$bar-height"/>
						</xsl:call-template>										
					</div>
				</body>
			</html>
		</ui:raw>
	</xsl:template>

	<xsl:template name="local:show-menu-switch">
  	<xsl:param name="items"/>
  	<xsl:param name="mode"/>
  	<xsl:param name="button-height"/>
  	<xsl:param name="bar-height"/>  	
  	  	
  	<table width="100%" cellpadding="0" cellspacing="0" border="0">
	  	<xsl:if test="$mode != 'all'">
				<xsl:for-each select="$items">
					<tr style="height:{$button-height}px;">
						<td class="menuButton{sw:if($mode = @id,'Active','')}" valign="middle" onclick="customRefresh('/vz/cp/panel/vzcc/menu?mode={@id}&amp;init=first')" onmouseover="this.className = '{sw:if($mode = @id,'menuButtonActive','menuButtonOver')}'" onmouseout="this.className = 'menuButton{sw:if($mode = @id,'Active','')}'">
							<img src="/{$theme}/icons/{@icon}_16.gif" align="{title}" title="{sw:text(string(title))}" hspace="5"/>
							<b><sw:text select="title/text()"/></b>
						</td>
					</tr>
				</xsl:for-each>
				<tr style="height:{$button-height}px;">
					<td class="menuButton">
						<a href="javascript:customRefresh('{$baseurl}/panel/vzcc/menu?mode=all')">
							<img src="/{$theme}/icons/file_dir.gif"  alt="Full View" title="{sw:text('Full View')}" style="padding-right: 5px; float:right"/>
						</a>
						<div class="refreshIcon" style="float:right;margin-right:3px">
							<!--onmouseover="_callTip('refresh_menu',event)" onmouseout="_callTip()"-->
							<a href="javascript:customRefresh('{$baseurl}/panel/vzcc/menu')" id="a_refresh_menu" onmouseover="customTitle('a_refresh_menu','refresh_menu')"><img src="/{$theme}/icons/menu_refresh.gif" title="{sw:text('Refresh')}"/></a>
						</div>					
					</td>
				</tr>
			</xsl:if>
				<xsl:if test="$mode = 'all'">
					<tr style="height:{$bar-height}px;">
						<td class="menuButton" valign="middle">
							<table width="100%" cellpadding="0" cellspacing="0" border="0">
								<tr>
									<td align="left">
									<div class="refreshIcon">
										<!--onmouseover="_callTip('refresh_menu',event)" onmouseout="_callTip()"-->
										<a href="javascript:customRefresh('{$baseurl}/panel/vzcc/menu')" id="a_refresh_menu" onmouseover="customTitle('a_refresh_menu','refresh_menu')"><img src="/{$theme}/icons/menu_refresh.gif" title="{sw:text('Refresh')}"/></a>
									</div>
									</td>
									<td align="right">
									<xsl:for-each select="$items">
										<div style="display:inline; padding:2px;padding-top:4px;">
											<a href="javascript:customRefresh('?mode={@id}&amp;init=first')" onmouseover="_callTip('{@tip}',event)" onmouseout="_callTip()"><img src="/{$theme}/icons/{@icon}_16.gif" align="{title}" title="{sw:text(string(title))}"/></a>
										</div>
									</xsl:for-each>		  					
									</td>
								</tr>
							</table>
					</td>
					</tr>
			</xsl:if>	
		</table>
  </xsl:template>

	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/nav_menu.xsl"/>
	<sw:include href="/lib/common.xsl"/>	
	<sw:include href="/lib/cred-filter.xsl"/>
  <sw:include href="/lib/swa/licensem.xsl"/>
  
</xsl:stylesheet>
