<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui" 
 	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"   
  xmlns:error	="http://www.swsoft.com/xsl/cp/error"
  >

  <xsl:template name="screen-sent">
		<xsl:choose>
	    <xsl:when test="/packet/data/mailer/error">
				<!-- mailer error occured: no mail configured -->
				<xsl:message>Can't mail restore link for Container #<xsl:value-of select="env:env2title(env:get-env(sw:ve-eid()))"/>: <xsl:value-of select="/packet/data/mailer/error/message"/></xsl:message>
  	    <ui:error>
    	    <xsl:value-of select="sw:text('Sending emails is unavailable, please contact your service provider for details.')"/>
      	</ui:error>
		    <ui:oldtext align="center" valign="top">
    		  <sw:text>
        		The password recovery instructions cannot be emailed to you<br/>
    		  </sw:text>        
		    </ui:oldtext>
    		<ui:bottom>
		    	<ui:oldtext/>
    		  <ui:button name="doReturn" type="ok"><sw:text>Ok</sw:text></ui:button>
		    </ui:bottom> 
	    </xsl:when>
			<xsl:otherwise>
		    <ui:oldtext align="center" valign="top">
    		  <sw:text>
        		The password recovery instructions have been emailed to you.<br/>
		        Please read and follow them.
    		  </sw:text>        
		    </ui:oldtext>
    		<ui:bottom>
		    	<ui:oldtext/>
    		  <ui:button name="doReturn" type="ok"><sw:text>Ok</sw:text></ui:button>
		    </ui:bottom> 
  			<!-- put sent information into session -->
		    <xsl:value-of select="sw:sesput('password-recovery-url-sent', 1)"/>
			</xsl:otherwise>
		</xsl:choose>
  </xsl:template>

  <xsl:template name="screen-changed">
    <ui:oldtext align="center" valign="top">
      <sw:text>
        <xsl:with-param name="login" select="$login"/>
        The password for %{login} has changed.
      </sw:text>        
    </ui:oldtext>
    <ui:bottom>
      <ui:oldtext/>
      <ui:button name="doLogout" type="ok"><sw:text>Ok</sw:text></ui:button>
    </ui:bottom> 
  </xsl:template>

  <xsl:template name="screen-password-form">
		<xsl:choose>
	    <xsl:when test="/packet/data/progm/error">
				<!-- system error occured: no such programm, vzenv is down, other -->
				<xsl:message>Can't change password for Container #<xsl:value-of select="$veid"/>: <xsl:value-of select="/packet/data/progm/error/message"/></xsl:message>
  	    <ui:error>
    	    <xsl:value-of select="sw:text('The system is unavailable, please contact your service provider for details.')"/>
      	</ui:error>
	    </xsl:when>
	 	   <xsl:when test="/packet/data/progm/exec/status != 0">
				<!-- program exec error occured: plesk password changer return nonzero rc -->
				<xsl:message>Can't change password for Container #<xsl:value-of select="$veid"/>: <xsl:value-of select="sw:base64-decode(/packet/data/progm/exec/output)"/></xsl:message>
  	    <ui:error>
    	    <xsl:value-of select="sw:text('The system is unavailable, please contact your service provider for details.')"/>
      	</ui:error>
			</xsl:when>
			<xsl:when test="error:has-errors()">
				<ui:error>
    	    <xsl:value-of select="error:get()"/>
  	      <xsl:if test="error:reset()"/>
	      </ui:error>
			</xsl:when>
		</xsl:choose>

    <ui:oldtext align="center" valign="top">
      <sw:text>
        <xsl:with-param name="login" select="$login"/>
        Please enter a new password for the %{login} user.
      </sw:text>
    </ui:oldtext>
    
    <ui:input type="password" name="passwd" title="{sw:text('Password')}"/>
    <ui:input type="password" name="retype" title="{sw:text('Retype the password')}"/>
    
    <ui:bottom>
      <ui:oldtext/>
      <xsl:choose>
        <xsl:when test="$login = 'admin'">
          <ui:button type="ok" name="_submit" tip="submit_plesk_pwd_change"><sw:text>Change</sw:text></ui:button>
        </xsl:when>
        <xsl:otherwise>
          <ui:button type="ok" name="_submit" tip="submit_root_pwd_change_{sw:if(vt:is-local-platform-windows(),'win','nix')}">
          	<sw:text>Ok</sw:text>
          </ui:button>
        </xsl:otherwise>
      </xsl:choose>
    </ui:bottom>

  </xsl:template>

  <sw:include href="../lib/progm.xsl"/> 
  <sw:include href="../lib/psa_auth.xsl"/>
	<!--  <sw:include href="../lib/screen.xsl"/> -->

  <xsl:template match="/">
    <xsl:choose>
      <!-- invalid session type: go to / -->
      <xsl:when test="$auth-type != 'restorepassword' and $auth-type != 'restoreauthmpassword'">
				<ui:redirect/>
      </xsl:when>

      <!-- we finish password recovery: go to login screen -->
      <xsl:when test="/packet/cookie/redirect">
				<ui:redirect/>
      </xsl:when>

      <!-- all other - show document -->
      <xsl:otherwise>
				<ui:front-screen id="03.00.00.00.05">
					<xsl:choose>
						<xsl:when test="/packet/cookie/sent and (/packet/data//ok or /packet/data/progm/exec/status = 0)">
							<xsl:call-template name="screen-sent"/>
						</xsl:when>
						<xsl:when test="/packet/cookie/sent and (/packet/data//error or /packet/data/progm/exec/status != 0)">
							<xsl:call-template name="screen-sent"/>
						</xsl:when>
						<xsl:when test="/packet/cookie/changed and (/packet/data//ok or /packet/data/progm/exec/status = 0)">
							<xsl:call-template name="screen-changed"/>
						</xsl:when>
						<xsl:when test="/packet/cookie/changed and (/packet/data//error or /packet/data/progm/exec/status != 0)">
							<xsl:attribute name="action">/vz/cp/restore-password?LoginTicket=<xsl:value-of select="$request/http_request/get/parameter[name = 'LoginTicket']/value"/></xsl:attribute>
							<xsl:call-template name="screen-password-form"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="action">/vz/cp/restore-password?LoginTicket=<xsl:value-of select="$request/http_request/get/parameter[name = 'LoginTicket']/value"/></xsl:attribute>
							<xsl:call-template name="screen-password-form"/>
						</xsl:otherwise>
					</xsl:choose>
				</ui:front-screen>
			</xsl:otherwise>
    </xsl:choose>
  </xsl:template>

	<sw:include href="../lib/common.xsl"/>

</xsl:stylesheet>
