<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl swa-mailer func local"
  xmlns:xsl		="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl	="http://exslt.org/common"
  xmlns:sw		="http://www.swsoft.com/xsl/cp"
  xmlns:ui		="http://www.swsoft.com/xsl/cp/ui" 
  xmlns:swa-mailer="http://www.swsoft.com/xsl/cp/swa-mailer"    
  xmlns:plesk			="http://www.swsoft.com/xsl/cp/plesk"
  xmlns:local			="http://www.swsoft.com/xsl/cp/local"
  xmlns:func			="http://exslt.org/functions"
  xmlns:env				="http://www.swsoft.com/xsl/cp/env"
  >

  <sw:include href="/lib/globals.xsl"/>
  <sw:include href="/lib/sso.xsl"/>

  <!-- common params for delegated UI pages -->
  <xsl:variable name="ui-type"      select="/http_request/*[self::post or self::get]/parameter[name = 'ui_type'     ]/value"/>
  <xsl:variable name="response-url" select="/http_request/*[self::post or self::get]/parameter[name = 'response_url']/value"/>
  <xsl:variable name="request-id"   select="/http_request/*[self::post or self::get]/parameter[name = 'request_id'  ]/value"/>
  <xsl:variable name="relay-state"  select="/http_request/*[self::post or self::get]/parameter[name = 'relay_state' ]/value"/>
  <xsl:variable name="message-id"   select="/http_request/*[self::post or self::get]/parameter[name = 'message_id'  ]/value"/>

  <xsl:template match="/">

    <!-- all screens respond to $response-url, preserving $request-id, $relay-state, supplying 'confirmed' -->

    <xsl:choose>

      <xsl:when test="$ui-type = 'idp_login'">
        <xsl:call-template name="screen-login"/>
      </xsl:when>

      <!-- Account Selection, output: name | (user_name, user_password) -->
      <xsl:when test="$ui-type = 'idp_select_name'">
        <xsl:variable name="users" select="/http_request/*[self::post or self::get]/parameter[substring(name, 1, 5) = 'name_']/value"/>
        <!-- For now it is autosubmit of first account -->
        <ui:redirect location="{$response-url}">
          <ui:arg name="name"><xsl:value-of select="$users[0]"/></ui:arg>
          <ui:arg name="request_id"><xsl:value-of select="$request-id"/></ui:arg>
          <ui:arg name="relay_state"><xsl:value-of select="$relay-state"/></ui:arg>
        </ui:redirect>
      </xsl:when>

      <xsl:when test="$ui-type = 'idp_fi_detach'">
        <xsl:call-template name="screen-unlink"/>
      </xsl:when>

      <xsl:when test="$ui-type = 'idp_fi_attach'">
        <xsl:call-template name="screen-linking"/>
      </xsl:when>

      <xsl:when test="$ui-type = 'idp_fi_update'">
        <xsl:call-template name="screen-fi-update"/>
      </xsl:when>

      <xsl:otherwise>
        <ui:raw>
          Unknown Delegated Ui Type.
        </ui:raw>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <!-- Login, output: user_name, user_password, addparam_* -->
  <xsl:template name="screen-login">
    <ui:front-screen id="03.00.00.00.03" title-long="Login into Product" title="IDP login" action="{$response-url}">

      <xsl:choose>
        <xsl:when test="$message-id">
          <ui:error>
            <xsl:choose>
              <xsl:when test="$message-id = 'AUTH_FAILED'">
                <sw:text>Authentication failed.</sw:text>							
              </xsl:when>							
              <xsl:when test="$message-id = 'SP_CREDS_REQUIRED'">
                <sw:text>No local account exists for your federated 
                  identity.</sw:text>
              </xsl:when>
            </xsl:choose>
          </ui:error>
        </xsl:when>      
      </xsl:choose>

      <ui:oldtext align="left" valign="top">
        <sw:text>Please enter your login information.</sw:text>
      </ui:oldtext>

      <ui:input type="text" name="user_name" title="{sw:text('Username')}" value=""/>
      <ui:input type="password" name="user_password" title="{sw:text('Password')}"/>

      <xsl:variable name="langs" select="sw:document('languages.xml')/languages/language[active]"/>
      <xsl:variable name="lang-default" select="$langs[default]/id"/>

      <xsl:choose>
        <xsl:when test="count($langs) &gt; 1">
          <ui:input type="combo" title="{sw:text('Interface Language')}" name="addparam_active_lang"
            onchange="var n=this.options[this.selectedIndex].value;eatCookie('vzcpLang');setCookie('vzcpLang',n);window.location.reload();" 
          >
            <option value="$lang-default"><sw:text>User Default</sw:text></option>
            <xsl:for-each select="$langs">
              <option value="{id}">
                <xsl:if test="$langObj/id = string(id)">
                  <xsl:attribute name="selected">1</xsl:attribute>
                </xsl:if>
              <sw:text select="name/text()"/></option>
            </xsl:for-each>
          </ui:input>      
        </xsl:when>
        <xsl:otherwise>
          <!-- one lang allowed -->
          <ui:hidden name="addparam_active_lang" value="{$lang-default}"/>
        </xsl:otherwise>
      </xsl:choose>

      <ui:bottom>
        <ui:button name="confirmed"><sw:text>Login_button</sw:text></ui:button>
      </ui:bottom>

      <ui:hidden name="request_id"  value="{$request-id}"/>
      <ui:hidden name="relay_state" value="{$relay-state}"/>
    </ui:front-screen>
  </xsl:template>

  <!-- Linking of local account to federated identity, output: mode = (create_new|use_existing|use_current), fi_user_name_id, fi_password?, fi_user_email -->
  <xsl:template name="screen-linking">

    <xsl:variable name="fi-name"    select="/http_request/*[self::post or self::get]/parameter[name = 'fi_user_name_id']/value"/>
    <xsl:variable name="local-name" select="/http_request/*[self::post or self::get]/parameter[name = 'local_user_id']/value"/>

    <ui:front-screen id="03.00.00.00.03" title-long="Associate local account with FI" title="Account Linking" action="{$response-url}">

      <xsl:choose>
        <xsl:when test="$message-id">
          <ui:error>
            <xsl:choose>
              <xsl:when test="$message-id = 'FI_AUTH_FAILED'">
                <sw:text>Federated identity authentication failed.</sw:text>							
              </xsl:when>							
              <xsl:when test="$message-id = 'FI_NOT_FOUND'">
                <sw:text>The requested federated identity does not 
                  exist.</sw:text>
              </xsl:when>
              <xsl:when test="$message-id = 'FI_ALREADY_EXISTS'">
                <sw:text>The requested federated identity already exists.</sw:text>
              </xsl:when>
            </xsl:choose>
          </ui:error>
        </xsl:when>
      </xsl:choose>

      <xsl:if test="$fi-name">
        <!-- enable "use_current" -->
      </xsl:if>
              
      <ui:oldtext align="left" valign="top">
        <xsl:text>Link account </xsl:text>
        <xsl:value-of select="$local-name"/>
        <xsl:text> to federated identity</xsl:text>
      </ui:oldtext>

      <ui:input type="text"     name="fi_user_name_id" title="{sw:text('Federated Identity')}" value="{$fi-name}"/>
      <ui:input type="password" name="fi_password" title="{sw:text('Federated Identity Password')}"/>
      <ui:input type="text"     name="fi_user_email" title="{sw:text('Federated Identity Email')}"/>

      <!-- mode -->
      <ui:input type="combo" title="{sw:text('Use:')}" name="mode">
        <option value="use_existing">
          <sw:text>an existing FI</sw:text> 
        </option>
        <option value="create_new">
          <sw:text>a new FI</sw:text> 
        </option>
        <xsl:if test="$fi-name">
          <option value="use_current">
            <sw:text>the current FI</sw:text> 
          </option>
        </xsl:if>
      </ui:input>      

      <ui:bottom>
        <ui:button name="confirmed"><sw:text>Link account</sw:text></ui:button>
      </ui:bottom>

      <ui:hidden name="request_id"  value="{$request-id}"/>
      <ui:hidden name="relay_state" value="{$relay-state}"/>
    </ui:front-screen>
  </xsl:template>

  <!-- Update of federated identity, output: current_fi_password, new_fi_password, fi_user_email -->
  <xsl:template name="screen-fi-update">

    <xsl:variable name="fi-name"  select="/http_request/*[self::post or self::get]/parameter[name = 'fi_user_name_id']/value"/>
    <xsl:variable name="fi-email" select="/http_request/*[self::post or self::get]/parameter[name = 'fi_user_email']/value"/>

    <ui:front-screen id="03.00.00.00.03" title-long="Update of Federated Identity" title="FI update" action="{$response-url}">

      <xsl:choose>
        <xsl:when test="$message-id">
          <ui:error>
            <xsl:choose>
              <xsl:when test="$message-id = 'FI_AUTH_FAILED'">
                <sw:text>Federated identity authentication failed.</sw:text>							
              </xsl:when>							
              <xsl:when test="$message-id = 'FI_NOT_FOUND'">
                <sw:text>The requested federated identity does not exist.</sw:text>
              </xsl:when>
            </xsl:choose>
          </ui:error>
        </xsl:when>
      </xsl:choose>

      <ui:oldtext align="left" valign="top">
        <xsl:text>Update properties of </xsl:text>
        <xsl:value-of select="$fi-name"/>
        <xsl:text> federated identity</xsl:text>
      </ui:oldtext>

      <ui:input type="text"     name="fi_user_name_id" title="{sw:text('Federated Identity')}" value="{$fi-name}"/>
      <ui:input type="password" name="current_fi_password" title="{sw:text('Current Federated Identity Password')}"/>
      <!-- TODO: javascript check passwords match -->
      <ui:input type="password" name="new_fi_password" title="{sw:text('New Federated Identity Password')}"/>
      <ui:input type="password" name="confirm_fi_password" title="{sw:text('Confirm New Password')}"/>
      <ui:input type="text"     name="fi_user_email" title="{sw:text('Federated Identity Email')}"/>

      <ui:bottom>
        <ui:button name="confirmed"><sw:text>Link account</sw:text></ui:button>
      </ui:bottom>

      <ui:hidden name="request_id"  value="{$request-id}"/>
      <ui:hidden name="relay_state" value="{$relay-state}"/>
    </ui:front-screen>
  </xsl:template>

  <!-- Detach of local account from Federated Identity. output: -->
  <xsl:template name="screen-unlink">

    <xsl:variable name="fi-name" select="/http_request/*[self::post or self::get]/parameter[name = 'fi_user_name_id']/value"/>
    <xsl:variable name="local-name" select="/http_request/*[self::post or self::get]/parameter[name = 'local_user_id']/value"/>

    <ui:front-screen id="03.00.00.00.03" title-long="De-associate local account from Federated Identity" title="Account unlink" action="{$response-url}">

      <ui:oldtext align="left" valign="top">
        <xsl:text>Unlink account </xsl:text>
        <xsl:value-of select="$local-name"/>
        <xsl:text> from federated identity</xsl:text>
      </ui:oldtext>

      <ui:bottom>
        <ui:button name="confirmed">
          <sw:text>Unlink account</sw:text>
        </ui:button>
      </ui:bottom>

      <ui:hidden name="request_id"  value="{$request-id}"/>
      <ui:hidden name="relay_state" value="{$relay-state}"/>
    </ui:front-screen>
  </xsl:template>

</xsl:stylesheet>

