<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred func authm browse dirm perms groups local env vzenv vzhn"
	xmlns:func="http://exslt.org/functions"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:perms="http://www.swsoft.com/xsl/cp/perms"
	xmlns:groups="http://www.swsoft.com/xsl/cp/groups"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:security="http://www.swsoft.com/xsl/cp/security"
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/sysdir/securman/groups.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms-ui.xsl"/>
	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vz/vzhn-core.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>

	<xsl:param name="access-denied"
		select="not(cred:check('vzcp.virtuozzo_group.security.usergroups'))"/>

	<!-- check permissions to show this page -->
	<xsl:template mode="screen" match="/">

		<xsl:variable name="group-id" select="authm:switch-context('securman-group-id')"/>
		<xsl:variable name="realm-info" select="security:realms-info()"/>
		<xsl:variable name="group" select="authm:get-group($group-id,$realm-info/current-eid,false())"/>
		<xsl:variable name="group-name" 
			select="sw:base64-decode($group/data/attr[name='name']/value | $group/name)"/>
		<xsl:if test="sw:sesputstr('securman-group-name',$group-name)"/>

		<ui:screen id="03.01.01.04.04">
			<ui:properties>
				<ui:form-get/>
			</ui:properties> 
			<ui:content>
				<ui:block width="full">
					<xsl:choose>
						<!-- Can`t find group -->
						<xsl:when test="$group[self::error]">
							<ui:operation-problem>
								<ui:type>vza-error</ui:type>
								<ui:descr>
									<sw:text>Unable to find the group.</sw:text>
								</ui:descr>
								<ui:reason>
									<sw:text>The requested group has already been removed.</sw:text>
								</ui:reason>
								<ui:solition>
									<sw:text>Return to the groups list and select another group.</sw:text>
								</ui:solition>
								<ui:vza-error>
									<xsl:copy-of select="$group/*"/>
								</ui:vza-error>
							</ui:operation-problem>
						</xsl:when>
						<!-- /Can`t find group -->
						<!-- Show group -->
						<xsl:otherwise>
							<ui:rows title="{sw:text('Group Details')}">
								<ui:row>
									<ui:cell-label>
										<sw:text>Name</sw:text>
									</ui:cell-label>
									<ui:cell-value>
										<xsl:value-of select="$group-name"/>
									</ui:cell-value>
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Description</sw:text>
									</ui:cell-label>
									<ui:cell-value>
										<xsl:value-of select="sw:base64-decode($group/data/attr[name='description']/value)"/>
									</ui:cell-value>
								</ui:row>
							</ui:rows>
							<xsl:call-template name="perms:show-owner-perms">
								<xsl:with-param name="owner-sid" select="$group/objectSid"/>
								<xsl:with-param name="browse-id" select="'03.01.01.04.04'"/>
								<xsl:with-param name="browse-url" select="'/sysdir/securman/groups/group'"/>
								<xsl:with-param name="browse-empty-msg">
									<sw:text>No permission has been assigned to the group.</sw:text>
								</xsl:with-param>
								<xsl:with-param name="add-screen-id" select="'03.01.01.04.06'"/>
							</xsl:call-template>

							<xsl:call-template name="local:show-users">
								<xsl:with-param name="group" select="$group"/>
							</xsl:call-template>
						</xsl:otherwise>
						<!-- /Show group -->
					</xsl:choose>
				</ui:block>
			</ui:content>

		</ui:screen>
	</xsl:template>

	<xsl:template name="local:show-users">
		<xsl:param name="group"/>
		<xsl:param name="realm-info"/>
		<xsl:variable name="group-members-rtf">
			<xsl:if test="$group/member_user">
				<xsl:copy-of select="authm:get-users-by-authname($group/member_user)/user"/>
			</xsl:if>
			<xsl:if test="$group/member_group">
				<xsl:copy-of select="authm:get-groups-by-authname($group/member_group)/group"/>
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="group-members" select="exsl:node-set($group-members-rtf)"/>
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="group-users" url="/sysdir/securman/groups/group"/>
					<ui:cols sorting-col="login">
						<ui:column id="icon" display-type="icon" show-url="yes" sorting="no" filter-title="{sw:text('Icon')}"/>
						<ui:column id="id" hidden="yes" for-select="no" for-url="no"/>
						<ui:column id="login" title="{sw:text('Login')}" filter="auto" show-url="no" nav-type="title"/>
						<ui:column id="name" title="{sw:text('Full Name')}" filter="auto" show-url="no"/>
						<ui:column id="email" title="{sw:text('Email')}" filter="auto"/>
						<ui:column id="description" title="{sw:text('Description')}" filter="auto"/>						
						<ui:column id="dn" title="{sw:text('Distinguished name')}" filter="auto" custom-hidden="yes"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>
		<ui:rows title="{sw:text('Included Users and Groups')}">
			<ui:browse title="{sw:text('Users and Groups')}">
				<ui:filter>
					<xsl:call-template name="browse:fill-filter">
						<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
						<xsl:with-param name="rows">
							<ui:browse-rows>
								<xsl:for-each select="$group-members/*">
									<ui:row>
										<icon><xsl:value-of select="sw:if(current()[self::user],'user_16.gif','usergroup_16.gif')"/></icon>
										<id>
											<xsl:value-of select="sw:base64-decode(name)"/>
										</id>
										<login>
											<xsl:value-of select="authm:user-login(.)"/>
										</login>
										<name>
											<xsl:value-of select="sw:base64-decode(data/attr[name='displayName']/value)"/>
										</name>
										<email>
											<xsl:value-of select="sw:base64-decode(data/attr[name='mail']/value)"/>
										</email>
										<description>
											<xsl:value-of select="sw:base64-decode(data/attr[name='description']/value)"/>
										</description>
										<dn>
											<xsl:value-of select="sw:base64-decode(data/attr[name='distinguishedName']/value)"/>
										</dn>
										<description>
											<xsl:value-of select="sw:base64-decode(data/attr[name='description']/value)"/>
										</description>
									</ui:row>
								</xsl:for-each>
							</ui:browse-rows>
						</xsl:with-param>
					</xsl:call-template>
				</ui:filter>
				<ui:browse-empty-msg>
					<sw:text>No users or groups are included in the group.</sw:text>
				</ui:browse-empty-msg>
			</ui:browse>
		</ui:rows>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
