<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred authm dirm server_group"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:security	="http://www.swsoft.com/xsl/cp/security"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
>

	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>	

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-usergroup" select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>
	<xsl:param name="access-denied" select="not($cr-usergroup)"/>
	
	<xsl:variable name="realms-info" select="security:realms-info()"/>
	<xsl:variable name="realm-info" select="$realms-info/realm[@eid=$realms-info/current-eid]"/>
	

	<xsl:template mode="screen" match="/">
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="groups" url="/sysdir/securman/groups/index"
						item-url="/sysdir/securman/groups/group" item-url-tip="view_group"/>
					<ui:cols sorting-col="name">
						<ui:column id="icon" display-type="icon" show-url="yes" sorting="no" filter-title="{sw:text('Icon')}"/>
						<ui:column id="id" for-url="yes" for-select="{sw:if($realm-info/@allow-deletion='true','yes','no')}" hidden="yes" />
						<ui:column id="name" title="{sw:text('Name')}" filter="auto" show-url="yes" nav-type="title"/>
						<ui:column id="description" title="{sw:text('Description')}" filter="auto"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="browse_result" select="authm:get-groups($realms-info/current-eid)/authm"/>
		<xsl:variable name="browse_error" select="$browse_result/error|$browse_result/authm/error"/>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$browse_result/group">
							<!-- 
								Workaround for bug #81968.
								Disable editing of groups in VZ internal realm and in non-default DN.
							-->
							<xsl:variable name="group-id" select="sw:base64-decode(name)"/>
							<xsl:variable name="disable-edit" 
								select="not(authm:is-group-editable($group-id,$realm-info))"/>
							<ui:row>
								<xsl:if test="$disable-edit">
									<xsl:attribute name="disable-checkbox"/>
								</xsl:if>
								<icon>usergroup_16.gif</icon>
								<id>
									<xsl:value-of select="$group-id"/>
								</id>
								<name>
									<xsl:value-of select="sw:base64-decode(data/attr[name='name']/value | name)"/>
								</name>
								<description>
									<xsl:value-of select="sw:base64-decode(data/attr[name='description']/value)"/>
								</description>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.01.01.04.00">
			<ui:properties>
				<ui:form-get/>
				<ui:no-default-form/>
				<ui:description width="full">
					<xsl:choose>
						<xsl:when test="$realm-info/@allow-creation='true' and $realm-info/@allow-deletion='true'">
							<sw:text>
								<xsl:with-param name="scope" select="$realm-info/@title"/>
								On this screen you can view a list of groups that exist in the '%{scope}' database. You can also create a new group or remove an existing one.
							</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>
								<xsl:with-param name="scope" select="$realm-info/@title"/>
								On this screen you can view a list of groups that exist in the '%{scope}' database.
							</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:description>
			</ui:properties>

			<xsl:call-template name="security:realms-tab-bar">
				<xsl:with-param name="current-tab" select="'groups'"/>
				<xsl:with-param name="realms-info" select="$realms-info"/>
				<xsl:with-param name="subtab-base-url" select="concat($baseurl,'/sysdir/securman/groups/index?')"/>	
			</xsl:call-template>

			<ui:content>

				<ui:block width="full">
					<xsl:choose>

						<xsl:when test="$realms-info[self::error]">
							<ui:operation-problem>
								<ui:type>vza-error</ui:type>
								<ui:descr>
									<sw:text>Unable to list authentication databases.</sw:text>
								</ui:descr>
								<ui:vza-error>
									<xsl:copy-of select="$realms-info/*"/>
								</ui:vza-error>
							</ui:operation-problem>
						</xsl:when>
						
						<xsl:when test="$browse_error">
							<ui:operation-problem>
								<ui:type>vza-error</ui:type>
								<ui:descr>
									<sw:text>Unable to list groups.</sw:text>
								</ui:descr>
								<ui:vza-error>
									<xsl:copy-of select="$browse_error/*"/>
								</ui:vza-error>
							</ui:operation-problem>
						</xsl:when>
						
						<xsl:otherwise>
							<ui:browse>
								<xsl:attribute name="title">
									<sw:text>Groups</sw:text>
								</xsl:attribute>
								
								<ui:browse-js-many>
									<ui:warn>
										<sw:text>Select at least one group!</sw:text>
									</ui:warn>
								</ui:browse-js-many>
								
								<ui:filter>
									<xsl:copy-of select="$filter"/>
								</ui:filter>
								
								<ui:browse-buttons type="list-selection">
									<ui:button icon="usergroup_new" new-obj-title="{sw:text('Group')}" 
										disabled="{not($realm-info/@allow-creation='true')}"								
										submit-href="manage?cmd=new"
										sandclock="false" tip="create_group" require-items="false">
										<sw:text>New Group</sw:text>
									</ui:button>								
									<ui:button type="list-selection" tip="delete_group" icon="delete"
										disabled="{not($realm-info/@allow-deletion='true')}"															
										confirmation="{sw:text('Are you sure you want to delete the selected group(s)?')}"
										script="if (!atLeastOne()) return false;" name="delete" width="150"
										>
										<sw:text>Delete</sw:text>
									</ui:button>
								</ui:browse-buttons>
								
								<!-- form definition for other controls -->
								<ui:form action="list-control"/>
								
								<ui:browse-empty-msg>
									<sw:text>No groups could be found. </sw:text>
								</ui:browse-empty-msg>
								
							</ui:browse>
						</xsl:otherwise>
					</xsl:choose>
				</ui:block>
			</ui:content>
		</ui:screen>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/swa/server-group.xsl"/>  

	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
