<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred form env local browse roles authm"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:roles="http://www.swsoft.com/xsl/cp/roles"
	xmlns:vzcpsecuritym="http://www.swsoft.com/xsl/cp/vzcpsecuritym"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
>

	<sw:include href="/lib/swa/vzcpsecuritym.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-usergroup" select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>

	<xsl:param name="wiz_code" select="'sm-group'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="screenid" select="$step_data/@screenid"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="create" select="not($form/group-id!='')"/>

	<xsl:param name="access-denied" select="not($cr-usergroup)"/>

	<!-- Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">
		<ui:screen id="{$screenid}">
			<ui:properties>
				<ui:form-get/>
				<ui:refresh-type>none</ui:refresh-type>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit">

					<ui:rows title="{sw:text('General Settings')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>Name</sw:text>
							</ui:cell-label>
							<ui:cell-input id="name">
								<xsl:choose>
									<xsl:when test="authm:vzadmin-group-name() = string($form/gen/name)">
										<xsl:attribute name="disabled">true</xsl:attribute>
										<xsl:attribute name="value"><xsl:value-of select="$form/src/cn"/></xsl:attribute>
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="value"><xsl:value-of select="$form/gen/name"/></xsl:attribute>
										<xsl:attribute name="required">true</xsl:attribute>
									</xsl:otherwise>
								</xsl:choose>
							</ui:cell-input>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Description</sw:text>
							</ui:cell-label>
							<ui:cell-input id="description" maxlength="256">
								<xsl:attribute name="value">
									<xsl:value-of select="$form/group/description"/>
								</xsl:attribute>
							</ui:cell-input>
						</ui:row>
					</ui:rows>
					
					<ui:rows>
						<xsl:attribute name="title">
							<sw:text>Included Users and Groups</sw:text>
						</xsl:attribute>
						<ui:row>
							<ui:cell-list-picker id="principals" size="10" style="width:400px;">
								<xsl:for-each select="$form/gen/principal">
									<ui:list-item id="{src}" title="{title}"/>
								</xsl:for-each>
								<ui:list-add-button
									onclick="open_details('{$baseurl}/sysdir/securman/users/select-popup?id=principals&amp;mode=realm-single&amp;realm={$form/src/realm-eid}','user_list',620,850); return false;"
									tip="add_users" do-submit="false" icon="user">
									<title>
										<sw:text>Add User</sw:text>
									</title>
								</ui:list-add-button>
								<ui:list-add-button
									onclick="open_details('{$baseurl}/sysdir/securman/groups/select-popup?id=principals&amp;mode=realm-single&amp;realm={$form/src/realm-eid}','group_list',620,850); return false;"
									tip="add_groups" do-submit="false" icon="usergroup">
									<title>
										<sw:text>Add Group</sw:text>
									</title>
								</ui:list-add-button>
							</ui:cell-list-picker>
						</ui:row>
					</ui:rows>
					
					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>

			</ui:content>
		</ui:screen>

	</xsl:template>


	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>

			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
