<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred local show voc env roles groups securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" xmlns:show="http://www.swsoft.com/xsl/cp/show"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc" xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:roles="http://www.swsoft.com/xsl/cp/roles"
	xmlns:groups="http://www.swsoft.com/xsl/cp/groups"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
	xmlns:users="http://www.swsoft.com/xsl/cp/users">

	<!-- Import required modules -->
	<sw:include href="/lib/swa/securitym.xsl"/>
	<sw:include href="/lib/sysdir/securman/roles.xsl"/>
	<!-- /Import required modules -->

	<xsl:param name="wiz_code" select="'securman-perms-obj-add'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="screen-id" select="$step_data/@screen-id"/>
	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- Step "Start" -->
	<xsl:template name="step_start">
		<ui:screen id="{$screen-id}">

			<ui:properties>
				<ui:form-get/>
				<ui:refresh-type>none</ui:refresh-type>
				<xsl:choose>
					<xsl:when test="$form/def/obj-type = 'hn.vz.vt'">
						<ui:description><sw:text>On this screen you can create a new permission for the current Hardware Node. This means that the users and/or groups you define in the <b>Users and Groups</b> section are assigned one or more roles you select in the <b>Assigned Roles</b> section. Each role consists of a number of operations that the respective users will be allowed to perform in the context of the current Hardware Node.<br/>Permissions for the whole Virtuozzo Group can be created on the Global Permissions tab, accessible by selecting Setup | Security on the left Parallels Infrastructure Manager menu.</sw:text></ui:description>
					</xsl:when>
					<xsl:when test="$form/def/obj-type = 've.vz.vt'">
						<ui:description><sw:text>On this screen you can create a new permission for the current Container. This means that the users and/or groups you define in the <b>Users and Groups</b> section are assigned one or more roles you select in the <b>Assigned Roles</b> section. Each role consists of a number of operations that the respective users will be allowed to perform in the context of the current Container.<br/>Permissions for the whole Virtuozzo Group can be created on the Global Permissions tab, accessible by selecting Setup | Security on the left Parallels Infrastructure Manager menu.</sw:text></ui:description>
					</xsl:when>
					<xsl:when test="$form/def/obj-type = 'unit.farm'">
						<ui:description><sw:text>On this screen you can create a new permission for the current folder. This means that the users and/or groups you define in the <b>Users and Groups</b> section are assigned one or more roles you select in the <b>Assigned Roles</b> section. Each role consists of a number of operations that the respective users will be allowed to perform in the context of the current folder.<br/>Permissions for the whole Virtuozzo Group can be created on the Global Permissions tab, accessible by selecting Setup | Security on the left Parallels Infrastructure Manager menu.</sw:text></ui:description>
					</xsl:when>
				</xsl:choose>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="start"/>
				<ui:block mode="edit">
					<ui:rows>
						<xsl:attribute name="title">
							<sw:text>Users and Groups</sw:text>
						</xsl:attribute>
						<ui:row>
							<ui:cell-text show-aster="true">
								<sw:text>Please specify the users and/or groups to have the permission.</sw:text>
							</ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-list-picker id="owners" size="10" style="width:400px;">
								<xsl:for-each select="$form/owners/owner">
									<ui:list-item id="{src}" title="{title}"/>
								</xsl:for-each>
								<ui:list-add-button
									onclick="open_details('{$baseurl}/sysdir/securman/users/select-popup?id=owners&amp;mode=realm-list','user_list',620,850); return false;"
									tip="add_users" do-submit="false" icon="user">
									<title>
										<sw:text>Add User</sw:text>
									</title>
								</ui:list-add-button>
								<ui:list-add-button
									onclick="open_details('{$baseurl}/sysdir/securman/groups/select-popup?id=owners&amp;mode=realm-list','group_list',620,850); return false;"
									tip="add_groups" do-submit="false" icon="usergroup">
									<title>
										<sw:text>Add Group</sw:text>
									</title>
								</ui:list-add-button>
							</ui:cell-list-picker>
						</ui:row>
					</ui:rows>
					<ui:rows title="{sw:text('Assigned Roles')}">
						<ui:row>
							<ui:cell-text show-aster="true">
								<sw:text>Please specify the roles for the permission.</sw:text>
							</ui:cell-text>
						</ui:row>
						<xsl:variable name="roles" select="securitym:list-assignable-roles()"/>
						<xsl:choose>
							<xsl:when test="count($roles) &gt; 0">
								<ui:row>
									<ui:cell-list-selector id="roles" size="6" colspan="2">
										<xsl:for-each select="$roles">
											<xsl:variable name="name" select="name"/>
											<ui:item value="{$name}"
												selected="{sw:if($form/roles/role/name=$name,'true','false')}">
												<xsl:value-of select="name"/>
											</ui:item>
										</xsl:for-each>
									</ui:cell-list-selector>
								</ui:row>
							</xsl:when>
							<xsl:otherwise>
								<ui:row>
									<ui:cell colspan="2">
										<sw:text>No roles have been configured in Parallels Infrastructure Manager yet.</sw:text>
									</ui:cell>
								</ui:row>
							</xsl:otherwise>
						</xsl:choose>
					</ui:rows>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="submit-title" select="sw:text('Save')"/>
							<xsl:with-param name="submit-sandclock" select="false()"/>
							<xsl:with-param name="next-title" select="sw:text('Next')"/>
						</xsl:call-template>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="$step = 'start'">
				<xsl:call-template name="step_start"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_start"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/common.xsl"/>


</xsl:stylesheet>
