<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred authm"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui" xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred">

	<sw:include href="/lib/swa/authm.xsl"/>

	<xsl:param name="access-denied"
		select="not(cred:check('vzcp.virtuozzo_group.security.usergroups'))"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="cr-realm-manage" select="cred:check('vzcp.virtuozzo_group.security.realms')"/>
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="realms" url="/sysdir/securman/realms/index" 
						item-url="/sysdir/securman/realms/realm"/>
					<ui:cols>
						<ui:column id="realm" for-select="{sw:if($cr-realm-manage,'yes','no')}" hidden="yes" for-url="yes" encode="no"/>
						<ui:column id="name" title="{sw:text('Name')}" filter="auto" show-url="yes"/>
						<ui:column id="address" title="{sw:text('Address')}" filter="auto"/>
						<ui:column id="port" title="{sw:text('Port')}" filter="auto"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="realms" select="authm:list-realms()"/>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$realms/*[type='1']">
							<ui:row>
								<xsl:if test="builtin">
									<xsl:attribute name="disable-checkbox"/>
								</xsl:if>
								<realm>
									<xsl:value-of select="id"/>
								</realm>
								<name>
									<xsl:value-of select="sw:text(string(name))"/>
								</name>
								<address><xsl:value-of select="address"/></address>
								<port><xsl:value-of select="port"/></port>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.01.01.05.00">

			<ui:properties>
				<ui:no-default-form/>
				<ui:description width="full">
					<sw:text>
						On this screen you can view a list of registered authentication databases, register a new users' database, or delete an existing one. Registering an authentication database in Parallels Infrastructure Manager allows you to provide the users from this database with access to the Hardware Nodes and their Containers.
					</sw:text>
				</ui:description>
			</ui:properties>

			<ui:tab-bar id="security" current-tab="realms"/>
			<ui:toolbar id="realm.add"/>
			<ui:content>

				<ui:block width="full">

					<xsl:choose>

						<!-- Can`t list due to some VZA error -->
						<xsl:when test="$realms[self::error]">
							<ui:operation-problem>
								<ui:type>vza-error</ui:type>
								<ui:descr>
									<sw:text>Unable to list authentication databases.</sw:text>
								</ui:descr>
								<ui:vza-error>
									<xsl:copy-of select="$realms/*"/>
								</ui:vza-error>
							</ui:operation-problem>
						</xsl:when>
						<!-- /Can`t list due to some VZA error -->

						<!-- Show list -->
						<xsl:otherwise>

							<ui:browse>
								<xsl:attribute name="title">
									<sw:text>Authentication Databases</sw:text>
								</xsl:attribute>

								<ui:browse-js-many>
									<ui:warn>
										<sw:text>Please select at least one database.</sw:text>
									</ui:warn>
								</ui:browse-js-many>

								<ui:filter>
									<xsl:copy-of select="$filter"/>
								</ui:filter>

								<ui:browse-buttons type="list-selection">
									<xsl:if test="$cr-realm-manage">
										<ui:button icon="realm_new" tip="register_realm" new-obj-title="{sw:text('Database')}" submit-href="add" require-items="false">
											<sw:text>Register Database</sw:text>
										</ui:button>																	
										<ui:button type="list-selection" tip="delete_realm" icon="delete"
											confirmation="{sw:text('Are you sure you want to delete the selected databases?')}"
											script="if (!atLeastOne()) return false;" name="delete" width="150">
											<sw:text>Delete</sw:text>
										</ui:button>
									</xsl:if>
								</ui:browse-buttons>

								<!-- form definition for other controls -->
								<ui:form action="list-control"/>

								<ui:browse-empty-msg>
									<sw:text>No databases could be found. </sw:text>
								</ui:browse-empty-msg>

							</ui:browse>
						</xsl:otherwise>
					</xsl:choose>
				</ui:block>
			</ui:content>
		</ui:screen>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
