<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:security="http://www.swsoft.com/xsl/cp/security"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>

	<xsl:param name="access-denied"
		select="not(cred:check('vzcp.virtuozzo_group.security.realms'))"/>

	<xsl:template mode="screen" match="/">
		
		<xsl:variable name="realms-info" select="security:realms-info()"/>
		<xsl:variable name="realm-info" select="$realms-info/realm[@eid=$realms-info/current-eid]"/>
		<xsl:variable name="realm" select="authm:list-realms()/realm[string(id)=$realms-info/current-eid]"/>
		
		<ui:screen id="03.01.01.05.02">
			<ui:properties>
				<ui:description mandatory="yes">
					<sw:text>
					On this screen you can view the current settings of the authentication database. 
					<br/>To edit the settings, click the <b>Configure</b> button at the top of the screen.
					</sw:text>
				</ui:description>
			</ui:properties>
			<ui:content>
				<ui:block>
					
					<ui:rows title="{sw:text('Authentication Database Details')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>Server Address</sw:text>
							</ui:cell-label>
							<ui:cell-text><xsl:value-of select="$realm/address"/></ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Port</sw:text>
							</ui:cell-label>
							<ui:cell-text><xsl:value-of select="$realm/port"/></ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Login</sw:text>
							</ui:cell-label>
							<ui:cell-text><xsl:value-of select="sw:base64-decode($realm/login/name)"/></ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Domain</sw:text>
							</ui:cell-label>
							<ui:cell-text><xsl:value-of select="sw:base64-decode($realm/login/domain)"/></ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-label><sw:text>Base DN</sw:text></ui:cell-label>
							<ui:cell-text><xsl:value-of select="$realm/base_dn"/></ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-label><sw:text>Default DN</sw:text></ui:cell-label>
							<ui:cell-text><xsl:value-of select="$realm/default_dn"/></ui:cell-text>
						</ui:row>						
					</ui:rows>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
