<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

	<sw:include href="/lib/swa/securitym.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cred" select="cred:check('vzcp.virtuozzo_group.security.roles')"/>

	<xsl:param name="wiz_code" select="'config-ordering'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>

	<xsl:param name="access-denied" select="not($cred)"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- Wizard, General Step  -->
	<xsl:template name="step_gen">

		<xsl:variable name="roles" select="securitym:list-assignable-roles()"/>

		<ui:screen id="{$step_data/@screen-id}">

			<ui:properties>
				<ui:form-get/>
				<ui:refresh-type>none</ui:refresh-type>
			</ui:properties>

			<ui:tab-bar id="security" current-tab="other" current-subtab="register"/>
			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit">

					<ui:rows title="{sw:text('General')}">
						<ui:row>
							<ui:cell-check id="enabled" checked="{$form/user-registration/enabled}" close="false">
								<ui:control-slave>login</ui:control-slave>
								<ui:control-slave>role_left</ui:control-slave>
								<ui:control-slave>role_right</ui:control-slave>
							</ui:cell-check>
							<ui:cell-text open="false">
								<sw:text>Enable new user registration</sw:text>
							</ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-check offset="1" id="login"
								checked="{$form/user-registration/show-login-register}" close="false"/>
							<ui:cell-text open="false">
								<sw:text>Show the 'Register' link on the Login screen</sw:text>
							</ui:cell-text>
						</ui:row>
					</ui:rows>

					<ui:rows title="{sw:text('Default Roles for New User')}">
						<ui:row>
							<ui:cell-list-selector id="role" size="12" colspan="2">
								<xsl:for-each select="$roles">
									<xsl:variable name="id" select="name"/>
									<ui:item value="{$id}"
										selected="{sw:if($form/user-registration/user-role[.=$id],true(),false())}">
										<xsl:value-of select="name"/>
									</ui:item>
								</xsl:for-each>
							</ui:cell-list-selector>
						</ui:row>
					</ui:rows>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>


	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<!-- Includes -->
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl"/>

	<!-- /Includes -->

</xsl:stylesheet>
