<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl global browse cred authm dirm users local server_group"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:users="http://www.swsoft.com/xsl/cp/users"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"	
	xmlns:security	="http://www.swsoft.com/xsl/cp/security"			
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
	xmlns:global="http://www.swsoft.com/xsl/cp/global"		
>


	<sw:include href="/lib/sysdir/securman/users.xsl"/>

	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-usergroup" select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>
	<xsl:param name="access-denied" select="not($cr-usergroup)"/>

	<xsl:variable name="realms-info" select="security:realms-info()"/>
	<xsl:variable name="realm-info" select="$realms-info/realm[@eid=$realms-info/current-eid]"/>
	
	<xsl:template mode="screen" match="/">
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="users" url="/sysdir/securman/users/index"
						item-url="/sysdir/securman/users/user"/>
					<ui:cols sorting-col="login">
						<ui:column id="icon" display-type="icon" show-url="yes" sorting="no" filter-title="{sw:text('Icon')}"/>
						<ui:column id="id" hidden="yes" for-select="{sw:if($realm-info/@allow-deletion='true','yes','no')}" for-url="yes"/>
						<ui:column id="login" title="{sw:text('Login')}" filter="auto" show-url="yes" nav-type="title"/>
						<ui:column id="name" title="{sw:text('Full Name')}" filter="auto" show-url="yes"/>
						<ui:column id="email" title="{sw:text('Email')}" filter="auto"/>
						<ui:column id="description" title="{sw:text('Description')}" filter="auto"/>
						<xsl:if 
							test="not($realm-info/@eid=$global:system-realm-id or $realm-info/@eid=sw:internal-realm-id())">
							<ui:column id="dn" title="{sw:text('Distinguished name')}" filter="auto" custom-hidden="yes"/>
						</xsl:if>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="auth-data" select="authm:get-users($realms-info/current-eid)"/>
		<xsl:variable name="auth-error" select="$auth-data/error|$auth-data/authm/error"/>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-filter">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="rows">
					<ui:browse-rows>
						<xsl:for-each select="$auth-data/authm/user">
							<ui:row>
								<icon>user_16.gif</icon>
								<id>
									<xsl:value-of select="sw:base64-decode(name)"/>
								</id>
								<login>
									<xsl:value-of select="authm:user-login(.)"/>
								</login>
								<name>
									<xsl:value-of select="sw:base64-decode(data/attr[name='displayName']/value)"/>
								</name>
								<email>
									<xsl:value-of select="sw:base64-decode(data/attr[name='mail']/value)"/>
								</email>
								<description>
									<xsl:value-of select="sw:base64-decode(data/attr[name='description']/value)"/>
								</description>
								<xsl:if 
									test="not($realm-info/@eid=$global:system-realm-id or $realm-info/@eid=sw:internal-realm-id())">
									<dn>
										<xsl:value-of select="sw:base64-decode(data/attr[name='distinguishedName']/value)"/>
									</dn>
								</xsl:if>
								<description>
									<xsl:value-of select="sw:base64-decode(data/attr[name='description']/value)"/>
								</description>
							</ui:row>
						</xsl:for-each>
					</ui:browse-rows>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="03.01.01.01.00">

			<ui:properties>
				<ui:no-default-form/>
				<ui:description width="full">
					<sw:text>
						<xsl:with-param name="scope" select="$realm-info/@title"/>
							The Security component allows you to organize and control the process of granting users access to Hardware Nodes and their Containers thru Parallels Infrastructure Manager. Using this component, you can: <br/><br/>- create new users and groups and include users in groups within modifiable authentication databases; <br/>- register users from external databases in Parallels Infrastructure Manager and grant them access to your Hardware Nodes and their Containers; <br/>- create roles which will define the scope of operations the user is authorized to perform in the Hardware Node and Container contexts. <br/><br/>On this screen you can view a list of users that exist in the '%{scope}' database.
					</sw:text>
					<sw:text>&amp;nbsp;</sw:text>
					<xsl:choose>
						<xsl:when test="$realm-info/@allow-creation='true' and $realm-info/@allow-deletion='true'">
							<sw:text>
								You can also create a new user or remove an existing one.
							</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>
								You cannot edit the users in this database by means of Parallels Infrastructure Manager.
							</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:description>
			</ui:properties>

			<xsl:call-template name="security:realms-tab-bar">
				<xsl:with-param name="current-tab" select="'users'"/>
				<xsl:with-param name="realms-info" select="$realms-info"/>
				<xsl:with-param name="subtab-base-url" select="concat($baseurl,'/sysdir/securman/users/index?')"/>	
			</xsl:call-template>
			
			<ui:content>

	
				<ui:block width="full">

					<xsl:choose>
					
						<!-- Can`t list due to realms VZA error -->
						<xsl:when test="$realms-info[self::error]">
							<ui:operation-problem>
								<ui:type>vza-error</ui:type>
								<ui:descr>
									<sw:text>Unable to list authentication databases.</sw:text>
								</ui:descr>
								<ui:vza-error>
									<xsl:copy-of select="$realms-info/*"/>
								</ui:vza-error>
							</ui:operation-problem>
						</xsl:when>
						<!-- /Can`t list due to some VZA error -->

						<!-- Can`t list due to some VZA error -->
						<xsl:when test="$auth-error">
							<ui:operation-problem>
								<ui:type>vza-error</ui:type>
								<ui:descr>
									<sw:text>Unable to list users.</sw:text>
								</ui:descr>
								<ui:vza-error>
									<xsl:copy-of select="$auth-error/*"/>
								</ui:vza-error>
							</ui:operation-problem>
						</xsl:when>
						<!-- /Can`t list due to some VZA error -->

						<!-- Show list -->
						<xsl:otherwise>

							<ui:browse>
								<xsl:attribute name="title">
									<sw:text>Users</sw:text>
								</xsl:attribute>

								<ui:browse-js-many>
									<ui:warn>
										<sw:text>Select at least one user!</sw:text>
									</ui:warn>
								</ui:browse-js-many>

								<ui:filter>
									<xsl:copy-of select="$filter"/>
								</ui:filter>

								<ui:browse-buttons type="list-selection">
								
									<ui:button type="list-selection" tip="new_user" icon="user_new" require-items="false"
										disabled="{not($realm-info/@allow-creation='true')}"
										new-obj-title="{sw:text('User')}" submit-href="{$baseurl}/sysdir/securman/users/manage?cmd=new"
									>
										<sw:text>New User</sw:text>
									</ui:button>										
									<ui:button type="list-selection" tip="delete_user" icon="delete"
										disabled="{not($realm-info/@allow-deletion='true')}"									
										confirmation="{sw:text('Are you sure you want to delete the selected user(s)?')}"
										script="if (!atLeastOne()) return false;" name="delete" width="150"
									>
										<sw:text>Delete</sw:text>
									</ui:button>
								</ui:browse-buttons>

								<!-- form definition for other controls -->
								<ui:form action="list-control"/>

								<ui:browse-empty-msg>
									<sw:text>No users could be found. </sw:text>
								</ui:browse-empty-msg>

							</ui:browse>
						</xsl:otherwise>
					</xsl:choose>
				</ui:block>
			</ui:content>
		</ui:screen>

	</xsl:template>
	

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/swa/server-group.xsl"/>
	
	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
