<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz cred form authm env local browse"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp" xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz" xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:env="http://www.swsoft.com/xsl/cp/env" xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions" xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse" xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:vzcpsecuritym="http://www.swsoft.com/xsl/cp/vzcpsecuritym">

	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/vzcpsecuritym.xsl"/>

	<!-- check permissions to show this page -->
	<xsl:variable name="cr-usergroup" select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>

	<xsl:param name="wiz_code" select="'sm-user'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="screenid" select="$step_data/@screenid"/>
	<xsl:variable name="path-id" select="string(wiz:getSteps()/step[@id = 'gen']/@screenid)"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<xsl:variable name="create" select="not($form/user-id!='')"/>

	<xsl:param name="access-denied" select="not($cr-usergroup)"/>

	<!-- Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">
		<ui:screen id="{$screenid}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit">

					<ui:rows title="{sw:text('User Data')}">

						<ui:row>
							<ui:cell-label>
								<sw:text>Login</sw:text>
							</ui:cell-label>
							<ui:cell-input id="username" required="true" value="{$form/gen/username}"/>
						</ui:row>
						
						<ui:row>
							<ui:cell-label>
								<sw:text>Full Name</sw:text>
							</ui:cell-label>
							<ui:cell-input id="displayName" value="{$form/user/displayName}"/>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Description</sw:text>
							</ui:cell-label>
							<ui:cell-input id="description" value="{$form/user/description}"/>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Email</sw:text>
							</ui:cell-label>
							<ui:cell-input id="mail" maxlength="255" value="{$form/user/mail}"> </ui:cell-input>
						</ui:row>
					</ui:rows>

					<ui:rows title="{sw:text('Password')}">
						
						<ui:row>
							<ui:cell-label>
								<sw:text>Type Password</sw:text>
							</ui:cell-label>
							<ui:cell-input mode-password="true" id="pwd" maxlength="64">
								<xsl:attribute name="value">
									<xsl:value-of select="$form/gen/pwd"/>
								</xsl:attribute>
								<xsl:if test="$create">
									<xsl:attribute name="required">true</xsl:attribute>
								</xsl:if>
							</ui:cell-input>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Retype Password</sw:text>
							</ui:cell-label>
							<ui:cell-input mode-password="true" id="pwd_re" maxlength="64">
								<xsl:attribute name="value">
									<xsl:value-of select="$form/gen/pwd_re"/>
								</xsl:attribute>
								<xsl:if test="$create">
									<xsl:attribute name="required">true</xsl:attribute>
								</xsl:if>
							</ui:cell-input>
						</ui:row>
					</ui:rows>

					<ui:rows title="{sw:text('Member of Groups')}">
						<xsl:variable name="groups" select="authm:get-groups($form/src/realm-eid)/authm"/>
						<xsl:if test="not($groups/group)">
							<ui:row>
								<ui:cell colspan="2">
									<sw:text>No groups have been configured in Parallels Infrastructure Manager yet.</sw:text>
								</ui:cell>
							</ui:row>
						</xsl:if>
						<xsl:if test="$groups/group">
							<ui:row>
								<ui:cell-list-selector id="group" size="6" colspan="2">
									<xsl:for-each select="$groups/group">
										<xsl:sort select="name"/>
										<xsl:variable name="id" select="sw:base64-decode(name)"/>
										<ui:item value="{$id}"
											selected="{sw:if($form/groups/group[sw:lc(id) = sw:lc($id)],true(),false())}">
											<xsl:value-of select="sw:base64-decode(data/attr[name='name']/value | name)"/>
										</ui:item>
									</xsl:for-each>
								</ui:cell-list-selector>
							</ui:row>
						</xsl:if>
					</ui:rows>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons"/>
					</ui:buttons>

				</ui:block>

			</ui:content>
		</ui:screen>

	</xsl:template>


	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>

			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	<sw:include href="../../../../layout/forms-list.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
