<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl browse cred authm users dirm"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:browse="http://www.swsoft.com/xsl/cp/browse" 
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"   
  xmlns:env="http://www.swsoft.com/xsl/cp/env" 
  xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
  xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
  xmlns:authm  ="http://www.swsoft.com/xsl/cp/authm"
	xmlns:users ="http://www.swsoft.com/xsl/cp/users"
  xmlns:dirm  ="http://www.swsoft.com/xsl/cp/dirm"
>
	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/sysdir/securman/users.xsl"/>	


  <!-- check permissions to show this page -->
	<xsl:template mode="screen" match="/">
		<xsl:variable name="control-id" select="sw:param('control-id')"/>
		<xsl:variable name="id-attr-get" select="sw:param('id-attr')"/>
		<xsl:variable name="id-attr" select="sw:if($id-attr-get!='',$id-attr-get,'cn')"/>
		
    <ui:popup-screen id="03.01.01.01.03" cred="vzcp.virtuozzo_group.security.usergroups" title="{sw:text('User Selector')}" icon="user">
	
	    <ui:properties>
	    	<ui:js-tail>
					<script language="JavaScript">
						function selectUser(id,title){								
							parent.opener.document.defaultForm.<xsl:value-of select="$control-id"/>.value=id; 
							parent.opener.document.defaultForm.<xsl:value-of select="$control-id"/>_title.value=title; 
							window.close();
						}				
					</script>
	    	</ui:js-tail>
	    	<ui:description>
	    		<sw:text>
	    			Click on the required user to select it.
	    		</sw:text> 
	    	</ui:description>
	    </ui:properties>

	    <ui:content>
	    
				<!-- Prepare Filter -->
				<xsl:variable name="filter_init_">
					<xsl:call-template name="browse:init-filter">
						<xsl:with-param name="browse">
							<ui:browse-setup id="user-selector-one" 
								url="/sysdir/securman/users/select-one-popup?id-attr={$id-attr}&amp;control-id={$control-id}" 
								item-url="#" item-onclick-jsfunc="selectUser"
								items-title="{sw:text('Users')}">
							</ui:browse-setup>
							
							<ui:cols sorting-col="name">
								<ui:column id="id" for-url="yes" for-onclick="yes" hidden="yes"/>
								<ui:column id="login" nav-type="title" title="{sw:text('Login')}" filter="auto"
			        		show-url="yes"
			        	/>
			        	<ui:column id="name" title="{sw:text('Full Name')}" filter="auto"
			        		show-url="yes"
			        	>
								</ui:column>											        	
			        	<ui:column id="email" title="{sw:text('Email')}" filter="auto"/>
			        </ui:cols>										      
						</xsl:with-param>
					</xsl:call-template>
		    </xsl:variable>
		    
		    <xsl:variable name="browse_result" select="authm:get-users()/authm"/>
		    
		    <xsl:variable name="filter">
		    	<xsl:call-template name="browse:fill-filter">
						<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
						<xsl:with-param name="rows">					
			        <ui:browse-rows>
			        	<xsl:for-each select="$browse_result/user">
			        		<xsl:variable name="user" select="dirm:attrs2nodes(data)"/>
			            <ui:row>
			            	<login><xsl:value-of select="$user/cn"/></login>
			            	<name><xsl:value-of select="$user/displayName"/></name>
			            	<email><xsl:value-of select="$user/mail"/></email>
			              <id>
											<xsl:value-of select="$user/*[name()=$id-attr]"/>
										</id>										
										<!--<enabled><xsl:value-of select="sw:if(disabled='1',0,1)"/></enabled>-->
			            </ui:row>
			          </xsl:for-each> 
		        	</ui:browse-rows>
		        </xsl:with-param>    
					</xsl:call-template>
		    </xsl:variable>
		    
		
				<ui:block width="full">
		
		      <ui:browse>
		      	<xsl:attribute name="title"><sw:text>Users</sw:text></xsl:attribute>    
		        
		        <ui:filter>
		        	<xsl:copy-of select="$filter"/>
		        </ui:filter>
		
		        <ui:browse-empty-msg>
		          <sw:text>No user could be found.</sw:text>
		        </ui:browse-empty-msg>        
		
		      </ui:browse>
		     
	
		  	</ui:block>
	    </ui:content>          

    </ui:popup-screen>

  </xsl:template>  

	<sw:include href="/lib/screen.xsl"/>

	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vza/hwm.xsl"/>
	<sw:include href="/lib/vzaconfig.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>
	  
</xsl:stylesheet>
