<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl browse cred authm users dirm local securitym"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
  xmlns:form	="http://www.swsoft.com/xsl/cp/form"	
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"	
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:users="http://www.swsoft.com/xsl/cp/users"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:security	="http://www.swsoft.com/xsl/cp/security"	
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
>

 	<sw:include href="/layout/forms-list.xsl"/>
	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/securitym.xsl"/>
	<sw:include href="/lib/sysdir/securman/users.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>

	<xsl:variable name="id" select="sw:param('id')"/>
	<xsl:variable name="mode" select="sw:param('mode')"/>

	<xsl:variable name="realms-info" select="security:realms-info('core-security-realm-popup')"/>

	<xsl:variable name="access-denied" 
		select="not(securitym:check-operation('environment.usersGroups.generalRead'))"/>

	<!-- Main template -->
	<xsl:template mode="screen" match="/">
	
		<ui:popup-screen id="03.01.01.01.07" title="{sw:text('Specify Users')}" icon="user">
	
			<ui:properties>
				<ui:js-tail>
					<script language="JavaScript">
						var inputSids = new Array();
						var inputObjects = new Array();
						
						function handleSubmit(){									
							var selectedCount = calcSelectedCount();

							inputObjects = getInputs();
							inputSids = new Array();

							if(!(inputObjects.length!=0 || selectedCount!=0)){
								alert('<sw:text>Please specify at least one user.</sw:text>');
								return false;
							}
							
							<xsl:if test="$mode='single'">	
							if( (inputObjects.length + selectedCount)!=1 ){
								alert('<sw:text>Please specify only one user.</sw:text>');
								return false;
							}
							</xsl:if>
																					
							if(inputObjects.length==0){
								submitUsers();
							}else{
								startInputsConvert();
							}
							
						}
						
						function startInputsConvert(){
							var str_logins='';
							//showSandclock();
							for(var i=0;i&lt;inputObjects.length;i++){
								str_logins = str_logins + '&amp;login='+encode64(inputObjects[i].value);
							}
							requestContent(
								'/vz/cp/core/users/seek-dynamic?realm_eid=<xsl:value-of select="sw:base64-encode($realms-info/current-eid)"/>'+str_logins
								,completeInputsConvert
								,'<xsl:value-of select="$ticket"/>','<xsl:value-of select="$ticketid"/>');
						}
						
						function completeInputsConvert(req){							
							var sids;
							var content = req.readyState==4?req.responseText:'';
							
							if(content!=''){
								//alert(content);
								sids = content.split('|');

								// process result
								var error='';
								for(var i=1;i&lt;sids.length;i++){
									var sid = sids[i];
									var inputIndex = i - 1;
									var input = inputObjects[inputIndex];
									if(sid==''){	
										error = error + '\n   ' + input.value;
										input.style.backgroundColor = '#ffd9d9';
									}else{
										inputSids.push(sid);
									}
								}
								
								// check and show error
								if(error!=''){
									error = '<sw:text>The following users have not been found in the authentication database:</sw:text>\n' + error;
									error = error + '\n\n<sw:text>Please correct the invalid usernames.</sw:text>';
									alert(error);
									
									//hideSandclock();
									return false;
								}							
								
								// complete
								submitUsers();
							}
						}
						
						function submitUsers(){
							submitList();
							submitInputs();
							window.close();
						}
						
						function submitInputs(){			
							for (var i=0;i&lt;inputObjects.length;i++){
								var loginInput = inputObjects[i];
								sendOneResult( loginInput.value, inputSids[i] );								
							}
						}
					
						function submitList(){								
							for (var i=0;i&lt;document.defaultForm.elements.length;i++){
								var o = document.defaultForm.elements[i];
								if(o.name=='id' &amp;&amp; o.checked) {
									for (var ii=0;ii&lt;listIDs.length;ii++){
										if(listIDs[ii]==o.value){
											sendOneResult(listTitles[ii],o.value);
										}
									}
								}
							}
						}
						
						function sendOneResult(title,sid){
							<xsl:choose>
								<xsl:when test="$mode='single'">
									var input = parent.opener.document.getElementById("<xsl:value-of select="$id"/>");
									input.value=sid; 
									parent.opener.document.getElementById("<xsl:value-of select="$id"/>_title").value=title; 
									if(input.onchange){
										input.onchange(); 									
									}
								</xsl:when>
								<xsl:otherwise>
									window.opener.listAdd('<xsl:value-of select="$id"/>',
										title, sid + '|' + title
									);
								</xsl:otherwise>
							</xsl:choose>
						}
						
						
					</script>
				</ui:js-tail>			
				<ui:description>
					<sw:text>
	    			Enter one or several user names and click the 'Add Selected' button.
	    		</sw:text>
				</ui:description>
			</ui:properties>	
			
			<xsl:if test="not($mode='realm-single')">
				<xsl:call-template name="security:realms-tab-bar-popup">
					<xsl:with-param name="realms-info" select="$realms-info"/>
					<xsl:with-param name="tab-base-url" select="concat($baseurl,'/sysdir/securman/users/select-popup?id=',$id,'&amp;mode=',$mode,'&amp;')"/>	
				</xsl:call-template>
			</xsl:if>
	
			<ui:content>
				<ui:block width="full">
	
					<xsl:call-template name="local:screen-input"/>				
					<xsl:call-template name="local:screen-list"/>
				
					<ui:buttons>
						<ui:button name="select" sandclock="false"
							script="handleSubmit();return false;">
							<sw:text>Add Selected</sw:text>
						</ui:button>
					</ui:buttons>
	
				</ui:block>
			</ui:content>
		</ui:popup-screen>
	
	</xsl:template>
	
	<!-- Show screen with form for manual input -->
	<xsl:template name="local:screen-input">
	
		<ui:java-script>
			function getInputs(){			
				var inputs = document.getElementsByTagName('input');
				var result = new Array();
				
				for (var i=0;i&lt;inputs.length;i++){
					o = inputs[i];
					if(o.type=='text' &amp;&amp; o.id.match('manually_id') &amp;&amp; o.style.display!='none'){
						o.style.backgroundColor = '';
						if(o.value!=''){
 							result.push(o);
 						}
					}
				}
				return result;
			}
		</ui:java-script>
		
		<ui:rows separate-tables="true" title="{sw:text('Specify Users Manually')}">
			<xsl:call-template name="form:show-list">
				<xsl:with-param name="config">
					<code>name</code>
					<add_label><sw:text>Add another input field.</sw:text></add_label>
					<remove_label><sw:text>Remove the input field.</sw:text></remove_label>
					<ui:new-row>
						<ui:cell-label>
							<sw:text>User Name</sw:text>
						</ui:cell-label>
						<ui:cell-input nowrap="1" maxlength="255" id="manually_id" tip="user"/>
					</ui:new-row>
				</xsl:with-param>
			</xsl:call-template>					
		</ui:rows>

	</xsl:template>

	<!-- Show screen with list selector -->
	<xsl:template name="local:screen-list">

		<!-- Prepare Filter -->
		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="user-selector"
						url="/sysdir/securman/users/select-popup?id={$id}&amp;mode={$mode}"
						select-column="id" items-title="{sw:text('Users')}"
					> 
						<xsl:attribute name="div-rows-id">myArea</xsl:attribute>
						<xsl:attribute name="div-rows-height">
							<xsl:value-of select="'350'"/>
						</xsl:attribute>
					</ui:browse-setup>
					<ui:cols sorting-col="login">
						<ui:column id="id" for-select="yes" hidden="yes"/>
						<ui:column id="login" title="{sw:text('Login')}" filter="auto"/>
						<ui:column id="name" title="{sw:text('Full Name')}" filter="auto"/>
						<ui:column id="email" title="{sw:text('Email')}" filter="auto"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="auth-data" select="authm:get-users($realms-info/current-eid)"/>
		<xsl:variable name="auth-error" select="$auth-data/error|$auth-data/authm/error"/>
		
		<xsl:choose>
			<xsl:when test="$auth-data/authm/user">

				<xsl:variable name="filter-rtf">
					<xsl:call-template name="browse:fill-filter">
						<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
						<xsl:with-param name="rows">
							<ui:browse-rows>
								<xsl:for-each select="$auth-data/authm/user">
									<ui:row>
										<login>
											<xsl:value-of select="authm:user-login(.)"/> 
										</login>
										<name>
											<xsl:value-of select="sw:base64-decode(data/attr[name='displayName']/value)"/>
										</name>
										<email>
											<xsl:value-of select="sw:base64-decode(data/attr[name='mail']/value)"/>
										</email>
										<id>
											<xsl:value-of select="data/attr[name='objectSid']/value"/>
										</id>
									</ui:row>
								</xsl:for-each>
							</ui:browse-rows>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="filter" select="exsl:node-set($filter-rtf)"/>
		
				<ui:java-script>
						var listTitles=new Array(
							<xsl:for-each select="$filter/ui:browse-rows/ui:row">
								"<xsl:value-of select="login"/>",
							</xsl:for-each>""
						);
						var listIDs=new Array(
							<xsl:for-each select="$filter/ui:browse-rows/ui:row">
								"<xsl:value-of select="id"/>",
							</xsl:for-each>""
						);
						
						function calcSelectedCount(){								
							<sw:die test="$id=''">
								GET parameter 'id' should be specified.
							</sw:die>
							var counter=0;
							for (var i=0;i&lt;document.defaultForm.elements.length;i++){
								var o = document.defaultForm.elements[i];
								if(o.name=='id' &amp;&amp; o.checked) {
									for (var ii=0;ii&lt;listIDs.length;ii++){
										if(listIDs[ii]==o.value){
											counter++												
										}
									}
								}
							}
							return counter;
						}

				</ui:java-script>
		
				<ui:rows separate-tables="true">
					<xsl:attribute name="title">
						<sw:text>Select Users From List</sw:text>
					</xsl:attribute>
					<ui:browse>
			
						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>
			
						<ui:browse-empty-msg>
							<sw:text>No user could be found.</sw:text>
						</ui:browse-empty-msg>
			
					</ui:browse>
				</ui:rows>
			</xsl:when>
			<xsl:otherwise>
				<ui:java-script>
					function submitSelectedList(){								
						return 0;
					}
					function calcSelectedCount(){
						return 0;
					}
				</ui:java-script>			
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

	<sw:include href="/lib/core/browse-filter-raw.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
