<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred func authm browse dirm perms users local env vzenv vzhn"
	xmlns:func="http://exslt.org/functions"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:dirm="http://www.swsoft.com/xsl/cp/dirm"
	xmlns:perms="http://www.swsoft.com/xsl/cp/perms"
	xmlns:users="http://www.swsoft.com/xsl/cp/users"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:env="http://www.swsoft.com/xsl/cp/env"
	xmlns:vzenv="http://www.swsoft.com/xsl/cp/vzenv"
	xmlns:vzhn="http://www.swsoft.com/xsl/cp/vzhn"
	xmlns:security="http://www.swsoft.com/xsl/cp/security">

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/dirm.xsl"/>
	<sw:include href="/lib/sysdir/securman/users.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms.xsl"/>
	<sw:include href="/lib/sysdir/securman/perms-ui.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vz/vzenv-core.xsl"/>
	<sw:include href="/lib/vz/vzhn-core.xsl"/>
	<sw:include href="/lib/core/security/core-ui.xsl"/>

	<xsl:variable name="screen-id" select="'03.01.01.01.04'"/>

	<xsl:param name="access-denied"
		select="not(cred:check('vzcp.virtuozzo_group.security.usergroups'))"/>

	<!-- check permissions to show this page -->
	<xsl:template mode="screen" match="/">

		<xsl:variable name="user-id" select="authm:switch-context('securman-user-id')"/>
		<xsl:variable name="realm-info" select="security:realms-info()"/>
		<xsl:variable name="user" select="authm:get-user(
			authm:user-key($user-id,$realm-info/current-eid))"/>
		<xsl:if test="sw:sesputstr('securman-user-name',$user/login )"/>

		<ui:screen id="{$screen-id}">
			<ui:properties/> 
			<ui:content>
				<ui:block>
					<xsl:choose>
						<!-- Can`t find user -->
						<xsl:when test="$user[self::error]">
							<ui:operation-problem>
								<ui:type>vza-error</ui:type>
								<ui:descr>
									<sw:text>Unable to find the user.</sw:text>
								</ui:descr>
								<ui:reason>
									<sw:text>The requested user has already been removed.</sw:text>
								</ui:reason>
								<ui:solition>
									<sw:text>Return to the users list and select another user.</sw:text>
								</ui:solition>
								<ui:vza-error>
									<xsl:copy-of select="$user/*"/>
								</ui:vza-error>
							</ui:operation-problem>
						</xsl:when>
						<!-- /Can`t find user -->
						<!-- Show user -->
						<xsl:otherwise>
							<ui:rows title="{sw:text('User Details')}">
								<ui:row>
									<ui:cell-label>
										<sw:text>Login</sw:text>
									</ui:cell-label>
									<ui:cell-value>
										<xsl:value-of select="$user/login"/>
									</ui:cell-value>
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Full Name</sw:text>
									</ui:cell-label>
									<ui:cell-value>
										<xsl:value-of select="$user/data/displayName"/>
									</ui:cell-value>
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Description</sw:text>
									</ui:cell-label>
									<ui:cell-value>
										<xsl:value-of select="$user/data/description"/>
									</ui:cell-value>
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Distinguished Name</sw:text>
									</ui:cell-label>
									<ui:cell-value>
										<xsl:value-of select="$user/data/distinguishedName"/>
									</ui:cell-value>									
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Email</sw:text>
									</ui:cell-label>
									<ui:cell-value>
										<xsl:value-of select="$user/data/mail"/>
									</ui:cell-value>
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Member Of</sw:text>
									</ui:cell-label>
									<ui:cell-value>
										<xsl:choose>
											<xsl:when test="count($user/group) > 0">
												<xsl:variable name="cr-manage-groups" select="cred:check('vzcp.virtuozzo_group.security.usergroups')"/>
												<xsl:for-each select="$user/group">
													<xsl:variable name="group" 
														select="authm:get-group(sw:base64-decode(name),realm,false())"/>
													<xsl:variable name="group-name"
														select="sw:base64-decode($group/data/attr[name='name']/value | name)"/>
													<xsl:choose>
														<xsl:when test="$cr-manage-groups">
															<a href="{$baseurl}/sysdir/securman/groups/group?cmd=v&amp;realm={realm}&amp;id={name}">
																<xsl:value-of select="$group-name"/>
															</a>
														</xsl:when>
														<xsl:otherwise>
															<xsl:value-of select="$group-name"/>
														</xsl:otherwise>
													</xsl:choose>
													<xsl:if test="position() != last()">,&#160;</xsl:if>
												</xsl:for-each>
											</xsl:when>
											<xsl:otherwise>
												<sw:text>None</sw:text>
											</xsl:otherwise>
										</xsl:choose>
									</ui:cell-value>
								</ui:row>
							</ui:rows>

							<xsl:call-template name="perms:show-owner-perms">
								<xsl:with-param name="owner-sid" select="$user/data/objectSid"/>
								<xsl:with-param name="browse-id" select="$screen-id"/>
								<xsl:with-param name="browse-url" select="'/sysdir/securman/users/user'"/>
								<xsl:with-param name="browse-empty-msg">
									<sw:text>No permission has been assigned to the user.</sw:text>
								</xsl:with-param>
								<xsl:with-param name="add-screen-id" select="'03.01.01.01.06'"/>
							</xsl:call-template>
							
							<ui:buttons>
								<xsl:if test="$realm-info/current-eid=sw:internal-realm-id()">
									<ui:button tip="manage_user" sandclock="false" icon="preferences" type="ok"
										submit-href="{$baseurl}/sysdir/securman/users/manage">
										<sw:text>Configure</sw:text>
									</ui:button>
								</xsl:if>
							</ui:buttons>

						</xsl:otherwise>
						<!-- /Show user -->
					</xsl:choose>
				</ui:block>
			</ui:content>

		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
