<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl env cred vzaconfig voc func trace backups licensem format"
  xmlns:xsl				="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl			="http://exslt.org/common"
  xmlns:func			="http://exslt.org/functions"
  xmlns:sw				="http://www.swsoft.com/xsl/cp"
  xmlns:str				="http://exslt.org/strings"
  xmlns:vt				="http://www.swsoft.com/xsl/cp/vt"  
  xmlns:ve				="http://www.swsoft.com/xsl/cp/ve"  
  xmlns:env				="http://www.swsoft.com/xsl/cp/env"
  xmlns:voc				="http://www.swsoft.com/xsl/cp/voc"
  xmlns:ui				="http://www.swsoft.com/xsl/cp/ui"
  xmlns:browse		="http://www.swsoft.com/xsl/cp/browse"   
	xmlns:cred  		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local  		="http://www.swsoft.com/xsl/cp/local"
	xmlns:vzaconfig	="http://www.swsoft.com/xsl/cp/vzaconfig"
  xmlns:trace			="http://www.swsoft.com/xsl/cp/trace"
  xmlns:backups		="http://www.swsoft.com/xsl/cp/backups"
  xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
  xmlns:format="http://www.swsoft.com/xsl/cp/format"
>
  <sw:include	href="/lib/common.xsl"/>
  <sw:include	href="/lib/vt/core.xsl"/>
  <sw:include	href="/lib/vt/ve-core.xsl"/> 
  <sw:include href="/lib/vt/backups-core.xsl"/>
  <sw:include href="/lib/utils/format-datetime.xsl"/>
  <sw:include href="/lib/utils/format-resusage.xsl"/>
	
	<!-- show backup details -->
  <xsl:template mode="screen" match="/">    
  							
		<!-- Init data -->
		<xsl:variable name="backup-id" select="sw:sesgetstr('vz-backup-id')"/>		
		<xsl:variable name="backup" select="backups:find-backup($backup-id)"/>		
		<xsl:variable name="env" select="backups:find-env-info($backup)/env"/>
		<xsl:variable name="hn-platform" select="ve:ve2platform($env)"/>
		<xsl:if test="sw:sesputstr('vz-backup-browseable',boolean($backup/capability/browsable))"/>
    
    
    <ui:screen id="23.00.00.04.00" bg="backup">			

      <ui:properties>
	    	<ui:form-get/>
        <ui:width value="fixed"/>
        <ui:description mandatory="yes">
          <sw:text>
            Please review the backup details here. <br/> After restoring the Container from this backup, all the current parameters of the Container will be replaced with those that were effective at the time of the backup creation.
          </sw:text>
        </ui:description>        
        
      </ui:properties>
      
      <xsl:choose>
      	<!-- Error occurred -->
	  		<xsl:when test="not($backup)">
	  			<xsl:call-template name="local:show-error">
	  				<xsl:with-param name="error" select="$backup"/>
	  			</xsl:call-template>
	  		</xsl:when>
	  		<!-- /Error occurred -->
      	<!-- Error occurred -->
	  		<xsl:when test="name($backup)='error'">
	  			<xsl:call-template name="local:show-vza-error">
	  				<xsl:with-param name="error" select="$backup"/>
	  			</xsl:call-template>
	  		</xsl:when>
	  		<!-- /Error occurred -->
	  		
	  		<!-- Show loaded backup -->      
      	<xsl:otherwise>
      	
					<ui:data-options id="ve-backup-type">
						<xsl:copy-of select="backups:backup-types()"/>
					</ui:data-options>
				
		      <ui:content>
		        <ui:block>															
							
							<ui:hidden name="id" value="{$backup-id}"/>							
							
							<!-- Show Actions -->
							<!--
							<ui:actions title="{sw:text('Actions')}">
								<ui:actions-set>
									<ui:action href="browse?mod=start" icon="backup"  sandclock="false" name="create_ve" tip="browse_backup">
										<sw:text>Browse Backup</sw:text>
									</ui:action>
								</ui:actions-set>
							</ui:actions>-->
							<!-- /Show Actions -->
		
		          <ui:rows title="{sw:text('Backup Information')}">
		            <ui:row>
		              <ui:cell-label><sw:text>Creation Date</sw:text></ui:cell-label>
		              <ui:cell-value><xsl:value-of select="format:date-time(sw:vzatime2utime($backup/time))"/></ui:cell-value>
		            </ui:row>
		            <ui:row>
		              <ui:cell-label><sw:text>Backup Size</sw:text></ui:cell-label>
		              <ui:cell-value>
		              	<xsl:value-of select="format:int2bytes($backup/size)"/></ui:cell-value>
		            </ui:row>
		            <ui:row>
		              <ui:cell-label><sw:text>Backup Type</sw:text></ui:cell-label>
		              <ui:cell-value>
		              	<ui:ve-backup-type><xsl:value-of select="$backup/type"/></ui:ve-backup-type>
		              </ui:cell-value>              
		            </ui:row>
            		<xsl:if test="$activeMode = 'vzcc'">
									<xsl:choose>
										<xsl:when test="$env">
											<ui:row>
												<ui:cell-label><sw:text>Container</sw:text></ui:cell-label>
												<ui:cell-value><xsl:value-of select="env:env2title($env)"/></ui:cell-value>
											</ui:row>
											<ui:row>
												<ui:cell-label><sw:text>IP Address(es)</sw:text></ui:cell-label>
												<ui:cell-value>
													<xsl:for-each select="$env/virtual_config/address">
														<xsl:value-of select="ip"/>
														<xsl:if test="position() != last()">
															<xsl:text>, </xsl:text>
														</xsl:if>
													</xsl:for-each>
												</ui:cell-value>
											</ui:row>          
										</xsl:when>
										<xsl:otherwise>
											<ui:row>
												<ui:cell-label><sw:text>Container</sw:text></ui:cell-label>
												<ui:cell-value>
													<img src="/{$theme}/icons/alert_yellow.gif" width="16" height="16"/>&#160;
													<sw:text>
														Error cp1302 retrieving the Container information.
													</sw:text>
												</ui:cell-value>
											</ui:row>
										</xsl:otherwise>
									</xsl:choose>
									<xsl:if test="cred:check-hw('vzcp.hn.view',$backup/storage_eid)">
										<ui:row>
											<ui:cell-label><sw:text>Backup Node</sw:text></ui:cell-label>
											<ui:cell-value><xsl:value-of select="env:eid2info($backup/storage_eid)/title"/></ui:cell-value>
										</ui:row>
									</xsl:if>
								</xsl:if>

		          </ui:rows>
		          
		          <xsl:if test="$backup/description!=''">
			          <ui:rows title="{sw:text('Backup Descripiton')}">
			            <ui:row>
			              <ui:cell-text><xsl:value-of select="sw:base64-decode($backup/description)"/></ui:cell-text>
			            </ui:row>
			          </ui:rows>
			        </xsl:if>
		          
		        </ui:block>
		      </ui:content>
		    </xsl:otherwise>
		    <!-- /Show loaded backup -->
		    
			</xsl:choose>
    </ui:screen>
  </xsl:template>
  
  <!-- Show error -->
	<xsl:template name="local:show-error">
		<ui:content>
			<ui:block>
				<ui:operation-problem>
					<ui:type>custom</ui:type>
					<ui:descr>
						<sw:text>The requested backup was not found.</sw:text>
					</ui:descr>					
					<ui:reason>
						<sw:text>The requested backup was removed.</sw:text>
					</ui:reason>
					<ui:solution>
						<sw:text>Return to the backup list and select another backup.</sw:text>
					</ui:solution>
				</ui:operation-problem>
			</ui:block>
		</ui:content>
		
	</xsl:template>
  
  <!-- Show some VZA error -->
	<xsl:template name="local:show-vza-error">
		<xsl:param name="error"/>
		<ui:content>
			<ui:block>
				<ui:operation-problem>
					<ui:type>vza-error</ui:type>
					<ui:descr>
						<sw:text>Error reading the backup details.</sw:text>
					</ui:descr>
					<ui:vza-error>
						<xsl:copy-of select="$error/*"/>
					</ui:vza-error>
					<ui:reason>
						<sw:text>The requested backup was removed.</sw:text>
					</ui:reason>
					<ui:solution>
						<sw:text>Return to the backup list and select another backup.</sw:text>
					</ui:solution>
				</ui:operation-problem>
			</ui:block>
		</ui:content>
	</xsl:template>
  
  <sw:include href="/lib/screen.xsl"/>  
  <sw:include href="/lib/vocabulary.xsl"/>
  
</xsl:stylesheet>
