<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz local cred voc backups env local licensem"
	xmlns:xsl					="http://www.w3.org/1999/XSL/Transform" 
	xmlns:exsl				="http://exslt.org/common"
	xmlns:sw					="http://www.swsoft.com/xsl/cp" 
	xmlns:local				="http://www.swsoft.com/xsl/cp/local"
	xmlns:error				="http://www.swsoft.com/xsl/cp/error"
	xmlns:wiz					="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:ui					="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func				="http://exslt.org/functions"
	xmlns:cred				="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env					="http://www.swsoft.com/xsl/cp/env"
	xmlns:voc					="http://www.swsoft.com/xsl/cp/voc"
	xmlns:backups			="http://www.swsoft.com/xsl/cp/backups"
	xmlns:form				="http://www.swsoft.com/xsl/cp/form" 
	xmlns:hn					="http://www.swsoft.com/xsl/cp/hn"
	xmlns:ve					="http://www.swsoft.com/xsl/cp/ve"
	xmlns:jobs				="http://www.swsoft.com/xsl/cp/jobs"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
	>

	<sw:include href="/lib/core/jobs/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/backups-core.xsl"/>
	<sw:include href="/lib/vt/backups-forms.xsl"/>	
	<sw:include href="/lib/vt/env-select.xsl"/>
	<sw:include href="/lib/vt/hn-select.xsl"/>
	<sw:include href="/layout/forms-list.xsl"/>

	<xsl:param name="wiz_code" select="'ve-new-backups'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="screen-id" select="$step_data/@screen-id"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	
	<xsl:param name="access-denied" 
		select="$form/def/env-set='current' and not(cred:check-env('vzcp.env.backups.backup',$form/backup/ve-eid))"/>
	
	<!-- Reinstall Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">

		<ui:screen id="{$screen-id}">

			<ui:properties>
				<ui:form-get/>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:contains-date-control/>
				<ui:description width="full">
					<xsl:choose>
						<xsl:when test="$form/def/vzcc and $form/def/env-set='select-multi'">
							<sw:text>On this screen you can define the Containers to back up and adjust various backup options before starting the backing up proper. To display or hide the available options, click the group headings below. To learn more about these options, click Help.
							</sw:text>
						</xsl:when>
						<xsl:otherwise>
							<sw:text>On this screen you can adjust various backup options before starting the backing up proper. To display or hide the available options, click the group headings below. To learn more about these options, click Help.
							</sw:text>
						</xsl:otherwise>
					</xsl:choose>
				</ui:description>
			</ui:properties>

			<ui:content>
				<ui:hidden name="step" value="gen"/>
				<ui:block mode="edit">

					<xsl:if test="$form/def/vzcc and $form/def/env-set='select-multi'">
						<ui:rows>
							<xsl:attribute name="title">
								<sw:text>Containers</sw:text>
							</xsl:attribute>
							<xsl:variable name="backup-home-branch" select="sw:sesgetstr('branch-backups-home')"/>
							<xsl:call-template name="env:multi-selector">
								<xsl:with-param name="eids" select="$form/backup/ve-eid"/>
								<xsl:with-param name="size" select="'10'"/>
								<xsl:with-param name="hn-eid" select="sw:if($backup-home-branch='vzhn',sw:hn-eid(),'')"/>
							</xsl:call-template>
						</ui:rows>
					</xsl:if>

					<ui:rows title="{sw:text('Backup Description')}">
						<ui:row>
							<ui:cell-text>
								<sw:text>You can leave your comments here:</sw:text>
							</ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-inputblock rows="3" id="description" width="50"
								maxlength="1000">
								<xsl:value-of select="$form/gen/description"/>
							</ui:cell-inputblock>
						</ui:row>
					</ui:rows>

					<xsl:if test="$form/def/vzcc">
						<ui:rows title="{sw:text('Backup Options')}" separate-tables="true"
							id="show_node" status-def="0" status="{$form/gen/server_show}"
							closed-text="{sw:text('Click to customize the backup options.')}"
						>
							<xsl:call-template name="backups:edit-backup-options">
								<xsl:with-param name="options" select="$form/gen"/>
								<xsl:with-param name="force-hn-eid" select="sw:if($form/def/cmd='renew',$form/backup[1]/hn-storage-eid,'')"/>
								<xsl:with-param name="show-server-default" select="true()"/>
							</xsl:call-template>	
						</ui:rows>
					</xsl:if>
			
					<!-- Exclude -->
					<ui:rows title="{sw:text('Exclude')}" separate-tables="true" id="show_excl"
						status-def="0" status="{$form/exclude/show}"
						closed-text="{sw:text('Click to exclude some files or paths from the backup process.')}"
					>
						<xsl:variable name="features-total" select="count($form/def/platform/features/exclude-system)"/>
						<xsl:variable name="platforms-total" select="count($form/def/platform)"/>
						<!-- XXX: state check should be removed when filem will be allways available -->						
						<xsl:variable name="exclude-path-selector" select="count($form/backup/ve-eid) = 1 and ve:context-state($form/backup/ve-eid) = $env-state/running"/>						

						<!-- At least one selected VE can be backuped with the following option -->
						<xsl:if test="$features-total!=0">
							<!-- But not all -->
							<xsl:if test="$features-total!=$platforms-total">
								<ui:row>
									<ui:cell-text>
										<sw:text>
											The following two options will be used for backing up only some of the selected Containers.
										</sw:text>
									</ui:cell-text>
								</ui:row>
							</xsl:if>
							<!-- /But not all -->
						</xsl:if>
						<!-- /At least one selected VE can be backuped with the following option -->						
						
						<xsl:call-template name="backups:edit-backup-paths">
							<xsl:with-param name="data" select="$form/exclude"/>
							<xsl:with-param name="list-type" select="'exclude'"/>							
							<xsl:with-param name="allow-exclude-system-and-hidden" select="$features-total!=0"/>
							<xsl:with-param name="show-system-and-hidden-warning" select="false()"/>
							<xsl:with-param name="ve-eid" select="$form/backup/ve-eid"/>														
							<xsl:with-param name="show-ve-paths-selector" select="$exclude-path-selector"/>							
						</xsl:call-template>
						
					</ui:rows>
					<!-- /Exclude-->
					
					<!-- Include -->
					<ui:rows title="{sw:text('Include')}" separate-tables="true" id="show_incl"
						status-def="0" status="{$form/include/show}"
						closed-text="{sw:text('Click to back up particular folders or files only.')}"
					>
						<xsl:variable name="show-path-selector" select="count($form/backup/ve-eid) = 1 and ve:context-state($form/backup/ve-eid) = $env-state/running"/>						

						<xsl:call-template name="backups:edit-backup-paths">
							<xsl:with-param name="data" select="$form/include"/>
							<xsl:with-param name="list-type" select="'include'"/>								
							<xsl:with-param name="ve-eid" select="$form/backup/ve-eid"/>														
							<xsl:with-param name="show-ve-paths-selector" select="$show-path-selector"/>							
						</xsl:call-template>
						
					</ui:rows>
					<!-- /Include-->	
				
					<!-- Backup At -->
					<xsl:if test="cred:check('vzcp.full_control')">
						<ui:rows title="{sw:text('Backup Start')}" separate-tables="true" id="show_timer"
							status-def="0" status="{$form/timer/show}"
							closed-text="{sw:text('Click to define the backup start time.')}"
							>
							<ui:row>
								<ui:cell-radio name="timer" id="timer_now" value="now" checked="{$form/timer/type='now'}">
									<ui:control-slave inverse="true">time</ui:control-slave>		
									<ui:control-slave inverse="true">start_date</ui:control-slave>		
								</ui:cell-radio>	
								<ui:cell cell-width="100%" align="left" colspan="2">
									<sw:text>Immediately</sw:text>
								</ui:cell>						
							</ui:row>				
							<ui:row>
								<ui:cell-radio name="timer" id="timer_time" value="time" checked="{$form/timer/type='time'}">
									<ui:control-slave>time</ui:control-slave>
									<ui:control-slave>start_date</ui:control-slave>
								</ui:cell-radio>
								<ui:cell cell-width="100%" align="left" colspan="2">
									<sw:text>At the following time:</sw:text>
								</ui:cell>						
							</ui:row>
							<xsl:call-template name="jobs:edit-timer-time">
								<xsl:with-param name="timer" select="$form/timer"/>
								<xsl:with-param name="offset" select="3"/>
							</xsl:call-template>
							<ui:row>
								<ui:cell-text offset="3">
									<ui:text-disabled>
										<sw:text>
											<xsl:with-param name="open">
												&lt;a href="/vz/cp/core/jobs/manage?mode=new"&gt;
											</xsl:with-param>
											<xsl:with-param name="close">
												&lt;/a&gt;
											</xsl:with-param>									
											For advanced backup scheduling, please go to the Management -> Scheduler -> %{open}New Task%{close} wizard.
										</sw:text>
									</ui:text-disabled>
								</ui:cell-text>						
							</ui:row>							
						</ui:rows>	
					</xsl:if>
					<!-- /Backup At -->

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="submit-title" select="sw:text('Backup')"/>
							<xsl:with-param name="submit-tip" select="'submit_new_backup'"/>
						</xsl:call-template>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<!-- Show HN selector -->
	<!--
	<xsl:template name="local:show-hn-selection">
 		<xsl:variable name="hn-list" select="hn:list()"/>

		<xsl:if test="count($hn-list/hn) &gt; 1">
			<ui:row>
				<ui:cell-label>
					<sw:text>Backup Node</sw:text>
				</ui:cell-label>
				<ui:cell-list id="server_eid" value="{$form/gen/server-eid}" style="width:300px">
					<ui:list-item id="" title="{sw:text('Use Server Settings')}"/>								
					<xsl:for-each select="$hn-list/hn">
						<xsl:sort select="hostname"/>
						<ui:list-item id="{eid}" title="{hostname}"> </ui:list-item>
					</xsl:for-each>
				</ui:cell-list>
			</ui:row>
		</xsl:if>
	</xsl:template>
	-->

	<!-- 
		Show operation problem screen.
		Arguments
			problem - RTF with operation problem description.
	-->
	<xsl:template name="local:show-oper-problem">
		<xsl:param name="problem"/>
		<ui:screen id="{$screen-id}">
			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
			</ui:properties>	
			<ui:content>    	    	    
				<ui:block>
					<ui:operation-problem>
						<xsl:copy-of select="$problem"/>
						<ui:descr>
							<sw:text>Creating new backups is unavailable now.</sw:text>
						</ui:descr>
					</ui:operation-problem>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>


	<!-- Redirect to last screen  -->
	<xsl:template name="local:redirect-limits-error">
		<xsl:if test="error:put($form/error[@type='limits'])"/>
		<ui:redirect path="last"/>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
		<!-- Check, is VE ready for backup -->
		<xsl:variable name="backup-problem">
			<xsl:if test="$form/def/env-set='current'">
				<xsl:copy-of select="voc:check-operation(
					'vzabackupm','backup_env','',$form/backup/ve-eid
				)"/>
			</xsl:if>
		</xsl:variable>

		<!-- /Check, is VE ready for backup -->
		
		<xsl:choose>
			<xsl:when test="$form/error[@type='limits']">
				<xsl:call-template name="local:redirect-limits-error"/>
			</xsl:when>
			<xsl:when test="$form/error">
				<sw:die>
					Uknown error '<xsl:value-of select="$form/error"/>'
				</sw:die>
			</xsl:when>
			<xsl:when test="$backup-problem!=''">
				<xsl:call-template name="local:show-oper-problem">
					<xsl:with-param name="problem" select="$backup-problem"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl"/>
	<!-- none -->

</xsl:stylesheet>
