<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local env show voc backups licensem"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:show	="http://www.swsoft.com/xsl/cp/show"   
	xmlns:voc		="http://www.swsoft.com/xsl/cp/voc"   
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"   		
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"   	
	xmlns:backups	="http://www.swsoft.com/xsl/cp/backups"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
 >
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/backups-core.xsl"/>
 	<sw:include href="/lib/vt/hn-select.xsl"/>


  <xsl:param name="wiz_code" 					select="'ves_restore_backup'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>
	<xsl:variable name="screen-id"			select="$step_data/@screen-id"/>
  <xsl:variable name="form" 					select="sw:sesget($wiz_data)"/>  
  <xsl:variable name="single-mode" 		select="count($form/def/backup)=1"/>
	
  <!-- Wizard, Step 'Confirm' -->
  <xsl:template name="step_confirm">
  	
  	<ui:screen id="{$screen-id}" bg="backup">
  	
	    <ui:properties>
	    	<ui:form-get/>
	      <ui:refresh-type>none</ui:refresh-type>	        
	      <xsl:if test="not($form/def/backup/oper-problem)">
					<ui:description mandatory="yes" show-alert="true">
						<sw:text>
							<b>Attention!</b><br/>
							You are going to restore the data from the Container backup. 
							<br /> 
							Restoring the Container from its backup will cause a loss of all data changes performed after the backup was made.
						</sw:text>
					</ui:description>
				</xsl:if>
	    </ui:properties>
	    	    
	    <ui:content>
      	<ui:hidden name="step" value="confirm"/>    
      	<ui:block>
      		
      		<!-- Show restore controls and other information -->
      		<xsl:choose>
      			<!-- We should restore only one VE amd this VE has a some problems with restore -->
      			<xsl:when test="$single-mode and $form/def/backup/oper-problem">
      				<ui:operation-problem>
								<xsl:copy-of select="$form/def/backup/oper-problem/*"/>
								<ui:disable-links/>
								<ui:descr><sw:text>Unable to restore the Container backup.</sw:text></ui:descr>
							</ui:operation-problem>
      			</xsl:when>
      			<!-- We operate with many backups. Ok, show section for every backup  -->
      			<xsl:otherwise>
      				<xsl:for-each select="$form/def/backup">
      					<xsl:variable name="icon" select="sw:if(oper-problem,
      						'alert_red.gif',sw:if(ve/exists,'alert_green.gif','alert_yellow.gif')
      					)"/>
      					<ui:rows separate-tables="true">
									<ui:rows-title>
										<img src="/{$theme}/icons/{$icon}" width="16" height="16" border="0"/>
										<ui:text>
											&#160;
											<sw:text>
												<xsl:with-param name="ve_title" select="ve/title"/>
												Restore Container %{ve_title}
											</sw:text>
										</ui:text>
									</ui:rows-title>
									<xsl:call-template name="local:show-backup">
										<xsl:with-param name="backup" select="."/>
										<xsl:with-param name="index" select="position()"/>
									</xsl:call-template>
								</ui:rows>
							</xsl:for-each>
      			</xsl:otherwise>
      		</xsl:choose>
      		<!-- /Show restore controls and other information -->
      		
      		<xsl:variable name="disable-restore" select="count($form/def/backup/oper-problem)=count($form/def/backup)"/>
      		
        	<ui:buttons>
	        	<xsl:call-template name="wiz:showButtons">
	        		<xsl:with-param name="submit-title" select="sw:text('Restore')"/>
							<xsl:with-param name="next-title" select="sw:text('Restore')"/>	        		
							<xsl:with-param name="disable-submit" select="$disable-restore"/>	        									
	        	</xsl:call-template>
	        </ui:buttons>
	        
	     	</ui:block>
	     	
	    </ui:content>   
    </ui:screen>
  </xsl:template>
  
  <xsl:template name="local:show-backup">
  	<xsl:param name="index"/>
  	<xsl:param name="backup"/>
  	
		<xsl:choose>
			<!-- Handle VE in bad state --> 
			<xsl:when test="$backup/oper-problem">
				<ui:row>
					<ui:cell-text>
						<ui:operation-problem>
							<ui:disable-links/>
							<ui:compact-mode/>
							<xsl:copy-of select="$backup/oper-problem/*"/>
							<ui:descr><sw:text>Unable to restore the Container backup.</sw:text></ui:descr>
						</ui:operation-problem>
					</ui:cell-text>
				</ui:row>
			</xsl:when>
			<!-- Handle deleted VE case --> 
			<xsl:when test="not($backup/ve/exists)">
			 <ui:hidden name="backup_{$index}" value="true"/>    
				<ui:row>
					<ui:cell-text colspan="2">
						<sw:text>
							Attention! This Container has been removed. Restoring the backup will have the Container recreated.
						</sw:text>
					</ui:cell-text>
				</ui:row>
				<ui:row>
					<ui:cell-label>
						<sw:text>
							Restore on Hardware Node
						</sw:text>
					</ui:cell-label>
					<ui:cell-list id="dst_eid_{$index}" value="{$backup/dst-eid}" width="80">
						<xsl:variable name="all-hns" select="hn:list()/hn"/>
						
						
						<xsl:variable name="compat-hns" select="$all-hns[
							platform=$backup/ve/platform or (
								$backup/ve/platform='linux.i386' and vt:is-platform-linux(platform)
							)
								or		 
							(
								$backup/ve/ignore-arch
									and 
								vt:is-platform-linux(platform)=vt:is-platform-linux($backup/ve/platform)
							)
						]"/>
						
						<xsl:if test="not($compat-hns)">
							<xsl:variable name="error">
								<sw:text>
									<xsl:with-param name="ve" select="$backup/ve/title"/>
									<xsl:with-param name="platform" select="vt:platform2title($backup/ve/platform)"/>
									Cannot restore the Containers, because no Hardware Nodes of the %{platform} platform are available.
								</sw:text>
							</xsl:variable>
							<xsl:if test="error:put($error)"/>
							<ui:list-item id="" title="{sw:text('No available HNs')}"/>
						</xsl:if>
						<xsl:for-each select="$compat-hns">
							<xsl:sort select="hostname"/>
							<ui:list-item id="{eid}">
								<xsl:attribute name="title"><xsl:value-of select="hostname"/></xsl:attribute>
							</ui:list-item>
						</xsl:for-each>
					</ui:cell-list>
				</ui:row>
			</xsl:when>
			<!-- We are ready to restore VE from this backup -->
			<xsl:otherwise>
			 <ui:hidden name="backup_{$index}" value="true"/>    
				<ui:row>
					<ui:cell-text>
						<sw:text>
							The Container is ready to be restored.
						</sw:text>
					</ui:cell-text>
				</ui:row>
			</xsl:otherwise>
		</xsl:choose>
  	
  </xsl:template>
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
			<xsl:choose>			
				<xsl:when test="$step = 'confirm'">
					<xsl:call-template name="step_confirm"/>
				</xsl:when>				
			</xsl:choose>
	</xsl:template>
	 		 	
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>
	
	<!-- System modules -->
	<sw:include href="/lib/common.xsl"/>			

		
</xsl:stylesheet>
