<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred requests"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:error="http://www.swsoft.com/xsl/cp/error"
	xmlns:hwm="http://www.swsoft.com/xsl/cp/hwm"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:requests="http://www.swsoft.com/xsl/cp/requests"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
>

	<sw:include href="/lib/swa/swa-mailer.xsl"/>

	<xsl:output method="xml"/>

	<!-- check permissions to this page -->
	<xsl:variable name="cr-cancel" select="cred:check('vzcp.env.ordering.admin')"/>
	<xsl:variable name="cr-reopen" select="$cr-cancel"/>
	<xsl:variable name="order-id-src" select="sw:param('order_id')"/>
	<xsl:variable name="order-id" select="sw:base64-decode($order-id-src)"/>
	<xsl:variable name="request" select="requests:find-request($order-id)"/>
	<xsl:variable name="action" select="sw:param('action')"/>

	<xsl:template match="/">

		<xsl:choose>
			<!-- no cancel cred -->
			<xsl:when test="$action='cancel_order' and not($cr-cancel) and not($request/requestStatus='OPEN')">
				<ui:redirect path="prev"/>
			</xsl:when>

			<!-- no reopen cred -->
			<xsl:when test="$action='reopen_order' and not($cr-reopen)">
				<ui:redirect path="prev"/>
			</xsl:when>

			<!-- Check selected orders-->
			<xsl:when test="not($order-id-src)">
				<xsl:if test="error:put(sw:text('Please specify some request.'),'')"/>
				<ui:redirect path="prev"/>
			</xsl:when>

			<!-- Cancel Request -->
			<xsl:when test="$action='cancel_order'">
				<xsl:variable name="error" select="requests:cancel-request($order-id)"/>
				<xsl:choose>
					<xsl:when test="$error=''">
						<xsl:if test="sw:sesput('msg',sw:text('The requests have been rejected successfully.'))"/>
						<ui:redirect path="prev"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="error:put(sw:text('Error canceling the request.'),$error)"/>
						<ui:redirect location="/vz/cp/vt/envrequests/view?id={$order-id-src}"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>

			<!-- Reopen Request -->
			<xsl:when test="$action='reopen_order'">
				<xsl:variable name="error" select="requests:reopen-order($order-id)"/>
				<xsl:choose>
					<xsl:when test="$error!=''">
						<xsl:if test="error:put(sw:text('Error reopening the request.'),$error)"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="sw:sesput('msg',sw:text('The request has been reopened successfully.'))"/>
					</xsl:otherwise>
				</xsl:choose>
				<ui:redirect location="/vz/cp/vt/envrequests/view?id={$order-id-src}"/>
			</xsl:when>

			<!-- Unknown post -->
			<xsl:otherwise>
				<ui:redirect path="prev"/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>

	<!-- credentials -->

	<sw:include href="/lib/cred.xsl"/>

	<sw:include href="/lib/globals.xsl"/>
	<sw:include href="/lib/common.xsl"/>
	<sw:include href="/lib/vt/envrequests.xsl"/>

</xsl:stylesheet>
