<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl cred requests licensem"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:authm			="http://www.swsoft.com/xsl/cp/authm"	
	xmlns:requests	="http://www.swsoft.com/xsl/cp/requests"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
>

	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>

	<xsl:variable name="admin-mode" select="cred:check('vzcp.env.ordering.admin')"/>
	<xsl:param name="access-denied-license" select="not(licensem:is-workflow-mgmt-allowed())"/>
	<xsl:param name="access-denied"
		select="not($admin-mode or cred:check('vzcp.env.ordering.user'))"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="config" select="requests:get-config()"/>
		<xsl:variable name="statuses" select="requests:get-statuses()"/>

		<xsl:variable name="filter_init_">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="user-orders" url="/vt/envrequests/index"
						item-url="/vt/envrequests/view" items-title="{sw:text('Container Requests')}"/>
					<ui:cols sorting-col="posted" sorting-direction="desc">
						<ui:column id="id" for-url="yes" for-select="yes" hidden="yes" ldap-id="requestId"/>
						<ui:column id="posted" show-url="yes" title="{sw:text('Posted')}" filter="interval"
							data-type="unixtime" filter-from-title="Posted after" filter-to-title="Posted before"
							ldap-id="postedDate"/>
						<xsl:if test="$admin-mode">
							<ui:column id="user" ldap-id="ownerName" title="{sw:text('Owner')}" filter="auto"/>
						</xsl:if>
						<ui:column id="user-id" ldap-id="ownerSid" hidden="yes">
							<xsl:if test="not($admin-mode)">
								<xsl:variable name="user" select="authm:get-user(sw:login()/login)"/>	
								<sw:die test="not($user)">
									Failed to get information for current login.
								</sw:die>
								<xsl:attribute name="filter">equal</xsl:attribute>
								<xsl:attribute name="value">
									<xsl:value-of select="sw:escape-bytes($user/data/objectSid)"/>
								</xsl:attribute>
							</xsl:if>
						</ui:column>
						<ui:column id="request-status" apply-templates="yes" title="{sw:text('Status')}"
							filter="select" ldap-id="requestStatus">
							<xsl:for-each select="$statuses">
								<ui:filter-option value="{@value}" title="{@title}"/>
							</xsl:for-each>
						</ui:column>
						<ui:column id="env-eid-link" ldap-id="objectId" title="{sw:text('Container')}"	apply-templates="yes"/>
						<ui:column id="sample" ldap-id="requestSampleName" title="{sw:text('Container Sample')}"
							filter="auto"/>
					</ui:cols>
				</xsl:with-param>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="filter">
			<xsl:call-template name="browse:fill-from-ldap">
				<xsl:with-param name="filter" select="exsl:node-set($filter_init_)"/>
				<xsl:with-param name="base-dn" select="requests:dn()"/>
				<xsl:with-param name="cookies" select="$statuses"/>
			</xsl:call-template>
		</xsl:variable>

		<ui:screen id="22.00.00.00.00">

			<ui:properties>
				<ui:form-get/>
				<ui:no-default-form/>
				<ui:contains-date-control/>
				<xsl:if test="$config/enabled='true'">
					<ui:description width="full">
						<sw:text>
							Parallels Infrastructure Manager users can ask the administrator to create additional Containers for themselves. This screen allows you to submit such a request as well as manage the existing ones.
						</sw:text>
					</ui:description>
				</xsl:if>
			</ui:properties>


			<ui:tab-bar id="envrequests" current-tab="index"/>
			<ui:content>

				<ui:block width="full">

					<xsl:if test="not($config/enabled='true')">
						<ui:alert>
							<sw:text>
	  						Container requests are disabled.
	  					</sw:text>
							<xsl:if test="$admin-mode">
								<br/>
	  						<sw:text>You can enable Container requests on the "Setup" tab.</sw:text>
	  					</xsl:if>
						</ui:alert>
					</xsl:if>

					<ui:browse>
						<ui:browse-js-many>
							<ui:warn>
								<sw:text>Select at least one Container request.</sw:text>
							</ui:warn>
						</ui:browse-js-many>

						<ui:filter>
							<xsl:copy-of select="$filter"/>
						</ui:filter>

						<ui:browse-buttons type="list-selection">
						
							<ui:button type="list-selection" tip="order_ve" icon="env_fromrequest" require-items="false"
								cred="vzcp.env.ordering.user"
								new-obj-title="{sw:text('Container Request')}" submit-href="{$baseurl}/vt/envrequests/new"
							>
								<sw:text>New Container Request</sw:text>
							</ui:button>	

							<xsl:if test="$admin-mode">
								<ui:button type="list-selection" tip="cancel_order" icon="delete"
									confirmation="{sw:text('Are you sure you want to reject the selected Container requests?')}"
									script="if (!atLeastOne()) return false;" name="delete" width="150">
									<sw:text>Reject Requests</sw:text>
								</ui:button>
							</xsl:if>
						</ui:browse-buttons>

						<!-- form definition for other controls -->
						<ui:form action="list-control"/>

						<ui:browse-empty-msg>
							<sw:text>No Container request could be found. </sw:text>
						</ui:browse-empty-msg>

					</ui:browse>
				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/core/browse-filter-ldap.xsl"/>
	<sw:include href="/lib/vt/envrequests.xsl"/>

</xsl:stylesheet>
