<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl func wiz local cred voc form env-samplem requests users licensem"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:form="http://www.swsoft.com/xsl/cp/form"
	xmlns:env-samplem="http://www.swsoft.com/xsl/cp/env-samplem"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:voc="http://www.swsoft.com/xsl/cp/voc"
	xmlns:vt="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:requests="http://www.swsoft.com/xsl/cp/requests"
	xmlns:users="http://www.swsoft.com/xsl/cp/users"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
	xmlns:sample="http://www.swsoft.com/xsl/cp/sample"	
>

	<!-- VZL functionality modules -->
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/swa/env-samplem.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>
	<sw:include href="/lib/sysdir/securman/users.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>	

	<xsl:param name="wiz_code" select="'ve-order'"/>
	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="step-cred" select="$step_data/@cred"/>
	<xsl:variable name="screen-id" select="$step_data/@screen-id"/>
	<xsl:variable name="admin-mode" select="cred:check('vzcp.env.ordering.admin')"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
	<!-- check permissions to show this page -->
	<xsl:param name="access-denied" select="$step-cred!='' and  not(cred:check($step-cred))"/>
	<xsl:param name="access-denied-license" select="not(licensem:is-workflow-mgmt-allowed())"/>

	<!-- Reinstall Wizard, Step 'General Settings' -->
	<xsl:template name="step_gen">

		<xsl:variable name="ordering" select="requests:get-config()"/>
		<xsl:variable name="samples-res" select="env-samplem:list-samples('virtuozzo')"/>
		<xsl:variable name="all-samples" select="$samples-res"/>
		<xsl:variable name="samples" select="$ordering/env-sample[.=$all-samples/id]"/>

		<ui:screen id="{$screen-id}">

			<xsl:choose>

				<!-- Problem - disabled ordering-->
				<xsl:when test="not($ordering/enabled='true')">

					<ui:content>
						<ui:block>
							<ui:operation-problem>
								<ui:type>custom</ui:type>
								<ui:descr>
									<sw:text>
										Container requesting is unavailable now.
									</sw:text>
								</ui:descr>
								<ui:reason>
									<sw:text>
										Container requesting has been disabled by the administrator.
									</sw:text>
								</ui:reason>
								<ui:solution>
									<xsl:choose>
										<xsl:when test="cred:check('vzcp.env.ordering.admin')">
											<ui:link href="/vz/cp/vt/envrequests/setup">
												<sw:text>
													Enable Container requesting.
												</sw:text>
											</ui:link>
										</xsl:when>
										<xsl:otherwise>
											<sw:text>
												Ask your administrator to enable Container requesting.
											</sw:text>
										</xsl:otherwise>
									</xsl:choose>
								</ui:solution>
							</ui:operation-problem>
						</ui:block>
					</ui:content>

				</xsl:when>
				<!-- /Problem - disabled ordering-->

				<!-- Problem - no samples -->
				<xsl:when test="not($samples)">

					<ui:content>
						<ui:block>
							<ui:operation-problem>
								<ui:type>custom</ui:type>
								<ui:descr>
									<sw:text>
										Container samples are unavailable now.
									</sw:text>
								</ui:descr>
								<ui:reason>
									<sw:text>
										No Container samples available.
									</sw:text>
								</ui:reason>
								<ui:solution>
									<sw:text>
										Ask your administrator to provide some Container samples for selection.
									</sw:text>
								</ui:solution>
							</ui:operation-problem>
						</ui:block>
					</ui:content>				
				</xsl:when>
				<!-- /Problem - no samples -->

				<!-- Allow to order -->
				<xsl:otherwise>

					<!-- Load user title -->
					<xsl:variable name="user-title" select="users:sid2login($form/data/ownerSid)"/>
					<!-- /Load user title -->

					<ui:properties>
						<ui:form-get/>
						<ui:refresh-type>none</ui:refresh-type>
					</ui:properties>

					<ui:content>
						<ui:hidden name="step" value="gen"/>
						<ui:block mode="edit">

							<xsl:if test="$admin-mode">
								<ui:rows title="{sw:text('Container Owner')}">
									<ui:row>
										<ui:cell-text colspan="3" show-aster="true">
											<ui:text-disabled>
												<sw:text>
													 Please select the user who will be the owner of the requested Container.
												</sw:text>
											</ui:text-disabled>
										</ui:cell-text>
									</ui:row>
									<ui:row>
										<ui:cell-selector id="user" align="left" value="{$user-title}" colspan="2"
											code-value="{$form/data/ownerSid}" width="60" required="true"
											link-tip="select_user"
											link-onclick="open_details('{$baseurl}/sysdir/securman/users/select-popup?id=user&amp;mode=single','user_list',620,850); return false;"											
											link-caption="{sw:text('Select...')}"/>
									</ui:row>
								</ui:rows>
							</xsl:if>

							<ui:rows title="{sw:text('Container Configuration')}">
							  <xsl:variable name="platforms" select="vt:platforms()/platform"/>							
								<xsl:variable name="selected-id" select="$form/data/requestSampleId"/>
								<xsl:variable name="selected-sample" select="$all-samples[id=$selected-id]"/>								
								<ui:row>
									<ui:cell-label>
										<sw:text>Container Sample</sw:text>
									</ui:cell-label>
									<ui:cell-list id="sample" value="{concat($selected-id,'|',sw:base64-encode($selected-sample/name))}" required="true">
										<xsl:for-each select="$platforms">
											<xsl:variable name="platform" select="@id"/>							
											<xsl:variable name="samples-on-platform" select="$all-samples[id=$samples and sample:sample2platform(.)=$platform]"/>
											<xsl:if test="$samples-on-platform">
												<xsl:variable name="group-title">
													<sw:text>
														<xsl:with-param name="platform" select="@title"/>
														-- %platform Samples --
													</sw:text>
												</xsl:variable>
												<ui:list-item disabled="true" title="{$group-title}"/>
												<xsl:for-each select="$samples-on-platform">
													<xsl:sort select="sw:uc(name)"/>					
													<xsl:variable name="complex-id" select="concat(id,'|',sw:base64-encode(name))"/>													
													<ui:list-item id="{$complex-id}" title="{name}"/>	
												</xsl:for-each>
											</xsl:if>
										</xsl:for-each>
									</ui:cell-list>
								</ui:row>
								
								<!--
								<ui:cell-radio name="sample"
											value="{concat($id,'|',sw:base64-encode($data/name))}"
											id="sample_{position()}"
										>
							
								<ui:row>
									<ui:cell-text colspan="3" show-aster="true">
										<ui:text-disabled>
											<sw:text>
												Select one of the available Container samples.
											</sw:text>
										</ui:text-disabled>
									</ui:cell-text>
								</ui:row>
								<xsl:for-each select="$samples">
									<xsl:sort select="sw:uc(name)"/>
									<xsl:variable name="id" select="."/>
									<xsl:variable name="data" select="$all-samples[id=$id]"/>
									<xsl:variable name="descr" select="sw:base64-decode($data/comment)"/>
									<ui:row>
										<ui:cell-radio name="sample"
											value="{concat($id,'|',sw:base64-encode($data/name))}"
											id="sample_{position()}"
										>
											<xsl:if test="$form/data/requestSampleId=$id">
												<xsl:attribute name="checked">true</xsl:attribute>
											</xsl:if>
										</ui:cell-radio>	
										<ui:cell-text nowrap="1">
											<ui:platform-os>
												<xsl:value-of select="sample:sample2platform($data)"/>
											</ui:platform-os>
											&#160;<xsl:value-of select="$data/name"/>
										</ui:cell-text>
										<ui:cell-text cell-width="100%"/>
									</ui:row>
									<ui:row>
										<ui:cell-text/>
										<ui:cell-text colspan="2">
											<xsl:value-of select="$descr"/>
										</ui:cell-text>
									</ui:row>
								</xsl:for-each>
								-->
							</ui:rows>
							<ui:rows>
								<xsl:attribute name="title">
									<sw:text>
										Container Administrative Password
									</sw:text>
								</xsl:attribute>
								<ui:row>
									<ui:cell-label>
										<sw:text>
			                Enter password</sw:text>
									</ui:cell-label>
									<ui:cell-input required="true" id="root_password" maxlength="64" mode-password="true">
										<xsl:attribute name="value">
											<xsl:value-of select="$form/data/requestEnvPassword"/>
										</xsl:attribute>
									</ui:cell-input>
								</ui:row>
								<ui:row>
									<ui:cell-label>
										<sw:text>Retype the password</sw:text>
									</ui:cell-label>
									<ui:cell-input mode-password="true" id="root_password_re" maxlength="64"
										required="true">
										<xsl:attribute name="value">
											<xsl:value-of select="$form/other/root-password-re"/>
										</xsl:attribute>
									</ui:cell-input>
								</ui:row>
							</ui:rows>


							<xsl:variable name="name-rule" select="$ordering/ve-name-rule"/>
							<xsl:variable name="hostname-rule" select="$ordering/hostname-rule"/>
							<xsl:if test="($name-rule!='' and $name-rule!='hidden') or ($hostname-rule!='' and $hostname-rule!='hidden')">
								<ui:rows title="{sw:text('Advanced Container Configuration')}">
									<xsl:if test="$name-rule!='' and $name-rule!='hidden'">
										<ui:row>
											<ui:cell-label>
												<sw:text>Name</sw:text>
											</ui:cell-label>
											<ui:cell-input id="name" maxlength="255"
												required="{boolean($name-rule='required')}"
												value="{$form/data/requestEnvName}"/>
										</ui:row>
									</xsl:if>
									
									<xsl:if test="$hostname-rule!='' and $hostname-rule!='hidden'">
										<ui:row>
											<ui:cell-label>
												<sw:text>Hostname</sw:text>
											</ui:cell-label>
											<ui:cell-input id="hostname" maxlength="255"
												required="{boolean($hostname-rule='required')}"
												value="{$form/data/requestEnvHostname}"/>
										</ui:row>
									</xsl:if>
								</ui:rows>
							</xsl:if>

							<ui:rows title="{sw:text('Description')}">
								<ui:row>
									<ui:cell-inputblock id="description" maxlength="65000" rows="5">
										<xsl:value-of select="$form/data/description"/>
									</ui:cell-inputblock>
								</ui:row>
							</ui:rows>


							<ui:buttons>
								<xsl:call-template name="wiz:showButtons">
									<xsl:with-param name="submit-title" select="sw:text('Request')"/>
									<xsl:with-param name="submit-tip" select="'order_ve'"/>
								</xsl:call-template>
							</ui:buttons>

						</ui:block>
					</ui:content>

				</xsl:otherwise>
			</xsl:choose>
		</ui:screen>
	</xsl:template>

	<!-- main document handler -->
	<xsl:template mode="screen" match="/">

		<xsl:choose>

			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<!-- Include -->
	<sw:include href="/lib/cred.xsl"/>

	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- Functionality  modules -->
	<sw:include href="/lib/vt/envrequests.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl"/>


	<!-- /Include -->

</xsl:stylesheet>
