<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred env-samplem securitym licensem"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:env-samplem="http://www.swsoft.com/xsl/cp/env-samplem"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:vt  ="http://www.swsoft.com/xsl/cp/vt"	
	xmlns:sample  ="http://www.swsoft.com/xsl/cp/sample"
	xmlns:securitym="http://www.swsoft.com/xsl/cp/securitym"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
 >

 	<sw:include href="/lib/swa/env-samplem.xsl"/>
	<sw:include href="/lib/swa/securitym.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>

  <!-- check permissions to show this page -->
	<xsl:variable name="cred"		select="cred:check('vzcp.env.ordering.admin')"/>

  <xsl:param name="wiz_code" select="'config-ordering'"/>
  
	<xsl:variable name="step_data"			select="wiz:getStep()"/>
	<xsl:variable name="step"						select="$step_data/@id"/>

  <xsl:param name="access-denied" select="not($cred)"/>
	<xsl:param name="access-denied-license" select="not(licensem:is-workflow-mgmt-allowed())"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>
  
  <!-- Wizard, General Step  -->
  <xsl:template name="step_gen">
  	<ui:screen  id="{$step_data/@screen-id}">
  	
    <ui:properties>
			<ui:form-get/>    
      <ui:refresh-type>none</ui:refresh-type>
    	<ui:description mandatory="yes">
    		<xsl:choose>
    			<xsl:when test="cred:check('vzcp.virtuozzo_group.security.roles')">
    				<sw:text>
    					<xsl:with-param name="aopen">&lt;a href="<xsl:value-of select="$baseurl"/>/sysdir/securman/perms/global" &gt;</xsl:with-param>
    					<xsl:with-param name="aclose">&lt;/a&gt;</xsl:with-param>
    					On this screen you can allow other users to request Containers for themselves. Only those users will be able to request Containers that are assigned the workflow user role in the global scope (on the %{aopen}Global Permissions%{aclose} screen). You can also set up the way Container requests will be submitted.</sw:text>
    			</xsl:when>
    			<xsl:otherwise>
    				<sw:text>On this screen you can allow other users to request Containers for themselves. Only those users will be able to request Containers that are assigned the workflow user role in the global scope. You can also set up the way Container requests will be submitted.</sw:text>
    			</xsl:otherwise>
    		</xsl:choose>
    	</ui:description>
    </ui:properties>
    
    <ui:tab-bar id="envrequests" current-tab="setup"/>
    <ui:content>
      <ui:hidden name="step" value="gen"/>    
      <ui:block mode="edit">
      	
   			<ui:rows title="{sw:text('General')}">
   				<ui:row>	
   					<ui:cell-check id="enabled" checked="{$form/ordering/enabled}" close="false"/>
   					<ui:cell-text open="false">
	        		<sw:text>Enable Container Requests</sw:text>
	        	</ui:cell-text>
					</ui:row>
				</ui:rows>
				
				<!-- load data -->
				<xsl:variable name="samples" select="env-samplem:list-samples('virtuozzo')"/>
				<!-- /load data -->
				
				<ui:rows title="{sw:text('Container Samples')}">
					<ui:row>
						<ui:cell-text>
							<ui:text-disabled>
								<sw:text>
									Here you can compile a list of Container samples available for Container requests.
								</sw:text>
							</ui:text-disabled>
						</ui:cell-text>
					</ui:row>
					<ui:row>
						<ui:cell-list-selector id="sample" size="12" colspan="2" sort-logic="true">
						  <xsl:variable name="platforms" select="vt:platforms()/platform"/>
							<xsl:for-each select="$platforms">
							  <xsl:variable name="platform" select="@id"/>							
								<xsl:variable name="samples-on-platform" select="$samples[sample:sample2platform(.)=$platform]"/>
								<xsl:if test="$samples-on-platform">
									<xsl:variable name="group-title">
										<sw:text>
											<xsl:with-param name="platform" select="@title"/>
											-- %platform Samples --
										</sw:text>
									</xsl:variable>
									<ui:item>
										<xsl:value-of select="$group-title"/>
									</ui:item>
									<xsl:for-each select="$samples-on-platform">	
										<xsl:sort select="sw:uc(name)"/>
										<xsl:variable name="id" select="id"/>
										<xsl:variable name="title" select="name"/>
										<ui:item value="{$id}" selected="{sw:if($form/ordering/env-sample[.=$id],true(),false())}">
											<xsl:value-of select="$title"/>
										</ui:item>
									</xsl:for-each>
								</xsl:if>
							</xsl:for-each>
						</ui:cell-list-selector>
					</ui:row>					
				</ui:rows>						
			
				<xsl:variable name="roles" select="securitym:list-assignable-roles()"/>
			
				<ui:rows title="{sw:text('Other')}">
					<ui:row>
						<ui:cell-label>
							<sw:text>Container Owner Default Role</sw:text>
						</ui:cell-label>
						<ui:cell-list id="default_role" value="{$form/ordering/default-role}" required="true">
							<ui:list-item id="" title="{sw:text('-- Select role --')}"/>
							<xsl:for-each select="$roles">
								<xsl:sort select="name"/>
								<ui:list-item id="{name}" title="{name}"/>
							</xsl:for-each>
						</ui:cell-list>
					</ui:row>
					<ui:row>
						<ui:cell/>
						<ui:cell-text>
							<ui:text-disabled>
								<sw:text>Select the role that will be assigned to the Container requester in the context of the Container that will be created for them.</sw:text>
							</ui:text-disabled>
						</ui:cell-text>
					</ui:row>
					<ui:row>	
   					<ui:cell-label>
	        		<sw:text>Container Name Input</sw:text>
	        	</ui:cell-label>
	        	<ui:cell-list id="ve_name_rule" style="width:300px" value="{$form/ordering/ve-name-rule}">
	        		<ui:list-item id="hidden" title="{sw:text('Hidden')}"/>
	        		<ui:list-item id="optional" title="{sw:text('Visible, Optional')}"/>
	        		<ui:list-item id="required" title="{sw:text('Visible, Required')}"/>
	        	</ui:cell-list>
					</ui:row>					
   				<ui:row>	
   					<ui:cell-label>
	        		<sw:text>Container Hostname Input</sw:text>
	        	</ui:cell-label>
	        	<ui:cell-list id="hostname_rule" style="width:300px" value="{$form/ordering/hostname-rule}">
	        		<ui:list-item id="hidden" title="{sw:text('Hidden')}"/>
	        		<ui:list-item id="optional" title="{sw:text('Visible, Optional')}"/>
	        		<ui:list-item id="required" title="{sw:text('Visible, Required')}"/>
	        	</ui:cell-list>
					</ui:row>
				</ui:rows>
				
        <ui:buttons>
        	<xsl:call-template name="wiz:showButtons"/>
        </ui:buttons>
        
     	</ui:block>
    </ui:content>   
    </ui:screen>
  </xsl:template>
  
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
	
		<xsl:choose>
			<xsl:when test="$step = 'gen'">
				<xsl:call-template name="step_gen"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_gen"/>
			</xsl:otherwise>
			
		</xsl:choose>
	
	</xsl:template>
	
	<!-- Includes -->	
	<!-- UI modules -->
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<!-- System modules -->
	<sw:include href="/lib/vocabulary.xsl"/>			
	
	<!-- /Includes -->	
	
</xsl:stylesheet>
