<!--
		 Copyright (c) SWsoft, 1999-2007
		 All rights reserved.
   -->

<xsl:stylesheet version="1.0"
	extension-element-prefixes="sw exsl cred requests local authm  show licensem format"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:requests="http://www.swsoft.com/xsl/cp/requests"
	xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:show="http://www.swsoft.com/xsl/cp/show"
	xmlns:authm="http://www.swsoft.com/xsl/cp/authm"
	xmlns:licensem="http://www.swsoft.com/xsl/cp/licensem"
	xmlns:format="http://www.swsoft.com/xsl/cp/format"
>

	<sw:include href="/lib/cred.xsl"/>
	<sw:include href="/lib/swa/authm.xsl"/>
	<sw:include href="/lib/vt/envrequests.xsl"/>
	<sw:include href="/lib/swa/licensem.xsl"/>
	<sw:include href="/lib/utils/format-datetime.xsl"/>
	
	<xsl:variable name="admin-mode" select="cred:check('vzcp.env.ordering.admin')"/>
	<xsl:param name="access-denied-license" select="not(licensem:is-workflow-mgmt-allowed())"/>
	<xsl:param name="access-denied" select="not($admin-mode or cred:check('vzcp.env.ordering.user'))"/>

	<xsl:template mode="screen" match="/">
		<xsl:variable name="request-get-id" select="sw:base64-decode(sw:param('id'))"/>
		
		<xsl:variable name="request-id">
			<xsl:choose>
				<xsl:when test="$request-get-id!=''">
					<xsl:if test="sw:sesputstr('ve-request-id',$request-get-id)"/>
					<xsl:value-of select="$request-get-id"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="sw:sesgetstr('ve-request-id')"/>			
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<ui:screen id="22.00.00.03.00" icon="env_fromrequest">
			<xsl:choose>
				<!-- Problem - Request ID is undefined-->
				<xsl:when test="$request-id=''">
					<ui:content>
						<ui:block>
							<ui:operation-problem>
								<ui:type>custom</ui:type>
								<ui:descr>
									<sw:text>
										No request ID is specified.
									</sw:text>
								</ui:descr>
								<ui:reason>
									<sw:text>
										The system is misconfigured.
									</sw:text>
								</ui:reason>
								<ui:solution>
									<sw:text>
										Contact the support team.
									</sw:text>
								</ui:solution>
							</ui:operation-problem>
						</ui:block>
					</ui:content>
				</xsl:when>
				<!-- /Problem - Request ID is undefined -->

				<!-- Request ID was specified -->
				<xsl:otherwise>

					<xsl:variable name="request" select="requests:find-request($request-id)"/>

					<xsl:choose>
						<!-- Problem - No such order-->
						<xsl:when test="not($request)">
							<ui:content>
								<ui:block>
									<ui:operation-problem>
										<ui:type>custom</ui:type>
										<ui:descr>
											<sw:text>
												<xsl:with-param name="id" select="$request-id"/>
												Cannot find Request #%{id}.
											</sw:text>
										</ui:descr>
										<ui:reason>
											<sw:text>
												The request has been already processed or canceled.
											</sw:text>
										</ui:reason>
										<ui:solution>
											<sw:text>
												Make a new request.
											</sw:text>
										</ui:solution>
									</ui:operation-problem>
								</ui:block>
							</ui:content>
						</xsl:when>
						<!-- /Problem - No such order-->
						<xsl:otherwise>
							<xsl:call-template name="local:review-order">
								<xsl:with-param name="request" select="$request"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
				<!-- /Request ID was specified -->
			</xsl:choose>

		</ui:screen>
	</xsl:template>

	<xsl:template name="local:review-order">
		<xsl:param name="request"/>
		<xsl:variable name="status" select="$request/requestStatus"/>
		<xsl:variable name="user" select="authm:get-user(authm:sid2user-key($request/ownerSid))"/>

		<ui:properties>
			<ui:form-get/>		
			<ui:description>
				<xsl:choose>
					<xsl:when test="$admin-mode and not($user)">
						<img src="/{$theme}/icons/alert_red.gif" width="16" height="16" border="0"
							/>&#160;
						<sw:text>
							Warning! The request cannot be processed because the user selected as the owner of the requested Container was deleted from the users list.
						</sw:text>
					</xsl:when>
					<xsl:otherwise>
						<sw:text>
							This screen allows you to view and manage the selected Container request.
						</sw:text>
					</xsl:otherwise>
				</xsl:choose>
			</ui:description>
		</ui:properties>

		<ui:content>
			<ui:block>
				<ui:rows title="{sw:text('Request Details')}">
					<!--
					<ui:row>
						<ui:cell-label>
							<sw:text>Request ID</sw:text>
						</ui:cell-label>
						<ui:cell-text>
							<xsl:value-of select="$request/id"/>
						</ui:cell-text>
					</ui:row>
					-->
					<ui:row>
						<ui:cell-label>
							<sw:text>Posted</sw:text>
						</ui:cell-label>
						<ui:cell-text>
							<xsl:value-of select="format:date-time($request/postedDate)"/>
						</ui:cell-text>
					</ui:row>
					<ui:row>
						<xsl:variable name="statuses" select="requests:get-statuses()"/>
						<ui:cell-label>
							<sw:text>Status</sw:text>
						</ui:cell-label>
						<ui:cell-text>
							<ui:request-status>
								<src>
									<xsl:value-of select="$request/requestStatus"/>
								</src>
								<title>
									<xsl:value-of select="$statuses[$request/requestStatus=@value]/@title"/>
								</title>
							</ui:request-status>
						</ui:cell-text>
					</ui:row>
				</ui:rows>
				<xsl:if test="$admin-mode">
					<ui:rows title="{sw:text('Owner Details')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>Owner Name</sw:text>
							</ui:cell-label>
							<ui:cell-text>
								<xsl:value-of select="$request/ownerName"/>
							</ui:cell-text>
						</ui:row>
						<ui:row>
							<ui:cell-label>
								<sw:text>Submitted From IP Address</sw:text>
							</ui:cell-label>
							<ui:cell-text>
								<xsl:value-of select="$request/postedIp"/>
							</ui:cell-text>
						</ui:row>
					</ui:rows>
				</xsl:if>
				<ui:rows title="{sw:text('Container Configuration')}">
					<xsl:choose>
						<xsl:when test="$request/objectId!=''">
							<ui:row>
								<ui:cell-label>
									<sw:text>Created Container</sw:text>
								</ui:cell-label>
								<ui:cell-text>
									<ui:env-eid-link>
										<xsl:value-of select="$request/objectId"/>
									</ui:env-eid-link>
								</ui:cell-text>
							</ui:row>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="$request/requestEnvName!=''">
								<ui:row>
									<ui:cell-label>
										<sw:text>Name</sw:text>
									</ui:cell-label>
									<ui:cell-text>
										<xsl:value-of select="$request/requestEnvName"/>
									</ui:cell-text>
								</ui:row>
							</xsl:if>
							<xsl:if test="$request/requestEnvHostname!=''">
								<ui:row>
									<ui:cell-label>
										<sw:text>Hostname</sw:text>
									</ui:cell-label>
									<ui:cell-text>
										<xsl:value-of select="$request/requestEnvHostname"/>
									</ui:cell-text>
								</ui:row>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>
					<ui:row>
						<ui:cell-label>
							<sw:text>Sample</sw:text>
						</ui:cell-label>
						<ui:cell-text>
							<xsl:value-of select="$request/requestSampleName"/>
						</ui:cell-text>
					</ui:row>
				</ui:rows>
				<xsl:if test="$request/description!=''">
					<ui:rows title="{sw:text('Description')}">
						<ui:row>
							<ui:cell-text>
								<xsl:value-of select="$request/description"/>
							</ui:cell-text>
						</ui:row>
					</ui:rows>
				</xsl:if>

				<!-- Post buttons -->
				<ui:buttons>
					<xsl:if test="$admin-mode">
						<xsl:if test="cred:check('vzcp.env.create')">
							<ui:button tip="order_create_ve" name="create_ve"
								submit-href="{$baseurl}/vt/envs/new?request-id={sw:base64-encode($request/requestId)}&amp;context=default_unit">
								<xsl:if test="not($status='OPEN') or not($user)">
									<xsl:attribute name="disabled">true</xsl:attribute>
								</xsl:if>
								<sw:text>New Container</sw:text>
							</ui:button>
						</xsl:if>
						<ui:button tip="order_reopen" name="reopen_order"
							submit-href="{$baseurl}/vt/envrequests/control?action=reopen_order&amp;order_id={sw:base64-encode($request/requestId)}">
							<xsl:if test="not($status='PROCESSING' or $status='COMPLETED')">
								<xsl:attribute name="disabled">true</xsl:attribute>
							</xsl:if>
							<sw:text>Reopen Request</sw:text>
						</ui:button>
					</xsl:if>
					<xsl:if test="$admin-mode or $request/requestStatus='OPEN'">
						<ui:button tip="order_cancel" name="cancel_order"
							submit-href="{$baseurl}/vt/envrequests/control?action=cancel_order&amp;order_id={sw:base64-encode($request/requestId)}">
							<sw:text>Reject Request</sw:text>
						</ui:button>
					</xsl:if>
				</ui:buttons>


			</ui:block>
		</ui:content>
	</xsl:template>

	<sw:include href="/lib/screen.xsl"/>

</xsl:stylesheet>
