<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred local units vt hn env"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:error="http://www.swsoft.com/xsl/cp/error"
  xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:func="http://exslt.org/functions"
	xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
	xmlns:local	="http://www.swsoft.com/xsl/cp/local"
	xmlns:units ="http://www.swsoft.com/xsl/cp/units"
	xmlns:vt		="http://www.swsoft.com/xsl/cp/vt"
	xmlns:env		="http://www.swsoft.com/xsl/cp/env"
	xmlns:hn		="http://www.swsoft.com/xsl/cp/hn"
>

	<sw:include href="/lib/cred-filter.xsl"/>
	<sw:include href="/lib/vt/core.xsl"/>
	<sw:include href="/lib/vt/env-core.xsl"/>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vt/hn-select.xsl"/>

  <xsl:param 		name="wiz_code" select="'envs-new'"/>  
	<xsl:variable name="step_data"	select="wiz:getStep()"/>
	<xsl:variable name="step"				select="$step_data/@id"/>
	<xsl:variable name="screen-id"		select="$step_data/@screen-id"/>

  <xsl:variable name="form" select="sw:sesget($wiz_data)"/>
    
   <!-- Wizard, Step 'Start Creation' -->
  <xsl:template name="step_start">
  	<ui:screen id="{$screen-id}">
  	
  	<!-- Preload some data -->
  	<xsl:variable name="all-hns" select="hn:list()/hn"/>
  	<xsl:variable name="accessible-hn-eids" 
  		select="cred:filter-valid-hw('vzcp.env.create',$all-hns/eid,false())"/>
  	<xsl:variable name="hns" select="$all-hns[string(eid)=$accessible-hn-eids]"/>
  		<xsl:if test="not($hns)">
  			<xsl:choose>
  				<xsl:when test="not($all-hns)">
  					<xsl:if test="error:put(sw:text('No Hardware Nodes are available for creating Containers.'))"/>
  				</xsl:when>
  				<xsl:otherwise>
  					<xsl:if test="error:put(sw:text('You are not allowed to create Containers on any of the Parallels Infrastructure Manager Nodes.'))"/>
  				</xsl:otherwise>
  			</xsl:choose>
  		</xsl:if>
		<xsl:variable name="techs" select="vt:techs()/tech"/>  	
  	<xsl:variable name="platforms" select="sw:if($form/hn-select/auto-platform!='',vt:platforms()/platform[not($form/envrequest-id) or @id=$form/hn-select/auto-platform],vt:platforms()/platform)"/>
  	<xsl:variable name="hns-oses-rtf">
  		<xsl:for-each select="$hns/platform">
  			<os><xsl:value-of select="substring-before(.,'.')"/></os>
  		</xsl:for-each>
  	</xsl:variable>
  	<xsl:variable name="hns-oses" select="exsl:node-set($hns-oses-rtf)"/>  	
  	<!-- /Preload some data -->  	
  	
    <ui:properties>
      <ui:refresh-type>none</ui:refresh-type>
      <ui:form-get/>
      
      <ui:description  mandatory="yes">      	
        <sw:text>
          This is the first step of the Container creation wizard. On this screen you can select the Hardware Node and specify the number of Containers.<br/> Click "Next" to proceed with the creation. 
        </sw:text>
      </ui:description>              
    </ui:properties>
    
    <ui:content>
      <ui:hidden name="step" value="start"/>    
      <ui:block mode="edit">      				
      
      	<xsl:if test="not($form/envrequest-id)">
					<ui:rows title="{sw:text('Multiple Container Configuration')}">
						<ui:row>
							<ui:cell-text close="false">
								<sw:text>Number of Containers to create</sw:text>
							</ui:cell-text>
							<ui:cell-text open="false" close="false" show-aster="false">&#160;</ui:cell-text>
							<ui:cell-input width="10" id="envs_count" maxlength="3" required="true" value="{$form/envs-count}" open="false">
								<xsl:if test="$form/def/order-id!=''">
									<xsl:attribute name="disabled">true</xsl:attribute>
								</xsl:if>
							</ui:cell-input>
						</ui:row>
					</ui:rows>
				</xsl:if>
									      
	      <!-- Specify Autoselection -->
	      <ui:rows title="{sw:text('Hardware Node Selection')}">
	      	<!-- Auto -->
	      	<ui:row>
	 					<ui:cell-radio name="method" id="method_auto" value="auto" checked="{$form/hn-select/method='auto'}">
							<ui:control-slave>auto_platform</ui:control-slave>
							<ui:control-slave inverse="true">hn</ui:control-slave>	 													
	 					</ui:cell-radio>
						<ui:cell cell-width="100%" align="left" colspan="2">
							<sw:text>Select Hardware Node Automatically</sw:text>
						</ui:cell>						
					</ui:row>
					<xsl:choose>
						<xsl:when test="$form/envrequest-id">
							<ui:hidden name="auto_platform" value="{$form/hn-select/auto-platform}"/>	
							<ui:hidden name="auto_tech" value="{$techs[1]/@id}"/>	
						</xsl:when>
						<xsl:otherwise>
							<!-- Select Technology -->
							<xsl:choose>
								<xsl:when test="count($techs)!=1">
									<ui:row>
										<ui:cell-text/>
										<ui:cell-text offset="1">
											<sw:text>Technology</sw:text>
										</ui:cell-text>
										<ui:cell-list id="auto_tech" value="{$form/hn-select/tech}" cell-width="100%">
											<xsl:for-each select="$techs">
												<ui:list-item id="{@id}" title="{@title}"/>								
											</xsl:for-each>
										</ui:cell-list>
									</ui:row>
								</xsl:when>
								<xsl:otherwise>
									<ui:hidden name="auto_tech" value="{$techs[1]/@id}"/>
								</xsl:otherwise>
							</xsl:choose>
							<ui:row>
								<ui:cell-text/>
								<ui:cell-text offset="1">
									<sw:text>Platform</sw:text>
								</ui:cell-text>
								<ui:cell-list id="auto_platform" value="{$form/hn-select/auto-platform}" cell-width="100%">
									<xsl:if test="not($form/hn-select/auto-platform!='')">
										<ui:list-item id="" title="{sw:text('-- Select the platform --')}"/>											
									</xsl:if>
									<ui:list-item id="" disabled="true" title="{sw:text('-- Select by OS --')}"/>	
									<xsl:for-each select="vt:vza-platform-oses( false() )[vt:vza2os(@value)=$hns-oses/os]">
										<ui:list-item id="{vt:vza2os(@value)}" title="{@title}"/>								
									</xsl:for-each>
									<ui:list-item id="" disabled="true" title="{sw:text('-- Select by OS and Architecture --')}"/>
									<xsl:for-each select="$platforms[@id=$hns/platform]">
										<ui:list-item id="{@id}" title="{@title}"/>								
									</xsl:for-each>
								</ui:cell-list>
							</ui:row>
						</xsl:otherwise>
					</xsl:choose>
					<!-- /Auto -->
					<!-- Select -->
					<ui:row>
	 					<ui:cell-radio name="method" id="method_select" value="select" checked="{$form/hn-select/method='select'}">
	 						<ui:control-slave>hn</ui:control-slave>
							<ui:control-slave inverse="true">auto_platform</ui:control-slave>	 						
						</ui:cell-radio>
						<ui:cell cell-width="100%" align="left" colspan="2">
							<sw:text>Select Hardware Node Manually</sw:text>
						</ui:cell>
					</ui:row>
					<ui:row>
						<ui:cell-text/>
						<ui:cell-text offset="1">
							<sw:text>Hardware Node</sw:text>
						</ui:cell-text>
						<ui:cell-list id="hn" value="{$form/hn-select/eid}" cell-width="100%">
							<xsl:choose>
								<xsl:when test="not($hns) or not($platforms)">
									<ui:list-item disabled="true" title="{sw:text('No Hardware Nodes Available')}"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:for-each select="$platforms">
										<xsl:variable name="hns-on-platform" select="$hns[platform=current()/@id]"/>
										<!-- Show HNs grouped by platforms -->
										<xsl:if test="$hns-on-platform">
											<xsl:variable name="group-title">
												<sw:text>
													<xsl:with-param name="platform" select="@title"/>
													-- %platform Hardware Nodes --
												</sw:text>
											</xsl:variable>
											<ui:list-item disabled="true" title="{$group-title}"/>
											<xsl:for-each select="$hns-on-platform">
												<xsl:choose>
													<!-- Online HN -->
													<xsl:when test="status=$env-state/running">
														<ui:list-item id="{eid}" title="{hostname}"/>
													</xsl:when>
													<!-- Offline HN -->
													<xsl:otherwise>
														<ui:list-item id="{eid}" grayed="true">
															<xsl:attribute name="title">
																<sw:text>
																	<xsl:with-param name="hostname" select="hostname"/>
																	%hostname (Offline)
																</sw:text>
															</xsl:attribute>
														</ui:list-item>
													</xsl:otherwise>
												</xsl:choose>
											</xsl:for-each>
										</xsl:if>
										<!-- /Show HNs grouped by platforms -->
									</xsl:for-each>
								</xsl:otherwise>
							</xsl:choose>
						</ui:cell-list>
					</ui:row>
					<!-- /Select -->
	      </ui:rows>
	      <!-- /Specify Autoselection -->	      
    		      
        <ui:buttons>
         	<ui:button id="ok" type="next" tip="wizard_next_step" name="next">
         		<sw:text>Next</sw:text>
         	</ui:button>
         	<ui:button type="cancel" sandclock="false" tip="wizard_cancel">
         		<sw:text>Cancel</sw:text>
         	</ui:button>
        </ui:buttons>
     </ui:block>
    </ui:content>   
    </ui:screen>
  </xsl:template> 
  
	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		
		<xsl:choose>
			<xsl:when test="$step = 'start'">
				<xsl:call-template name="step_start"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="step_start"/>
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>
	
	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>			
	
</xsl:stylesheet>
