<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl sw func local cred show server_group"
  xmlns:xsl			="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl		="http://exslt.org/common"
  xmlns:sw			="http://www.swsoft.com/xsl/cp"
  xmlns:local		="http://www.swsoft.com/xsl/cp/local"
  xmlns:func		="http://exslt.org/functions"
	xmlns:cred		="http://www.swsoft.com/xsl/cp/cred"
	xmlns:ui		="http://www.swsoft.com/xsl/cp/ui"
	xmlns:show		="http://www.swsoft.com/xsl/cp/show"
	xmlns:units		="http://www.swsoft.com/xsl/cp/units"
	xmlns:server_group="http://www.swsoft.com/xsl/cp/server_group"
>
	<sw:include href="/lib/core/units-core.xsl"/>	

	<xsl:template mode="screen" match="/">
				
		<xsl:variable name="func" select="sw:param('func')"/>
		<xsl:choose>
			<xsl:when test="$func='register'">
				
				<xsl:variable name="data-rtf">
					<ip><xsl:value-of select="sw:base64-decode(sw:param('ip'))"/></ip>
					<user><xsl:value-of select="sw:base64-decode(sw:param('user'))"/></user>
					<password><xsl:value-of select="sw:base64-decode(sw:param('password'))"/></password>
					<parent-dn><xsl:value-of select="sw:base64-decode(sw:param('parent-dn'))"/></parent-dn>	
					<xsl:if test="sw:base64-decode(sw:param('force'))='1'">
						<force/>
					</xsl:if>
				</xsl:variable>
				<xsl:variable name="data" select="exsl:node-set($data-rtf)"/>
	
				<xsl:variable name="packet-rtf" select="local:make-packet($data)"/>
				<xsl:variable name="res" select="sw:xchg($packet-rtf)/packet/data"/>
				<xsl:variable name="res-error" select="$res/error|$res/server_group/error"/>
				
				<xsl:choose>
					<xsl:when test="$res-error">
						<ui:raw>
							<xsl:value-of select="$res-error/message"/>
						</ui:raw>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="hn-eid" select="$res/server_group/eid"/>		
						<xsl:if test="$data/parent-dn!='' and not(units:is-dn-top($data/parent-dn))">
							<xsl:variable name="res-folder">
								<xsl:choose>
									<xsl:when test="units:is-tree-logical($data/parent-dn)">
										<xsl:copy-of select="sw:xchg(local:add-to-folder($hn-eid,$data/parent-dn))/packet/data"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:copy-of select="sw:xchg(local:move-to-folder($hn-eid,$data/parent-dn))/packet/data"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:variable>
						</xsl:if>
						<ui:raw>!ok!</ui:raw>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
		</xsl:choose>
										
  </xsl:template>
  
  <!-- *********************************************************** -->
	<func:function name="local:make-packet">
		<xsl:param name="data"/>
		<!--|-->
		<func:result>
			<packet log="on">
				<target>server_group</target>
				<cookie>
				</cookie>
				<data>
					<server_group>
						<add>
							<conn_info>
								<address><xsl:value-of select="$data/ip"/></address>
								<login>
									<name>
										<xsl:value-of select="sw:base64-encode($data/user)"/>
									</name>
								  <xsl:copy-of select="server_group:get-system-realm()"/>
								</login>
								<xsl:if test="$data/password!=''">
									<password>
										<xsl:value-of select="sw:base64-encode($data/password)"/>
									</password>
								</xsl:if>
							</conn_info>
							<xsl:if test="$data/force">
								<force/>
							</xsl:if>
						</add>
					</server_group>
				</data>
			</packet>
		</func:result>
	</func:function>
  
  <func:function name="local:add-to-folder">		
		<xsl:param name="eid"/>
		<xsl:param name="dn"/>
				
		<func:result>
			<packet log="on">
				<target>infrastructurem</target>        
				<data>
					<infrastructurem>
						<add_env>
							<name><xsl:value-of disable-output-escaping="yes" select="units:decode-dn($dn)"/></name>
							<eid><xsl:value-of select="$eid"/></eid>							
						</add_env>
					</infrastructurem>
				</data>
			</packet>
		</func:result>
		
	</func:function>
	
	<func:function name="local:move-to-folder">		
		<xsl:param name="eid"/>
		<xsl:param name="dn"/>
				
		<func:result>
			<packet log="on">
				<target>infrastructurem</target>        
				<data>
					<infrastructurem>
						<move_env>
							<src><xsl:value-of disable-output-escaping="yes" select="units:decode-dn(units:infra-top-dn())"/></src>
							<dst><xsl:value-of disable-output-escaping="yes" select="units:decode-dn($dn)"/></dst>
							<eid><xsl:value-of select="$eid"/></eid>							
						</move_env>
					</infrastructurem>
				</data>
			</packet>
		</func:result>
		
	</func:function>
  
	<!-- includes -->
	
  <sw:include href="/lib/screen.xsl"/>
  <sw:include href="/lib/vocabulary.xsl"/>  
  <sw:include href="/lib/swa/server-group.xsl"/>  

</xsl:stylesheet>
