<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl func wiz cred"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:wiz="http://www.swsoft.com/xsl/cp/wiz"
	xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
	xmlns:func="http://exslt.org/functions"
	xmlns:cred="http://www.swsoft.com/xsl/cp/cred"
	xmlns:request="http://www.swsoft.com/xsl/cp/request"		
>

	<xsl:param name="wiz_code" select="'cluster-node'"/>

	<xsl:variable name="step_data" select="wiz:getStep()"/>
	<xsl:variable name="step" select="$step_data/@id"/>
	<xsl:variable name="screen-id" select="$step_data/@screen-id"/>

	<xsl:variable name="form" select="sw:sesget($wiz_data)"/>

	<!-- Wizard, Step 'General Settings' -->
	<xsl:template name="step_reg">
		<ui:screen id="{$screen-id}">

			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:description mandatory="yes">
					<sw:text>Here you should specify the Hardware Node connection information.</sw:text>
				</ui:description>
				<ui:form-get/>
			</ui:properties>
			
			<ui:content>
				<ui:hidden name="step" value="reg"/>
				<ui:block mode="edit">

					<ui:rows title="{sw:text('Connection to Hardware Node')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>Node Address</sw:text>
							</ui:cell-label>
							<ui:cell-input id="ip" maxlsength="15" width="20" required="true">
								<xsl:attribute name="value">
									<xsl:value-of select="$form/reg/ip"/>
								</xsl:attribute>
							</ui:cell-input>
						</ui:row>
					</ui:rows>

					<ui:rows title="{sw:text('Administrative Login to Hardware Node')}">
						<ui:row>
							<ui:cell-label>
								<sw:text>User Name</sw:text>
							</ui:cell-label>
							<ui:cell-input id="user" maxlength="100" width="20" required="true">
								<xsl:attribute name="value">
									<xsl:value-of select="$form/reg/user"/>
								</xsl:attribute>
							</ui:cell-input>
						</ui:row>
						<ui:row>
							<ui:cell/>
							<ui:cell/>
						</ui:row>

						<ui:row>
							<ui:cell-label>
								<sw:text>Password</sw:text>
							</ui:cell-label>
							<ui:cell-input mode-password="true" id="password" width="20" maxlength="64"
								required="true">
								<xsl:attribute name="value">
									<xsl:value-of select="$form/reg/password"/>
								</xsl:attribute>
							</ui:cell-input>
						</ui:row>
					</ui:rows>

					<ui:rows title="{sw:text('Registration Options')}">
						<ui:row table-width="none">
							<ui:cell-check id="force" checked="{$form/reg/force='1'}"/>
							<ui:cell-text>
								<sw:text>Force registration even if Node is already registered in another Virtuozzo Group</sw:text>
							</ui:cell-text>
						</ui:row>
					</ui:rows>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="next-title" select="sw:text('Register')"/>
          		<xsl:with-param name="next-sandclock" select="false()"/>
						</xsl:call-template>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>
	
	<!-- Wizard, Step 'Progress' -->
	<xsl:template name="step_progress">
		<ui:screen id="{$screen-id}">

			<ui:properties>
				<ui:refresh-type>none</ui:refresh-type>
				<ui:form-get/>
			</ui:properties>
			
			<ui:content>
				<ui:hidden name="step" value="progress"/>
				<ui:block mode="view">

					
	      	<ui:raw>	      		
						<br/>	      		
						<img id="img_size" width="16" border="0" height="16" src="/{$theme}/icons/indicator.gif"/>
						&#160;<sw:text>Connecting to Hardware Node...</sw:text>
						<br/>  
						<br/>
						<input id="result_code" name="result_code" type="hidden" value="none"/>
						<input id="result_message" name="result_message" type="hidden" value=""/>
						<script>
							function onLoad(){
								requestContent('/vz/cp/vt/hns/new-dynamic?func=register'
										+'&amp;ip=<xsl:value-of select="sw:base64-encode($form/reg/ip)"/>'
										+'&amp;user=<xsl:value-of select="sw:base64-encode($form/reg/user)"/>'
										+'&amp;password=<xsl:value-of select="sw:base64-encode($form/reg/password)"/>'
										+'&amp;force=<xsl:value-of select="sw:base64-encode($form/reg/force)"/>'
										+'&amp;parent-dn=<xsl:value-of select="sw:base64-encode($form/parent-folder/dn)"/>'
									,receiveData,'<xsl:value-of select="$ticket"/>',
									'<xsl:value-of select="$ticketid"/>'
								);
							}
							function receiveData(req){
								var content = req.readyState==4?req.responseText:'';
								if(content!=''){
									var result_code = document.getElementById('result_code');
									if(content.indexOf('!ok!')!=-1){
										result_code.value = 'ok';
									}else{
										var result_message = document.getElementById('result_message');
										result_code.value = 'error';
										result_message.value = content;
									}
									doSubmit();
								}
							}
						</script>
	      	</ui:raw>

					<ui:buttons>
						<xsl:call-template name="wiz:showButtons">
							<xsl:with-param name="show-submit" select="false()"/>
						</xsl:call-template>
					</ui:buttons>

				</ui:block>
			</ui:content>
		</ui:screen>
	</xsl:template>




	<!-- main document handler -->
	<xsl:template mode="screen" match="/">
		<xsl:choose>
			<xsl:when test="$step = 'reg'">
				<xsl:call-template name="step_reg"/>
			</xsl:when>
			<xsl:when test="$step = 'progress'">
				<xsl:call-template name="step_progress"/>
			</xsl:when>			
			<xsl:otherwise>
				<xsl:call-template name="step_reg"/>
			</xsl:otherwise>

		</xsl:choose>
	</xsl:template>


	<sw:include href="/lib/screen.xsl"/>
	<sw:include href="/lib/wizard.xsl"/>

	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
