<!--
  Copyright (c) SWsoft, 1999-2007
  All rights reserved.
  -->

<xsl:stylesheet version="1.0" extension-element-prefixes="sw exsl hn browse cred"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common"
  xmlns:sw="http://www.swsoft.com/xsl/cp"
  xmlns:browse="http://www.swsoft.com/xsl/cp/browse"
  xmlns:ui="http://www.swsoft.com/xsl/cp/ui"
  xmlns:hn="http://www.swsoft.com/xsl/cp/hn"
  xmlns:vt="http://www.swsoft.com/xsl/cp/vt"
  xmlns:env="http://www.swsoft.com/xsl/cp/env"
  xmlns:cred  ="http://www.swsoft.com/xsl/cp/cred"
>
	<sw:include href="/lib/vt/hn-core.xsl"/>
	<sw:include href="/lib/vt/hn-list.xsl"/>

	<xsl:variable name="id" select="sw:param('id')"/>
	<xsl:variable name="mode" select="sw:param('mode')"/>
	<xsl:variable name="dn" select="sw:param('dn')"/>
	<xsl:variable name="state" select="string( sw:param('state') )"/>
	<xsl:variable name="platform" select="string( sw:param('platform') )"/>
	<xsl:variable name="arch" select="string( sw:param('arch') )"/>

  <!-- check permissions to show this page -->
	<xsl:template mode="screen" match="/">

		<!-- Prepare Filter -->
		<xsl:variable name="filter-rtf">
			<xsl:call-template name="browse:init-filter">
				<xsl:with-param name="browse">
					<ui:browse-setup id="hns-popup"
						url="/vt/hns/select-popup?id={$id}&amp;mode={$mode}&amp;platform={$platform}&amp;arch={$arch}"
						select-column="id"
						items-title="{sw:text('Hardware Nodes')}">
					</ui:browse-setup>
	        <ui:cols sorting-col="id" sorting-direction="desc">
	         	<xsl:call-template name="hn:get-browse-cols">
	         		<xsl:with-param name="show-url" select="false()"/>
	         		<xsl:with-param name="state" select="sw:if(string($state)='', false(), $state)"/>
	         		<xsl:with-param name="id-cols">
		         		<ui:column id="id" hidden="yes" vza-id="env.eid" nav-type="id">
					        <xsl:attribute name="for-select">yes</xsl:attribute>
		         		</ui:column>
		         		<xsl:if test="not($platform='')">
			         		<ui:column id="platform-os-selector" hidden="yes" vza-id="env.config.os.platform"
			         			filter="equal" value="{$platform}"/>
			         		<xsl:if test="not($arch='')">
				         		<ui:column id="architecture-selector" vza-id="env.config.architecture"
				         			hidden="yes" filter="equal" value="{$arch}"/>
			         		</xsl:if>
		         		</xsl:if>
	         		</xsl:with-param>
	         	</xsl:call-template>
	        </ui:cols>
				</xsl:with-param>
			</xsl:call-template>
    </xsl:variable>

    <xsl:variable name="filter-res-rtf">
    	<xsl:call-template name="hn:fill-filter">
				<xsl:with-param name="filter-rtf" select="$filter-rtf"/>
				<xsl:with-param name="filter-dn" select="$dn"/>
			</xsl:call-template>
    </xsl:variable>
    <xsl:variable name="filter-res" select="exsl:node-set($filter-res-rtf)"/>

    <ui:popup-screen id="11.01.00.00.00" title="{sw:text('Hardware Node(s) Selector')}" icon="hw_node">
	    <ui:properties>
	    	<ui:js-tail>
					<script language="JavaScript">
						var listTitles=new Array(
							<xsl:for-each select="$filter-res/ui:browse-rows/ui:row">
								"<xsl:value-of select='env:title(name,hostname,ips)'/>",
							</xsl:for-each>"");
						var listIDs=new Array(
							<xsl:for-each select="$filter-res/ui:browse-rows/ui:row">
								"<xsl:value-of select='id'/>",
							</xsl:for-each>"");
						function submitSelected(){
							<xsl:choose>
								<xsl:when test="$mode='list'">
									<sw:die test="$id=''">
										GET parameter 'id' should be specified.
									</sw:die>
									for (var i=0;i&lt;document.defaultForm.elements.length;i++){
										var o = document.defaultForm.elements[i];
									  if(o.name=='id' &amp;&amp; o.checked) {
									  	for (var ii=0;ii&lt;listIDs.length;ii++){
									  		if(listIDs[ii]==o.value){
									  			window.opener.listAdd('<xsl:value-of select="$id"/>',listTitles[ ii ],o.value);
											  }
										  }
									  }
									}
								</xsl:when>
								<xsl:when test="$mode='callback'">
									var selectedEID = new Array();
									var hns = document.getElementsByName('id');
									<![CDATA[
									for (var i=0; i < hns.length; i++){
										if (hns[i].checked)
											selectedEID[selectedEID.length] = hns[i].value;
									}
									window.opener.addFavs('hn.core.vt',selectedEID.join(','));
									]]>
								</xsl:when>
								<xsl:otherwise>
									var ids='';
									for (var i=0;i&lt;document.defaultForm.elements.length;i++){
										var o = document.defaultForm.elements[i];
									  if(o.name=='id' &amp;&amp; o.checked) {
										 	if(ids!=''){
										 		ids = ids+',';
										 	}
										 	ids = ids + o.value;
									  }
									}
									window.opener.document.defaultForm.hn_add_ids.value=ids;
									window.opener.doSubmit();
								</xsl:otherwise>
							</xsl:choose>
						window.close();
						}
					</script>
	    	</ui:js-tail>
	    </ui:properties>

	    <ui:content>

				<ui:block width="full">

		      <ui:browse>
		      	<xsl:attribute name="title"><sw:text>Hardware Nodes</sw:text></xsl:attribute>

		        <ui:filter>
		        	<xsl:copy-of select="$filter-res-rtf"/>
		        </ui:filter>

		        <!-- form definition for other controls -->
		        <ui:form action="list-control"/>

		        <ui:browse-empty-msg>
		          <sw:text>No Hardware Node could be found.</sw:text>
		        </ui:browse-empty-msg>

		      </ui:browse>

		      <!-- Show submit buttons -->
			   	<ui:buttons>
					 <ui:button tip="add_sel_hn" name="select" sandclock="false" script="submitSelected();return false;">
	           	<sw:text>Use Selected</sw:text>
           </ui:button>
				</ui:buttons>

		  	</ui:block>
	    </ui:content>

    </ui:popup-screen>

  </xsl:template>

	<sw:include href="/lib/screen.xsl"/>

	<sw:include href="/lib/core/browse-filter-vza.xsl"/>
	<sw:include href="/lib/vocabulary.xsl"/>

</xsl:stylesheet>
