<!--
Copyright (c) SWsoft, 1999-2007
Abstract: Join trees, find similar nodes by IDs
Lasr Review: 
Last Update: $Id: join-trees.xsl,v 1.9 2007-03-26 11:39:02 baza Exp $
-->

<xsl:stylesheet version="1.0" extension-element-prefixes="exsl func sw"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:exsl="http://exslt.org/common"
	xmlns:func="http://exslt.org/functions" xmlns:local="http://www.swsoft.com/xsl/cp/local"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<!--
		input - file-list with structure:
	   
	   <files>
	        <file href="a.xml"/>
	        <file href="b.xml"/>
	        ...
	   </files>
   -->


	<func:function name="local:joining-unique-condition">
		<xsl:param name="context"/>
		<xsl:param name="node"/>
		<xsl:param name="key"/>
		
		<func:result select="name($context)=name($node) 
			and ($context/@*[name()=$key][1]=$node/@*[name()=$key][1] or not($context/@*[name()=$key]) and not($node/@*[name()=$key]))">
		</func:result>
		
	</func:function>


	<func:function name="local:join">
		<xsl:param name="first"/>
		<xsl:param name="second"/>
		<xsl:param name="key"/>
	

		<func:result>
			
			<xsl:variable name="joined-match" select="$first | $second"/>

			<xsl:variable name="joined-nodes">
				<xsl:for-each select="$joined-match">
					<xsl:copy>
						<xsl:copy-of select="attribute::*"/>
						<xsl:attribute name="joining-position">
							<xsl:value-of select="position()"/>
						</xsl:attribute>
					</xsl:copy>
				</xsl:for-each>
			</xsl:variable>

			<xsl:for-each select="exsl:node-set($joined-nodes)/node()">
				<xsl:sort data-type="number" select="@sort-order"/>
				
				<xsl:choose>
					<xsl:when test="not(@*[name()=$key]) and ($first/parent::* or $second/parent::*)">
						<xsl:variable name="joined-element" select="$joined-match[position() = current()/@joining-position]"/>
						<xsl:if test="$joined-element">
							<xsl:element name="{name($joined-element)}">
								<xsl:copy-of select="$joined-element/attribute::*"/>
								<xsl:copy-of select="$joined-element/child::node()"/>
							</xsl:element>
						</xsl:if>
					</xsl:when>
					<xsl:when test="not(preceding-sibling::*[local:joining-unique-condition(., current(),$key)])">
						<xsl:copy>
							<xsl:copy-of select="attribute::*[name()!='joining-position']"/>
							
							<xsl:variable name="joined-attributes" 
								select="following-sibling::*[local:joining-unique-condition(., current(),$key)]
								/attribute::*[name()!=$key and name()!='context']"/>
							
							<xsl:for-each select="exsl:node-set($joined-attributes)">
								<xsl:choose>
									<xsl:when test="attribute::*[name()=name(current())]
										or following-sibling::*[name()=name(current())]">
										<xsl:message terminate="yes">
											<xsl:text>Error: Joining rule - Attributes can't dublicate.</xsl:text>
											<xsl:text>Dublicated attribute is </xsl:text>
											<xsl:value-of select="name()"/>
										</xsl:message>
									</xsl:when>
									<xsl:when test="name()!='joining-position'">
										<xsl:attribute name="{name()}" >
											<xsl:value-of select="."/>
										</xsl:attribute>
									</xsl:when>
								</xsl:choose>
							</xsl:for-each>							
							
							<xsl:copy-of select="local:join(
								$first[local:joining-unique-condition(., current(),$key)]/child::node(),
								$second[local:joining-unique-condition(., current(),$key)]/child::node(),
								$key
							)"/>
						</xsl:copy>
					</xsl:when>
				</xsl:choose>				
			</xsl:for-each>

		</func:result>

	</func:function>


	<func:function name="local:join-file-to-tree">
		<xsl:param name="tree"/>
		<xsl:param name="files"/>
		<xsl:param name="key"/>
		
		<xsl:choose>

			<!-- no more work -->
			<xsl:when test="not($files)">
				<func:result select="$tree"/>
			</xsl:when>

			<xsl:otherwise>
				<xsl:variable name="f1" select="document($files[1]/@href)"/>
				<xsl:variable name="ret" select="local:join($tree/*, $f1/*,$key)"/>
				<func:result
					select="local:join-file-to-tree(exsl:node-set($ret), $files[position() &gt; 1],$key)"
				/>
			</xsl:otherwise>

		</xsl:choose>

	</func:function>

	<xsl:template match="/">

		<xsl:variable name="files" select="//file"/>
		<xsl:variable name="f1" select="document($files[1]/@href)"/>

		<xsl:variable name="key-custom" select="$f1/*[1]/@id-key"/>
		<xsl:variable name="key">
			<xsl:choose>
				<xsl:when test="$key-custom">
					<xsl:value-of select="string($key-custom)"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="'id'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
	
		<xsl:copy-of
			select="local:join-file-to-tree($f1, $files[position() &gt; 1],$key)"/>
	</xsl:template>

</xsl:stylesheet>
