<xsl:stylesheet version="1.0" extension-element-prefixes="exsl sw"
	xmlns:sw="http://www.swsoft.com/xsl/cp"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:set="http://exslt.org/sets"
	xmlns:exsl="http://exslt.org/common"
>

	<xsl:param name="new-config-ns" select="exsl:node-set($config)/*[1]" />
	<xsl:param name="old-config-ns" select="/*[1]" />

	<xsl:template match="demo-mode" mode="old_auth">
		<xsl:copy-of select="." />
	</xsl:template>

	<xsl:template match="auth" mode="old_auth">
		<auth>
			<xsl:variable name="lcType" select="sw:lc(type)" />
			<xsl:variable name="user" select="user" />
			<xsl:copy-of select="disabled|user|domain|type" />
			<xsl:copy-of select="$new-config-ns/access/auth[sw:lc(type) = $lcType and ( user = $user or ( not(user) and not($user) ) )][1]/creds" />
		</auth>
	</xsl:template>

	<xsl:template match="auth" mode="new_auth">
		<xsl:variable name="lcType" select="sw:lc(type)" />
		<xsl:if test="not($old-config-ns/access/auth[sw:lc(type) = $lcType])">
			<xsl:copy-of select="." />
		</xsl:if>
	</xsl:template>

	<xsl:template match="access" mode="new" priority="3">
		<access>
			<xsl:apply-templates select="$old-config-ns/access/*" mode="old_auth" />
			<xsl:apply-templates select="$new-config-ns/access/auth" mode="new_auth" />
		</access>
	</xsl:template>

	<xsl:template match="*[*]" mode="new" priority="2">
		<xsl:param name="old-node-parent" select="$old-config-ns" />
		<xsl:variable name="me" select="." />
		<xsl:variable name="name" select="name()" />
		<xsl:variable name="old-node-p" select="1 + count($me/../*[name() = $name and generate-id(.) = generate-id($me)]/preceding-sibling::*[name() = $name])" />
		<xsl:element name="{name()}">
			<xsl:apply-templates select="node() | @*" mode="new">
				<xsl:with-param name="old-node-parent" select="$old-node-parent/*[name() = $name][position() = number($old-node-p)]" />
			</xsl:apply-templates>
		</xsl:element>
	</xsl:template>

	<xsl:template match="*" mode="new" priority="1">
		<xsl:param name="old-node-parent" select="$old-config-ns" />
		<xsl:variable name="me" select="." />
		<xsl:variable name="name" select="name()" />
		<xsl:variable name="old-node-p" select="1 + count($me/../*[name() = $name and generate-id(.) = generate-id($me)]/preceding-sibling::*[name() = $name])" />
		<xsl:variable name="old-node">
			<xsl:if test="$old-node-parent">
				<xsl:copy-of select="$old-node-parent/*[name() = $name][position() = number($old-node-p)]" />
			</xsl:if>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$old-node != ''">
				<xsl:copy-of select="$old-node" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="$me" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="@* | node()" mode="new" priority="0">
		<xsl:copy-of select="." />
	</xsl:template>

	<xsl:template match="*" mode="old">
		<xsl:variable name="me" select="." />
		<xsl:if test="not($new-config-ns/*[name() = name($me)])" >
			<xsl:copy-of select="$me" />
		</xsl:if>
	</xsl:template>
	
	<!-- vps-template -> env-sample -->
	<xsl:template match="vps-template">
		<xsl:element name="env-sample">
			<xsl:apply-templates select="node()"/>
		</xsl:element>
	</xsl:template>

	<xsl:template match="/">
		<exsl:document href="vzcpcon.conf.merged" method="xml" indent="yes">
			<xsl:element name="vzcpcon">
				<xsl:apply-templates select="$new-config-ns/*" mode="new" />
				<xsl:apply-templates select="$old-config-ns/*" mode="old" />
			</xsl:element>
		</exsl:document>
	</xsl:template>
</xsl:stylesheet>
